#!/usr/bin/perl
# "Optimal Suffix Stemmer" for Serbian language as described in 2008 paper:
#   Vlado Keselj and Danko Sipka. A Suffix Subsumption-based Approach
#   to Building Stemmers and Lemmatizers for Highly Inflectional
#    Languages with Sparse Resources.  In INFOTHECA, Journal of
#    Informatics and Librarianship, No 1-2, Volume IX, May 2008.
# Resources available at: http://www.cs.dal.ca/~vlado/nlp/2007-sr/
# stemmer-opt.pl
# Version 1.0, 2009-04-29, written by Vlado Keselj
# Reads standard input and produces stemmed output.
# The used algorithm is not efficient.

while (<>) {
    # Stem words longer than 3 letters and not shorter than 31
    while (/\b[a-zA-Z-]{4,30}\b/)
    { print $`.&stem($&); $_ = $'; }
    print;
}

sub stem {
    my $w = shift;
    my $s = "\L$w";
    while ($s>$MaxSuffixLen or (!exists($Rules{$s}) and $s ne ''))
    { $s = substr($s,1) }
    return $w if $s eq '';
    return substr($w,0,length($w) - $Rules{$s});
}

# 17839 Opt rules, form: 'suffix' => 'removed suffix'
# Training accuracy = 81.8309759422188
BEGIN {
%Rules = (
'e' => 'e',
'u' => 'u',
'i' => 'i',
'a' => 'a',
'om' => 'om',
'o' => '',
'im' => 'im',
'ama' => 'ama',
'ih' => 'ih',
'te' => 'e',
'ima' => 'ima',
'mo' => 'mo',
'oj' => 'oj',
'omu' => 'omu',
'oga' => 'oga',
'og' => 'og',
'ti' => 'i',
't' => '',
'h' => 'h',
'm' => '',
'cyesx' => 'cyesx',
'cyu' => 'cyu',
'le' => 'le',
'la' => 'la',
'li' => 'li',
'cye' => 'cye',
'lo' => 'lo',
'cyete' => 'cyete',
'cyemo' => 'cyemo',
'ne' => 'e',
'ni' => 'i',
'sxe' => 'xe',
'na' => 'a',
'no' => 'o',
'ste' => '',
'vsxi' => '',
'smo' => '',
'n' => '',
'ju' => 'ju',
'jte' => 'jte',
'jmo' => 'jmo',
'j' => 'j',
'sx' => '',
'ci' => 'ci',
'ite' => 'ite',
'imo' => 'imo',
'ka' => 'ka',
'ku' => 'ku',
'kom' => 'kom',
'ke' => 'ke',
'hu' => 'hu',
'em' => '',
'io' => 'io',
'isx' => 'x',
'icyu' => 'icyu',
'icyete' => 'icyete',
'icyesx' => 'icyesx',
'icyemo' => 'icyemo',
'icye' => 'icye',
'iti' => 'ti',
'it' => 't',
'ilo' => 'ilo',
'ili' => 'ili',
'ile' => 'ile',
'ila' => 'ila',
'cxe' => 'cxe',
'cima' => 'cima',
'ivsxi' => 'ivsxi',
'isxe' => 'isxe',
'iste' => 'iste',
'ismo' => 'ismo',
'k' => 'k',
'tima' => 'ima',
'ujete' => 'ujete',
'ujesx' => 'ujesx',
'ujemo' => 'ujemo',
'ujem' => 'ujem',
'uje' => 'uje',
'uju' => 'uju',
'asxe' => 'asxe',
'aste' => 'aste',
'asmo' => 'asmo',
'ah' => 'ah',
'ko' => 'ko',
'xcyu' => '',
'kama' => 'kama',
'ene' => 'e',
'ena' => 'ena',
'en' => 'en',
'eno' => 'o',
'eni' => 'i',
'ahu' => 'ahu',
'jucyi' => 'jucyi',
'aka' => 'aka',
'ute' => 'ute',
'uji' => 'uji',
'ujite' => 'ujite',
'ujimo' => 'ujimo',
'ala' => 'la',
'ao' => 'o',
'at' => '',
'acyesx' => 'cyesx',
'acyu' => 'cyu',
'acyete' => 'cyete',
'acyemo' => 'cyemo',
'acye' => 'cye',
'ati' => 'i',
'alo' => 'lo',
'ali' => 'li',
'ale' => 'le',
'avsxi' => 'vsxi',
'ova' => 'ova',
'ivavsxi' => 'ivavsxi',
'ivati' => 'ivati',
'ivat' => 'ivat',
'ivasxe' => 'ivasxe',
'ivaste' => 'ivaste',
'ivasmo' => 'ivasmo',
'ivao' => 'ivao',
'ivano' => 'ivano',
'ivani' => 'ivani',
'ivane' => 'ivane',
'ivana' => 'ivana',
'ivan' => 'ivan',
'ivalo' => 'ivalo',
'ivali' => 'ivali',
'ivale' => 'ivale',
'ivala' => 'ivala',
'ivah' => 'ivah',
'ivacyu' => 'ivacyu',
'ivacyete' => 'ivacyete',
'ivacyesx' => 'ivacyesx',
'ivacyemo' => 'ivacyemo',
'ivacye' => 'ivacye',
'iva' => 'a',
'ivahu' => 'ivahu',
'nye' => 'e',
'yeno' => '',
'yeni' => '',
'yene' => '',
'yena' => '',
'yen' => '',
'ete' => 'e',
'ana' => 'na',
'emo' => 'o',
'esx' => '',
'ca' => 'ca',
'cu' => 'u',
'ce' => 'e',
'ano' => 'no',
'ani' => 'ni',
'ane' => 'ne',
'an' => 'n',
'lyeno' => 'yeno',
'lyeni' => 'yeni',
'lyene' => 'yene',
'lyena' => 'yena',
'lyen' => 'yen',
'nyu' => 'u',
'ava' => 'ava',
'am' => 'm',
'ta' => 'a',
'ucyu' => 'u',
'ucyete' => 'cyete',
'ucyesx' => 'cyesx',
'ucyemo' => 'cyemo',
'ucye' => 'e',
'uo' => 'o',
'ulo' => 'o',
'uli' => 'i',
'ule' => 'e',
'ula' => 'a',
'uti' => 'i',
'ut' => '',
'usxe' => 'e',
'uste' => 'te',
'usmo' => 'mo',
'uvsxi' => 'uvsxi',
'uh' => 'h',
'aca' => 'aca',
'uto' => 'o',
'uta' => 'a',
'ujte' => 'ujte',
'ovavsxi' => 'ovavsxi',
'ovati' => 'ovati',
'ovat' => 'ovat',
'ovasxe' => 'ovasxe',
'ovaste' => 'ovaste',
'ovasmo' => 'ovasmo',
'ovao' => 'ovao',
'ovano' => 'ovano',
'ovani' => 'ovani',
'ovane' => 'ovane',
'ovana' => 'ovana',
'ovan' => 'ovan',
'ovalo' => 'ovalo',
'ovali' => 'ovali',
'ovale' => 'ovale',
'ovala' => 'ovala',
'ovah' => 'ovah',
'ovacyu' => 'ovacyu',
'ovacyete' => 'ovacyete',
'ovacyesx' => 'ovacyesx',
'ovacyemo' => 'ovacyemo',
'ovacye' => 'ovacye',
'ujmo' => 'ujmo',
'uj' => 'uj',
'tu' => 'u',
'cem' => 'cem',
'ujucyi' => 'ujucyi',
'umo' => 'umo',
'ac' => 'ac',
'va' => 'va',
'ije' => 'e',
'ovahu' => 'ovahu',
'xeno' => 'eno',
'xeni' => 'eni',
'xene' => 'ene',
'xena' => 'ena',
'xen' => 'en',
'ove' => 'ove',
'ovi' => 'ovi',
'vu' => 'vu',
'vom' => 'vom',
'vo' => 'vo',
'ovima' => 'ovima',
'xe' => '',
'tim' => 'tim',
'me' => 'me',
'ma' => 'ma',
'vima' => 'vima',
'mu' => 'mu',
'timo' => 'timo',
'tite' => 'tite',
'mi' => 'mi',
'mom' => 'mom',
'xu' => '',
'tisx' => 'tisx',
'nya' => 'a',
'eg' => 'g',
'ga' => 'ga',
'ega' => 'ga',
'ata' => 'ata',
'emu' => 'u',
'tio' => 'tio',
'xem' => '',
'xete' => 'e',
'xemo' => '',
'gu' => 'gu',
'ate' => 'e',
'gom' => 'gom',
'amo' => 'mo',
'asx' => 'sx',
'aju' => 'ju',
'aj' => 'j',
'ajte' => 'jte',
'ajmo' => 'jmo',
'zi' => 'zi',
'je' => 'je',
'xesx' => 'xesx',
'ticyu' => 'ticyu',
'ticyete' => 'ticyete',
'ticyesx' => 'ticyesx',
'ticyemo' => 'ticyemo',
'ticye' => 'ticye',
'titi' => 'titi',
'tit' => 'tit',
'tilo' => 'tilo',
'tili' => 'tili',
'tile' => 'tile',
'tila' => 'tila',
'mima' => 'mima',
'ge' => 'ge',
'tom' => 'om',
'ecyu' => 'ecyu',
'ecyete' => 'ecyete',
'ecyesx' => 'ecyesx',
'ecyemo' => 'ecyemo',
'ecye' => 'ecye',
'ak' => 'ak',
'tih' => 'tih',
'zxe' => 'zxe',
'iju' => 'u',
'cyeno' => 'cyeno',
'cyeni' => 'cyeni',
'cyene' => 'cyene',
'cyena' => 'cyena',
'cyen' => 'cyen',
'anye' => 'e',
'eti' => 'i',
'ijem' => 'ijem',
'et' => '',
'eo' => 'eo',
'elo' => 'elo',
'eli' => 'eli',
'ele' => 'ele',
'ela' => 'ela',
'tisxe' => 'tisxe',
'com' => 'om',
'tiste' => 'tiste',
'tismo' => 'tismo',
'g' => 'g',
'tem' => 'tem',
'tivsxi' => 'tivsxi',
'cama' => 'ama',
'yasxe' => '',
'yaste' => '',
'yasmo' => '',
'yahu' => '',
'yah' => '',
'co' => 'o',
'x' => '',
'cyi' => 'cyi',
'tmo' => 'tmo',
'xte' => 'te',
'xmo' => 'mo',
'eta' => 'a',
'etu' => 'u',
'etom' => 'om',
'cxi' => 'i',
'esxe' => 'esxe',
'xucyi' => '',
'este' => 'este',
'esmo' => 'esmo',
'avavsxi' => 'vsxi',
'avati' => 'ti',
'avat' => 't',
'avasxe' => 'sxe',
'avaste' => 'ste',
'avasmo' => 'smo',
'avao' => 'o',
'avano' => 'no',
'avani' => 'ni',
'avane' => 'ne',
'avana' => 'na',
'avan' => 'n',
'avalo' => 'lo',
'avali' => 'li',
'avale' => 'le',
'avala' => 'la',
'avahu' => 'hu',
'avah' => 'h',
'avacyu' => 'cyu',
'avacyete' => 'cyete',
'avacyesx' => 'cyesx',
'avacyemo' => 'cyemo',
'avacye' => 'cye',
'nyima' => 'ima',
'lom' => 'lom',
'lu' => 'lu',
'zima' => 'zima',
'ad' => '',
'adi' => 'i',
'adima' => 'adima',
'nyem' => 'em',
'lyasxe' => 'sxe',
'lyaste' => 'ste',
'lyasmo' => 'smo',
'lyahu' => 'yahu',
'lyah' => 'h',
'to' => 'to',
'iji' => 'i',
'ija' => 'a',
'ijom' => 'om',
'anya' => 'a',
'eh' => 'eh',
'ja' => 'ja',
'ijomu' => 'ijomu',
'ijoj' => 'ijoj',
'ijim' => 'm',
'ijih' => 'h',
'ijemu' => 'ijemu',
'ijega' => 'ijega',
'ijeg' => 'ijeg',
'nu' => 'u',
'evsxi' => 'evsxi',
'ecyi' => 'ecyi',
'kao' => 'o',
'cxu' => 'u',
'tasxe' => 'tasxe',
'taste' => 'taste',
'tasmo' => 'tasmo',
'tao' => 'tao',
'tacyu' => 'tacyu',
'tacyete' => 'tacyete',
'tacyesx' => 'tacyesx',
'tacyemo' => 'tacyemo',
'tacye' => 'tacye',
'tavsxi' => 'tavsxi',
'tati' => 'tati',
'tat' => 'tat',
'talo' => 'talo',
'tali' => 'tali',
'tale' => 'tale',
'tala' => 'tala',
'tah' => 'tah',
'go' => 'go',
'cxite' => 'ite',
'cximo' => 'imo',
'tan' => 'tan',
'tano' => 'tano',
'tani' => 'tani',
'tane' => 'tane',
'tana' => 'tana',
'ocxe' => 'cxe',
'ocu' => 'ocu',
'ocima' => 'cima',
'oci' => 'ci',
'ocem' => 'ocem',
'oce' => 'oce',
'oca' => 'oca',
'laca' => 'laca',
'lac' => 'lac',
'jima' => 'jima',
'ra' => 'a',
'cyem' => 'cyem',
'cxem' => 'cxem',
'jem' => 'jem',
'de' => 'e',
'sti' => 'i',
'xi' => '',
'jeli' => 'jeli',
'jele' => 'jele',
'jela' => 'jela',
'jelo' => 'jelo',
'sxcyu' => 'sxcyu',
'sxcyete' => 'sxcyete',
'sxcyesx' => 'sxcyesx',
'sxcyemo' => 'sxcyemo',
'sxcye' => 'sxcye',
'jecyu' => 'jecyu',
'jecyete' => 'jecyete',
'jecyesx' => 'jecyesx',
'jecyemo' => 'jecyemo',
'jecye' => 'jecye',
'xite' => 'ite',
'ximo' => 'imo',
'ru' => 'u',
'rom' => 'om',
'lye' => 'lye',
'jeti' => 'jeti',
'jet' => 'jet',
'ara' => 'a',
're' => 'e',
'du' => 'du',
'tama' => 'tama',
'cyite' => 'cyite',
'cyimo' => 'cyimo',
'ri' => 'i',
'lyu' => 'u',
'kavsxi' => 'vsxi',
'tahu' => 'tahu',
'si' => 'i',
'lya' => '',
'di' => 'i',
'eva' => '',
'nom' => 'om',
'kati' => 'ti',
'kat' => 't',
'kaste' => 'ste',
'kasxe' => 'sxe',
'kasmo' => 'smo',
'kalo' => 'lo',
'kali' => 'li',
'kale' => 'le',
'kala' => 'la',
'kah' => 'h',
'kacyu' => 'cyu',
'kacyete' => 'cyete',
'kacyesx' => 'cyesx',
'kacyemo' => 'cyemo',
'kacye' => 'cye',
'kano' => 'no',
'kani' => 'ni',
'kane' => 'ne',
'kana' => 'na',
'kan' => 'n',
'enye' => 'e',
'ji' => 'i',
'taka' => 'taka',
'lima' => 'lima',
'be' => 'be',
'cxete' => 'cxete',
'tku' => 'tku',
'tkom' => 'tkom',
'tke' => 'tke',
'tka' => 'tka',
'bu' => 'bu',
'bi' => 'bi',
'cxemo' => 'cxemo',
'evi' => 'i',
'eve' => 'e',
'ba' => 'ba',
'nyi' => 'i',
'nyom' => 'om',
'evima' => 'ima',
'gama' => 'gama',
'kova' => 'kova',
'bom' => 'bom',
'bo' => 'bo',
'bama' => 'bama',
'ovanye' => 'ovanye',
'kahu' => 'kahu',
'aba' => 'aba',
'lyem' => 'lyem',
'alya' => 'alya',
'ha' => 'ha',
'aja' => 'a',
'hom' => 'hom',
'xcyeno' => '',
'xcyeni' => '',
'xcyene' => '',
'xcyena' => '',
'xcyen' => '',
'nyo' => 'o',
'nyama' => 'ama',
'xasxe' => '',
'xaste' => '',
'xasmo' => '',
'xah' => '',
'kovi' => 'kovi',
'jesxe' => 'jesxe',
'xahu' => '',
'kovima' => 'kovima',
'kove' => 'kove',
'st' => 't',
'ar' => '',
'anyu' => 'u',
'jevsxi' => 'jevsxi',
'jeste' => 'jeste',
'jesmo' => 'jesmo',
'jeh' => 'jeh',
'ij' => 'ij',
'da' => '',
'cxa' => 'a',
'ijete' => 'ijete',
'do' => 'o',
'cy' => '',
'ijesx' => 'ijesx',
'dom' => 'om',
'cxim' => 'im',
'tak' => 'tak',
'ijemo' => 'ijemo',
'dama' => 'ama',
'rima' => 'ima',
'jom' => 'om',
'ada' => 'a',
'lyima' => 'ima',
'lama' => 'ama',
'xcxe' => '',
'he' => 'he',
'cx' => '',
'nama' => 'ama',
'anyem' => 'em',
'ijte' => 'ijte',
'ijmo' => 'ijmo',
'nte' => 'te',
'nmo' => 'mo',
'iveno' => 'iveno',
'iveni' => 'iveni',
'ivene' => 'ivene',
'ivena' => 'ivena',
'iven' => 'iven',
'gavsxi' => 'vsxi',
'cxena' => 'ena',
'anyima' => 'ima',
'ou' => 'ou',
'oi' => 'i',
'oe' => 'oe',
'oa' => 'a',
'cxeno' => 'eno',
'cxeni' => 'eni',
'cxene' => 'ene',
'cxen' => 'en',
'xenye' => '',
'ye' => '',
'enyu' => 'u',
'cxisx' => 'isx',
'ro' => 'o',
'ki' => 'i',
'yenye' => 'e',
'nim' => 'im',
'zxi' => 'i',
'sima' => 'ima',
'nite' => 'ite',
'nimo' => 'imo',
'cyasxe' => 'cyasxe',
'cyaste' => 'cyaste',
'cyasmo' => 'cyasmo',
'cyahu' => 'cyahu',
'cyah' => 'cyah',
'lyi' => 'i',
'koga' => 'oga',
'kim' => 'im',
'zxite' => 'ite',
'zximo' => 'imo',
'oima' => 'ima',
'komu' => 'omu',
'koj' => 'oj',
'kog' => 'og',
'jete' => 'ete',
'jesx' => 'esx',
'jemo' => 'emo',
'cxte' => 'te',
'cxmo' => 'mo',
'kih' => 'ih',
'gosxe' => '',
'goste' => 'te',
'gosmo' => '',
'goh' => '',
'vi' => 'vi',
've' => 've',
's' => '',
'rama' => 'ama',
'cxiti' => 'iti',
'cxit' => 'it',
'cxio' => 'io',
'cxilo' => 'ilo',
'cxili' => 'ili',
'cxile' => 'ile',
'cxila' => 'ila',
'cxicyu' => 'icyu',
'cxicyete' => 'icyete',
'cxicyesx' => 'icyesx',
'cxicyemo' => 'icyemo',
'cxicye' => 'icye',
'cxasxe' => 'asxe',
'cxaste' => 'aste',
'cxasmo' => 'asmo',
'cxah' => 'ah',
'yeti' => 'ti',
'yet' => 't',
'yelo' => 'o',
'yeli' => 'li',
'yele' => 'le',
'yela' => 'la',
'yecyu' => '',
'yecyete' => '',
'yecyesx' => '',
'yecyemo' => '',
'yecye' => '',
'se' => 'e',
'cxahu' => 'ahu',
'ajucyi' => 'jucyi',
'nih' => 'ih',
'lim' => 'im',
'tko' => 'tko',
'nete' => 'ete',
'nesx' => 'esx',
'nemo' => 'emo',
'nem' => 'em',
'xevima' => 'evima',
'xevi' => 'i',
'xeve' => 'e',
'xeva' => 'a',
'ivu' => 'u',
'ivom' => 'om',
'cxom' => 'om',
'su' => 'u',
'mama' => 'mama',
'ivo' => 'o',
'ivi' => 'i',
'ive' => 'e',
'iv' => '',
'dite' => 'ite',
'dimo' => 'imo',
'lte' => 'te',
'ivomu' => 'omu',
'ivoj' => 'oj',
'ivoga' => 'oga',
'ivog' => 'og',
'ivim' => 'im',
'ivih' => 'ih',
'vama' => 'ama',
'nio' => 'io',
'lmo' => 'mo',
'l' => '',
'klo' => 'lo',
'kli' => 'li',
'kle' => 'le',
'kla' => 'la',
'kate' => 'te',
'kaju' => 'ju',
'kajte' => 'jte',
'kajmo' => 'jmo',
'kaj' => 'j',
'dosxe' => 'dosxe',
'doste' => 'doste',
'dosmo' => 'dosmo',
'doh' => 'doh',
'sci' => 'ci',
'sa' => 'a',
'lio' => 'io',
'kasx' => 'sx',
'kamo' => 'mo',
'kam' => 'm',
'dem' => 'dem',
'tecyu' => 'tecyu',
'tecyete' => 'tecyete',
'tecyesx' => 'tecyesx',
'tecyemo' => 'tecyemo',
'tecye' => 'tecye',
'sxcxe' => 'xcxe',
'oama' => 'oama',
'gova' => 'gova',
'xnyeno' => 'xnyeno',
'xnyeni' => 'xnyeni',
'xnyene' => 'xnyene',
'xnyena' => 'xnyena',
'xnyen' => 'xnyen',
'tomu' => 'omu',
'so' => 'o',
'lyom' => 'om',
'lite' => 'ite',
'lisx' => 'isx',
'limo' => 'imo',
'toj' => 'oj',
'toga' => 'oga',
'tog' => 'og',
'tjeti' => 'tjeti',
'scima' => 'cima',
'niti' => 'iti',
'nit' => 'it',
'nilo' => 'ilo',
'nili' => 'ili',
'nile' => 'ile',
'nila' => 'ila',
'nicyu' => 'icyu',
'nicyete' => 'icyete',
'nicyesx' => 'icyesx',
'nicyemo' => 'icyemo',
'nicye' => 'icye',
'licyu' => 'icyu',
'licyete' => 'icyete',
'licyesx' => 'icyesx',
'licyemo' => 'icyemo',
'licye' => 'icye',
'kanye' => 'nye',
'zxu' => 'u',
'tkama' => 'tkama',
'tjeli' => 'tjeli',
'teti' => 'i',
'tet' => '',
'teo' => 'teo',
'telo' => 'telo',
'teli' => 'teli',
'tele' => 'tele',
'tela' => 'tela',
'som' => 'om',
'cxama' => 'ama',
'tjet' => 'tjet',
'tjelo' => 'tjelo',
'tjele' => 'tjele',
'tjela' => 'tjela',
'tjecyu' => 'tjecyu',
'tjecyete' => 'tjecyete',
'tjecyesx' => 'tjecyesx',
'tjecyemo' => 'tjecyemo',
'tjecye' => 'tjecye',
'sxi' => 'i',
'liti' => 'iti',
'lit' => 'it',
'lilo' => 'ilo',
'lili' => 'ili',
'lile' => 'ile',
'lila' => 'ila',
'govima' => 'govima',
'govi' => 'govi',
'gove' => 'gove',
'eih' => 'eih',
'ecy' => 'ecy',
'cxo' => 'o',
'zxem' => 'zxem',
'utu' => 'u',
'utom' => 'om',
'utim' => 'tim',
'nisx' => 'isx',
'lyenye' => 'e',
'kute' => 'ute',
'kumo' => 'umo',
'egosxe' => 'egosxe',
'egoste' => 'egoste',
'egosmo' => 'egosmo',
'egoh' => 'egoh',
'ego' => 'ego',
'egavsxi' => 'egavsxi',
'zxete' => 'xete',
'zxesx' => 'xesx',
'zxemo' => 'xemo',
'utomu' => 'omu',
'utoj' => 'oj',
'utoga' => 'oga',
'utog' => 'og',
'utih' => 'tih',
'yenyu' => '',
'jite' => 'ite',
'jimo' => 'imo',
'dete' => 'dete',
'desx' => 'desx',
'demo' => 'demo',
'zak' => 'zak',
'sxu' => 'u',
'yesx' => '',
'sku' => 'u',
'skom' => 'om',
'ske' => 'e',
'ska' => 'a',
'ome' => 'e',
'lih' => 'ih',
'ilom' => 'om',
'tova' => 'ova',
'ssxe' => 'ssxe',
'tasx' => 'sx',
'ilu' => 'u',
'icyi' => 'i',
'icy' => '',
'enyima' => 'ima',
'enyem' => 'em',
'enya' => 'a',
'cxivsxi' => 'ivsxi',
'ze' => 'e',
'tate' => 'te',
'tamo' => 'mo',
'tam' => 'm',
'taju' => 'ju',
'tajte' => 'jte',
'tajmo' => 'jmo',
'taj' => 'j',
'pu' => 'u',
'po' => 'o',
'pe' => 'e',
'tesxe' => 'tesxe',
'teste' => 'teste',
'tesmo' => 'tesmo',
'slo' => 'slo',
'sli' => 'li',
'sle' => 'le',
'sla' => 'sla',
'gao' => 'o',
'deni' => 'deni',
'dene' => 'dene',
'zu' => 'u',
'sama' => 'ama',
'rasxe' => 'asxe',
'raste' => 'aste',
'rasmo' => 'asmo',
'rah' => 'ah',
'ilima' => 'ilima',
'ijesxe' => 'ijesxe',
'deno' => 'deno',
'dena' => 'dena',
'den' => 'den',
'cya' => 'a',
'yevsxi' => '',
'yesxe' => '',
'yeste' => '',
'yesmo' => '',
'yeh' => '',
'tovima' => 'ovima',
'tovi' => 'ovi',
'tove' => 'ove',
'lyim' => 'im',
'kinya' => 'a',
'ikinyu' => 'ikinyu',
'ikinyom' => 'ikinyom',
'ikinyo' => 'ikinyo',
'ikinyi' => 'ikinyi',
'ikinye' => 'ikinye',
'ikinyama' => 'ikinyama',
'ikinya' => 'ikinya',
'dye' => 'e',
'aku' => 'ku',
'akom' => 'kom',
'ake' => 'ke',
'tevsxi' => 'tevsxi',
'teh' => 'teh',
'isxu' => 'xu',
'zxeno' => 'eno',
'zxeni' => 'eni',
'zxene' => 'ene',
'zxena' => 'ena',
'zxen' => 'en',
'sxite' => 'ite',
'sih' => 'ih',
'sao' => 'ao',
'ivenyu' => 'ivenyu',
'ijecyesx' => 'ijecyesx',
'dyu' => 'u',
'sximo' => 'imo',
'nisxe' => 'isxe',
'niste' => 'iste',
'nismo' => 'ismo',
'livsxi' => 'ivsxi',
'kima' => 'kima',
'ijecyu' => 'ijecyu',
'ijecyete' => 'ijecyete',
'ijecyemo' => 'ijecyemo',
'ijecye' => 'ijecye',
'asa' => 'a',
'zaka' => 'zaka',
'tjevsxi' => 'tjevsxi',
'tjesxe' => 'tjesxe',
'tjeste' => 'tjeste',
'tjesmo' => 'tjesmo',
'tjeh' => 'tjeh',
'tje' => 'tje',
'pi' => 'i',
'pa' => 'a',
'nivsxi' => 'ivsxi',
'lisxe' => 'isxe',
'liste' => 'iste',
'lismo' => 'ismo',
'ijeti' => 'ti',
'dyem' => 'em',
'cxetu' => 'etu',
'cxetom' => 'etom',
'cxeta' => 'eta',
'aci' => 'ci',
'ucyima' => 'ima',
'ucyem' => 'em',
'ucya' => 'a',
'sxem' => 'xem',
'pcxe' => 'cxe',
'ovu' => 'u',
'ijet' => 'ijet',
'ijelo' => 'ijelo',
'ijeli' => 'i',
'ijele' => 'e',
'ijela' => 'ijela',
'ho' => 'ho',
'dte' => 'te',
'cxadima' => 'adima',
'cxadi' => 'adi',
'cxad' => 'ad',
'astim' => 'im',
'asti' => 'i',
'zxim' => 'im',
'vavsxi' => 'vsxi',
'vati' => 'ti',
'vat' => 't',
'vasxe' => 'sxe',
'vaste' => 'ste',
'vasmo' => 'smo',
'vao' => 'o',
'valo' => 'lo',
'vali' => 'li',
'vale' => 'le',
'vala' => 'la',
'vah' => 'h',
'vacyu' => 'cyu',
'vacyete' => 'cyete',
'vacyesx' => 'cyesx',
'vacyemo' => 'cyemo',
'vacye' => 'cye',
'pcu' => 'cu',
'pcima' => 'cima',
'pci' => 'ci',
'pcem' => 'cem',
'pce' => 'ce',
'pca' => 'ca',
'knu' => 'u',
'kne' => 'e',
'ijen' => '',
'd' => '',
'baca' => 'baca',
'bac' => 'bac',
'astih' => 'ih',
'zxisx' => 'isx',
'vano' => 'no',
'vani' => 'ni',
'vane' => 'ne',
'vana' => 'na',
'van' => 'n',
'sxete' => 'xete',
'sxesx' => 'xesx',
'sxemo' => 'xemo',
'pom' => 'om',
'nomu' => 'omu',
'noj' => 'oj',
'noga' => 'oga',
'nog' => 'og',
'knute' => 'ute',
'knem' => 'em',
'ijeno' => 'ijeno',
'ijeni' => 'i',
'ijene' => 'e',
'ijena' => 'ijena',
'ie' => 'e',
'icyima' => 'ima',
'icya' => 'a',
'duju' => 'uju',
'dujete' => 'ujete',
'dujesx' => 'ujesx',
'dujemo' => 'ujemo',
'dujem' => 'ujem',
'duje' => 'uje',
'dne' => 'e',
'cyima' => 'ima',
'zx' => '',
'xcyasxe' => '',
'xcyaste' => '',
'xcyasmo' => '',
'xcyahu' => '',
'xcyah' => '',
'pama' => 'ama',
'nuti' => 'uti',
'nut' => 'ut',
'lyo' => 'o',
'hama' => 'hama',
'eklo' => 'klo',
'ekli' => 'kli',
'ekle' => 'kle',
'ekla' => 'kla',
'ekao' => 'kao',
'cxih' => 'ih',
'apa' => 'a',
'zxte' => 'te',
'zxmo' => 'mo',
'zxiti' => 'iti',
'zxit' => 'it',
'zxio' => 'io',
'zxilo' => 'ilo',
'zxili' => 'ili',
'zxile' => 'ile',
'zxila' => 'ila',
'zxicyu' => 'icyu',
'zxicyete' => 'icyete',
'zxicyesx' => 'icyesx',
'zxicyemo' => 'icyemo',
'zxicye' => 'icye',
'zgo' => 'zgo',
'xenyu' => '',
'ucyi' => 'i',
'stu' => 'u',
'rat' => 't',
'nuo' => 'uo',
'nulo' => 'ulo',
'nuli' => 'uli',
'nule' => 'ule',
'nula' => 'ula',
'nucyu' => 'ucyu',
'nucyete' => 'ucyete',
'nucyesx' => 'ucyesx',
'nucyemo' => 'ucyemo',
'nucye' => 'ucye',
'lyama' => 'ama',
'isxi' => 'xi',
'ijeste' => 'ijeste',
'ijesmo' => 'ijesmo',
'eru' => 'u',
'dni' => 'i',
'dnem' => 'dnem',
'cxecyi' => 'ecyi',
'astu' => 'u',
'astomu' => 'omu',
'astom' => 'om',
'astoj' => 'oj',
'astoga' => 'oga',
'astog' => 'og',
'asto' => 'o',
'asta' => 'a',
'ast' => '',
'zgosxe' => 'zgosxe',
'zgoste' => 'zgoste',
'zgosmo' => 'zgosmo',
'zgoh' => 'zgoh',
'zgavsxi' => 'vsxi',
'zem' => 'zem',
'za' => 'a',
'rala' => 'la',
'kuju' => 'uju',
'kujete' => 'ujete',
'kujesx' => 'ujesx',
'kujemo' => 'ujemo',
'kujem' => 'ujem',
'kuje' => 'uje',
'ijeh' => 'ijeh',
'icyom' => 'om',
'erete' => 'erete',
'eresx' => 'eresx',
'eremo' => 'eremo',
'erem' => 'erem',
'ere' => 'e',
'dnu' => 'u',
'alom' => 'om',
'zimo' => 'imo',
'tanye' => 'e',
'rani' => 'ni',
'lacyesx' => 'cyesx',
'kujucyi' => 'ujucyi',
'kujte' => 'ujte',
'kujmo' => 'ujmo',
'kuj' => 'uj',
'kovavsxi' => 'ovavsxi',
'kovati' => 'ovati',
'kovat' => 'ovat',
'kovasxe' => 'ovasxe',
'kovaste' => 'ovaste',
'kovasmo' => 'ovasmo',
'kovao' => 'ovao',
'kovano' => 'ovano',
'kovani' => 'ovani',
'kovane' => 'ovane',
'kovana' => 'ovana',
'kovan' => 'ovan',
'kovalo' => 'ovalo',
'kovali' => 'ovali',
'kovale' => 'ovale',
'kovala' => 'ovala',
'kovah' => 'ovah',
'kovacyu' => 'ovacyu',
'kovacyete' => 'ovacyete',
'kovacyesx' => 'ovacyesx',
'kovacyemo' => 'ovacyemo',
'kovacye' => 'ovacye',
'ijevsxi' => 'ijevsxi',
'eri' => 'i',
'dute' => 'ute',
'cxavsxi' => 'vsxi',
'cxati' => 'ti',
'cxat' => 't',
'cxao' => 'o',
'cxano' => 'no',
'cxani' => 'ni',
'cxane' => 'ne',
'cxana' => 'na',
'cxan' => 'n',
'cxalo' => 'lo',
'cxali' => 'li',
'cxale' => 'le',
'cxala' => 'la',
'cxacyu' => 'cyu',
'cxacyete' => 'cyete',
'cxacyesx' => 'cyesx',
'cxacyemo' => 'cyemo',
'cxacye' => 'cye',
'alu' => 'u',
'acya' => '',
'zite' => 'ite',
'sxeno' => 'xeno',
'sxeni' => 'xeni',
'sxene' => 'xene',
'sxena' => 'xena',
'sxen' => 'xen',
'ravsxi' => 'vsxi',
'rati' => 'ti',
'rao' => 'o',
'ralo' => 'lo',
'rali' => 'li',
'rale' => 'le',
'rahu' => 'ahu',
'racyu' => 'cyu',
'racyete' => 'cyete',
'racyesx' => 'cyesx',
'racyemo' => 'cyemo',
'racye' => 'cye',
'ov' => '',
'lyenya' => 'a',
'kusx' => '',
'kovahu' => 'ovahu',
'knumo' => 'knumo',
'isxete' => 'xete',
'isxesx' => 'xesx',
'isxemo' => 'xemo',
'isxem' => 'xem',
'isavsxi' => 'avsxi',
'isati' => 'ati',
'isat' => 'at',
'isasxe' => 'asxe',
'isaste' => 'aste',
'isasmo' => 'asmo',
'isao' => 'ao',
'isalo' => 'alo',
'isali' => 'ali',
'isale' => 'ale',
'isala' => 'ala',
'isah' => 'ah',
'isacyu' => 'acyu',
'isacyete' => 'acyete',
'isacyesx' => 'acyesx',
'isacyemo' => 'acyemo',
'isacye' => 'acye',
'erite' => 'ite',
'erimo' => 'imo',
'elim' => 'im',
'dumo' => 'umo',
'dnute' => 'dnute',
'dnite' => 'ite',
'dnimo' => 'imo',
'disx' => 'isx',
'dio' => 'io',
'dim' => 'im',
'asxi' => 'i',
'asxa' => 'a',
'alima' => 'lima',
'zesx' => 'zesx',
'yenyima' => 'ima',
'yenyem' => 'em',
'yenya' => 'a',
'temo' => 'temo',
'rano' => 'no',
'ovom' => 'om',
'lyite' => 'ite',
'lyimo' => 'imo',
'lyih' => 'ih',
'kte' => 'e',
'knesx' => 'esx',
'kmo' => '',
'hovima' => 'hovima',
'hovi' => 'hovi',
'hove' => 'hove',
'hova' => 'hova',
'dujucyi' => 'ujucyi',
'dujte' => 'ujte',
'dujmo' => 'ujmo',
'duj' => 'uj',
'cyenye' => 'e',
'zete' => 'zete',
'zemo' => 'zemo',
'tete' => 'e',
'tesx' => 'tesx',
'site' => 'ite',
'simo' => 'imo',
'rane' => 'ne',
'rana' => 'na',
'ran' => 'n',
'r' => '',
'nyeno' => 'yeno',
'nyeni' => 'yeni',
'nyene' => 'yene',
'nyena' => 'yena',
'nyen' => 'yen',
'mte' => 'te',
'lyoj' => 'lyoj',
'lyemu' => 'lyemu',
'lyega' => 'lyega',
'lyeg' => 'lyeg',
'koste' => 'koste',
'kosmo' => 'kosmo',
'knusx' => 'knusx',
'knte' => 'knte',
'knmo' => 'knmo',
'knite' => 'ite',
'jucyim' => 'm',
'jeno' => 'no',
'jena' => 'na',
'jen' => 'n',
'itu' => 'u',
'itom' => 'om',
'ita' => 'a',
'iri' => 'i',
'icxe' => 'cxe',
'gati' => 'ti',
'gat' => 't',
'gasxe' => 'sxe',
'gaste' => 'ste',
'gasmo' => 'smo',
'gano' => 'no',
'gani' => 'ni',
'gane' => 'ne',
'gana' => 'na',
'gan' => 'n',
'galo' => 'lo',
'gali' => 'li',
'gale' => 'le',
'gala' => 'la',
'gah' => 'h',
'gacyu' => 'cyu',
'gacyete' => 'cyete',
'gacyesx' => 'cyesx',
'gacyemo' => 'cyemo',
'gacye' => 'cye',
'egnute' => 'ute',
'egnusx' => 'egnusx',
'egnumo' => 'egnumo',
'egnu' => 'u',
'egnte' => 'egnte',
'egnmo' => 'egnmo',
'egnem' => 'em',
'egne' => 'e',
'egn' => 'egn',
'egao' => 'egao',
'dnuto' => 'dnuto',
'dnuti' => 'dnuti',
'dnuta' => 'dnuta',
'dnut' => 'dnut',
'dnete' => 'dnete',
'dnesx' => 'dnesx',
'dnemo' => 'dnemo',
'dmo' => 'mo',
'atu' => 'u',
'aga' => 'ga',
'zosxe' => 'zosxe',
'zoste' => 'zoste',
'zosmo' => 'zosmo',
'zoh' => 'zoh',
'zeno' => 'zeno',
'zeni' => 'zeni',
'zene' => 'zene',
'zena' => 'zena',
'zen' => 'zen',
'zaca' => 'zaca',
'zac' => 'zac',
'sxa' => 'a',
'scu' => 'cu',
'scem' => 'cem',
'sce' => 'ce',
'sca' => 'ca',
'reno' => 'eno',
'reni' => 'eni',
'rene' => 'ene',
'rena' => 'ena',
'ren' => 'en',
'nasxe' => 'sxe',
'naste' => 'ste',
'nasmo' => 'smo',
'nahu' => 'ahu',
'nah' => 'h',
'lyomu' => 'lyomu',
'kosxe' => 'kosxe',
'jucyih' => 'h',
'jeni' => 'i',
'jene' => 'e',
'glo' => 'lo',
'gli' => 'li',
'gle' => 'le',
'gla' => 'la',
'evavsxi' => 'vsxi',
'evati' => 'ti',
'evat' => 't',
'evasxe' => 'sxe',
'evaste' => 'ste',
'evasmo' => 'smo',
'evao' => 'o',
'evano' => 'no',
'evani' => 'ni',
'evane' => 'ne',
'evana' => 'na',
'evan' => 'n',
'evalo' => 'lo',
'evali' => 'li',
'evale' => 'le',
'evala' => 'la',
'evah' => 'h',
'evacyu' => 'cyu',
'evacyete' => 'cyete',
'evacyesx' => 'cyesx',
'evacyemo' => 'cyemo',
'evacye' => 'cye',
'es' => '',
'elih' => 'ih',
'eglo' => 'eglo',
'egli' => 'egli',
'egle' => 'egle',
'egla' => 'egla',
'dyeno' => 'yeno',
'dyeni' => 'yeni',
'dyene' => 'yene',
'dyena' => 'yena',
'dyen' => 'yen',
'dya' => 'a',
'dilo' => 'ilo',
'dili' => 'ili',
'dile' => 'ile',
'dila' => 'ila',
'dicyu' => 'icyu',
'dicyete' => 'icyete',
'dicyesx' => 'icyesx',
'dicyemo' => 'icyemo',
'dicye' => 'icye',
'atom' => 'om',
'asxu' => 'u',
'zxasxe' => 'asxe',
'zxaste' => 'aste',
'zxasmo' => 'asmo',
'zxah' => 'ah',
'zom' => 'om',
'sxao' => 'o',
'stimo' => 'timo',
'rim' => 'im',
'koh' => 'koh',
'knimo' => 'imo',
'kni' => 'i',
'knete' => 'ete',
'knemo' => 'emo',
'jucyiu' => 'u',
'jucyiomu' => 'omu',
'jucyiom' => 'om',
'jucyioj' => 'oj',
'jucyiemu' => 'emu',
'jucyiem' => 'em',
'jucyiega' => 'ega',
'jucyieg' => 'eg',
'jucyie' => 'e',
'jucyia' => 'a',
'gnute' => 'ute',
'gnusx' => '',
'gnumo' => '',
'gnu' => 'u',
'gnem' => 'em',
'gne' => 'e',
'gahu' => 'hu',
'eto' => 'o',
'ese' => 'e',
'elom' => 'om',
'ecxe' => 'cxe',
'diti' => 'iti',
'dit' => 'it',
'asxom' => 'om',
'any' => '',
'zxahu' => 'ahu',
'xa' => '',
'ucxem' => 'cxem',
'ucxe' => 'cxe',
'sxlo' => 'sxlo',
'sta' => 'a',
'lasxe' => 'sxe',
'laste' => 'ste',
'lasmo' => 'smo',
'lah' => 'h',
'knuvsxi' => 'uvsxi',
'knuto' => 'uto',
'knuti' => 'uti',
'knuta' => 'uta',
'knut' => 'ut',
'knusxe' => 'usxe',
'knuste' => 'uste',
'knusmo' => 'usmo',
'knuo' => 'uo',
'knulo' => 'ulo',
'knuli' => 'uli',
'knule' => 'ule',
'knula' => 'ula',
'knuh' => 'uh',
'knucyu' => 'ucyu',
'knucyete' => 'ucyete',
'knucyesx' => 'ucyesx',
'knucyemo' => 'ucyemo',
'knucye' => 'ucye',
'iu' => 'u',
'ire' => 'e',
'iom' => 'om',
'ia' => 'a',
'gnte' => '',
'gnmo' => '',
'gn' => '',
'etim' => 'tim',
'elu' => 'u',
'ecxem' => 'cxem',
'cxisxe' => 'isxe',
'cxiste' => 'iste',
'cxismo' => 'ismo',
'ako' => 'ko',
'acxe' => 'e',
'acima' => 'cima',
'zo' => 'o',
'yu' => '',
'veno' => 'o',
'veni' => 'i',
'vene' => 'e',
'vena' => 'a',
'ven' => '',
'ukao' => 'kao',
'sxte' => 'te',
'sxom' => 'om',
'sxli' => 'sxli',
'sxle' => 'sxle',
'sxla' => 'sxla',
'stom' => 'om',
'stite' => 'tite',
'stim' => 'tim',
'stih' => 'tih',
'riti' => 'iti',
'osxe' => 'e',
'oste' => 'te',
'osmo' => 'mo',
'lyte' => 'te',
'lymo' => 'mo',
'ly' => '',
'lova' => 'ova',
'lavsxi' => 'vsxi',
'lati' => 'ti',
'lat' => 't',
'lao' => 'o',
'lano' => 'no',
'lani' => 'ni',
'lane' => 'ne',
'lana' => 'na',
'lan' => 'n',
'lalo' => 'lo',
'lali' => 'li',
'lale' => 'le',
'lala' => 'la',
'lacyu' => 'cyu',
'lacyete' => 'cyete',
'lacyemo' => 'cyemo',
'lacye' => 'cye',
'itih' => 'ih',
'isa' => 'a',
'ijasxe' => 'sxe',
'ijaste' => 'ste',
'ijasmo' => 'smo',
'ijah' => 'h',
'icxite' => 'ite',
'icximo' => 'imo',
'icxi' => 'i',
'evahu' => 'hu',
'etih' => 'tih',
'esu' => 'u',
'esete' => 'e',
'esesx' => 'sesx',
'esemo' => 'semo',
'esem' => 'sem',
'elomu' => 'omu',
'eloj' => 'oj',
'eloga' => 'oga',
'elog' => 'og',
'egnuvsxi' => 'uvsxi',
'egnuto' => 'uto',
'egnuti' => 'uti',
'egnuta' => 'uta',
'egnut' => 'ut',
'egnusxe' => 'usxe',
'egnuste' => 'uste',
'egnusmo' => 'usmo',
'egnuo' => 'uo',
'egnulo' => 'ulo',
'egnuli' => 'uli',
'egnule' => 'ule',
'egnula' => 'ula',
'egnuh' => 'uh',
'egnucyu' => 'ucyu',
'egnucyete' => 'ucyete',
'egnucyesx' => 'ucyesx',
'egnucyemo' => 'ucyemo',
'egnucye' => 'ucye',
'egnite' => 'ite',
'egnimo' => 'imo',
'egni' => 'i',
'egnete' => 'ete',
'egnesx' => 'esx',
'egnemo' => 'emo',
'ucy' => '',
'sxmo' => 'mo',
'rite' => 'ite',
'risx' => 'isx',
'rimo' => 'imo',
'p' => '',
'lyisx' => 'isx',
'kn' => 'n',
'jahu' => 'ahu',
'ivanye' => 'e',
'itomu' => 'omu',
'itoj' => 'oj',
'itoga' => 'oga',
'itog' => 'og',
'ito' => 'o',
'itim' => 'im',
'iru' => 'u',
'ireno' => 'eno',
'ireni' => 'eni',
'irene' => 'ene',
'irena' => 'ena',
'iren' => 'en',
'iomu' => 'omu',
'ioj' => 'oj',
'ijahu' => 'hu',
'iemu' => 'emu',
'iem' => 'em',
'iega' => 'ega',
'ieg' => 'eg',
'ekute' => 'kute',
'ekusx' => 'kusx',
'ekumo' => 'kumo',
'eku' => 'ku',
'ekte' => 'kte',
'ekmo' => 'kmo',
'ek' => 'k',
'avate' => 'te',
'avasx' => 'sx',
'avamo' => 'mo',
'avam' => 'm',
'avaju' => 'ju',
'avajte' => 'jte',
'avajmo' => 'jmo',
'avaj' => 'j',
'asxima' => 'ima',
'xnyasxe' => 'xnyasxe',
'xnyaste' => 'xnyaste',
'xnyasmo' => 'xnyasmo',
'xnyahu' => 'xnyahu',
'xnyah' => 'xnyah',
'xim' => 'im',
'uku' => 'ku',
'uk' => 'k',
'tosxe' => 'tosxe',
'toste' => 'toste',
'tosmo' => 'tosmo',
'toh' => 'toh',
'teno' => 'teno',
'teni' => 'teni',
'tene' => 'tene',
'tena' => 'tena',
'ten' => 'ten',
'sxama' => 'ama',
'svsxi' => 'svsxi',
'rte' => 'te',
'rmo' => 'mo',
'psxcyu' => 'psxcyu',
'psxcyete' => 'psxcyete',
'psxcyesx' => 'psxcyesx',
'psxcyemo' => 'psxcyemo',
'psxcye' => 'psxcye',
'psti' => 'psti',
'ovo' => 'o',
'nima' => 'ima',
'mete' => 'e',
'mesx' => 'mesx',
'memo' => 'memo',
'mem' => 'mem',
'lyenyu' => 'u',
'lomu' => 'omu',
'jo' => 'o',
'jasxe' => 'asxe',
'jaste' => 'aste',
'jasmo' => 'asmo',
'jama' => 'ama',
'jah' => 'ah',
'isxite' => 'xite',
'isximo' => 'ximo',
'isano' => 'ano',
'isani' => 'ani',
'isane' => 'ane',
'isana' => 'ana',
'isan' => 'an',
'ira' => '',
'ikao' => 'kao',
'ika' => 'ka',
'igavsxi' => 'igavsxi',
'gnusxe' => 'usxe',
'gnite' => 'ite',
'gnimo' => 'imo',
'gnesx' => 'esx',
'etomu' => 'omu',
'etoj' => 'oj',
'etoga' => 'oga',
'etog' => 'og',
'cxevima' => 'evima',
'cxevi' => 'evi',
'cxeve' => 'eve',
'cxeva' => 'eva',
'cxemu' => 'cxemu',
'cxega' => 'cxega',
'cxcima' => 'cima',
'cxci' => 'ci',
'akama' => 'kama',
'adya' => 'a',
'zama' => 'ama',
'ya' => '',
'xlyeno' => 'xlyeno',
'xlyeni' => 'xlyeni',
'xlyene' => 'xlyene',
'xlyena' => 'xlyena',
'xlyen' => 'xlyen',
'xisx' => 'isx',
'ukte' => 'e',
'ukmo' => 'kmo',
'uklo' => 'klo',
'ukli' => 'kli',
'ukle' => 'e',
'ukla' => 'kla',
'uih' => 'uih',
'sxo' => 'o',
'sxasxe' => 'sxe',
'sxaste' => 'ste',
'sxasmo' => 'smo',
'sxahu' => 'xahu',
'sxah' => 'h',
'stem' => '',
'siti' => 'iti',
'sit' => 'it',
'sisx' => 'isx',
'sio' => 'io',
'sim' => 'im',
'silo' => 'ilo',
'sili' => 'ili',
'sile' => 'ile',
'sila' => 'ila',
'sicyu' => 'icyu',
'sicyete' => 'icyete',
'sicyesx' => 'icyesx',
'sicyemo' => 'icyemo',
'sicye' => 'icye',
'sh' => 'sh',
'rit' => 'it',
'rio' => 'io',
'rilo' => 'ilo',
'rili' => 'ili',
'rile' => 'ile',
'rila' => 'ila',
'ricyu' => 'icyu',
'ricyete' => 'icyete',
'ricyesx' => 'icyesx',
'ricyemo' => 'icyemo',
'ricye' => 'icye',
'nute' => 'ute',
'isxeno' => 'xeno',
'isxeni' => 'xeni',
'isxene' => 'xene',
'isxena' => 'xena',
'isxen' => 'xen',
'isahu' => 'ahu',
'irasxe' => 'sxe',
'igosxe' => 'igosxe',
'igoste' => 'igoste',
'igosmo' => 'igosmo',
'igoh' => 'igoh',
'igo' => 'go',
'icxu' => 'xu',
'icxete' => 'xete',
'icxemo' => 'xemo',
'icxem' => 'xem',
'gnuvsxi' => 'uvsxi',
'gnuto' => 'uto',
'gnuti' => 'uti',
'gnuta' => 'uta',
'gnut' => 'ut',
'gnuste' => 'uste',
'gnusmo' => 'usmo',
'gnuo' => 'uo',
'gnulo' => 'ulo',
'gnuli' => 'uli',
'gnule' => 'ule',
'gnula' => 'ula',
'gnuh' => 'uh',
'gnucyu' => 'ucyu',
'gnucyete' => 'ucyete',
'gnucyesx' => 'ucyesx',
'gnucyemo' => 'ucyemo',
'gnucye' => 'ucye',
'gni' => 'i',
'gnete' => 'ete',
'gnemo' => 'emo',
'eknute' => 'ute',
'eknusx' => 'eknusx',
'eknumo' => 'eknumo',
'eknu' => 'u',
'eknem' => 'em',
'ekne' => 'e',
'disxe' => 'isxe',
'cxaka' => 'aka',
'bite' => 'ite',
'bimo' => 'imo',
'bem' => 'bem',
'aza' => 'a',
'zxih' => 'ih',
'y' => '',
'ugosxe' => 'ugosxe',
'ugoste' => 'ugoste',
'ugosmo' => 'ugosmo',
'ugoh' => 'ugoh',
'ugo' => 'go',
'ugavsxi' => 'gavsxi',
'toro' => 'toro',
'sxcyi' => 'sxcyi',
'sto' => 'to',
'stete' => 'e',
'stesx' => 'stesx',
'stemo' => 'stemo',
'sko' => 'o',
'ski' => 'i',
'sem' => 'sem',
'savsxi' => 'vsxi',
'sati' => 'ti',
'sat' => 't',
'sasxe' => 'sxe',
'saste' => 'ste',
'sasmo' => 'smo',
'salo' => 'lo',
'sali' => 'li',
'sale' => 'le',
'sala' => 'ala',
'sah' => 'h',
'sacyu' => 'cyu',
'sacyete' => 'cyete',
'sacyesx' => 'cyesx',
'sacyemo' => 'cyemo',
'sacye' => 'cye',
'rih' => 'ih',
'pte' => 'te',
'pete' => 'ete',
'pesx' => 'esx',
'pemo' => 'emo',
'pem' => 'em',
'ovanya' => 'a',
'lyavsxi' => 'vsxi',
'lyati' => 'ti',
'lyate' => 'te',
'lyat' => 't',
'lyasx' => 'sx',
'lyao' => 'o',
'lyano' => 'no',
'lyani' => 'ni',
'lyane' => 'ne',
'lyana' => 'na',
'lyan' => 'n',
'lyamo' => 'mo',
'lyam' => 'm',
'lyalo' => 'lo',
'lyali' => 'li',
'lyale' => 'le',
'lyala' => 'la',
'lyaju' => 'ju',
'lyajte' => 'jte',
'lyajmo' => 'jmo',
'lyaj' => 'j',
'lyacyu' => 'cyu',
'lyacyete' => 'cyete',
'lyacyesx' => 'cyesx',
'lyacyemo' => 'cyemo',
'lyacye' => 'cye',
'late' => 'te',
'lahu' => 'hu',
'irmo' => 'mo',
'iraste' => 'ste',
'irasmo' => 'smo',
'irahu' => 'hu',
'irah' => 'h',
'eknte' => 'eknte',
'eknmo' => 'eknmo',
'ekn' => 'ekn',
'ecyem' => 'cyem',
'dyima' => 'ima',
'diste' => 'iste',
'dismo' => 'ismo',
'dih' => 'ih',
'dga' => 'dga',
'cxku' => 'u',
'cxkom' => 'om',
'cxke' => 'e',
'cxka' => 'a',
'cxenye' => 'e',
'cxak' => 'ak',
'bete' => 'bete',
'besx' => 'besx',
'bemo' => 'bemo',
'ato' => 'o',
'aru' => 'u',
'are' => 'e',
'ami' => 'i',
'ame' => 'e',
'acyi' => '',
'zxivsxi' => 'ivsxi',
'zxisxe' => 'isxe',
'zxiste' => 'iste',
'zxismo' => 'ismo',
'yasx' => 'sx',
'xnyenye' => 'xnyenye',
'xiti' => 'iti',
'xit' => 'it',
'xio' => 'io',
'xilo' => 'ilo',
'xili' => 'ili',
'xile' => 'ile',
'xila' => 'ila',
'xicyu' => 'icyu',
'xicyete' => 'icyete',
'xicyesx' => 'icyesx',
'xicyemo' => 'icyemo',
'xicye' => 'icye',
'ukute' => 'ute',
'ukusx' => 'kusx',
'ukumo' => 'umo',
'tute' => 'ute',
'tumo' => 'umo',
'tanyu' => 'u',
'stima' => 'tima',
'skomu' => 'omu',
'skoj' => 'oj',
'skoga' => 'oga',
'skog' => 'og',
'skim' => 'im',
'skih' => 'ih',
'sete' => 'e',
'sesx' => 'sesx',
'semo' => 'semo',
'sano' => 'no',
'sani' => 'ni',
'sane' => 'ne',
'sana' => 'ana',
'san' => 'n',
'ruk' => '',
'rucxiti' => 'iti',
'pmo' => 'mo',
'plo' => 'plo',
'pli' => 'li',
'ple' => 'le',
'pla' => 'pla',
'ovomu' => 'omu',
'ovoj' => 'oj',
'ovoga' => 'oga',
'ovog' => 'og',
'ovim' => 'im',
'ovih' => 'ih',
'ogo' => 'o',
'nuvsxi' => 'uvsxi',
'nuto' => 'uto',
'nuta' => 'uta',
'nusxe' => 'usxe',
'nuste' => 'uste',
'nusmo' => 'usmo',
'nuh' => 'uh',
'lovima' => 'ima',
'lovi' => 'i',
'loj' => 'oj',
'loga' => 'ga',
'log' => 'g',
'kou' => 'u',
'koi' => 'i',
'koe' => 'e',
'koa' => 'a',
'jelu' => 'u',
'jelom' => 'om',
'isxom' => 'om',
'isxima' => 'ima',
'isxa' => 'a',
'is' => '',
'iruku' => 'iruku',
'irukomu' => 'irukomu',
'irukom' => 'irukom',
'irukoj' => 'irukoj',
'irukoga' => 'irukoga',
'irukog' => 'irukog',
'iruko' => 'iruko',
'irukim' => 'irukim',
'irukih' => 'irukih',
'iruki' => 'iruki',
'iruke' => 'iruke',
'iruka' => 'iruka',
'iruk' => 'iruk',
'irucxte' => 'irucxte',
'irucxmo' => 'irucxmo',
'irucxiti' => 'irucxiti',
'irucxite' => 'irucxite',
'irucxit' => 'irucxit',
'irucxisx' => 'irucxisx',
'irucxio' => 'irucxio',
'irucximo' => 'irucximo',
'irucxim' => 'irucxim',
'irucxilo' => 'irucxilo',
'irucxili' => 'irucxili',
'irucxile' => 'irucxile',
'irucxila' => 'irucxila',
'irucxicyu' => 'irucxicyu',
'irucxicyete' => 'irucxicyete',
'irucxicyesx' => 'irucxicyesx',
'irucxicyemo' => 'irucxicyemo',
'irucxicye' => 'irucxicye',
'irucxi' => 'irucxi',
'irucxeno' => 'irucxeno',
'irucxeni' => 'irucxeni',
'irucxene' => 'irucxene',
'irucxena' => 'irucxena',
'irucxen' => 'irucxen',
'irucxe' => 'irucxe',
'irucx' => 'irucx',
'irte' => 'te',
'irati' => 'ti',
'irat' => 't',
'irani' => 'ni',
'irane' => 'ne',
'ir' => '',
'ilyeno' => 'yeno',
'ilyeni' => 'yeni',
'ilyene' => 'yene',
'ilyena' => 'yena',
'ilyen' => 'yen',
'ijima' => 'jima',
'gute' => 'gute',
'gumo' => 'gumo',
'eu' => 'u',
'enu' => 'u',
'dyusx' => 'dyusx',
'dyte' => 'dyte',
'dymo' => 'dymo',
'dy' => '',
'divsxi' => 'ivsxi',
'cyenya' => 'a',
'cxima' => 'ima',
'cetu' => 'etu',
'cetom' => 'etom',
'ceta' => 'eta',
'cadima' => 'adima',
'cadi' => 'adi',
'cad' => 'ad',
'beno' => 'o',
'bena' => 'a',
'ben' => 'ben',
'arom' => 'om',
'ari' => 'i',
'amu' => 'u',
'amom' => 'om',
'acxa' => 'a',
'zasxe' => 'asxe',
'zaste' => 'aste',
'zasmo' => 'asmo',
'zao' => 'o',
'zah' => 'ah',
'yi' => '',
'yate' => 'te',
'yamo' => 'mo',
'yam' => 'm',
'xom' => '',
'venye' => 'e',
'tanya' => 'a',
'sxiti' => 'iti',
'sxit' => 'it',
'sxio' => 'io',
'sxilo' => 'ilo',
'sxili' => 'ili',
'sxile' => 'ile',
'sxila' => 'ila',
'sxicyu' => 'icyu',
'sxicyete' => 'icyete',
'sxicyesx' => 'icyesx',
'sxicyemo' => 'icyemo',
'sxicye' => 'icye',
'stomu' => 'omu',
'stoj' => 'oj',
'stoga' => 'oga',
'stog' => 'og',
'ovete' => 'ovete',
'ovesx' => 'ovesx',
'ovemo' => 'ovemo',
'ovem' => 'ovem',
'ok' => 'k',
'ocyu' => 'u',
'ocyi' => 'i',
'ocyete' => 'cyete',
'ocyesx' => 'cyesx',
'ocyemo' => 'cyemo',
'ocye' => 'e',
'ocy' => '',
'lamo' => 'mo',
'kovu' => 'u',
'kovomu' => 'omu',
'kovom' => 'om',
'kovoj' => 'oj',
'kovoga' => 'oga',
'kovog' => 'og',
'kovo' => 'o',
'kovim' => 'im',
'kovih' => 'ih',
'isxte' => 'xte',
'isi' => 'i',
'ise' => 'e',
'irucxivsxi' => 'irucxivsxi',
'irucxisxe' => 'irucxisxe',
'irucxiste' => 'irucxiste',
'irucxismo' => 'irucxismo',
'irucxih' => 'irucxih',
'irite' => 'ite',
'irimo' => 'imo',
'irije' => 'irije',
'irem' => 'em',
'irano' => 'no',
'irana' => 'na',
'iralo' => 'lo',
'irali' => 'li',
'irale' => 'le',
'irala' => 'la',
'ikavsxi' => 'vsxi',
'ikati' => 'i',
'ikat' => '',
'ikasxe' => 'sxe',
'ikaste' => 'ste',
'ikasmo' => 'smo',
'ikano' => 'no',
'ikani' => 'ni',
'ikane' => 'ne',
'ikana' => 'na',
'ikan' => 'n',
'ikalo' => 'lo',
'ikali' => 'li',
'ikale' => 'le',
'ikala' => 'la',
'ikah' => 'h',
'ikacyu' => 'cyu',
'ikacyete' => 'cyete',
'ikacyesx' => 'cyesx',
'ikacyemo' => 'cyemo',
'ikacye' => 'cye',
'gate' => 'te',
'gasx' => 'sx',
'gamo' => 'mo',
'gam' => 'm',
'gaju' => 'ju',
'gajte' => 'jte',
'gajmo' => 'jmo',
'gaj' => 'j',
'eom' => 'om',
'enom' => 'om',
'ei' => 'i',
'ecya' => 'a',
'ea' => 'a',
'dyute' => 'ute',
'dyumo' => 'umo',
'cxenyu' => 'u',
'cxanye' => 'cxanye',
'bosxe' => 'bosxe',
'boste' => 'boste',
'bosmo' => 'bosmo',
'boh' => 'boh',
'beni' => 'i',
'bene' => 'e',
'bao' => 'o',
'azxe' => 'e',
'acy' => '',
'zxa' => 'a',
'zavsxi' => 'vsxi',
'zati' => 'ti',
'zat' => 't',
'zalo' => 'lo',
'zali' => 'li',
'zale' => 'le',
'zala' => 'la',
'zahu' => 'ahu',
'zacyu' => 'cyu',
'zacyete' => 'cyete',
'zacyesx' => 'cyesx',
'zacyemo' => 'cyemo',
'zacye' => 'cye',
'yavsxi' => 'vsxi',
'yati' => 'ti',
'yat' => 't',
'yao' => 'o',
'yano' => 'no',
'yani' => '',
'yane' => 'ne',
'yana' => 'na',
'yan' => 'n',
'yalo' => 'lo',
'yali' => 'li',
'yale' => 'le',
'yala' => 'la',
'yaju' => 'ju',
'yajte' => 'jte',
'yajmo' => 'jmo',
'yaj' => 'j',
'yacyu' => 'cyu',
'yacyete' => 'cyete',
'yacyesx' => 'cyesx',
'yacyemo' => 'cyemo',
'yacye' => 'cye',
'vahu' => 'hu',
'tujucyi' => 'ujucyi',
'tuju' => 'uju',
'tujte' => 'ujte',
'tujmo' => 'ujmo',
'tujete' => 'ujete',
'tujesx' => 'ujesx',
'tujemo' => 'ujemo',
'tujem' => 'ujem',
'tuje' => 'uje',
'tuj' => 'uj',
'ticyi' => 'i',
'ticy' => '',
'tecyi' => 'tecyi',
'tara' => 'ara',
'tar' => 'ar',
'tanyima' => 'ima',
'tanyem' => 'em',
'taca' => 'taca',
'tac' => 'tac',
'sxim' => 'im',
'stosxe' => 'e',
'stoste' => 'stoste',
'stosmo' => 'stosmo',
'stoh' => 'stoh',
'steno' => 'o',
'steni' => 'i',
'stene' => 'e',
'stena' => 'a',
'sten' => 'sten',
'seno' => 'o',
'seni' => 'i',
'sene' => 'e',
'sena' => 'a',
'sen' => 'sen',
'sahu' => 'ahu',
'pvsxi' => 'pvsxi',
'ovite' => 'e',
'ovimo' => 'imo',
'oih' => 'ih',
'ognu' => 'u',
'ognte' => '',
'ognmo' => '',
'ognem' => 'em',
'ogne' => 'e',
'ogn' => '',
'net' => 'et',
'mlyeno' => 'lyeno',
'mlyeni' => 'lyeni',
'mlyene' => 'lyene',
'mlyena' => 'lyena',
'mlyen' => 'lyen',
'mite' => 'ite',
'mimo' => 'imo',
'mim' => 'im',
'lecyu' => 'ecyu',
'lecye' => 'ecye',
'lasx' => 'sx',
'lanye' => 'nye',
'lam' => 'm',
'laju' => 'ju',
'lajte' => 'jte',
'lajmo' => 'jmo',
'laj' => 'j',
'kov' => '',
'koima' => 'ima',
'isxucyi' => 'xucyi',
'isxmo' => 'xmo',
'iresxe' => 'iresxe',
'ilte' => 'te',
'ilmo' => 'mo',
'iliti' => 'iti',
'ilite' => 'ite',
'ilit' => 'it',
'ilisx' => 'isx',
'ilio' => 'io',
'ilimo' => 'imo',
'ilim' => 'im',
'ililo' => 'ilo',
'ilili' => 'ili',
'ilile' => 'ile',
'ilila' => 'ila',
'ilicyu' => 'icyu',
'ilicyete' => 'icyete',
'ilicyesx' => 'icyesx',
'ilicyemo' => 'icyemo',
'ilicye' => 'icye',
'il' => '',
'gujucyi' => 'ujucyi',
'guju' => 'uju',
'gujte' => 'ujte',
'gujmo' => 'ujmo',
'gujete' => 'ujete',
'gujesx' => 'ujesx',
'gujemo' => 'ujemo',
'gujem' => 'ujem',
'guje' => 'uje',
'guj' => 'uj',
'gi' => 'i',
'ganye' => 'nye',
'elye' => 'e',
'eima' => 'ima',
'ecyima' => 'ima',
'dxu' => 'u',
'dxom' => 'om',
'dxo' => 'dxo',
'dxa' => 'a',
'davsxi' => 'vsxi',
'dati' => 'ti',
'date' => 'te',
'dat' => 't',
'dasxe' => 'sxe',
'dasx' => 'sx',
'daste' => 'ste',
'dasmo' => 'smo',
'dao' => 'o',
'dano' => 'no',
'dani' => 'ni',
'dane' => 'ne',
'dana' => 'na',
'dan' => 'n',
'damo' => 'mo',
'dam' => 'm',
'dalo' => 'lo',
'dali' => 'li',
'dale' => 'le',
'dala' => 'la',
'daju' => 'ju',
'dajte' => 'jte',
'dajmo' => 'jmo',
'daj' => 'j',
'dahu' => 'hu',
'dah' => 'h',
'dacyu' => 'cyu',
'dacyete' => 'cyete',
'dacyesx' => 'cyesx',
'dacyemo' => 'cyemo',
'dacye' => 'cye',
'cxomu' => 'cxomu',
'cxoj' => 'cxoj',
'cite' => 'ite',
'cimo' => 'imo',
'bavsxi' => 'vsxi',
'bati' => 'ti',
'bat' => 't',
'basxe' => 'sxe',
'baste' => 'ste',
'basmo' => 'smo',
'bano' => 'no',
'bani' => 'ni',
'bane' => 'ne',
'bana' => 'na',
'ban' => 'n',
'balo' => 'lo',
'bali' => 'li',
'bale' => 'le',
'bala' => 'la',
'bah' => 'h',
'bacyu' => 'cyu',
'bacyete' => 'cyete',
'bacyesx' => 'cyesx',
'bacyemo' => 'cyemo',
'bacye' => 'cye',
'azxu' => 'u',
'azxite' => 'ite',
'azximo' => 'imo',
'azxi' => 'i',
'azxete' => 'zxete',
'azxesx' => 'zxesx',
'azxemo' => 'zxemo',
'azxem' => 'zxem',
'atima' => 'ima',
'atim' => 'im',
'anu' => 'u',
'aly' => '',
'akao' => 'o',
'aih' => 'ih',
'agosxe' => 'gosxe',
'agoste' => 'goste',
'agosmo' => 'gosmo',
'agoh' => 'goh',
'ago' => 'go',
'agavsxi' => 'vsxi',
'adxa' => 'adxa',
'zano' => 'no',
'zani' => 'ni',
'zane' => 'ne',
'zana' => 'na',
'zan' => 'n',
'yem' => '',
'xnye' => 'nye',
'utiju' => 'u',
'utijomu' => 'ijomu',
'utijom' => 'om',
'utijoj' => 'ijoj',
'utijim' => 'ijim',
'utijih' => 'ijih',
'utiji' => 'i',
'utijemu' => 'ijemu',
'utijem' => 'ijem',
'utijega' => 'ijega',
'utijeg' => 'ijeg',
'utije' => 'e',
'utija' => 'a',
'sxisx' => 'isx',
'sxcyeno' => 'xcyeno',
'sxcyeni' => 'xcyeni',
'sxcyene' => 'xcyene',
'sxcyena' => 'xcyena',
'sxcyen' => 'xcyen',
'sivsxi' => 'ivsxi',
'sisxe' => 'isxe',
'siste' => 'iste',
'sismo' => 'ismo',
'reti' => 'eti',
'ranost' => 't',
'pavsxi' => 'vsxi',
'pati' => 'ti',
'pat' => 't',
'pasxe' => 'sxe',
'paste' => 'ste',
'pasmo' => 'smo',
'pao' => 'o',
'pano' => 'no',
'pani' => 'ni',
'pane' => 'ne',
'pana' => 'na',
'pan' => 'n',
'palo' => 'lo',
'pali' => 'li',
'pale' => 'le',
'pala' => 'la',
'pah' => 'h',
'pacyu' => 'cyu',
'pacyete' => 'cyete',
'pacyesx' => 'cyesx',
'pacyemo' => 'cyemo',
'pacye' => 'cye',
'ogosxe' => 'gosxe',
'ogoste' => 'te',
'ogosmo' => 'gosmo',
'ogoh' => 'goh',
'oglo' => '',
'ogli' => '',
'ogle' => '',
'ogla' => '',
'ogavsxi' => 'gavsxi',
'ogao' => '',
'neti' => 'eti',
'neo' => 'eo',
'nelo' => 'elo',
'neli' => 'eli',
'nele' => 'ele',
'nela' => 'ela',
'necyu' => 'ecyu',
'necyete' => 'ecyete',
'necyesx' => 'ecyesx',
'necyemo' => 'ecyemo',
'necye' => 'ecye',
'love' => 'e',
'lovavsxi' => 'ovavsxi',
'lovati' => 'ovati',
'lovat' => 'ovat',
'lovasxe' => 'ovasxe',
'lovaste' => 'ovaste',
'lovasmo' => 'ovasmo',
'lovao' => 'ovao',
'lovano' => 'ovano',
'lovani' => 'ovani',
'lovane' => 'ovane',
'lovana' => 'ovana',
'lovan' => 'ovan',
'lovalo' => 'ovalo',
'lovali' => 'ovali',
'lovale' => 'ovale',
'lovala' => 'ovala',
'lovahu' => 'ovahu',
'lovah' => 'ovah',
'lovacyu' => 'ovacyu',
'lovacyete' => 'ovacyete',
'lovacyesx' => 'ovacyesx',
'lovacyemo' => 'ovacyemo',
'lovacye' => 'ovacye',
'leti' => 'i',
'let' => 't',
'leo' => 'eo',
'lelo' => 'elo',
'leli' => 'eli',
'lele' => 'ele',
'lela' => 'ela',
'lecyete' => 'ecyete',
'lecyesx' => 'ecyesx',
'lecyemo' => 'ecyemo',
'kanyu' => 'u',
'kanyima' => 'ima',
'kanyem' => 'em',
'kanya' => 'a',
'jedyeno' => 'yeno',
'jedyeni' => 'yeni',
'jedyene' => 'yene',
'jedyena' => 'yena',
'jedyen' => 'yen',
'jedte' => 'te',
'jedmo' => 'mo',
'jedite' => 'ite',
'jedisx' => 'isx',
'jedimo' => 'imo',
'jedim' => 'im',
'jedi' => 'i',
'jede' => 'e',
'jed' => '',
'irio' => 'io',
'iricyu' => 'icyu',
'iricye' => 'icye',
'iresx' => 'esx',
'iravsxi' => 'vsxi',
'irao' => 'o',
'iranosxcyu' => 'iranosxcyu',
'iranostima' => 'iranostima',
'iranosti' => 'iranosti',
'iran' => 'n',
'iracyu' => 'cyu',
'iracyete' => 'cyete',
'iracyesx' => 'cyesx',
'iracyemo' => 'cyemo',
'iracye' => 'cye',
'ilivsxi' => 'ilivsxi',
'ilisxe' => 'ilisxe',
'iliste' => 'iliste',
'ilismo' => 'ilismo',
'ilih' => 'ilih',
'ici' => 'i',
'govavsxi' => 'ovavsxi',
'govati' => 'ovati',
'govat' => 'ovat',
'govasxe' => 'ovasxe',
'govaste' => 'ovaste',
'govasmo' => 'ovasmo',
'govao' => 'ovao',
'govano' => 'ovano',
'govani' => 'ovani',
'govane' => 'ovane',
'govana' => 'ovana',
'govan' => 'ovan',
'govalo' => 'ovalo',
'govali' => 'ovali',
'govale' => 'ovale',
'govala' => 'ovala',
'govahu' => 'ovahu',
'govah' => 'ovah',
'govacyu' => 'ovacyu',
'govacyete' => 'ovacyete',
'govacyesx' => 'ovacyesx',
'govacyemo' => 'ovacyemo',
'govacye' => 'ovacye',
'ezxe' => 'e',
'etima' => 'ima',
'eju' => 'u',
'dxi' => 'i',
'dxe' => 'e',
'dxama' => 'ama',
'cxeg' => 'cxeg',
'cavsxi' => 'vsxi',
'cati' => 'ti',
'cat' => 't',
'casxe' => 'sxe',
'caste' => 'ste',
'casmo' => 'smo',
'cacyu' => 'cyu',
'cacyete' => 'cyete',
'cacyesx' => 'cyesx',
'cacyemo' => 'cyemo',
'cacye' => 'cye',
'amama' => 'ama',
'aknuvsxi' => 'uvsxi',
'aknuto' => 'uto',
'aknuti' => 'uti',
'aknute' => 'ute',
'aknuta' => 'uta',
'aknut' => 'ut',
'aknusxe' => 'usxe',
'aknusx' => '',
'aknuste' => 'uste',
'aknusmo' => 'usmo',
'aknuo' => 'uo',
'aknumo' => '',
'aknulo' => 'ulo',
'aknuli' => 'uli',
'aknule' => 'ule',
'aknula' => 'ula',
'aknuh' => 'uh',
'aknucyu' => 'ucyu',
'aknucyete' => 'ucyete',
'aknucyesx' => 'ucyesx',
'aknucyemo' => 'ucyemo',
'aknucye' => 'ucye',
'aknu' => 'u',
'aknte' => 'te',
'aknmo' => 'mo',
'aknite' => 'ite',
'aknimo' => 'imo',
'akni' => 'i',
'aknete' => 'ete',
'aknesx' => 'esx',
'aknemo' => 'emo',
'aknem' => 'em',
'akne' => 'e',
'akn' => '',
'aklo' => 'lo',
'akli' => 'i',
'akle' => 'e',
'akla' => 'la',
'aje' => 'e',
'zxenyu' => 'u',
'z' => '',
'yte' => 'te',
'ymo' => 'mo',
'yanye' => 'nye',
'xivsxi' => 'ivsxi',
'xih' => 'ih',
'xenyima' => 'ima',
'xenyem' => 'em',
'xenya' => 'a',
'xavsxi' => '',
'xati' => '',
'xat' => '',
'xao' => '',
'xano' => '',
'xani' => '',
'xane' => '',
'xana' => '',
'xan' => '',
'xalo' => '',
'xali' => '',
'xale' => '',
'xala' => '',
'xacyu' => '',
'xacyete' => '',
'xacyesx' => '',
'xacyemo' => '',
'xacye' => '',
'unu' => 'u',
'unte' => 'te',
'unmo' => 'mo',
'unete' => 'ete',
'unesx' => 'esx',
'unemo' => 'emo',
'unem' => 'em',
'une' => 'e',
'un' => '',
'ucxete' => 'cxete',
'ucxemo' => 'cxemo',
'tovavsxi' => 'ovavsxi',
'tovati' => 'ovati',
'tovat' => 'ovat',
'tovasxe' => 'ovasxe',
'tovaste' => 'ovaste',
'tovasmo' => 'ovasmo',
'tovao' => 'ovao',
'tovano' => 'ovano',
'tovani' => 'ovani',
'tovane' => 'ovane',
'tovana' => 'ovana',
'tovan' => 'ovan',
'tovalo' => 'ovalo',
'tovali' => 'ovali',
'tovale' => 'ovale',
'tovala' => 'ovala',
'tovahu' => 'ovahu',
'tovah' => 'ovah',
'tovacyu' => 'ovacyu',
'tovacyete' => 'ovacyete',
'tovacyesx' => 'ovacyesx',
'tovacyemo' => 'ovacyemo',
'tovacye' => 'ovacye',
'tilu' => 'u',
'tilom' => 'tilom',
'tilima' => 'tilima',
'tero' => 'tero',
'tega' => 'tega',
'taku' => 'ku',
'takom' => 'kom',
'take' => 'ke',
'tacxe' => 'e',
'tacima' => 'cima',
'taci' => 'ci',
'sxivsxi' => 'ivsxi',
'sticyu' => 'ticyu',
'sticyete' => 'ticyete',
'sticyesx' => 'ticyesx',
'sticyemo' => 'ticyemo',
'sticye' => 'ticye',
'sosxe' => 'sosxe',
'soste' => 'soste',
'sosmo' => 'sosmo',
'soh' => 'soh',
'rugati' => 'rugati',
'rate' => 'te',
'rasx' => 'sx',
'oh' => 'oh',
'ognute' => 'ute',
'ognusx' => '',
'ognumo' => '',
'nyeti' => 'yeti',
'nyasxe' => 'yasxe',
'nyaste' => 'yaste',
'nyasmo' => 'yasmo',
'nyahu' => 'yahu',
'nyah' => 'yah',
'nije' => '',
'miti' => 'iti',
'mit' => 'it',
'misx' => 'isx',
'mio' => 'io',
'milo' => 'ilo',
'mili' => 'ili',
'mile' => 'ile',
'mila' => 'ila',
'micyu' => 'icyu',
'micyete' => 'icyete',
'micyesx' => 'icyesx',
'micyemo' => 'icyemo',
'micye' => 'icye',
'lyeti' => 'yeti',
'lyete' => 'te',
'lyet' => 'yet',
'lyesx' => 'esx',
'lyenyima' => 'ima',
'lyenyem' => 'em',
'lyemo' => 'emo',
'lyelo' => 'yelo',
'lyeli' => 'yeli',
'lyele' => 'yele',
'lyela' => 'yela',
'lyecyu' => 'yecyu',
'lyecyete' => 'yecyete',
'lyecyesx' => 'yecyesx',
'lyecyemo' => 'yecyemo',
'lyecye' => 'yecye',
'lacxu' => 'u',
'lacxite' => 'ite',
'lacximo' => 'imo',
'lacxi' => 'i',
'lacxete' => 'cxete',
'lacxemo' => 'cxemo',
'lacxem' => 'cxem',
'lacxe' => 'e',
'iviju' => 'iju',
'ivijomu' => 'ijomu',
'ivijom' => 'ijom',
'ivijoj' => 'ijoj',
'ivijim' => 'ijim',
'ivijih' => 'ijih',
'iviji' => 'iji',
'ivijemu' => 'ijemu',
'ivijem' => 'ijem',
'ivijega' => 'ijega',
'ivijeg' => 'ijeg',
'ivije' => 'ije',
'ivija' => 'ija',
'ivate' => 'te',
'ivamo' => 'mo',
'ivajte' => 'jte',
'ivajmo' => 'jmo',
'ivaj' => 'j',
'itima' => 'ima',
'isu' => 'u',
'isom' => 'om',
'iruje' => 'uje',
'irugavsxi' => 'irugavsxi',
'irugati' => 'irugati',
'irugat' => 'irugat',
'irugasxe' => 'irugasxe',
'irugaste' => 'irugaste',
'irugasmo' => 'irugasmo',
'irugao' => 'irugao',
'irugano' => 'irugano',
'irugani' => 'irugani',
'irugane' => 'irugane',
'irugana' => 'irugana',
'irugan' => 'irugan',
'irugalo' => 'irugalo',
'irugali' => 'irugali',
'irugale' => 'irugale',
'irugala' => 'irugala',
'irugah' => 'irugah',
'irugacyu' => 'irugacyu',
'irugacyete' => 'irugacyete',
'irugacyesx' => 'irugacyesx',
'irugacyemo' => 'irugacyemo',
'irugacye' => 'irugacye',
'iruga' => 'iruga',
'irom' => 'om',
'irim' => 'im',
'irih' => 'ih',
'iricyete' => 'icyete',
'iricyesx' => 'icyesx',
'iricyemo' => 'icyemo',
'ireti' => 'ireti',
'iret' => 'iret',
'ireste' => 'ireste',
'iresmo' => 'iresmo',
'iremo' => 'emo',
'ireli' => 'ireli',
'irele' => 'irele',
'irecyu' => 'irecyu',
'igao' => 'o',
'icima' => 'cima',
'esxite' => 'xite',
'esximo' => 'ximo',
'esxi' => 'i',
'est' => 'st',
'enije' => 'e',
'ejte' => 'ejte',
'ejmo' => 'ejmo',
'ej' => 'ej',
'ehu' => 'hu',
'dyom' => 'om',
'dyi' => 'i',
'dyasxe' => 'yasxe',
'dyaste' => 'yaste',
'dyasmo' => 'yasmo',
'dyahu' => 'yahu',
'dyah' => 'yah',
'deo' => 'eo',
'cxucyi' => 'cxucyi',
'cao' => 'o',
'cano' => 'no',
'cani' => 'ni',
'cane' => 'ne',
'cana' => 'na',
'can' => 'n',
'calo' => 'lo',
'cali' => 'li',
'cale' => 'le',
'cala' => 'la',
'cahu' => 'hu',
'cah' => 'h',
'bahu' => 'hu',
'avanye' => 'e',
'av' => '',
'atama' => 'ama',
'arima' => 'ima',
'anom' => 'om',
'anama' => 'ama',
'aji' => 'i',
'zxenye' => 'e',
'yuju' => '',
'yujete' => '',
'yujesx' => '',
'yujemo' => '',
'yujem' => '',
'yuje' => '',
'yom' => '',
'yete' => '',
'yemo' => '',
'yaka' => 'ka',
'yak' => 'k',
'xo' => '',
'xnyacxe' => 'cxe',
'xdyeno' => 'xdyeno',
'xdyeni' => 'xdyeni',
'xdyene' => 'xdyene',
'xdyena' => 'xdyena',
'xdyen' => 'xdyen',
'xate' => '',
'xasx' => '',
'xamo' => '',
'xama' => '',
'xam' => '',
'vim' => 'im',
'vih' => 'ih',
'vate' => 'te',
'tma' => 'ma',
'tije' => 'e',
'temu' => 'u',
'teg' => 'teg',
'sxevima' => 'xevima',
'sxevi' => 'xevi',
'sxeve' => 'xeve',
'sxeva' => 'xeva',
'sxavsxi' => 'vsxi',
'stiti' => 'titi',
'stit' => 'tit',
'stisxe' => 'tisxe',
'stisx' => 'tisx',
'stiste' => 'tiste',
'stismo' => 'tismo',
'stio' => 'tio',
'stilo' => 'tilo',
'stili' => 'tili',
'stile' => 'tile',
'stila' => 'tila',
'rucxavati' => 'rucxavati',
'romu' => 'u',
'roj' => '',
'roga' => 'oga',
'rog' => 'og',
'rirati' => 'ti',
'ricyi' => 'i',
'rgnuti' => 'uti',
'racija' => 'a',
'pite' => 'ite',
'pimo' => 'imo',
'omi' => 'i',
'olyu' => 'u',
'olyite' => 'ite',
'olyimo' => 'imo',
'olyi' => 'i',
'olyete' => 'olyete',
'olyesx' => 'olyesx',
'olyemo' => 'olyemo',
'olyem' => 'em',
'olye' => 'e',
'ogu' => 'gu',
'ogom' => 'gom',
'oge' => 'ge',
'lyiv' => '',
'lute' => 'ute',
'lumo' => 'umo',
'lujucyi' => 'ujucyi',
'luju' => 'uju',
'lujte' => 'ujte',
'lujmo' => 'ujmo',
'lujete' => 'ujete',
'lujesx' => 'ujesx',
'lujemo' => 'ujemo',
'lujem' => 'ujem',
'luje' => 'uje',
'luj' => 'uj',
'jeveno' => 'jeveno',
'jeveni' => 'jeveni',
'jevene' => 'jevene',
'jevena' => 'jevena',
'jeven' => 'jeven',
'jelim' => 'im',
'ivasx' => 'sx',
'ivam' => 'm',
'ivaju' => 'ju',
'itije' => 'ije',
'isima' => 'ima',
'iruju' => 'uju',
'irucxavavsxi' => 'irucxavavsxi',
'irucxavati' => 'irucxavati',
'irucxavat' => 'irucxavat',
'irucxavasxe' => 'irucxavasxe',
'irucxavaste' => 'irucxavaste',
'irucxavasmo' => 'irucxavasmo',
'irucxavao' => 'irucxavao',
'irucxavano' => 'irucxavano',
'irucxavani' => 'irucxavani',
'irucxavane' => 'irucxavane',
'irucxavana' => 'irucxavana',
'irucxavan' => 'irucxavan',
'irucxavalo' => 'irucxavalo',
'irucxavali' => 'irucxavali',
'irucxavale' => 'irucxavale',
'irucxavala' => 'irucxavala',
'irucxavahu' => 'irucxavahu',
'irucxavah' => 'irucxavah',
'irucxavacyu' => 'irucxavacyu',
'irucxavacyete' => 'irucxavacyete',
'irucxavacyesx' => 'irucxavacyesx',
'irucxavacyemo' => 'irucxavacyemo',
'irucxavacye' => 'irucxavacye',
'irucxava' => 'irucxava',
'iroj' => 'iroj',
'irisx' => 'isx',
'iriravsxi' => 'iriravsxi',
'irirati' => 'irirati',
'irirate' => 'irirate',
'irirat' => 'irirat',
'irirasxe' => 'irirasxe',
'irirasx' => 'irirasx',
'iriraste' => 'iriraste',
'irirasmo' => 'irirasmo',
'irirao' => 'irirao',
'irirano' => 'irirano',
'irirani' => 'irirani',
'irirane' => 'irirane',
'irirana' => 'irirana',
'iriran' => 'iriran',
'iriramo' => 'iriramo',
'iriram' => 'iriram',
'iriralo' => 'iriralo',
'irirali' => 'irirali',
'irirale' => 'irirale',
'irirala' => 'irirala',
'irirajucyi' => 'irirajucyi',
'iriraju' => 'iriraju',
'irirajte' => 'irirajte',
'irirajmo' => 'irirajmo',
'iriraj' => 'iriraj',
'irirahu' => 'irirahu',
'irirah' => 'irirah',
'iriracyu' => 'iriracyu',
'iriracyete' => 'iriracyete',
'iriracyesx' => 'iriracyesx',
'iriracyemo' => 'iriracyemo',
'iriracye' => 'iriracye',
'irira' => 'irira',
'irijesxe' => 'irijesxe',
'irijeli' => 'irijeli',
'irijele' => 'irijele',
'irevsxi' => 'irevsxi',
'irete' => 'ete',
'ireo' => 'ireo',
'irelo' => 'irelo',
'irela' => 'irela',
'ireh' => 'ireh',
'irecyete' => 'irecyete',
'irecyesx' => 'irecyesx',
'irecyemo' => 'irecyemo',
'irecye' => 'irecye',
'iranim' => 'iranim',
'iranih' => 'iranih',
'iraciju' => 'iraciju',
'iracijom' => 'iracijom',
'iracijo' => 'iracijo',
'iraciji' => 'iraciji',
'iracije' => 'iracije',
'iracijama' => 'iracijama',
'iracija' => 'iracija',
'iku' => 'ku',
'ikom' => 'kom',
'ike' => 'ke',
'ikahu' => 'kahu',
'iglo' => 'lo',
'igli' => 'li',
'igle' => 'le',
'igla' => 'la',
'icavsxi' => 'avsxi',
'icati' => 'ati',
'icat' => 'at',
'icasxe' => 'asxe',
'icaste' => 'aste',
'icasmo' => 'asmo',
'icao' => 'ao',
'icano' => 'ano',
'icani' => 'ani',
'icane' => 'ane',
'icana' => 'ana',
'ican' => 'an',
'icalo' => 'alo',
'icali' => 'ali',
'icale' => 'ale',
'icala' => 'ala',
'icah' => 'ah',
'icacyu' => 'acyu',
'icacyete' => 'acyete',
'icacyesx' => 'acyesx',
'icacyemo' => 'acyemo',
'icacye' => 'acye',
'ica' => 'a',
'ezxu' => 'xu',
'ezxite' => 'xite',
'ezximo' => 'ximo',
'ezxi' => 'i',
'ezxete' => 'xete',
'ezxesx' => 'xesx',
'ezxemo' => 'xemo',
'ezxem' => 'xem',
'esxeno' => 'xeno',
'esxeni' => 'xeni',
'esxene' => 'xene',
'esxena' => 'xena',
'esxen' => 'xen',
'esti' => 'sti',
'era' => 'a',
'enim' => 'im',
'enih' => 'ih',
'elyu' => 'u',
'elyeno' => 'yeno',
'elyeni' => 'yeni',
'elyene' => 'yene',
'elyena' => 'yena',
'elyen' => 'yen',
'elyem' => 'em',
'elte' => 'te',
'elmo' => 'mo',
'elite' => 'ite',
'elisx' => 'isx',
'elio' => 'io',
'elimo' => 'imo',
'el' => '',
'egati' => 'gati',
'egat' => 'gat',
'egasxe' => 'gasxe',
'egaste' => 'gaste',
'egasmo' => 'gasmo',
'egano' => 'gano',
'egani' => 'gani',
'egane' => 'gane',
'egana' => 'gana',
'egan' => 'gan',
'egalo' => 'galo',
'egali' => 'gali',
'egale' => 'gale',
'egala' => 'gala',
'egah' => 'gah',
'egacyu' => 'gacyu',
'egacyete' => 'gacyete',
'egacyesx' => 'gacyesx',
'egacyemo' => 'gacyemo',
'egacye' => 'gacye',
'dyoste' => 'dyoste',
'dyosmo' => 'dyosmo',
'dyoh' => 'dyoh',
'dyite' => 'dyite',
'dyimo' => 'dyimo',
'dujite' => 'ujite',
'dujimo' => 'ujimo',
'duji' => 'uji',
'delo' => 'elo',
'deli' => 'eli',
'dele' => 'ele',
'dela' => 'ela',
'cyom' => 'om',
'cyo' => 'o',
'cyenyu' => 'u',
'cyenyima' => 'ima',
'cyenyem' => 'em',
'cyama' => 'ama',
'cxicyom' => 'om',
'cxicyima' => 'ima',
'cxicyi' => 'i',
'cxicya' => 'a',
'cxicy' => '',
'c' => '',
'bate' => 'te',
'basx' => 'sx',
'banye' => 'nye',
'bamo' => 'mo',
'bam' => 'm',
'baju' => 'ju',
'bajte' => 'jte',
'bajmo' => 'jmo',
'baj' => 'j',
'b' => '',
'atomu' => 'omu',
'atoj' => 'oj',
'atoga' => 'oga',
'atog' => 'og',
'atih' => 'ih',
'aha' => 'ha',
'acxu' => 'u',
'acxi' => 'i',
'zxom' => 'om',
'zxama' => 'ama',
'zicyu' => 'icyu',
'zicyete' => 'icyete',
'zicyesx' => 'icyesx',
'zicyemo' => 'icyemo',
'zicye' => 'icye',
'zate' => 'te',
'zasx' => 'sx',
'zamo' => 'mo',
'zam' => 'm',
'zaju' => 'ju',
'zajte' => 'jte',
'zajmo' => 'jmo',
'zaj' => 'j',
'yite' => '',
'yimo' => '',
'yanya' => 'a',
'xlyedniku' => 'xlyedniku',
'xlyednikom' => 'xlyednikom',
'xlyednike' => 'xlyednike',
'xlyednika' => 'xlyednika',
'xlyednik' => 'xlyednik',
'xlyednicxe' => 'xlyednicxe',
'xlyednicima' => 'xlyednicima',
'xlyednici' => 'xlyednici',
'xisxe' => 'xe',
'xiste' => 'iste',
'xismo' => 'ismo',
'xcima' => 'cima',
'xci' => 'ci',
'xanye' => '',
'xaju' => '',
'xajte' => '',
'xajmo' => '',
'xaj' => '',
'voj' => '',
'vog' => 'og',
'vasx' => 'sx',
'vamo' => 'mo',
'vam' => 'm',
'uvenyu' => 'uvenyu',
'uveno' => 'veno',
'uveni' => 'veni',
'uvene' => 'vene',
'uvena' => 'vena',
'uven' => 'ven',
'ujucyiu' => 'u',
'ujucyiomu' => 'omu',
'ujucyiom' => 'om',
'ujucyioj' => 'oj',
'ujucyim' => 'm',
'ujucyih' => 'h',
'ujucyiemu' => 'emu',
'ujucyiem' => 'em',
'ujucyiega' => 'ega',
'ujucyieg' => 'eg',
'ujucyie' => 'e',
'ujucyia' => 'a',
'tkomu' => 'komu',
'tkoj' => 'koj',
'tkoga' => 'koga',
'tkog' => 'kog',
'tkim' => 'kim',
'tkih' => 'kih',
'tki' => 'ki',
'ticyom' => 'om',
'ticyima' => 'ima',
'ticya' => 'a',
'sxto' => 'to',
'stivsxi' => 'tivsxi',
'stenyu' => 'u',
'stavsxi' => 'vsxi',
'stati' => 'ti',
'stat' => 't',
'stasxe' => 'sxe',
'staste' => 'ste',
'stasmo' => 'smo',
'stao' => 'o',
'stano' => 'no',
'stani' => 'ni',
'stane' => 'ne',
'stana' => 'na',
'stan' => 'n',
'stalo' => 'lo',
'stali' => 'li',
'stale' => 'le',
'stala' => 'la',
'stah' => 'h',
'stacyu' => 'cyu',
'stacyete' => 'cyete',
'stacyesx' => 'cyesx',
'stacyemo' => 'cyemo',
'stacye' => 'cye',
'sovima' => 'ovima',
'sovi' => 'ovi',
'sove' => 'ove',
'sova' => 'ova',
'ruirati' => 'ruirati',
'rsxe' => 'sxe',
'rste' => 'te',
'rsmo' => 'mo',
'rovati' => 'ovati',
'rojiti' => 'iti',
'rijeti' => 'ijeti',
'rija' => 'a',
'rgnute' => 'ute',
'rgnu' => 'u',
'rgnte' => '',
'rgnmo' => '',
'rgnem' => 'em',
'rgne' => 'e',
'rgn' => '',
'rglo' => 'lo',
'rgli' => 'li',
'rgle' => 'le',
'rgla' => 'la',
'rgao' => 'o',
'rcyu' => 'cyu',
'rcyi' => 'cyi',
'rcyete' => 'cyete',
'rcyesx' => 'cyesx',
'rcyemo' => 'cyemo',
'rcye' => 'cye',
'rcy' => 'cy',
'rasxiti' => 'iti',
'ranye' => 'nye',
'plyeno' => 'lyeno',
'plyeni' => 'lyeni',
'plyene' => 'lyene',
'plyena' => 'lyena',
'plyen' => 'lyen',
'pku' => 'ku',
'pkom' => 'kom',
'pke' => 'ke',
'pka' => 'ka',
'pate' => 'te',
'pasx' => 'sx',
'pamo' => 'mo',
'pam' => 'm',
'paju' => 'ju',
'pajte' => 'jte',
'pajmo' => 'jmo',
'paj' => 'j',
'oom' => 'om',
'nyeli' => 'yeli',
'nevsxi' => 'evsxi',
'nesxe' => 'esxe',
'neste' => 'este',
'nesmo' => 'esmo',
'neh' => 'eh',
'mih' => 'ih',
'lyednik' => 'lyednik',
'lyanye' => 'nye',
'licyi' => 'i',
'levsxi' => 'evsxi',
'lesxe' => 'esxe',
'leste' => 'este',
'lesmo' => 'esmo',
'leh' => 'eh',
'kome' => 'ome',
'koama' => 'koama',
'kiju' => 'ju',
'kijomu' => 'ijomu',
'kijom' => 'jom',
'kijoj' => 'ijoj',
'kijim' => 'ijim',
'kijih' => 'ijih',
'kiji' => 'ji',
'kijemu' => 'ijemu',
'kijem' => 'ijem',
'kijega' => 'ijega',
'kijeg' => 'ijeg',
'kije' => 'je',
'kija' => 'ja',
'jesu' => 'u',
'jesete' => '',
'jesesx' => '',
'jesemo' => '',
'jesem' => '',
'jese' => 'e',
'jes' => '',
'jelomu' => 'omu',
'jeloj' => 'oj',
'jeloga' => 'oga',
'jelog' => 'og',
'jelima' => 'ima',
'jelih' => 'ih',
'jedyasxe' => 'yasxe',
'jedyaste' => 'yaste',
'jedyasmo' => 'yasmo',
'jedyahu' => 'yahu',
'jedyah' => 'yah',
'itiju' => 'iju',
'itijomu' => 'ijomu',
'itijom' => 'ijom',
'itijoj' => 'ijoj',
'itijim' => 'ijim',
'itijih' => 'ijih',
'itiji' => 'iji',
'itijemu' => 'ijemu',
'itijem' => 'ijem',
'itijega' => 'ijega',
'itijeg' => 'ijeg',
'itija' => 'ija',
'istu' => 'u',
'istom' => 'om',
'istima' => 'ima',
'isti' => 'i',
'ista' => 'a',
'ist' => '',
'irujete' => 'ujete',
'irujesx' => 'ujesx',
'irujemo' => 'ujemo',
'irujem' => 'ujem',
'iruiravsxi' => 'iruiravsxi',
'iruirati' => 'iruirati',
'iruirate' => 'iruirate',
'iruirat' => 'iruirat',
'iruirasxe' => 'iruirasxe',
'iruirasx' => 'iruirasx',
'iruiraste' => 'iruiraste',
'iruirasmo' => 'iruirasmo',
'iruirao' => 'iruirao',
'iruirano' => 'iruirano',
'iruirani' => 'iruirani',
'iruirane' => 'iruirane',
'iruirana' => 'iruirana',
'iruiran' => 'iruiran',
'iruiramo' => 'iruiramo',
'iruiram' => 'iruiram',
'iruiralo' => 'iruiralo',
'iruirali' => 'iruirali',
'iruirale' => 'iruirale',
'iruirala' => 'iruirala',
'iruiraju' => 'iruiraju',
'iruirajte' => 'iruirajte',
'iruirajmo' => 'iruirajmo',
'iruiraj' => 'iruiraj',
'iruirahu' => 'iruirahu',
'iruirah' => 'iruirah',
'iruiracyu' => 'iruiracyu',
'iruiracyete' => 'iruiracyete',
'iruiracyesx' => 'iruiracyesx',
'iruiracyemo' => 'iruiracyemo',
'iruiracye' => 'iruiracye',
'iruira' => 'iruira',
'irugate' => 'irugate',
'irugasx' => 'irugasx',
'irugamo' => 'irugamo',
'irugam' => 'irugam',
'irugaju' => 'irugaju',
'irugajte' => 'irugajte',
'irugajmo' => 'irugajmo',
'irugaj' => 'irugaj',
'irucxuju' => 'irucxuju',
'irucxujite' => 'irucxujite',
'irucxujimo' => 'irucxujimo',
'irucxuji' => 'irucxuji',
'irucxujete' => 'irucxujete',
'irucxujesx' => 'irucxujesx',
'irucxujemo' => 'irucxujemo',
'irucxujem' => 'irucxujem',
'irucxuje' => 'irucxuje',
'iro' => 'o',
'irisxe' => 'isxe',
'iriste' => 'iste',
'irismo' => 'ismo',
'iriju' => 'iriju',
'irijom' => 'irijom',
'iriji' => 'iriji',
'irijevsxi' => 'irijevsxi',
'irijeti' => 'irijeti',
'irijet' => 'irijet',
'irijeste' => 'irijeste',
'irijesmo' => 'irijesmo',
'irijelo' => 'irijelo',
'irijela' => 'irijela',
'irijeh' => 'irijeh',
'irijecyu' => 'irijecyu',
'irijecyete' => 'irijecyete',
'irijecyesx' => 'irijecyesx',
'irijecyemo' => 'irijecyemo',
'irijecye' => 'irijecye',
'irija' => 'irija',
'iricyi' => 'i',
'iricy' => '',
'irante' => 'irante',
'irada' => 'irada',
'inu' => 'u',
'inomu' => 'omu',
'inom' => 'om',
'inoj' => 'oj',
'inoga' => 'oga',
'inog' => 'og',
'ino' => 'o',
'inim' => 'im',
'inih' => 'ih',
'ini' => 'i',
'ine' => 'e',
'ina' => 'a',
'ilyivu' => 'ilyivu',
'ilyivomu' => 'ilyivomu',
'ilyivom' => 'ilyivom',
'ilyivoj' => 'ilyivoj',
'ilyivoga' => 'ilyivoga',
'ilyivog' => 'ilyivog',
'ilyivo' => 'ilyivo',
'ilyivim' => 'ilyivim',
'ilyivih' => 'ilyivih',
'ilyivi' => 'ilyivi',
'ilyive' => 'ilyive',
'ilyiva' => 'ilyiva',
'ilyiv' => 'ilyiv',
'ilama' => 'ama',
'iknuvsxi' => 'uvsxi',
'iknuto' => 'uto',
'iknuti' => 'uti',
'iknute' => 'ute',
'iknuta' => 'uta',
'iknut' => 'ut',
'iknusxe' => 'usxe',
'iknuste' => 'uste',
'iknusmo' => 'usmo',
'iknuo' => 'uo',
'iknulo' => 'ulo',
'iknuli' => 'uli',
'iknule' => 'ule',
'iknula' => 'ula',
'iknuh' => 'uh',
'iknucyu' => 'ucyu',
'iknucyete' => 'ucyete',
'iknucyesx' => 'ucyesx',
'iknucyemo' => 'ucyemo',
'iknucye' => 'ucye',
'iknu' => 'u',
'iknite' => 'ite',
'iknimo' => 'imo',
'ikni' => 'i',
'iknete' => 'ete',
'iknesx' => 'esx',
'iknemo' => 'emo',
'iknem' => 'em',
'ikne' => 'e',
'ignuvsxi' => 'uvsxi',
'ignuto' => 'uto',
'ignuti' => 'uti',
'ignute' => 'ute',
'ignuta' => 'uta',
'ignut' => 'ut',
'ignusxe' => 'usxe',
'ignusx' => '',
'ignuste' => 'uste',
'ignusmo' => 'usmo',
'ignuo' => 'uo',
'ignumo' => '',
'ignulo' => 'ulo',
'ignuli' => 'uli',
'ignule' => 'ule',
'ignula' => 'ula',
'ignuh' => 'uh',
'ignucyu' => 'ucyu',
'ignucyete' => 'ucyete',
'ignucyesx' => 'ucyesx',
'ignucyemo' => 'ucyemo',
'ignucye' => 'ucye',
'ignu' => 'u',
'ignte' => '',
'ignmo' => '',
'ignite' => 'ite',
'ignimo' => 'imo',
'igni' => 'i',
'ignete' => 'ete',
'ignesx' => 'esx',
'ignemo' => 'emo',
'ignem' => 'em',
'igne' => 'e',
'ign' => '',
'icahu' => 'ahu',
'gomu' => 'omu',
'goj' => 'oj',
'goga' => 'oga',
'gog' => 'og',
'gim' => 'im',
'fu' => 'u',
'fom' => 'om',
'fo' => 'o',
'fi' => 'i',
'fe' => 'e',
'fama' => 'ama',
'fa' => 'a',
'evu' => 'u',
'evom' => 'om',
'erom' => 'om',
'enomu' => 'omu',
'enoj' => 'oj',
'enoga' => 'oga',
'enog' => 'og',
'eme' => 'e',
'ekom' => 'kom',
'eke' => 'ke',
'eka' => 'ka',
'ecima' => 'cima',
'eci' => 'ci',
'dyosxe' => 'dyosxe',
'dyesx' => 'yesx',
'deti' => 'eti',
'det' => 'et',
'decyu' => 'ecyu',
'decyete' => 'ecyete',
'decyesx' => 'ecyesx',
'decyemo' => 'ecyemo',
'decye' => 'ecye',
'cyte' => 'te',
'cymo' => 'mo',
'cxenyima' => 'ima',
'cxenyem' => 'em',
'cxenya' => 'a',
'cate' => 'te',
'casx' => 'sx',
'canye' => 'nye',
'camo' => 'mo',
'cam' => 'm',
'caju' => 'ju',
'cajte' => 'jte',
'cajmo' => 'jmo',
'caj' => 'j',
'afa' => 'a',
'acxem' => 'em',
'zxo' => 'o',
'zxenyima' => 'ima',
'zxenyem' => 'em',
'zxenya' => 'a',
'zxecyi' => 'ecyi',
'zlo' => 'lo',
'zli' => 'li',
'zle' => 'le',
'zla' => 'la',
'ziti' => 'iti',
'zit' => 'it',
'zio' => 'io',
'zim' => 'im',
'zilo' => 'ilo',
'zili' => 'ili',
'zile' => 'ile',
'zila' => 'ila',
'zde' => 'de',
'yujite' => '',
'yujimo' => '',
'yuji' => '',
'yo' => '',
'yim' => '',
'yenu' => 'u',
'yenomu' => 'omu',
'yenom' => 'om',
'yenoj' => 'oj',
'yenoga' => 'oga',
'yenog' => 'og',
'yenim' => 'im',
'yenih' => 'ih',
'yanyu' => 'u',
'yanyima' => 'ima',
'yanyem' => 'em',
'yama' => '',
'xnyelo' => 'yelo',
'xnyeli' => 'yeli',
'xnyele' => 'yele',
'xnyela' => 'yela',
'xlyu' => 'xlyu',
'xcxetu' => 'etu',
'xcxetom' => 'etom',
'xcxeta' => 'eta',
'xcxadima' => 'adima',
'xcxadi' => 'adi',
'xcxad' => 'ad',
'vaju' => 'ju',
'vajte' => 'jte',
'vajmo' => 'jmo',
'vaj' => 'j',
'uka' => 'ka',
'tni' => 'i',
'tnem' => 'em',
'tne' => 'e',
'tigosxe' => 'gosxe',
'tigoste' => 'goste',
'tigosmo' => 'gosmo',
'tigoh' => 'goh',
'tigo' => 'go',
'tignuvsxi' => '',
'tignuto' => '',
'tignuti' => '',
'tignute' => '',
'tignuta' => '',
'tignut' => '',
'tignusxe' => '',
'tignusx' => '',
'tignuste' => '',
'tignusmo' => '',
'tignuo' => '',
'tignumo' => '',
'tignulo' => '',
'tignuli' => '',
'tignule' => '',
'tignula' => '',
'tignuh' => '',
'tignucyu' => '',
'tignucyete' => '',
'tignucyesx' => '',
'tignucyemo' => '',
'tignucye' => '',
'tignu' => '',
'tignte' => '',
'tignmo' => '',
'tignite' => '',
'tignimo' => '',
'tigni' => '',
'tignete' => '',
'tignesx' => '',
'tignemo' => '',
'tignem' => '',
'tigne' => '',
'tign' => '',
'tiglo' => '',
'tigli' => '',
'tigle' => '',
'tigla' => '',
'tigavsxi' => 'gavsxi',
'tigao' => '',
'tetu' => 'u',
'tetom' => 'om',
'teta' => 'a',
'tasxcyu' => 'tasxcyu',
'tasxcyite' => 'tasxcyite',
'tasxcyimo' => 'tasxcyimo',
'tasxcyi' => 'tasxcyi',
'tasxcyete' => 'tasxcyete',
'tasxcyesx' => 'tasxcyesx',
'tasxcyemo' => 'tasxcyemo',
'tasxcyem' => 'tasxcyem',
'tasxcye' => 'tasxcye',
'sxucyi' => 'xucyi',
'sxima' => 'ima',
'sxecyi' => 'ecyi',
'stama' => 'tama',
'stahu' => 'hu',
'skama' => 'kama',
'sate' => 'te',
'saka' => 'aka',
'rukcija' => 'rukcija',
'ruisati' => 'ruisati',
'rt' => 't',
'rojavati' => 'ti',
'rgosxe' => 'gosxe',
'rgoste' => 'goste',
'rgosmo' => 'gosmo',
'rgoh' => 'goh',
'rgo' => 'go',
'rgnuvsxi' => 'uvsxi',
'rgnuto' => 'uto',
'rgnuta' => 'uta',
'rgnut' => 'ut',
'rgnusxe' => 'usxe',
'rgnusx' => '',
'rgnuste' => 'uste',
'rgnusmo' => 'usmo',
'rgnuo' => 'uo',
'rgnumo' => '',
'rgnulo' => 'ulo',
'rgnuli' => 'uli',
'rgnule' => 'ule',
'rgnula' => 'ula',
'rgnuh' => 'uh',
'rgnucyu' => 'ucyu',
'rgnucyete' => 'ucyete',
'rgnucyesx' => 'ucyesx',
'rgnucyemo' => 'ucyemo',
'rgnucye' => 'ucye',
'rgnite' => 'ite',
'rgnimo' => 'imo',
'rgni' => 'i',
'rgnete' => 'ete',
'rgnesx' => 'esx',
'rgnemo' => 'emo',
'rgavsxi' => 'vsxi',
'renye' => 'enye',
'rem' => 'em',
'rator' => '',
'rastu' => 'u',
'rasti' => 'i',
'raniti' => 'iti',
'ramo' => 'mo',
'ram' => 'm',
'raju' => 'ju',
'rajte' => 'jte',
'rajmo' => 'jmo',
'raj' => 'j',
'rada' => 'a',
'podne' => 'podne',
'pesxe' => 'esxe',
'panye' => 'nye',
'pahu' => 'hu',
'ovama' => 'ama',
'omom' => 'om',
'omo' => 'o',
'oma' => 'a',
'nyet' => 'yet',
'nyelo' => 'yelo',
'nyele' => 'yele',
'nyela' => 'yela',
'nyecyu' => 'yecyu',
'nyecyete' => 'yecyete',
'nyecyesx' => 'yecyesx',
'nyecyemo' => 'yecyemo',
'nyecye' => 'yecye',
'necyi' => 'ecyi',
'mlyasxe' => 'lyasxe',
'mlyaste' => 'lyaste',
'mlyasmo' => 'lyasmo',
'mlyahu' => 'lyahu',
'mlyah' => 'lyah',
'masxe' => 'sxe',
'maste' => 'ste',
'masmo' => 'smo',
'macyu' => 'cyu',
'macyete' => 'cyete',
'macyesx' => 'cyesx',
'macyemo' => 'cyemo',
'macye' => 'cye',
'lyenom' => 'lyenom',
'liju' => 'u',
'lije' => 'e',
'letu' => 'u',
'letom' => 'om',
'leta' => 'a',
'lanyu' => 'u',
'kata' => 'a',
'kalu' => 'lu',
'kalom' => 'lom',
'kalima' => 'lima',
'jim' => 'im',
'jih' => 'ih',
'javsxi' => 'avsxi',
'jati' => 'ati',
'jate' => 'te',
'jat' => 'at',
'jasx' => 'sx',
'jao' => 'ao',
'janye' => 'nye',
'jano' => 'ano',
'jani' => 'ani',
'jane' => 'ane',
'jana' => 'ana',
'jan' => 'an',
'jamo' => 'mo',
'jam' => 'm',
'jalo' => 'alo',
'jali' => 'ali',
'jale' => 'ale',
'jala' => 'ala',
'jaju' => 'ju',
'jajte' => 'jte',
'jajmo' => 'jmo',
'jaj' => 'j',
'jacyu' => 'acyu',
'jacyete' => 'acyete',
'jacyesx' => 'acyesx',
'jacyemo' => 'acyemo',
'jacye' => 'acye',
'isxao' => 'o',
'isivsxi' => 'isivsxi',
'isiti' => 'isiti',
'isite' => 'isite',
'isit' => 'isit',
'isisxe' => 'isisxe',
'isisx' => 'isisx',
'isiste' => 'isiste',
'isismo' => 'isismo',
'isio' => 'isio',
'isimo' => 'isimo',
'isim' => 'isim',
'isilo' => 'isilo',
'isili' => 'isili',
'isile' => 'isile',
'isila' => 'isila',
'isih' => 'isih',
'isicyu' => 'isicyu',
'isicyete' => 'isicyete',
'isicyesx' => 'isicyesx',
'isicyemo' => 'isicyemo',
'isicye' => 'isicye',
'iruzxu' => 'iruzxu',
'iruzxite' => 'iruzxite',
'iruzximo' => 'iruzximo',
'iruzxi' => 'iruzxi',
'iruzxete' => 'iruzxete',
'iruzxesx' => 'iruzxesx',
'iruzxemo' => 'iruzxemo',
'iruzxem' => 'iruzxem',
'iruzxe' => 'iruzxe',
'irukciju' => 'irukciju',
'irukcijom' => 'irukcijom',
'irukcijo' => 'irukcijo',
'irukciji' => 'irukciji',
'irukcije' => 'irukcije',
'irukcijama' => 'irukcijama',
'irukcija' => 'irukcija',
'iruji' => 'uji',
'iruisxucyi' => 'iruisxucyi',
'iruisxu' => 'iruisxu',
'iruisxte' => 'iruisxte',
'iruisxmo' => 'iruisxmo',
'iruisxete' => 'iruisxete',
'iruisxesx' => 'iruisxesx',
'iruisxeno' => 'iruisxeno',
'iruisxeni' => 'iruisxeni',
'iruisxene' => 'iruisxene',
'iruisxena' => 'iruisxena',
'iruisxen' => 'iruisxen',
'iruisxemo' => 'iruisxemo',
'iruisxem' => 'iruisxem',
'iruisxe' => 'iruisxe',
'iruisx' => 'iruisx',
'iruisavsxi' => 'iruisavsxi',
'iruisati' => 'iruisati',
'iruisat' => 'iruisat',
'iruisasxe' => 'iruisasxe',
'iruisaste' => 'iruisaste',
'iruisasmo' => 'iruisasmo',
'iruisao' => 'iruisao',
'iruisalo' => 'iruisalo',
'iruisali' => 'iruisali',
'iruisale' => 'iruisale',
'iruisala' => 'iruisala',
'iruisahu' => 'iruisahu',
'iruisah' => 'iruisah',
'iruisacyu' => 'iruisacyu',
'iruisacyete' => 'iruisacyete',
'iruisacyesx' => 'iruisacyesx',
'iruisacyemo' => 'iruisacyemo',
'iruisacye' => 'iruisacye',
'iruirajucyi' => 'iruirajucyi',
'irovavsxi' => 'irovavsxi',
'irovati' => 'irovati',
'irovat' => 'irovat',
'irovasxe' => 'irovasxe',
'irovaste' => 'irovaste',
'irovasmo' => 'irovasmo',
'irovao' => 'irovao',
'irovano' => 'irovano',
'irovani' => 'irovani',
'irovane' => 'irovane',
'irovana' => 'irovana',
'irovan' => 'irovan',
'irovalo' => 'irovalo',
'irovali' => 'irovali',
'irovale' => 'irovale',
'irovala' => 'irovala',
'irovah' => 'irovah',
'irovacyu' => 'irovacyu',
'irovacyete' => 'irovacyete',
'irovacyesx' => 'irovacyesx',
'irovacyemo' => 'irovacyemo',
'irovacye' => 'irovacye',
'irova' => 'ova',
'irojte' => 'irojte',
'irojmo' => 'irojmo',
'irojivsxi' => 'irojivsxi',
'irojiti' => 'irojiti',
'irojite' => 'irojite',
'irojit' => 'irojit',
'irojisxe' => 'irojisxe',
'irojisx' => 'irojisx',
'irojiste' => 'irojiste',
'irojismo' => 'irojismo',
'irojio' => 'irojio',
'irojimo' => 'irojimo',
'irojim' => 'irojim',
'irojilo' => 'irojilo',
'irojili' => 'irojili',
'irojile' => 'irojile',
'irojila' => 'irojila',
'irojih' => 'irojih',
'irojicyu' => 'irojicyu',
'irojicyete' => 'irojicyete',
'irojicyesx' => 'irojicyesx',
'irojicyemo' => 'irojicyemo',
'irojicye' => 'irojicye',
'iroji' => 'iroji',
'irojeno' => 'irojeno',
'irojeni' => 'irojeni',
'irojene' => 'irojene',
'irojena' => 'irojena',
'irojen' => 'irojen',
'iroje' => 'iroje',
'irojavavsxi' => 'irojavavsxi',
'irojavati' => 'irojavati',
'irojavate' => 'irojavate',
'irojavat' => 'irojavat',
'irojavasxe' => 'irojavasxe',
'irojavasx' => 'irojavasx',
'irojavaste' => 'irojavaste',
'irojavasmo' => 'irojavasmo',
'irojavao' => 'irojavao',
'irojavano' => 'irojavano',
'irojavani' => 'irojavani',
'irojavane' => 'irojavane',
'irojavana' => 'irojavana',
'irojavan' => 'irojavan',
'irojavamo' => 'irojavamo',
'irojavam' => 'irojavam',
'irojavalo' => 'irojavalo',
'irojavali' => 'irojavali',
'irojavale' => 'irojavale',
'irojavala' => 'irojavala',
'irojavaju' => 'irojavaju',
'irojavajte' => 'irojavajte',
'irojavajmo' => 'irojavajmo',
'irojavaj' => 'irojavaj',
'irojavahu' => 'irojavahu',
'irojavah' => 'irojavah',
'irojavacyu' => 'irojavacyu',
'irojavacyete' => 'irojavacyete',
'irojavacyesx' => 'irojavacyesx',
'irojavacyemo' => 'irojavacyemo',
'irojavacye' => 'irojavacye',
'irojava' => 'irojava',
'irizxem' => 'irizxem',
'irizxe' => 'irizxe',
'irima' => 'ima',
'irijo' => 'o',
'irijeno' => 'irijeno',
'irijeni' => 'irijeni',
'irijene' => 'irijene',
'irijena' => 'irijena',
'irijen' => 'irijen',
'irijama' => 'ama',
'irigute' => 'irigute',
'irigusx' => 'irigusx',
'irigumo' => 'irigumo',
'irigu' => 'irigu',
'irigte' => 'irigte',
'irigosxe' => 'irigosxe',
'irigoste' => 'irigoste',
'irigosmo' => 'irigosmo',
'irigoh' => 'irigoh',
'irigo' => 'irigo',
'irigmo' => 'irigmo',
'iriglo' => 'iriglo',
'irigli' => 'irigli',
'irigle' => 'irigle',
'irigla' => 'irigla',
'irigavsxi' => 'irigavsxi',
'irigao' => 'irigao',
'irig' => 'irig',
'irava' => 'irava',
'iratoru' => 'iratoru',
'iratorom' => 'iratorom',
'iratorima' => 'iratorima',
'iratori' => 'iratori',
'iratore' => 'iratore',
'iratora' => 'iratora',
'irator' => 'irator',
'irate' => 'te',
'iradu' => 'iradu',
'iradom' => 'iradom',
'irado' => 'irado',
'iradi' => 'iradi',
'irade' => 'irade',
'iradama' => 'iradama',
'iknusx' => 'iknusx',
'iknumo' => 'iknumo',
'iknte' => 'iknte',
'iknmo' => 'iknmo',
'ikn' => 'ikn',
'iklo' => 'lo',
'ikli' => 'li',
'ikle' => 'le',
'ikla' => 'la',
'ikanye' => 'nye',
'hao' => 'o',
'gih' => 'ih',
'etmo' => 'tmo',
'etije' => 'etije',
'esxte' => 'te',
'esxmo' => 'mo',
'esxiti' => 'iti',
'esxit' => 'it',
'esxisx' => 'isx',
'esxio' => 'io',
'esxim' => 'im',
'esxilo' => 'ilo',
'esxili' => 'ili',
'esxile' => 'ile',
'esxila' => 'ila',
'esxicyu' => 'icyu',
'esxicyete' => 'icyete',
'esxicyesx' => 'icyesx',
'esxicyemo' => 'icyemo',
'esxicye' => 'icye',
'esxcyu' => 'sxcyu',
'esxcyete' => 'sxcyete',
'esxcyesx' => 'sxcyesx',
'esxcyemo' => 'sxcyemo',
'esxcye' => 'sxcye',
'esite' => 'ite',
'esimo' => 'imo',
'esi' => 'i',
'esao' => 'sao',
'esa' => 'a',
'er' => '',
'emte' => 'te',
'elyete' => 'elyete',
'elyesx' => 'elyesx',
'elyemo' => 'elyemo',
'egu' => 'gu',
'egahu' => 'gahu',
'dyo' => 'o',
'dyama' => 'ama',
'dnucye' => 'ucye',
'dajucyi' => 'jucyi',
'cyuju' => 'uju',
'cyujete' => 'ujete',
'cyujesx' => 'ujesx',
'cyujemo' => 'ujemo',
'cyujem' => 'ujem',
'cyuje' => 'uje',
'cyucyi' => 'cyucyi',
'cyavsxi' => 'vsxi',
'cyati' => 'ti',
'cyat' => 't',
'cyao' => 'o',
'cyano' => 'no',
'cyani' => 'ni',
'cyane' => 'ne',
'cyana' => 'na',
'cyan' => 'n',
'cyalo' => 'lo',
'cyali' => 'li',
'cyale' => 'le',
'cyala' => 'la',
'cyacyu' => 'cyu',
'cyacyete' => 'cyete',
'cyacyesx' => 'cyesx',
'cyacyemo' => 'cyemo',
'cyacye' => 'cye',
'cxcu' => 'cu',
'cxcem' => 'cem',
'cxce' => 'ce',
'cxca' => 'ca',
'cxate' => 'te',
'cxasx' => 'sx',
'cxamo' => 'mo',
'cxam' => 'm',
'cxaju' => 'ju',
'cxajte' => 'jte',
'cxajmo' => 'jmo',
'cxaj' => 'j',
'cxaca' => 'aca',
'cxac' => 'ac',
'bima' => 'ima',
'avu' => 'u',
'avom' => 'om',
'avo' => 'o',
'avi' => 'i',
'asxite' => 'ite',
'asximo' => 'imo',
'asxcyeno' => 'xcyeno',
'asxcyeni' => 'xcyeni',
'asxcyene' => 'xcyene',
'asxcyena' => 'xcyena',
'asxcyen' => 'xcyen',
'astiti' => 'titi',
'astite' => 'tite',
'astit' => 'tit',
'astisx' => 'tisx',
'astio' => 'tio',
'astimo' => 'timo',
'astilo' => 'tilo',
'astili' => 'tili',
'astile' => 'tile',
'astila' => 'tila',
'asticyu' => 'ticyu',
'asticyete' => 'ticyete',
'asticyesx' => 'ticyesx',
'asticyemo' => 'ticyemo',
'asticye' => 'ticye',
'asima' => 'ima',
'asi' => 'i',
'akoj' => 'oj',
'akavsxi' => 'vsxi',
'akati' => 'ti',
'akat' => 't',
'akasxe' => 'sxe',
'akaste' => 'ste',
'akasmo' => 'smo',
'akano' => 'no',
'akani' => 'ni',
'akane' => 'ne',
'akana' => 'na',
'akan' => 'n',
'akalo' => 'lo',
'akali' => 'li',
'akale' => 'le',
'akala' => 'la',
'akahu' => 'hu',
'akah' => 'h',
'akacyu' => 'cyu',
'akacyete' => 'cyete',
'akacyesx' => 'cyesx',
'akacyemo' => 'cyemo',
'akacye' => 'cye',
'ajom' => 'om',
'ajo' => 'o',
'ajem' => 'jem',
'ajama' => 'ama',
'acyasxe' => 'sxe',
'acyaste' => 'ste',
'acyasmo' => 'smo',
'acyahu' => 'hu',
'acyah' => 'h',
'zxavsxi' => 'vsxi',
'zxati' => 'ti',
'zxat' => 't',
'zxao' => 'o',
'zxano' => 'no',
'zxani' => 'ni',
'zxane' => 'ne',
'zxana' => 'na',
'zxan' => 'n',
'zxalo' => 'lo',
'zxali' => 'li',
'zxale' => 'le',
'zxala' => 'la',
'zxacyu' => 'cyu',
'zxacyete' => 'cyete',
'zxacyesx' => 'cyesx',
'zxacyemo' => 'cyemo',
'zxacye' => 'cye',
'zte' => 'te',
'zovima' => 'ovima',
'zovi' => 'ovi',
'zove' => 'ove',
'zova' => 'ova',
'zmo' => 'mo',
'zisx' => 'isx',
'zdem' => 'zdem',
'zanye' => 'anye',
'yivavsxi' => 'ivavsxi',
'yivati' => 'ivati',
'yivat' => 'ivat',
'yivasxe' => 'ivasxe',
'yivaste' => 'ivaste',
'yivasmo' => 'ivasmo',
'yivao' => 'ivao',
'yivano' => 'ivano',
'yivani' => 'ivani',
'yivane' => 'ivane',
'yivana' => 'ivana',
'yivan' => 'ivan',
'yivalo' => 'ivalo',
'yivali' => 'ivali',
'yivale' => 'ivale',
'yivala' => 'ivala',
'yivahu' => 'ivahu',
'yivah' => 'ivah',
'yivacyu' => 'ivacyu',
'yivacyete' => 'ivacyete',
'yivacyesx' => 'ivacyesx',
'yivacyemo' => 'ivacyemo',
'yivacye' => 'ivacye',
'yiva' => 'iva',
'yih' => '',
'yenije' => '',
'xsx' => 'xsx',
'xnyeti' => 'yeti',
'xnyet' => 'yet',
'xnyecyu' => 'yecyu',
'xnyecyete' => 'yecyete',
'xnyecyesx' => 'yecyesx',
'xnyecyemo' => 'yecyemo',
'xnyecye' => 'yecye',
'xnyaku' => 'ku',
'xnyakom' => 'kom',
'xnyake' => 'ke',
'xnyaka' => 'ka',
'xnyak' => 'k',
'xnyacxu' => 'u',
'xnyacxom' => 'om',
'xnyacxo' => 'o',
'xnyacxi' => 'i',
'xnyacxama' => 'ama',
'xnyacxa' => 'a',
'xnyacima' => 'cima',
'xnyaci' => 'ci',
'xm' => 'm',
'xlyednosxcyu' => 'xlyednosxcyu',
'xlyednostima' => 'xlyednostima',
'xlyednosti' => 'xlyednosti',
'xku' => 'u',
'xkom' => 'om',
'xke' => 'e',
'xka' => 'a',
'xiu' => 'u',
'xiomu' => 'omu',
'xiom' => 'om',
'xioj' => 'oj',
'xiemu' => 'emu',
'xiem' => 'em',
'xiega' => 'ega',
'xieg' => 'eg',
'xie' => 'e',
'xia' => 'a',
'xevu' => 'u',
'xevomu' => 'omu',
'xevom' => 'om',
'xevoj' => 'oj',
'xevoga' => 'oga',
'xevog' => 'og',
'xevo' => 'o',
'xevim' => 'im',
'xevih' => 'ih',
'xev' => '',
'xenyeu' => 'u',
'xenyeom' => 'om',
'xenyeima' => 'ima',
'xenyei' => 'i',
'xenyea' => 'a',
'xecyi' => 'cyi',
'xdyasxe' => 'xdyasxe',
'xdyaste' => 'xdyaste',
'xdyasmo' => 'xdyasmo',
'xdyahu' => 'xdyahu',
'xdyah' => 'xdyah',
'xcyete' => '',
'xcyesx' => '',
'xcyemo' => '',
'xcye' => '',
'xaka' => 'ka',
'xak' => 'k',
'vlyeno' => 'lyeno',
'vlyeni' => 'lyeni',
'vlyene' => 'lyene',
'vlyena' => 'lyena',
'vlyen' => 'lyen',
'usxte' => 'te',
'usxmo' => 'mo',
'usxivsxi' => 'ivsxi',
'usxiti' => 'iti',
'usxite' => 'ite',
'usxit' => 'it',
'usxisxe' => 'isxe',
'usxisx' => 'isx',
'usxiste' => 'iste',
'usxismo' => 'ismo',
'usxio' => 'io',
'usximo' => 'imo',
'usxim' => 'im',
'usxilo' => 'ilo',
'usxili' => 'ili',
'usxile' => 'ile',
'usxila' => 'ila',
'usxih' => 'ih',
'usxicyu' => 'icyu',
'usxicyete' => 'icyete',
'usxicyesx' => 'icyesx',
'usxicyemo' => 'icyemo',
'usxicye' => 'icye',
'usxi' => 'i',
'usxeno' => 'eno',
'usxeni' => 'eni',
'usxene' => 'ene',
'usxena' => 'ena',
'usxen' => 'en',
'usx' => '',
'um' => '',
'ulu' => 'u',
'ulom' => 'om',
'ukavsxi' => 'kavsxi',
'ukati' => 'kati',
'ukat' => 'kat',
'ukasxe' => 'kasxe',
'ukaste' => 'kaste',
'ukasmo' => 'kasmo',
'ukano' => 'kano',
'ukani' => 'kani',
'ukane' => 'kane',
'ukana' => 'kana',
'ukan' => 'kan',
'ukalo' => 'kalo',
'ukali' => 'kali',
'ukale' => 'kale',
'ukala' => 'kala',
'ukah' => 'kah',
'ukacyu' => 'kacyu',
'ukacyete' => 'kacyete',
'ukacyesx' => 'kacyesx',
'ukacyemo' => 'kacyemo',
'ukacye' => 'kacye',
'ucxu' => 'cxu',
'ucxite' => 'ite',
'ucximo' => 'imo',
'ucxi' => 'i',
'tlo' => 'lo',
'tli' => 'i',
'tle' => 'e',
'tla' => 'la',
'tisxu' => 'xu',
'tiju' => 'u',
'tijesxe' => 'tijesxe',
'tijem' => 'ijem',
'telu' => 'u',
'telomu' => 'telomu',
'telom' => 'om',
'teloj' => 'teloj',
'teloga' => 'teloga',
'telog' => 'telog',
'telim' => 'telim',
'telih' => 'telih',
'teknute' => 'knute',
'teknusx' => 'knusx',
'teknumo' => 'knumo',
'teknu' => 'knu',
'teknte' => 'knte',
'teknmo' => 'knmo',
'teknem' => 'knem',
'tekne' => 'kne',
'tekn' => 'kn',
'teklo' => 'klo',
'tekli' => 'kli',
'tekle' => 'kle',
'tekla' => 'kla',
'tekao' => 'kao',
'teih' => 'ih',
'tegosxe' => 'gosxe',
'tegoste' => 'goste',
'tegosmo' => 'gosmo',
'tegoh' => 'goh',
'tego' => 'go',
'tegavsxi' => 'gavsxi',
'tecy' => 'cy',
'talu' => 'lu',
'talom' => 'lom',
'tadima' => 'tadima',
'tadi' => 'tadi',
'tad' => 'tad',
'sxta' => 'ta',
'sxisxe' => 'isxe',
'sxiste' => 'iste',
'sxismo' => 'ismo',
'sxih' => 'ih',
'sxenyu' => 'u',
'state' => 'te',
'stasx' => 'sx',
'stamo' => 'mo',
'stam' => 'm',
'staju' => 'ju',
'stajte' => 'jte',
'stajmo' => 'jmo',
'staj' => 'j',
'sata' => 'ata',
'sasx' => 'sx',
'samo' => 'mo',
'sam' => 'm',
'saju' => 'ju',
'sajte' => 'jte',
'sajmo' => 'jmo',
'saj' => 'j',
'rtavsxi' => 'vsxi',
'rtati' => 'ti',
'rtat' => 't',
'rtasxe' => 'sxe',
'rtaste' => 'ste',
'rtasmo' => 'smo',
'rtao' => 'o',
'rtano' => 'no',
'rtani' => 'ni',
'rtane' => 'ne',
'rtana' => 'na',
'rtan' => 'n',
'rtalo' => 'lo',
'rtali' => 'li',
'rtale' => 'le',
'rtala' => 'la',
'rtah' => 'h',
'rtacyu' => 'cyu',
'rtacyete' => 'cyete',
'rtacyesx' => 'cyesx',
'rtacyemo' => 'cyemo',
'rtacye' => 'cye',
'rta' => 'ta',
'ricy' => '',
'ret' => 'et',
'resxiti' => 'iti',
'resxe' => 'esxe',
'resti' => 'sti',
'remu' => 'u',
'recyu' => 'ecyu',
'recyete' => 'ecyete',
'recyesx' => 'ecyesx',
'recyemo' => 'ecyemo',
'recye' => 'ecye',
'rcyite' => 'cyite',
'rcyimo' => 'cyimo',
'rcyem' => 'cyem',
'ratura' => 'a',
'rasxte' => 'te',
'rasxmo' => 'mo',
'rasxite' => 'ite',
'rasxit' => 'it',
'rasxisx' => 'isx',
'rasxio' => 'io',
'rasximo' => 'imo',
'rasxim' => 'im',
'rasxilo' => 'ilo',
'rasxili' => 'ili',
'rasxile' => 'ile',
'rasxila' => 'ila',
'rasxicyu' => 'icyu',
'rasxicyete' => 'icyete',
'rasxicyesx' => 'icyesx',
'rasxicyemo' => 'icyemo',
'rasxicye' => 'icye',
'rasxi' => 'i',
'rasxeno' => 'eno',
'rasxeni' => 'eni',
'rasxene' => 'ene',
'rasxena' => 'ena',
'rasxen' => 'en',
'rasxcye' => 'sxcye',
'rasnost' => 'rasnost',
'ranyivati' => 'ivati',
'rakcija' => 'a',
'raka' => 'aka',
'rak' => 'k',
'rajucyi' => 'jucyi',
'rajati' => 'ti',
'psxcyi' => 'psxcyi',
'psao' => 'psao',
'pko' => 'ko',
'pisx' => 'isx',
'pio' => 'io',
'pim' => 'im',
'pevsxi' => 'evsxi',
'peti' => 'eti',
'pet' => 'et',
'peste' => 'este',
'pesmo' => 'esmo',
'peo' => 'eo',
'pelo' => 'elo',
'peli' => 'eli',
'pele' => 'ele',
'pela' => 'ela',
'peh' => 'eh',
'pecyu' => 'ecyu',
'pecyete' => 'ecyete',
'pecyesx' => 'ecyesx',
'pecyemo' => 'ecyemo',
'pecye' => 'ecye',
'pcxi' => 'i',
'pcxa' => '',
'ovsxi' => 'vsxi',
'ovovima' => 'ovovima',
'ovovi' => 'ovovi',
'ovove' => 'ovove',
'ovova' => 'ovova',
'omima' => 'ima',
'omim' => 'im',
'omih' => 'ih',
'ojite' => 'ite',
'ojisx' => 'isx',
'ojimo' => 'imo',
'ojim' => 'im',
'oji' => 'i',
'oje' => 'e',
'ogima' => '',
'ogi' => 'i',
'ogama' => 'gama',
'ocyima' => 'ima',
'nyim' => 'im',
'nyih' => 'ih',
'nyavsxi' => 'vsxi',
'nyati' => 'ti',
'nyat' => 't',
'nyao' => 'o',
'nyano' => 'no',
'nyani' => 'ni',
'nyane' => 'ne',
'nyana' => 'na',
'nyan' => 'n',
'nyalo' => 'lo',
'nyali' => 'li',
'nyale' => 'le',
'nyala' => 'la',
'nyak' => 'k',
'nyacyu' => 'cyu',
'nyacyete' => 'cyete',
'nyacyesx' => 'cyesx',
'nyacyemo' => 'cyemo',
'nyacye' => 'cye',
'nyacxa' => 'a',
'numo' => 'umo',
'nujucyi' => 'ujucyi',
'nuju' => 'uju',
'nujte' => 'ujte',
'nujmo' => 'ujmo',
'nujete' => 'ujete',
'nujesx' => 'ujesx',
'nujemo' => 'ujemo',
'nujem' => 'ujem',
'nuje' => 'uje',
'nuj' => 'uj',
'novavsxi' => 'ovavsxi',
'novati' => 'ovati',
'novat' => 'ovat',
'novasxe' => 'ovasxe',
'novaste' => 'ovaste',
'novasmo' => 'ovasmo',
'novao' => 'ovao',
'novano' => 'ovano',
'novani' => 'ovani',
'novane' => 'ovane',
'novana' => 'ovana',
'novan' => 'ovan',
'novalo' => 'ovalo',
'novali' => 'ovali',
'novale' => 'ovale',
'novala' => 'ovala',
'novahu' => 'ovahu',
'novah' => 'ovah',
'novacyu' => 'ovacyu',
'novacyete' => 'ovacyete',
'novacyesx' => 'ovacyesx',
'novacyemo' => 'ovacyemo',
'novacye' => 'ovacye',
'nova' => 'ova',
'nesu' => 'esu',
'nesete' => 'esete',
'nesesx' => 'esesx',
'nesemo' => 'esemo',
'nesem' => 'esem',
'nese' => 'ese',
'nes' => 'es',
'mivsxi' => 'ivsxi',
'misxe' => 'isxe',
'miste' => 'iste',
'mismo' => 'ismo',
'menu' => 'u',
'macyi' => 'acyi',
'lyiti' => 'iti',
'lyit' => 'it',
'lyio' => 'io',
'lyilo' => 'ilo',
'lyili' => 'ili',
'lyile' => 'ile',
'lyila' => 'ila',
'lyicyu' => 'icyu',
'lyicyete' => 'icyete',
'lyicyesx' => 'icyesx',
'lyicyemo' => 'icyemo',
'lyicye' => 'icye',
'lyevsxi' => 'yevsxi',
'lyesxe' => 'yesxe',
'lyeste' => 'yeste',
'lyesmo' => 'yesmo',
'lyenu' => 'u',
'lyenomu' => 'lyenomu',
'lyenoga' => 'lyenoga',
'lyenog' => 'lyenog',
'lyenim' => 'lyenim',
'lyenije' => '',
'lyeh' => 'yeh',
'lyednost' => 'lyednost',
'lyanyu' => 'u',
'lyanyima' => 'ima',
'lyanyem' => 'em',
'lyanya' => 'a',
'ltu' => 'u',
'ltom' => 'om',
'lti' => 'i',
'lta' => 'a',
'lou' => 'u',
'lomom' => 'om',
'lomima' => 'ima',
'lomi' => 'i',
'lome' => 'e',
'loma' => 'a',
'loima' => 'ima',
'loi' => 'i',
'loe' => 'e',
'loa' => 'a',
'lijem' => 'ijem',
'licyom' => 'om',
'licyima' => 'ima',
'licya' => 'a',
'licy' => '',
'latim' => 'tim',
'lanyima' => 'ima',
'lanyem' => 'em',
'lanya' => '',
'katu' => 'u',
'katom' => 'om',
'kastu' => 'u',
'kastomu' => 'omu',
'kastom' => 'om',
'kastoj' => 'oj',
'kastoga' => 'oga',
'kastog' => 'og',
'kasto' => 'o',
'kastim' => 'im',
'kastih' => 'ih',
'kasti' => 'i',
'kasta' => 'a',
'kalacyesx' => 'lacyesx',
'kalacxu' => 'lacxu',
'kalacxite' => 'lacxite',
'kalacximo' => 'lacximo',
'kalacxi' => 'lacxi',
'kalacxete' => 'lacxete',
'kalacxemo' => 'lacxemo',
'kalacxem' => 'lacxem',
'kalacxe' => 'lacxe',
'kajucyi' => 'jucyi',
'kacxu' => 'u',
'kacxite' => 'ite',
'kacximo' => 'imo',
'kacxi' => 'i',
'kacxete' => 'cxete',
'kacxemo' => 'cxemo',
'kacxem' => 'em',
'kacxe' => 'e',
'juju' => 'uju',
'jujite' => 'ujite',
'jujimo' => 'ujimo',
'juji' => 'uji',
'jemu' => 'u',
'ivalu' => 'ivalu',
'ivalom' => 'ivalom',
'ivalima' => 'ivalima',
'isxlo' => 'sxlo',
'isxli' => 'sxli',
'isxle' => 'sxle',
'isxla' => 'sxla',
'istama' => 'ama',
'isanye' => 'e',
'irvu' => 'irvu',
'irvom' => 'irvom',
'irvo' => 'irvo',
'irva' => 'irva',
'irute' => 'ute',
'irumo' => 'umo',
'irujucyi' => 'ujucyi',
'irujte' => 'ujte',
'irujmo' => 'ujmo',
'irujite' => 'ujite',
'irujimo' => 'ujimo',
'iruj' => 'uj',
'irtu' => 'irtu',
'irtomu' => 'irtomu',
'irtom' => 'irtom',
'irtoj' => 'irtoj',
'irtoga' => 'irtoga',
'irtog' => 'irtog',
'irto' => 'irto',
'irtim' => 'irtim',
'irtih' => 'irtih',
'irti' => 'irti',
'irta' => 'irta',
'irt' => 'irt',
'irovahu' => 'ovahu',
'irizi' => 'irizi',
'iriti' => 'iti',
'irit' => 'it',
'irilo' => 'ilo',
'irili' => 'ili',
'irile' => 'ile',
'irila' => 'ila',
'irigom' => 'irigom',
'irige' => 'irige',
'iriga' => 'iriga',
'iresxite' => 'iresxite',
'iresximo' => 'iresximo',
'iresxi' => 'iresxi',
'iremu' => 'iremu',
'ireblyiva' => 'ireblyiva',
'irebi' => 'irebi',
'irebe' => 'irebe',
'ireb' => 'ireb',
'irazxi' => 'irazxi',
'irazxe' => 'irazxe',
'iraturu' => 'iraturu',
'iraturom' => 'iraturom',
'iraturo' => 'iraturo',
'iraturi' => 'iraturi',
'irature' => 'irature',
'iraturama' => 'iraturama',
'iratura' => 'iratura',
'iratu' => 'u',
'iratom' => 'om',
'iratima' => 'ima',
'irata' => 'a',
'irasx' => 'sx',
'irasnosxcyu' => 'irasnosxcyu',
'irasnostima' => 'irasnostima',
'irasnosti' => 'irasnosti',
'iranyuju' => 'iranyuju',
'iranyujite' => 'iranyujite',
'iranyujimo' => 'iranyujimo',
'iranyuji' => 'iranyuji',
'iranyujete' => 'iranyujete',
'iranyujesx' => 'iranyujesx',
'iranyujemo' => 'iranyujemo',
'iranyujem' => 'iranyujem',
'iranyuje' => 'iranyuje',
'iranyivavsxi' => 'iranyivavsxi',
'iranyivati' => 'iranyivati',
'iranyivat' => 'iranyivat',
'iranyivasxe' => 'iranyivasxe',
'iranyivaste' => 'iranyivaste',
'iranyivasmo' => 'iranyivasmo',
'iranyivao' => 'iranyivao',
'iranyivano' => 'iranyivano',
'iranyivani' => 'iranyivani',
'iranyivane' => 'iranyivane',
'iranyivana' => 'iranyivana',
'iranyivan' => 'iranyivan',
'iranyivalo' => 'iranyivalo',
'iranyivali' => 'iranyivali',
'iranyivale' => 'iranyivale',
'iranyivala' => 'iranyivala',
'iranyivahu' => 'iranyivahu',
'iranyivah' => 'iranyivah',
'iranyivacyu' => 'iranyivacyu',
'iranyivacyete' => 'iranyivacyete',
'iranyivacyesx' => 'iranyivacyesx',
'iranyivacyemo' => 'iranyivacyemo',
'iranyivacye' => 'iranyivacye',
'iranyiva' => 'iranyiva',
'iranyeno' => 'iranyeno',
'iranyeni' => 'iranyeni',
'iranyene' => 'iranyene',
'iranyena' => 'iranyena',
'iranyen' => 'iranyen',
'iranu' => 'nu',
'iranomu' => 'nomu',
'iranom' => 'nom',
'iranoj' => 'noj',
'iranoga' => 'noga',
'iranog' => 'nog',
'iranmo' => 'iranmo',
'iranivsxi' => 'iranivsxi',
'iraniti' => 'iraniti',
'iranite' => 'iranite',
'iranit' => 'iranit',
'iranisxe' => 'iranisxe',
'iranisx' => 'iranisx',
'iraniste' => 'iraniste',
'iranismo' => 'iranismo',
'iranio' => 'iranio',
'iranimo' => 'iranimo',
'iranilo' => 'iranilo',
'iranili' => 'iranili',
'iranile' => 'iranile',
'iranila' => 'iranila',
'iranicyu' => 'iranicyu',
'iranicyete' => 'iranicyete',
'iranicyesx' => 'iranicyesx',
'iranicyemo' => 'iranicyemo',
'iranicye' => 'iranicye',
'irama' => 'ama',
'irakciju' => 'irakciju',
'irakcijom' => 'irakcijom',
'irakcijo' => 'irakcijo',
'irakciji' => 'irakciji',
'irakcije' => 'irakcije',
'irakcijama' => 'irakcijama',
'irakcija' => 'irakcija',
'ime' => 'e',
'ilyasxe' => 'lyasxe',
'ilyaste' => 'lyaste',
'ilyasmo' => 'lyasmo',
'ilyahu' => 'lyahu',
'ilyah' => 'lyah',
'ijeveno' => 'ijeveno',
'ijeveni' => 'ijeveni',
'ijevene' => 'ijevene',
'ijevena' => 'ijevena',
'ijeven' => 'ijeven',
'ijetu' => 'u',
'ijetom' => 'om',
'ijeto' => 'o',
'ijeta' => 'ta',
'ijesxte' => 'te',
'ijesxmo' => 'mo',
'ijesxivsxi' => 'ivsxi',
'ijesxiti' => '',
'ijesxite' => 'ite',
'ijesxit' => 'it',
'ijesxisxe' => 'isxe',
'ijesxisx' => 'isx',
'ijesxiste' => 'iste',
'ijesxismo' => 'ismo',
'ijesxio' => 'io',
'ijesximo' => 'imo',
'ijesxim' => 'im',
'ijesxilo' => 'ilo',
'ijesxili' => 'ili',
'ijesxile' => 'ile',
'ijesxila' => 'ila',
'ijesxih' => 'ih',
'ijesxicyu' => 'icyu',
'ijesxicyete' => 'icyete',
'ijesxicyesx' => 'icyesx',
'ijesxicyemo' => 'icyemo',
'ijesxicye' => 'icye',
'ijesxi' => 'i',
'ijesxeno' => 'xeno',
'ijesxeni' => 'xeni',
'ijesxene' => 'xene',
'ijesxena' => 'xena',
'ijesxen' => 'xen',
'idyute' => 'dyute',
'idyusx' => 'dyusx',
'idyumo' => 'dyumo',
'idyu' => 'dyu',
'idyte' => 'dyte',
'idymo' => 'dymo',
'idyem' => 'dyem',
'idye' => 'dye',
'idy' => 'dy',
'icyem' => 'cyem',
'icxte' => 'te',
'icxmo' => 'mo',
'icxisx' => 'isx',
'icxim' => 'im',
'icxecyi' => 'icxecyi',
'icx' => '',
'huju' => 'uju',
'hujete' => 'ujete',
'hujesx' => 'ujesx',
'hujemo' => 'ujemo',
'hujem' => 'ujem',
'huje' => 'uje',
'havsxi' => 'vsxi',
'hati' => 'ti',
'hat' => 't',
'hasxe' => 'sxe',
'haste' => 'ste',
'hasmo' => 'smo',
'hano' => 'no',
'hani' => 'ni',
'hane' => 'ne',
'hana' => 'na',
'han' => 'n',
'halo' => 'lo',
'hali' => 'li',
'hale' => 'le',
'hala' => 'la',
'hah' => 'h',
'hacyu' => 'cyu',
'hacyete' => 'cyete',
'hacyesx' => 'cyesx',
'hacyemo' => 'cyemo',
'hacye' => 'cye',
'gmo' => 'mo',
'galu' => 'galu',
'galom' => 'galom',
'galima' => 'galima',
'ezi' => 'i',
'evomu' => 'omu',
'evoj' => 'oj',
'evoga' => 'oga',
'evog' => 'og',
'evo' => 'o',
'evim' => 'im',
'evih' => 'ih',
'etite' => 'tite',
'etisx' => 'tisx',
'etio' => 'tio',
'etimo' => 'timo',
'etavsxi' => 'tavsxi',
'etati' => 'tati',
'etat' => 'tat',
'etasxe' => 'tasxe',
'etaste' => 'taste',
'etasmo' => 'tasmo',
'etao' => 'tao',
'etano' => 'tano',
'etani' => 'tani',
'etane' => 'tane',
'etana' => 'tana',
'etan' => 'tan',
'etalo' => 'talo',
'etali' => 'tali',
'etale' => 'tale',
'etala' => 'tala',
'etah' => 'tah',
'etacyu' => 'tacyu',
'etacyete' => 'tacyete',
'etacyesx' => 'tacyesx',
'etacyemo' => 'tacyemo',
'etacye' => 'tacye',
'esxu' => 'u',
'esxete' => 'xete',
'esxesx' => 'xesx',
'esxemo' => 'xemo',
'esxem' => 'xem',
'esiti' => 'iti',
'esit' => 'it',
'esih' => 'ih',
'eseno' => 'seno',
'eseni' => 'seni',
'esene' => 'sene',
'esena' => 'sena',
'esen' => 'sen',
'esavsxi' => 'avsxi',
'esati' => 'ati',
'esat' => 'at',
'esasxe' => 'asxe',
'esaste' => 'aste',
'esasmo' => 'asmo',
'esano' => 'ano',
'esani' => 'ani',
'esane' => 'ane',
'esana' => 'ana',
'esan' => 'an',
'esalo' => 'alo',
'esali' => 'ali',
'esale' => 'ale',
'esala' => 'ala',
'esah' => 'ah',
'esacyu' => 'acyu',
'esacyete' => 'acyete',
'esacyesx' => 'acyesx',
'esacyemo' => 'acyemo',
'esacye' => 'acye',
'erucyi' => 'erucyi',
'ero' => 'o',
'enama' => 'ama',
'elyte' => 'te',
'elyom' => 'om',
'elymo' => 'mo',
'elyi' => 'i',
'elyevsxi' => 'yevsxi',
'elyeti' => 'yeti',
'elyet' => 'yet',
'elyesxe' => 'yesxe',
'elyeste' => 'yeste',
'elyesmo' => 'yesmo',
'elyelo' => 'yelo',
'elyeli' => 'yeli',
'elyele' => 'yele',
'elyela' => 'yela',
'elyeh' => 'yeh',
'elyecyu' => 'yecyu',
'elyecyete' => 'yecyete',
'elyecyesx' => 'yecyesx',
'elyecyemo' => 'yecyemo',
'elyecye' => 'yecye',
'elya' => 'a',
'ely' => '',
'elivsxi' => 'ivsxi',
'eliti' => 'iti',
'elit' => 'it',
'elisxe' => 'isxe',
'eliste' => 'iste',
'elismo' => 'ismo',
'elilo' => 'ilo',
'elili' => 'ili',
'elile' => 'ile',
'elila' => 'ila',
'elicyu' => 'icyu',
'elicyete' => 'icyete',
'elicyesx' => 'icyesx',
'elicyemo' => 'icyemo',
'elicye' => 'icye',
'eleti' => 'eti',
'elet' => 'et',
'eleo' => 'eo',
'elelo' => 'elo',
'eleli' => 'eli',
'elele' => 'ele',
'elela' => 'ela',
'elecyu' => 'ecyu',
'elecyete' => 'ecyete',
'elecyesx' => 'ecyesx',
'elecyemo' => 'ecyemo',
'elecye' => 'ecye',
'eknite' => 'ite',
'eknimo' => 'imo',
'eknete' => 'ete',
'eknesx' => 'esx',
'eknemo' => 'emo',
'egom' => 'gom',
'ege' => 'ge',
'ecyite' => 'cyite',
'ecyimo' => 'cyimo',
'ecyeno' => 'cyeno',
'ecyeni' => 'cyeni',
'ecyene' => 'cyene',
'ecyena' => 'cyena',
'ecyen' => 'cyen',
'dyomu' => 'omu',
'dyoj' => 'oj',
'dyim' => 'im',
'dyih' => 'ih',
'dyete' => 'yete',
'dyemu' => 'emu',
'dyega' => 'ega',
'dyeg' => 'eg',
'dovavsxi' => 'ovavsxi',
'dovati' => 'ovati',
'dovat' => 'ovat',
'dovasxe' => 'ovasxe',
'dovaste' => 'ovaste',
'dovasmo' => 'ovasmo',
'dovao' => 'ovao',
'dovano' => 'ovano',
'dovani' => 'ovani',
'dovane' => 'ovane',
'dovana' => 'ovana',
'dovan' => 'ovan',
'dovalo' => 'ovalo',
'dovali' => 'ovali',
'dovale' => 'ovale',
'dovala' => 'ovala',
'dovahu' => 'ovahu',
'dovah' => 'ovah',
'dovacyu' => 'ovacyu',
'dovacyete' => 'ovacyete',
'dovacyesx' => 'ovacyesx',
'dovacyemo' => 'ovacyemo',
'dovacye' => 'ovacye',
'dova' => 'ova',
'dnuvsxi' => 'uvsxi',
'dnusxe' => 'usxe',
'dnuste' => 'uste',
'dnusmo' => 'usmo',
'dnuo' => 'uo',
'dnulo' => 'ulo',
'dnuli' => 'uli',
'dnule' => 'ule',
'dnula' => 'ula',
'dnuh' => 'uh',
'dnucyu' => 'ucyu',
'dnucyete' => 'ucyete',
'dnucyesx' => 'ucyesx',
'dnucyemo' => 'ucyemo',
'devsxi' => 'evsxi',
'danye' => 'nye',
'cyujite' => 'ujite',
'cyujimo' => 'ujimo',
'cyuji' => 'uji',
'cyivsxi' => 'ivsxi',
'cyiti' => 'iti',
'cyit' => 'it',
'cyisx' => 'isx',
'cyio' => 'io',
'cyim' => 'm',
'cyilo' => 'ilo',
'cyili' => 'ili',
'cyile' => 'ile',
'cyila' => 'ila',
'cyicyu' => 'icyu',
'cyicyete' => 'icyete',
'cyicyesx' => 'icyesx',
'cyicyemo' => 'icyemo',
'cyicye' => 'icye',
'cyasx' => 'sx',
'cxnici' => 'i',
'cxko' => 'o',
'cxastu' => 'u',
'cxastomu' => 'omu',
'cxastom' => 'om',
'cxastoj' => 'oj',
'cxastoga' => 'oga',
'cxastog' => 'og',
'cxasto' => 'o',
'cxastim' => 'im',
'cxastih' => 'ih',
'cxasti' => 'i',
'cxasta' => 'a',
'cxast' => '',
'ceno' => 'eno',
'ceni' => 'eni',
'cene' => 'ene',
'cena' => 'ena',
'cen' => 'en',
'bte' => 'te',
'bova' => 'ova',
'bmo' => 'mo',
'blyeno' => 'lyeno',
'blyeni' => 'lyeni',
'blyene' => 'lyene',
'blyena' => 'lyena',
'blyen' => 'lyen',
'biti' => 'iti',
'bit' => 'it',
'bisx' => 'isx',
'bio' => 'io',
'bim' => 'im',
'bilo' => 'ilo',
'bili' => 'ili',
'bile' => 'ile',
'bila' => 'ila',
'bicyu' => 'icyu',
'bicyete' => 'icyete',
'bicyesx' => 'icyesx',
'bicyemo' => 'icyemo',
'bicye' => 'icye',
'benavsxi' => 'benavsxi',
'benati' => 'benati',
'benate' => 'benate',
'benat' => 'benat',
'benasxe' => 'benasxe',
'benasx' => 'benasx',
'benaste' => 'benaste',
'benasmo' => 'benasmo',
'benao' => 'benao',
'benano' => 'benano',
'benani' => 'benani',
'benane' => 'benane',
'benana' => 'benana',
'benan' => 'benan',
'benamo' => 'benamo',
'benam' => 'benam',
'benalo' => 'benalo',
'benali' => 'benali',
'benale' => 'benale',
'benala' => 'benala',
'benaju' => 'benaju',
'benajte' => 'benajte',
'benajmo' => 'benajmo',
'benaj' => 'benaj',
'benah' => 'benah',
'benacyu' => 'benacyu',
'benacyete' => 'benacyete',
'benacyesx' => 'benacyesx',
'benacyemo' => 'benacyemo',
'benacye' => 'benacye',
'bak' => 'k',
'avih' => 'ih',
'ave' => 'e',
'avanyu' => 'nyu',
'atmo' => 'tmo',
'atiti' => 'titi',
'atite' => 'tite',
'atit' => 'tit',
'atisx' => 'tisx',
'atio' => 'tio',
'atimo' => 'timo',
'atilo' => 'tilo',
'atili' => 'tili',
'atile' => 'tile',
'atila' => 'tila',
'atiju' => 'u',
'atijomu' => 'ijomu',
'atijom' => 'om',
'atijoj' => 'ijoj',
'atijim' => 'ijim',
'atijih' => 'ijih',
'atiji' => 'i',
'atijemu' => 'ijemu',
'atijem' => 'ijem',
'atijega' => 'ijega',
'atijeg' => 'ijeg',
'atije' => 'e',
'atija' => 'a',
'aticyu' => 'ticyu',
'aticyete' => 'ticyete',
'aticyesx' => 'ticyesx',
'aticyemo' => 'ticyemo',
'aticye' => 'ticye',
'asxte' => 'te',
'asxo' => 'o',
'asxmo' => 'mo',
'asxivsxi' => 'ivsxi',
'asxiti' => 'iti',
'asxit' => 'it',
'asxisx' => 'isx',
'asxio' => 'io',
'asxim' => 'im',
'asxilo' => 'ilo',
'asxili' => 'ili',
'asxile' => 'ile',
'asxila' => 'ila',
'asxicyu' => 'icyu',
'asxicyete' => 'icyete',
'asxicyesx' => 'icyesx',
'asxicyemo' => 'icyemo',
'asxicye' => 'icye',
'asxeno' => 'xeno',
'asxeni' => 'xeni',
'asxene' => 'xene',
'asxena' => 'xena',
'asxen' => 'xen',
'asxama' => 'ama',
'astivsxi' => 'tivsxi',
'astisxe' => 'tisxe',
'astiste' => 'tiste',
'astismo' => 'tismo',
'aro' => 'o',
'arama' => 'ama',
'anyom' => 'om',
'anyo' => 'o',
'anyi' => 'i',
'anije' => 'e',
'amte' => 'te',
'amlyeno' => 'lyeno',
'amlyeni' => 'lyeni',
'amlyene' => 'lyene',
'amlyena' => 'lyena',
'amlyen' => 'lyen',
'amiti' => 'iti',
'amite' => 'ite',
'amit' => 'it',
'amisx' => 'isx',
'amio' => 'io',
'amimo' => 'imo',
'amima' => 'ima',
'amim' => 'im',
'amilo' => 'ilo',
'amili' => 'ili',
'amile' => 'ile',
'amila' => 'ila',
'amicyu' => 'icyu',
'amicyete' => 'icyete',
'amicyesx' => 'icyesx',
'amicyemo' => 'icyemo',
'amicye' => 'icye',
'akomu' => 'omu',
'akoga' => 'oga',
'akog' => 'og',
'akim' => 'im',
'akih' => 'ih',
'aki' => 'i',
'akacxu' => 'cxu',
'akacxite' => 'cxite',
'akacximo' => 'cximo',
'akacxi' => 'cxi',
'akacxete' => 'cxete',
'akacxemo' => 'cxemo',
'akacxem' => 'cxem',
'akacxe' => 'cxe',
'ajite' => 'jite',
'ajimo' => 'jimo',
'ajete' => 'jete',
'ajesx' => 'jesx',
'ajemo' => 'jemo',
'ajavsxi' => 'vsxi',
'ajati' => 'ti',
'ajat' => 't',
'ajasxe' => 'sxe',
'ajaste' => 'ste',
'ajasmo' => 'smo',
'ajao' => 'o',
'ajano' => 'no',
'ajani' => 'ni',
'ajane' => 'ne',
'ajana' => 'na',
'ajan' => 'n',
'ajalo' => 'lo',
'ajali' => 'li',
'ajale' => 'le',
'ajala' => 'la',
'ajahu' => 'hu',
'ajah' => 'h',
'ajacyu' => 'cyu',
'ajacyete' => 'cyete',
'ajacyesx' => 'cyesx',
'ajacyemo' => 'cyemo',
'ajacye' => 'cye',
'ahom' => 'hom',
'ahe' => 'he',
'acyeno' => 'cyeno',
'acyeni' => 'cyeni',
'acyene' => 'cyene',
'acyena' => 'cyena',
'acyen' => 'cyen',
'acxite' => 'ite',
'acximo' => 'imo',
'acxima' => 'ima',
'acx' => '',
'zdosxe' => 'zdosxe',
'zdoste' => 'zdoste',
'zdosmo' => 'zdosmo',
'zdoh' => 'zdoh',
'yute' => 'ute',
'yumo' => 'umo',
'yujucyi' => 'ujucyi',
'yujte' => 'ujte',
'yujmo' => 'ujmo',
'yuj' => 'uj',
'yomu' => 'omu',
'yoj' => 'oj',
'yivu' => 'u',
'yivsxi' => 'ivsxi',
'yivomu' => 'omu',
'yivom' => 'om',
'yivoj' => 'oj',
'yivoga' => 'oga',
'yivog' => 'og',
'yivo' => 'o',
'yivim' => 'im',
'yivih' => 'ih',
'yivi' => 'i',
'yive' => 'e',
'yiv' => '',
'yiti' => 'iti',
'yit' => 'it',
'yisx' => 'isx',
'yio' => 'io',
'yilo' => 'ilo',
'yili' => 'ili',
'yile' => 'ile',
'yila' => 'ila',
'yicyu' => 'icyu',
'yicyete' => 'icyete',
'yicyesx' => 'icyesx',
'yicyemo' => 'icyemo',
'yicye' => 'icye',
'yevima' => 'evima',
'yevi' => 'evi',
'yeve' => 'eve',
'yeva' => 'eva',
'yemu' => 'emu',
'yelu' => 'lu',
'yelomu' => '',
'yelom' => 'lom',
'yeloj' => '',
'yeloga' => '',
'yelog' => '',
'yelim' => '',
'yelih' => '',
'yega' => 'ega',
'yeg' => 'eg',
'xtaca' => 'taca',
'xtac' => 'tac',
'xomu' => 'omu',
'xoj' => 'oj',
'xnyivu' => 'u',
'xnyivomu' => 'omu',
'xnyivom' => 'om',
'xnyivoj' => 'oj',
'xnyivoga' => 'oga',
'xnyivog' => 'og',
'xnyivo' => 'o',
'xnyivim' => 'im',
'xnyiviju' => 'xnyiviju',
'xnyivijomu' => 'xnyivijomu',
'xnyivijom' => 'xnyivijom',
'xnyivijoj' => 'xnyivijoj',
'xnyivijim' => 'xnyivijim',
'xnyivijih' => 'xnyivijih',
'xnyiviji' => 'xnyiviji',
'xnyivijemu' => 'xnyivijemu',
'xnyivijem' => 'xnyivijem',
'xnyivijega' => 'xnyivijega',
'xnyivijeg' => 'xnyivijeg',
'xnyivije' => 'xnyivije',
'xnyivija' => 'xnyivija',
'xnyivih' => 'ih',
'xnyivi' => 'i',
'xnyive' => 'e',
'xnyiva' => 'iva',
'xnyiv' => '',
'xlyedyuju' => 'xlyedyuju',
'xlyedyujete' => 'xlyedyujete',
'xlyedyujesx' => 'xlyedyujesx',
'xlyedyujemo' => 'xlyedyujemo',
'xlyedyujem' => 'xlyedyujem',
'xlyedyuje' => 'xlyedyuje',
'xlyedyivavsxi' => 'xlyedyivavsxi',
'xlyedyivati' => 'xlyedyivati',
'xlyedyivat' => 'xlyedyivat',
'xlyedyivasxe' => 'xlyedyivasxe',
'xlyedyivaste' => 'xlyedyivaste',
'xlyedyivasmo' => 'xlyedyivasmo',
'xlyedyivao' => 'xlyedyivao',
'xlyedyivano' => 'xlyedyivano',
'xlyedyivani' => 'xlyedyivani',
'xlyedyivane' => 'xlyedyivane',
'xlyedyivana' => 'xlyedyivana',
'xlyedyivan' => 'xlyedyivan',
'xlyedyivalo' => 'xlyedyivalo',
'xlyedyivali' => 'xlyedyivali',
'xlyedyivale' => 'xlyedyivale',
'xlyedyivala' => 'xlyedyivala',
'xlyedyivahu' => 'xlyedyivahu',
'xlyedyivah' => 'xlyedyivah',
'xlyedyivacyu' => 'xlyedyivacyu',
'xlyedyivacyete' => 'xlyedyivacyete',
'xlyedyivacyesx' => 'xlyedyivacyesx',
'xlyedyivacyemo' => 'xlyedyivacyemo',
'xlyedyivacye' => 'xlyedyivacye',
'xlyedyiva' => 'xlyedyiva',
'xlyednyu' => 'xlyednyu',
'xlyednyomu' => 'xlyednyomu',
'xlyednyom' => 'xlyednyom',
'xlyednyoj' => 'xlyednyoj',
'xlyednyoga' => 'xlyednyoga',
'xlyednyog' => 'xlyednyog',
'xlyednyo' => 'xlyednyo',
'xlyednyim' => 'xlyednyim',
'xlyednyih' => 'xlyednyih',
'xlyednyi' => 'xlyednyi',
'xlyednye' => 'xlyednye',
'xlyednya' => 'xlyednya',
'xlyasxe' => 'sxe',
'xlyaste' => 'ste',
'xlyasmo' => 'smo',
'xlyahu' => 'hu',
'xlyah' => 'h',
'xima' => '',
'xenije' => '',
'xcyenye' => 'e',
'xcu' => 'cu',
'xcom' => 'com',
'xco' => 'co',
'xcem' => 'cem',
'xce' => 'e',
'xcama' => 'cama',
'xca' => 'ca',
'xanyu' => 'u',
'xanyima' => 'ima',
'xanyem' => 'em',
'xanya' => 'anya',
'xalyite' => '',
'xaca' => 'aca',
'vte' => 'te',
'vou' => 'u',
'voima' => 'ima',
'voi' => 'i',
'voe' => 'e',
'voa' => 'a',
'vmo' => 'mo',
'viti' => 'iti',
'vit' => 'it',
'vio' => 'io',
'vilo' => 'ilo',
'vili' => 'ili',
'vile' => 'ile',
'vila' => 'ila',
'vicyu' => 'icyu',
'vicyete' => 'icyete',
'vicyesx' => 'icyesx',
'vicyemo' => 'icyemo',
'vicye' => 'icye',
'vaka' => 'aka',
'vak' => 'ak',
'v' => '',
'ulomu' => 'ulomu',
'uloj' => 'uloj',
'uloga' => 'uloga',
'ulog' => 'ulog',
'ulim' => 'im',
'ulih' => 'ih',
'uknite' => 'ite',
'uknimo' => 'imo',
'ukanye' => 'kanye',
'uci' => 'ci',
'tusx' => 'tusx',
'tucyi' => 'cyi',
'tou' => 'u',
'toru' => 'u',
'toromu' => 'toromu',
'torom' => 'om',
'toroj' => 'toroj',
'toroga' => 'a',
'torog' => '',
'torim' => 'im',
'torih' => 'ih',
'tori' => 'i',
'tore' => 'e',
'tora' => 'a',
'tor' => '',
'toima' => 'ima',
'toi' => 'i',
'toe' => 'e',
'toa' => 'a',
'tnuto' => 'uto',
'tnuti' => 'uti',
'tnute' => 'ute',
'tnuta' => 'uta',
'tnut' => 'ut',
'tnu' => 'u',
'tnite' => 'ite',
'tnimo' => 'imo',
'tnete' => 'ete',
'tnesx' => 'esx',
'tnemo' => 'emo',
'tkute' => 'tkute',
'tkumo' => 'tkumo',
'tkujucyi' => 'tkujucyi',
'tkuju' => 'uju',
'tkujte' => 'tkujte',
'tkujmo' => 'tkujmo',
'tkujete' => 'ujete',
'tkujesx' => 'ujesx',
'tkujemo' => 'ujemo',
'tkujem' => 'ujem',
'tkuje' => 'uje',
'tkuj' => 'tkuj',
'tkovavsxi' => 'ovavsxi',
'tkovati' => 'ovati',
'tkovat' => 'ovat',
'tkovasxe' => 'ovasxe',
'tkovaste' => 'ovaste',
'tkovasmo' => 'ovasmo',
'tkovao' => 'ovao',
'tkovano' => 'ovano',
'tkovani' => 'ovani',
'tkovane' => 'ovane',
'tkovana' => 'ovana',
'tkovan' => 'ovan',
'tkovalo' => 'ovalo',
'tkovali' => 'ovali',
'tkovale' => 'ovale',
'tkovala' => 'ovala',
'tkovahu' => 'tkovahu',
'tkovah' => 'ovah',
'tkovacyu' => 'ovacyu',
'tkovacyete' => 'ovacyete',
'tkovacyesx' => 'ovacyesx',
'tkovacyemo' => 'ovacyemo',
'tkovacye' => 'ovacye',
'tkova' => 'ova',
'tkano' => 'no',
'tkani' => 'ni',
'tkane' => 'ne',
'tkana' => 'na',
'tkan' => 'n',
'tjelu' => 'tjelu',
'tjelomu' => 'tjelomu',
'tjelom' => 'tjelom',
'tjeloj' => 'tjeloj',
'tjeloga' => 'tjeloga',
'tjelog' => 'tjelog',
'tjelim' => 'tjelim',
'tjelih' => 'tjelih',
'tisxom' => 'om',
'tisxi' => 'i',
'tisxama' => 'tisxama',
'tisxa' => 'a',
'tijomu' => 'ijomu',
'tijom' => 'om',
'tijoj' => 'ijoj',
'tijim' => 'ijim',
'tijih' => 'ijih',
'tiji' => 'i',
'tijevsxi' => 'tijevsxi',
'tijeti' => 'tijeti',
'tijet' => 'tijet',
'tijeste' => 'tijeste',
'tijesmo' => 'tijesmo',
'tijemu' => 'ijemu',
'tijelo' => 'o',
'tijeli' => 'tijeli',
'tijele' => 'tijele',
'tijela' => 'a',
'tijeh' => 'tijeh',
'tijega' => 'ijega',
'tijeg' => 'ijeg',
'tijecyu' => 'tijecyu',
'tijecyete' => 'tijecyete',
'tijecyesx' => 'tijecyesx',
'tijecyemo' => 'tijecyemo',
'tijecye' => 'tijecye',
'tija' => 'a',
'tignucyima' => 'tignucyima',
'tignucyem' => 'tignucyem',
'tignucya' => 'tignucya',
'tie' => 'ie',
'tgodisxnyi' => 'tgodisxnyi',
'tezi' => 'i',
'tevima' => 'evima',
'tevi' => 'evi',
'teve' => 'eve',
'teva' => 'eva',
'teju' => 'teju',
'tejte' => 'tejte',
'tejmo' => 'tejmo',
'tej' => 'tej',
'tegu' => 'gu',
'tegom' => 'gom',
'tege' => 'ge',
'tegama' => 'gama',
'tanu' => 'nu',
'talima' => 'lima',
'taknuvsxi' => 'uvsxi',
'taknuto' => 'uto',
'taknuti' => 'uti',
'taknute' => 'ute',
'taknuta' => 'uta',
'taknut' => 'ut',
'taknusxe' => 'usxe',
'taknusx' => 'knusx',
'taknuste' => 'uste',
'taknusmo' => 'usmo',
'taknuo' => 'uo',
'taknumo' => 'knumo',
'taknulo' => 'ulo',
'taknuli' => 'uli',
'taknule' => 'ule',
'taknula' => 'ula',
'taknuh' => 'uh',
'taknucyu' => 'ucyu',
'taknucyete' => 'ucyete',
'taknucyesx' => 'ucyesx',
'taknucyemo' => 'ucyemo',
'taknucye' => 'ucye',
'taknu' => 'u',
'taknte' => 'knte',
'taknmo' => 'knmo',
'taknite' => 'ite',
'taknimo' => 'imo',
'takni' => 'i',
'taknete' => 'ete',
'taknesx' => 'esx',
'taknemo' => 'emo',
'taknem' => 'em',
'takne' => 'e',
'takn' => 'takn',
'taklo' => 'klo',
'takli' => 'i',
'takle' => 'e',
'takla' => 'kla',
'takao' => 'kao',
'taih' => 'ih',
'tagosxe' => 'tagosxe',
'tagoste' => 'tagoste',
'tagosmo' => 'tagosmo',
'tagoh' => 'tagoh',
'tago' => 'go',
'tagavsxi' => 'tagavsxi',
'tacyi' => '',
'tacy' => 'cy',
'sxou' => 'sxou',
'sxoima' => 'sxoima',
'sxoi' => 'sxoi',
'sxoe' => 'sxoe',
'sxoama' => 'sxoama',
'sxoa' => 'sxoa',
'sxlu' => 'lu',
'sxlomu' => 'omu',
'sxlom' => 'lom',
'sxloj' => 'oj',
'sxloga' => 'oga',
'sxlog' => 'og',
'sxlim' => 'im',
'sxlih' => 'ih',
'sxiveno' => 'iveno',
'sxiveni' => 'iveni',
'sxivene' => 'ivene',
'sxivena' => 'ivena',
'sxiven' => 'iven',
'sxiju' => 'u',
'sxijte' => 'ijte',
'sxijmo' => 'ijmo',
'sxijete' => 'ijete',
'sxijesx' => 'ijesx',
'sxijemo' => 'ijemo',
'sxijem' => 'ijem',
'sxije' => 'e',
'sxij' => 'ij',
'sxenye' => '',
'sxcyasxe' => 'xcyasxe',
'sxcyaste' => 'xcyaste',
'sxcyasmo' => 'xcyasmo',
'sxcyahu' => 'xcyahu',
'sxcyah' => 'xcyah',
'sxati' => 'ti',
'sxate' => 'te',
'sxat' => 't',
'sxasx' => 'sx',
'sxanye' => 'e',
'sxano' => 'no',
'sxani' => 'ni',
'sxane' => 'ne',
'sxana' => 'na',
'sxan' => 'n',
'sxamo' => 'mo',
'sxam' => 'm',
'sxalo' => 'lo',
'sxali' => 'li',
'sxale' => 'le',
'sxala' => 'la',
'sxaju' => 'ju',
'sxajte' => 'jte',
'sxajmo' => 'jmo',
'sxaj' => 'j',
'sxacyu' => 'cyu',
'sxacyete' => 'cyete',
'sxacyesx' => 'cyesx',
'sxacyemo' => 'cyemo',
'sxacye' => 'cye',
'stanye' => 'e',
'smu' => 'mu',
'smom' => 'mom',
'sma' => 'ma',
'skavsxi' => 'vsxi',
'skati' => 'ti',
'skate' => 'te',
'skat' => 't',
'skasxe' => 'sxe',
'skasx' => 'sx',
'skaste' => 'ste',
'skasmo' => 'smo',
'skao' => 'o',
'skano' => 'no',
'skani' => 'ni',
'skane' => 'ne',
'skana' => 'na',
'skan' => 'n',
'skamo' => 'mo',
'skam' => 'm',
'skalo' => 'lo',
'skali' => 'li',
'skale' => 'le',
'skala' => 'la',
'skaju' => 'ju',
'skajte' => 'jte',
'skajmo' => 'jmo',
'skaj' => 'j',
'skahu' => 'hu',
'skah' => 'h',
'skacyu' => 'cyu',
'skacyete' => 'cyete',
'skacyesx' => 'cyesx',
'skacyemo' => 'cyemo',
'skacye' => 'cye',
'secyi' => 'ecyi',
'satu' => 'u',
'satom' => 'om',
'rzati' => 'ti',
'rvo' => 'vo',
'rument' => 'rument',
'ruktor' => 'ruktor',
'rukost' => 't',
'ruga' => 'ga',
'rucxivati' => 'ivati',
'rti' => 'ti',
'rtahu' => 'tahu',
'rova' => 'ova',
'rosxiti' => 'iti',
'ronomski' => 'ronomski',
'ronomija' => 'a',
'ronom' => 'om',
'rojstvo' => '',
'rojenye' => 'rojenye',
'rofobija' => 'a',
'rlyati' => 'ti',
'rizati' => 'ti',
'rivati' => 'ivati',
'rina' => 'a',
'rilu' => 'u',
'rilom' => 'om',
'rilima' => 'ilima',
'riju' => 'u',
'rijski' => 'i',
'rijesxiti' => 'iti',
'rijeliti' => 'rijeliti',
'rijebiti' => 'iti',
'rig' => 'rig',
'ricyom' => 'om',
'ricyima' => 'ima',
'ricya' => 'a',
'rgati' => 'ti',
'resxnica' => 'a',
'reste' => 'este',
'resmo' => 'esmo',
'resati' => 'ati',
'reo' => 'eo',
'renyu' => 'u',
'renu' => 'u',
'relo' => 'elo',
'reliti' => 'reliti',
'reli' => 'eli',
'rele' => 'ele',
'rela' => 'ela',
'rega' => 'ga',
'reg' => 'g',
'recyi' => 'cyi',
'reblyivati' => 'reblyivati',
'rebiti' => 'iti',
'rcxavati' => 'ti',
'rcxati' => 'ati',
'razxivacxki' => 'razxivacxki',
'razxiti' => 'iti',
'ratmo' => 'tmo',
'ratiti' => 'titi',
'ratite' => 'tite',
'ratit' => 'tit',
'ratisx' => 'tisx',
'ratio' => 'tio',
'ratimo' => 'timo',
'ratim' => 'tim',
'ratilo' => 'tilo',
'ratili' => 'tili',
'ratile' => 'tile',
'ratila' => 'tila',
'raticyu' => 'ticyu',
'raticyete' => 'ticyete',
'raticyesx' => 'ticyesx',
'raticyemo' => 'ticyemo',
'raticye' => 'ticye',
'rasxlyiv' => '',
'rasxivsxi' => 'ivsxi',
'rasxisxe' => 'isxe',
'rasxiste' => 'iste',
'rasxismo' => 'ismo',
'rasxih' => 'ih',
'rasxcyu' => 'sxcyu',
'rasxcyete' => 'sxcyete',
'rasxcyesx' => 'sxcyesx',
'rasxcyemo' => 'sxcyemo',
'rasxasxe' => 'asxe',
'rasxaste' => 'aste',
'rasxasmo' => 'asmo',
'rasxahu' => 'ahu',
'rasxah' => 'ah',
'rastosxe' => 'stosxe',
'rastoste' => 'stoste',
'rastosmo' => 'stosmo',
'rastomu' => 'omu',
'rastom' => 'om',
'rastoj' => 'oj',
'rastoh' => 'stoh',
'rastoga' => 'oga',
'rastog' => 'og',
'rasto' => 'o',
'rastite' => 'stite',
'rastimo' => 'stimo',
'rastim' => 'im',
'rastih' => 'ih',
'rastete' => 'stete',
'rastesx' => 'stesx',
'rasteno' => 'steno',
'rasteni' => 'steni',
'rastene' => 'stene',
'rastena' => 'stena',
'rasten' => 'sten',
'rastemo' => 'stemo',
'rastem' => 'stem',
'rasta' => 'a',
'rast' => '',
'rasiti' => 'iti',
'rasite' => 'ite',
'rasit' => 'it',
'rasisx' => 'isx',
'rasio' => 'io',
'rasimo' => 'imo',
'rasim' => 'im',
'rasilo' => 'ilo',
'rasili' => 'ili',
'rasile' => 'ile',
'rasila' => 'ila',
'rasicyu' => 'icyu',
'rasicyete' => 'icyete',
'rasicyesx' => 'icyesx',
'rasicyemo' => 'icyemo',
'rasicye' => 'icye',
'rasi' => 'i',
'rase' => 'e',
'ras' => 's',
'ranyu' => 'nyu',
'ranyima' => 'ima',
'ranyenost' => 't',
'ranyem' => 'em',
'ranya' => 'a',
'rant' => '',
'ranstvo' => 'vo',
'ranski' => 'i',
'ranka' => 'ka',
'ranacxki' => 'i',
'rakt' => '',
'rajnost' => 't',
'rahovati' => 'ovati',
'rahirati' => 'ti',
'raga' => 'ga',
'racyeno' => 'cyeno',
'racyeni' => 'cyeni',
'racyene' => 'cyene',
'racyena' => 'cyena',
'racyen' => 'cyen',
'psxeno' => 'xeno',
'psxeni' => 'xeni',
'psxene' => 'xene',
'psxena' => 'xena',
'psxen' => 'xen',
'pste' => 'te',
'pssxe' => 'pssxe',
'psmo' => 'mo',
'pslo' => 'pslo',
'psli' => 'psli',
'psle' => 'psle',
'psla' => 'psla',
'psavsxi' => 'avsxi',
'psati' => 'ati',
'psat' => 'at',
'psasxe' => 'asxe',
'psaste' => 'aste',
'psasmo' => 'asmo',
'psalo' => 'alo',
'psali' => 'ali',
'psale' => 'ale',
'psala' => 'ala',
'psahu' => 'psahu',
'psah' => 'ah',
'psacyu' => 'acyu',
'psacyete' => 'acyete',
'psacyesx' => 'acyesx',
'psacyemo' => 'acyemo',
'psacye' => 'acye',
'ps' => '',
'pkama' => 'kama',
'pjevsxi' => 'jevsxi',
'pjeveno' => 'pjeveno',
'pjeveni' => 'pjeveni',
'pjevene' => 'pjevene',
'pjevena' => 'pjevena',
'pjeven' => 'pjeven',
'pjeti' => 'jeti',
'pjet' => 'jet',
'pjesxe' => 'jesxe',
'pjeste' => 'jeste',
'pjesmo' => 'jesmo',
'pjelo' => 'jelo',
'pjeli' => 'jeli',
'pjele' => 'jele',
'pjela' => 'jela',
'pjeh' => 'jeh',
'pjecyu' => 'jecyu',
'pjecyete' => 'jecyete',
'pjecyesx' => 'jecyesx',
'pjecyemo' => 'jecyemo',
'pjecye' => 'jecye',
'pje' => 'je',
'pima' => 'ima',
'piju' => 'u',
'pijte' => 'ijte',
'pijmo' => 'ijmo',
'pijete' => 'ijete',
'pijesx' => 'ijesx',
'pijemo' => 'ijemo',
'pijem' => 'ijem',
'pije' => 'e',
'pij' => 'ij',
'pcxu' => 'pcxu',
'pcxom' => 'pcxom',
'pcxim' => 'im',
'pcxavsxi' => 'vsxi',
'pcxati' => 'ti',
'pcxat' => 't',
'pcxasxe' => 'sxe',
'pcxaste' => 'ste',
'pcxasmo' => 'smo',
'pcxao' => 'o',
'pcxanye' => 'nye',
'pcxano' => 'no',
'pcxani' => 'ni',
'pcxane' => 'ne',
'pcxana' => 'na',
'pcxan' => 'n',
'pcxalo' => 'lo',
'pcxali' => 'li',
'pcxale' => 'le',
'pcxala' => 'la',
'pcxahu' => 'hu',
'pcxah' => 'h',
'pcxacyu' => 'cyu',
'pcxacyete' => 'cyete',
'pcxacyesx' => 'cyesx',
'pcxacyemo' => 'cyemo',
'pcxacye' => 'cye',
'paka' => 'aka',
'ozi' => 'zi',
'ovanyu' => 'u',
'ovanyima' => 'ima',
'ovanyem' => 'em',
'oro' => 'o',
'omte' => 'te',
'omlyeno' => 'lyeno',
'omlyeni' => 'lyeni',
'omlyene' => 'lyene',
'omlyena' => 'lyena',
'omlyen' => 'lyen',
'omivsxi' => 'ivsxi',
'omiti' => 'iti',
'omite' => 'ite',
'omit' => 'it',
'omisxe' => 'isxe',
'omisx' => 'isx',
'omiste' => 'iste',
'omismo' => 'ismo',
'omio' => 'io',
'omimo' => 'imo',
'omilo' => 'ilo',
'omili' => 'i',
'omile' => 'e',
'omila' => 'ila',
'omicyu' => 'icyu',
'omicyete' => 'icyete',
'omicyesx' => 'icyesx',
'omicyemo' => 'icyemo',
'omicye' => 'icye',
'olyima' => 'ima',
'olya' => 'a',
'oli' => 'i',
'ole' => 'e',
'ola' => 'a',
'ognete' => 'ognete',
'ognesx' => 'ognesx',
'ognemo' => 'ognemo',
'ocxnyacxa' => 'cxnyacxa',
'ocxnica' => 'a',
'ocama' => 'ama',
'obova' => 'ova',
'obom' => 'om',
'nyomu' => 'omu',
'nyoj' => 'oj',
'nyoga' => 'oga',
'nyog' => 'og',
'nyiv' => '',
'nyenyu' => 'u',
'nyate' => 'te',
'nyasx' => 'sx',
'nyanye' => 'nye',
'nyamo' => 'mo',
'nyam' => 'm',
'nyaju' => 'ju',
'nyajte' => 'jte',
'nyajmo' => 'jmo',
'nyaj' => 'j',
'nucyi' => 'ucyi',
'nou' => 'u',
'noima' => 'ima',
'noi' => 'i',
'noe' => 'e',
'noa' => 'a',
'nijevsxi' => 'ijevsxi',
'nijeti' => 'ijeti',
'nijet' => 'ijet',
'nijesxe' => 'ijesxe',
'nijeste' => 'ijeste',
'nijesmo' => 'ijesmo',
'nijeno' => 'ijeno',
'nijeni' => 'ijeni',
'nijene' => 'ijene',
'nijena' => 'ijena',
'nijen' => 'ijen',
'nijelo' => 'ijelo',
'nijeli' => 'ijeli',
'nijele' => 'ijele',
'nijela' => 'ijela',
'nijeh' => 'ijeh',
'nijecyu' => 'ijecyu',
'nijecyete' => 'ijecyete',
'nijecyesx' => 'ijecyesx',
'nijecyemo' => 'ijecyemo',
'nijecye' => 'ijecye',
'nie' => 'e',
'momu' => 'omu',
'moj' => 'oj',
'moga' => 'oga',
'mog' => 'og',
'menima' => 'menima',
'menem' => 'em',
'mena' => 'a',
'mavsxi' => 'vsxi',
'mati' => 'ti',
'mate' => 'te',
'mat' => 't',
'masx' => 'sx',
'mao' => 'o',
'mano' => 'no',
'mani' => 'ni',
'mane' => 'ne',
'mana' => 'na',
'man' => 'n',
'mamo' => 'mo',
'mam' => 'm',
'malo' => 'lo',
'mali' => 'li',
'male' => 'le',
'mala' => 'la',
'maknuvsxi' => 'aknuvsxi',
'maknuto' => 'aknuto',
'maknuti' => 'aknuti',
'maknute' => 'aknute',
'maknuta' => 'aknuta',
'maknut' => 'aknut',
'maknusxe' => 'aknusxe',
'maknusx' => 'aknusx',
'maknuste' => 'aknuste',
'maknusmo' => 'aknusmo',
'maknuo' => 'aknuo',
'maknumo' => 'aknumo',
'maknulo' => 'aknulo',
'maknuli' => 'aknuli',
'maknule' => 'aknule',
'maknula' => 'aknula',
'maknuh' => 'aknuh',
'maknucyu' => 'aknucyu',
'maknucyete' => 'aknucyete',
'maknucyesx' => 'aknucyesx',
'maknucyemo' => 'aknucyemo',
'maknucye' => 'aknucye',
'maknu' => 'aknu',
'maknte' => 'aknte',
'maknmo' => 'aknmo',
'maknite' => 'aknite',
'maknimo' => 'aknimo',
'makni' => 'akni',
'maknete' => 'aknete',
'maknesx' => 'aknesx',
'maknemo' => 'aknemo',
'maknem' => 'aknem',
'makne' => 'akne',
'makn' => 'akn',
'maklo' => 'aklo',
'makli' => 'akli',
'makle' => 'akle',
'makla' => 'akla',
'makao' => 'akao',
'maih' => 'aih',
'mahu' => 'hu',
'mah' => 'h',
'magosxe' => 'agosxe',
'magoste' => 'agoste',
'magosmo' => 'agosmo',
'magoh' => 'agoh',
'mago' => 'ago',
'magavsxi' => 'agavsxi',
'macy' => 'acy',
'lyuju' => 'uju',
'lyujite' => 'ujite',
'lyujimo' => 'ujimo',
'lyuji' => 'uji',
'lyujete' => 'ujete',
'lyujesx' => 'ujesx',
'lyujemo' => 'ujemo',
'lyujem' => 'ujem',
'lyuje' => 'uje',
'lyenoj' => 'oj',
'lyenih' => 'ih',
'lyedyivati' => 'lyedyivati',
'lyednyi' => 'lyednyi',
'lyecyi' => 'ecyi',
'ltima' => 'ima',
'lt' => '',
'lovu' => 'u',
'lovomu' => 'omu',
'lovom' => 'om',
'lovoj' => 'oj',
'lovoga' => 'oga',
'lovog' => 'og',
'lovo' => 'o',
'lovim' => 'im',
'lovih' => 'ih',
'lov' => '',
'lomte' => 'te',
'lomo' => 'o',
'lomlyeno' => 'lyeno',
'lomlyeni' => 'lyeni',
'lomlyene' => 'lyene',
'lomlyena' => 'lyena',
'lomlyen' => 'lyen',
'lomivsxi' => 'ivsxi',
'lomiti' => 'iti',
'lomite' => 'ite',
'lomit' => 'it',
'lomisxe' => 'isxe',
'lomisx' => 'isx',
'lomiste' => 'iste',
'lomismo' => 'ismo',
'lomio' => 'io',
'lomimo' => 'imo',
'lomim' => 'im',
'lomilo' => 'ilo',
'lomili' => 'ili',
'lomile' => 'ile',
'lomila' => 'ila',
'lomih' => 'ih',
'lomicyu' => 'icyu',
'lomicyete' => 'icyete',
'lomicyesx' => 'icyesx',
'lomicyemo' => 'icyemo',
'lomicye' => 'icye',
'liveno' => 'iveno',
'liveni' => 'iveni',
'livene' => 'ivene',
'livena' => 'ivena',
'liven' => 'iven',
'lijte' => 'ijte',
'lijom' => 'om',
'lijmo' => 'ijmo',
'liji' => 'i',
'lijete' => 'ijete',
'lijesx' => 'ijesx',
'lijemo' => 'ijemo',
'lija' => 'a',
'lij' => 'ij',
'licyite' => 'cyite',
'licyimo' => 'cyimo',
'licyem' => 'cyem',
'letomu' => 'omu',
'letoj' => 'oj',
'letoga' => 'oga',
'letog' => 'og',
'leto' => 'o',
'letim' => 'tim',
'letih' => 'ih',
'lete' => 'e',
'lecyi' => 'cyi',
'lecya' => 'a',
'latmo' => 'tmo',
'latiti' => 'titi',
'latite' => 'tite',
'latit' => 'tit',
'latisx' => 'tisx',
'latio' => 'tio',
'latimo' => 'timo',
'latilo' => 'tilo',
'latili' => 'tili',
'latile' => 'tile',
'latila' => 'tila',
'latih' => 'tih',
'laticyu' => 'ticyu',
'laticyete' => 'ticyete',
'laticyesx' => 'ticyesx',
'laticyemo' => 'ticyemo',
'laticye' => 'ticye',
'lata' => 'a',
'lalyu' => 'lyu',
'lalyite' => 'lyite',
'lalyimo' => 'lyimo',
'lalyi' => 'lyi',
'lalyete' => 'lyete',
'lalyesx' => 'lyesx',
'lalyemo' => 'lyemo',
'lalyem' => 'lyem',
'lalye' => 'lye',
'ladima' => 'adima',
'ladi' => 'i',
'lad' => '',
'lacyeno' => 'cyeno',
'lacyeni' => 'cyeni',
'lacyene' => 'cyene',
'lacyena' => 'cyena',
'lacyen' => 'cyen',
'kujite' => 'ujite',
'kujimo' => 'ujimo',
'kuji' => 'uji',
'komo' => 'komo',
'knucyima' => 'ucyima',
'knucyem' => 'ucyem',
'knucya' => 'ucya',
'knom' => 'nom',
'kno' => 'no',
'kna' => 'na',
'kivavsxi' => 'ivavsxi',
'kivati' => 'ivati',
'kivat' => 'ivat',
'kivasxe' => 'ivasxe',
'kivaste' => 'ivaste',
'kivasmo' => 'ivasmo',
'kivao' => 'ivao',
'kivano' => 'ivano',
'kivani' => 'ivani',
'kivane' => 'ivane',
'kivana' => 'ivana',
'kivan' => 'ivan',
'kivalo' => 'ivalo',
'kivali' => 'ivali',
'kivale' => 'ivale',
'kivala' => 'ivala',
'kivahu' => 'ivahu',
'kivah' => 'ivah',
'kivacyu' => 'ivacyu',
'kivacyete' => 'ivacyete',
'kivacyesx' => 'ivacyesx',
'kivacyemo' => 'ivacyemo',
'kivacye' => 'ivacye',
'kiva' => 'iva',
'katomu' => 'omu',
'katoj' => 'oj',
'katoga' => 'oga',
'katog' => 'og',
'kato' => 'o',
'katim' => 'im',
'katih' => 'ih',
'kast' => '',
'kacyi' => 'cyi',
'jujete' => 'ujete',
'jujesx' => 'ujesx',
'jujemo' => 'ujemo',
'jujem' => 'ujem',
'juje' => 'uje',
'jucyu' => 'u',
'jucyom' => 'om',
'jucyo' => 'o',
'jucyemu' => 'emu',
'jucyem' => 'em',
'jucyega' => 'ega',
'jucyeg' => 'eg',
'jucye' => 'e',
'jucya' => 'a',
'joj' => 'oj',
'jiti' => 'ti',
'jit' => 't',
'jisx' => 'isx',
'jio' => 'o',
'jilo' => 'lo',
'jili' => 'li',
'jile' => 'le',
'jila' => 'la',
'jicyu' => 'cyu',
'jicyete' => 'cyete',
'jicyesx' => 'cyesx',
'jicyemo' => 'cyemo',
'jicye' => 'cye',
'jerivati' => 'ivati',
'jerati' => 'ti',
'jema' => 'a',
'jegnuvsxi' => 'gnuvsxi',
'jegnuto' => 'gnuto',
'jegnuti' => 'gnuti',
'jegnute' => 'gnute',
'jegnuta' => 'gnuta',
'jegnut' => 'gnut',
'jegnusxe' => 'gnusxe',
'jegnuste' => 'gnuste',
'jegnusmo' => 'gnusmo',
'jegnuo' => 'gnuo',
'jegnulo' => 'gnulo',
'jegnuli' => 'gnuli',
'jegnule' => 'gnule',
'jegnula' => 'gnula',
'jegnuh' => 'gnuh',
'jegnucyu' => 'gnucyu',
'jegnucyete' => 'gnucyete',
'jegnucyesx' => 'gnucyesx',
'jegnucyemo' => 'gnucyemo',
'jegnucye' => 'gnucye',
'jegnu' => 'gnu',
'jegnite' => 'gnite',
'jegnimo' => 'gnimo',
'jegni' => 'gni',
'jegnete' => 'gnete',
'jegnesx' => 'gnesx',
'jegnemo' => 'gnemo',
'jegnem' => 'gnem',
'jegne' => 'gne',
'jega' => 'ga',
'jedyenyu' => 'u',
'jecyima' => 'ima',
'jecyi' => 'cyi',
'jecyem' => 'cyem',
'jecya' => 'a',
'jecy' => 'cy',
'jecati' => 'ti',
'ivima' => 'ima',
'ivajucyi' => 'ajucyi',
'itku' => 'tku',
'itkom' => 'tkom',
'itke' => 'tke',
'itka' => 'tka',
'itaka' => 'taka',
'itak' => 'tak',
'isxevima' => 'xevima',
'isxevi' => 'xevi',
'isxeve' => 'xeve',
'isxeva' => 'xeva',
'irzavsxi' => 'irzavsxi',
'irzati' => 'irzati',
'irzate' => 'irzate',
'irzat' => 'irzat',
'irzasxe' => 'irzasxe',
'irzasx' => 'irzasx',
'irzaste' => 'irzaste',
'irzasmo' => 'irzasmo',
'irzao' => 'irzao',
'irzano' => 'irzano',
'irzani' => 'irzani',
'irzane' => 'irzane',
'irzana' => 'irzana',
'irzan' => 'irzan',
'irzamo' => 'irzamo',
'irzam' => 'irzam',
'irzalo' => 'irzalo',
'irzali' => 'irzali',
'irzale' => 'irzale',
'irzala' => 'irzala',
'irzaju' => 'irzaju',
'irzajte' => 'irzajte',
'irzajmo' => 'irzajmo',
'irzaj' => 'irzaj',
'irzah' => 'irzah',
'irzacyu' => 'irzacyu',
'irzacyete' => 'irzacyete',
'irzacyesx' => 'irzacyesx',
'irzacyemo' => 'irzacyemo',
'irzacye' => 'irzacye',
'irza' => 'irza',
'irvima' => 'irvima',
'iruzi' => 'iruzi',
'irumentu' => 'irumentu',
'irumentom' => 'irumentom',
'irumentima' => 'irumentima',
'irumenti' => 'irumenti',
'irumente' => 'irumente',
'irumenta' => 'irumenta',
'irument' => 'irument',
'iruktoru' => 'iruktoru',
'iruktorom' => 'iruktorom',
'iruktorima' => 'iruktorima',
'iruktori' => 'iruktori',
'iruktore' => 'iruktore',
'iruktora' => 'iruktora',
'iruktor' => 'iruktor',
'irukosxcyu' => 'irukosxcyu',
'irukostima' => 'irukostima',
'irukosti' => 'irukosti',
'iruja' => 'iruja',
'iruisxenye' => 'iruisxenye',
'iruiranye' => 'iruiranye',
'irugu' => 'irugu',
'irugom' => 'irugom',
'irugo' => 'irugo',
'iruge' => 'iruge',
'irugama' => 'irugama',
'irucxivavsxi' => 'irucxivavsxi',
'irucxivati' => 'irucxivati',
'irucxivat' => 'irucxivat',
'irucxivasxe' => 'irucxivasxe',
'irucxivaste' => 'irucxivaste',
'irucxivasmo' => 'irucxivasmo',
'irucxivao' => 'irucxivao',
'irucxivano' => 'irucxivano',
'irucxivani' => 'irucxivani',
'irucxivane' => 'irucxivane',
'irucxivana' => 'irucxivana',
'irucxivan' => 'irucxivan',
'irucxivalo' => 'irucxivalo',
'irucxivali' => 'irucxivali',
'irucxivale' => 'irucxivale',
'irucxivala' => 'irucxivala',
'irucxivahu' => 'irucxivahu',
'irucxivah' => 'irucxivah',
'irucxivacyu' => 'irucxivacyu',
'irucxivacyete' => 'irucxivacyete',
'irucxivacyesx' => 'irucxivacyesx',
'irucxivacyemo' => 'irucxivacyemo',
'irucxivacye' => 'irucxivacye',
'irucxiva' => 'irucxiva',
'irucxasxe' => 'irucxasxe',
'irucxaste' => 'irucxaste',
'irucxasmo' => 'irucxasmo',
'irucxahu' => 'irucxahu',
'irucxah' => 'irucxah',
'irosxte' => 'irosxte',
'irosxmo' => 'irosxmo',
'irosxivsxi' => 'irosxivsxi',
'irosxiti' => 'irosxiti',
'irosxite' => 'irosxite',
'irosxit' => 'irosxit',
'irosxisxe' => 'irosxisxe',
'irosxisx' => 'irosxisx',
'irosxiste' => 'irosxiste',
'irosxismo' => 'irosxismo',
'irosxio' => 'irosxio',
'irosximo' => 'irosximo',
'irosxim' => 'irosxim',
'irosxilo' => 'irosxilo',
'irosxili' => 'irosxili',
'irosxile' => 'irosxile',
'irosxila' => 'irosxila',
'irosxih' => 'irosxih',
'irosxicyu' => 'irosxicyu',
'irosxicyete' => 'irosxicyete',
'irosxicyesx' => 'irosxicyesx',
'irosxicyemo' => 'irosxicyemo',
'irosxicye' => 'irosxicye',
'irosxi' => 'irosxi',
'irosxeno' => 'irosxeno',
'irosxeni' => 'irosxeni',
'irosxene' => 'irosxene',
'irosxena' => 'irosxena',
'irosxen' => 'irosxen',
'irosxe' => 'irosxe',
'irosx' => 'irosx',
'ironomu' => 'ironomu',
'ironomsku' => 'ironomsku',
'ironomskomu' => 'ironomskomu',
'ironomskom' => 'ironomskom',
'ironomskoj' => 'ironomskoj',
'ironomskoga' => 'ironomskoga',
'ironomskog' => 'ironomskog',
'ironomsko' => 'ironomsko',
'ironomskim' => 'ironomskim',
'ironomskih' => 'ironomskih',
'ironomski' => 'ironomski',
'ironomske' => 'ironomske',
'ironomska' => 'ironomska',
'ironomom' => 'ironomom',
'ironomima' => 'ironomima',
'ironomiju' => 'ironomiju',
'ironomijom' => 'ironomijom',
'ironomijo' => 'ironomijo',
'ironomiji' => 'ironomiji',
'ironomije' => 'ironomije',
'ironomijama' => 'ironomijama',
'ironomija' => 'ironomija',
'ironomi' => 'ironomi',
'ironome' => 'ironome',
'ironoma' => 'ironoma',
'ironom' => 'ironom',
'iromu' => 'iromu',
'irojstvou' => 'irojstvou',
'irojstvom' => 'irojstvom',
'irojstvoima' => 'irojstvoima',
'irojstvoi' => 'irojstvoi',
'irojstvoe' => 'irojstvoe',
'irojstvoa' => 'irojstvoa',
'irojstvo' => 'irojstvo',
'irojenyu' => 'irojenyu',
'irojenyima' => 'irojenyima',
'irojenyem' => 'irojenyem',
'irojenye' => 'irojenye',
'irojenya' => 'irojenya',
'iroga' => 'iroga',
'irog' => 'irog',
'irofu' => 'irofu',
'irofom' => 'irofom',
'irofobiju' => 'irofobiju',
'irofobijom' => 'irofobijom',
'irofobijo' => 'irofobijo',
'irofobiji' => 'irofobiji',
'irofobije' => 'irofobije',
'irofobijama' => 'irofobijama',
'irofobija' => 'irofobija',
'irofi' => 'irofi',
'irofe' => 'irofe',
'irofa' => 'irofa',
'irlyavsxi' => 'irlyavsxi',
'irlyati' => 'irlyati',
'irlyate' => 'irlyate',
'irlyat' => 'irlyat',
'irlyasxe' => 'irlyasxe',
'irlyasx' => 'irlyasx',
'irlyaste' => 'irlyaste',
'irlyasmo' => 'irlyasmo',
'irlyao' => 'irlyao',
'irlyano' => 'irlyano',
'irlyani' => 'irlyani',
'irlyane' => 'irlyane',
'irlyana' => 'irlyana',
'irlyan' => 'irlyan',
'irlyamo' => 'irlyamo',
'irlyam' => 'irlyam',
'irlyalo' => 'irlyalo',
'irlyali' => 'irlyali',
'irlyale' => 'irlyale',
'irlyala' => 'irlyala',
'irlyaju' => 'irlyaju',
'irlyajte' => 'irlyajte',
'irlyajmo' => 'irlyajmo',
'irlyaj' => 'irlyaj',
'irlyah' => 'irlyah',
'irlyacyu' => 'irlyacyu',
'irlyacyete' => 'irlyacyete',
'irlyacyesx' => 'irlyacyesx',
'irlyacyemo' => 'irlyacyemo',
'irlyacye' => 'irlyacye',
'irlya' => 'irlya',
'irizima' => 'irizima',
'irizavsxi' => 'irizavsxi',
'irizati' => 'irizati',
'irizate' => 'irizate',
'irizat' => 'irizat',
'irizasxe' => 'irizasxe',
'irizasx' => 'irizasx',
'irizaste' => 'irizaste',
'irizasmo' => 'irizasmo',
'irizao' => 'irizao',
'irizano' => 'irizano',
'irizani' => 'irizani',
'irizane' => 'irizane',
'irizana' => 'irizana',
'irizan' => 'irizan',
'irizamo' => 'irizamo',
'irizam' => 'am',
'irizalo' => 'irizalo',
'irizali' => 'irizali',
'irizale' => 'irizale',
'irizala' => 'irizala',
'irizaju' => 'irizaju',
'irizajte' => 'irizajte',
'irizajmo' => 'irizajmo',
'irizaj' => 'irizaj',
'irizahu' => 'irizahu',
'irizah' => 'irizah',
'irizacyu' => 'irizacyu',
'irizacyete' => 'irizacyete',
'irizacyesx' => 'irizacyesx',
'irizacyemo' => 'irizacyemo',
'irizacye' => 'irizacye',
'iriza' => 'iriza',
'iriranye' => 'iriranye',
'irinu' => 'irinu',
'irinom' => 'irinom',
'irino' => 'irino',
'irini' => 'irini',
'irine' => 'irine',
'irinama' => 'irinama',
'irina' => 'irina',
'irijsku' => 'u',
'irijskomu' => 'omu',
'irijskom' => 'om',
'irijskoj' => 'oj',
'irijskoga' => 'oga',
'irijskog' => 'og',
'irijsko' => 'o',
'irijskim' => 'im',
'irijskih' => 'ih',
'irijski' => 'i',
'irijske' => 'e',
'irijska' => 'a',
'irijesxivsxi' => 'irijesxivsxi',
'irijesxiti' => 'irijesxiti',
'irijesxit' => 'irijesxit',
'irijesxisxe' => 'irijesxisxe',
'irijesxiste' => 'irijesxiste',
'irijesxismo' => 'irijesxismo',
'irijesxio' => 'irijesxio',
'irijesxilo' => 'irijesxilo',
'irijesxili' => 'irijesxili',
'irijesxile' => 'irijesxile',
'irijesxila' => 'irijesxila',
'irijesxih' => 'irijesxih',
'irijesxicyu' => 'irijesxicyu',
'irijesxicyete' => 'irijesxicyete',
'irijesxicyesx' => 'irijesxicyesx',
'irijesxicyemo' => 'irijesxicyemo',
'irijesxicye' => 'irijesxicye',
'irijesxi' => 'irijesxi',
'irijelyeno' => 'irijelyeno',
'irijelyeni' => 'irijelyeni',
'irijelyene' => 'irijelyene',
'irijelyena' => 'irijelyena',
'irijelyen' => 'irijelyen',
'irijelte' => 'irijelte',
'irijelmo' => 'irijelmo',
'irijelivsxi' => 'irijelivsxi',
'irijeliti' => 'irijeliti',
'irijelite' => 'irijelite',
'irijelit' => 'irijelit',
'irijelisxe' => 'irijelisxe',
'irijelisx' => 'irijelisx',
'irijeliste' => 'irijeliste',
'irijelismo' => 'irijelismo',
'irijelio' => 'irijelio',
'irijelimo' => 'irijelimo',
'irijelim' => 'irijelim',
'irijelilo' => 'irijelilo',
'irijelili' => 'irijelili',
'irijelile' => 'irijelile',
'irijelila' => 'irijelila',
'irijelih' => 'irijelih',
'irijelicyu' => 'irijelicyu',
'irijelicyete' => 'irijelicyete',
'irijelicyesx' => 'irijelicyesx',
'irijelicyemo' => 'irijelicyemo',
'irijelicye' => 'irijelicye',
'irijel' => 'irijel',
'irijebte' => 'irijebte',
'irijebmo' => 'irijebmo',
'irijeblyeno' => 'irijeblyeno',
'irijeblyeni' => 'irijeblyeni',
'irijeblyene' => 'irijeblyene',
'irijeblyena' => 'irijeblyena',
'irijeblyen' => 'irijeblyen',
'irijebivsxi' => 'irijebivsxi',
'irijebiti' => 'irijebiti',
'irijebite' => 'irijebite',
'irijebit' => 'irijebit',
'irijebisxe' => 'irijebisxe',
'irijebisx' => 'irijebisx',
'irijebiste' => 'irijebiste',
'irijebismo' => 'irijebismo',
'irijebio' => 'irijebio',
'irijebimo' => 'irijebimo',
'irijebim' => 'irijebim',
'irijebilo' => 'irijebilo',
'irijebili' => 'irijebili',
'irijebile' => 'irijebile',
'irijebila' => 'irijebila',
'irijebih' => 'irijebih',
'irijebicyu' => 'irijebicyu',
'irijebicyete' => 'irijebicyete',
'irijebicyesx' => 'irijebicyesx',
'irijebicyemo' => 'irijebicyemo',
'irijebicye' => 'irijebicye',
'irijebi' => 'irijebi',
'irijebe' => 'irijebe',
'irijeb' => 'irijeb',
'irici' => 'i',
'irgnuvsxi' => 'irgnuvsxi',
'irgnuto' => 'irgnuto',
'irgnuti' => 'irgnuti',
'irgnute' => 'irgnute',
'irgnuta' => 'irgnuta',
'irgnut' => 'irgnut',
'irgnusxe' => 'irgnusxe',
'irgnuste' => 'irgnuste',
'irgnusmo' => 'irgnusmo',
'irgnuo' => 'irgnuo',
'irgnulo' => 'irgnulo',
'irgnuli' => 'irgnuli',
'irgnule' => 'irgnule',
'irgnula' => 'irgnula',
'irgnuh' => 'irgnuh',
'irgnucyu' => 'irgnucyu',
'irgnucyete' => 'irgnucyete',
'irgnucyesx' => 'irgnucyesx',
'irgnucyemo' => 'irgnucyemo',
'irgnucye' => 'irgnucye',
'irgnu' => 'irgnu',
'irgnite' => 'irgnite',
'irgnimo' => 'irgnimo',
'irgni' => 'irgni',
'irgnete' => 'irgnete',
'irgnesx' => 'irgnesx',
'irgnemo' => 'irgnemo',
'irgnem' => 'irgnem',
'irgne' => 'irgne',
'irgavsxi' => 'irgavsxi',
'irgati' => 'irgati',
'irgate' => 'irgate',
'irgat' => 'irgat',
'irgasxe' => 'irgasxe',
'irgasx' => 'irgasx',
'irgaste' => 'irgaste',
'irgasmo' => 'irgasmo',
'irgao' => 'irgao',
'irgano' => 'irgano',
'irgani' => 'irgani',
'irgane' => 'irgane',
'irgana' => 'irgana',
'irgan' => 'irgan',
'irgamo' => 'irgamo',
'irgam' => 'irgam',
'irgalo' => 'irgalo',
'irgali' => 'irgali',
'irgale' => 'irgale',
'irgala' => 'irgala',
'irgaju' => 'irgaju',
'irgajte' => 'irgajte',
'irgajmo' => 'irgajmo',
'irgaj' => 'irgaj',
'irgah' => 'irgah',
'irgacyu' => 'irgacyu',
'irgacyete' => 'irgacyete',
'irgacyesx' => 'irgacyesx',
'irgacyemo' => 'irgacyemo',
'irgacye' => 'irgacye',
'irga' => 'irga',
'iresxte' => 'iresxte',
'iresxnicu' => 'iresxnicu',
'iresxnicom' => 'iresxnicom',
'iresxnico' => 'iresxnico',
'iresxnici' => 'iresxnici',
'iresxnice' => 'iresxnice',
'iresxnicama' => 'iresxnicama',
'iresxnica' => 'iresxnica',
'iresxmo' => 'iresxmo',
'iresxivsxi' => 'iresxivsxi',
'iresxiti' => 'iresxiti',
'iresxit' => 'iresxit',
'iresxisxe' => 'iresxisxe',
'iresxisx' => 'iresxisx',
'iresxiste' => 'iresxiste',
'iresxismo' => 'iresxismo',
'iresxio' => 'iresxio',
'iresxim' => 'iresxim',
'iresxilo' => 'iresxilo',
'iresxili' => 'iresxili',
'iresxile' => 'iresxile',
'iresxila' => 'iresxila',
'iresxih' => 'iresxih',
'iresxicyu' => 'iresxicyu',
'iresxicyete' => 'iresxicyete',
'iresxicyesx' => 'iresxicyesx',
'iresxicyemo' => 'iresxicyemo',
'iresxicye' => 'iresxicye',
'iresxeno' => 'iresxeno',
'iresxeni' => 'iresxeni',
'iresxene' => 'iresxene',
'iresxena' => 'iresxena',
'iresxen' => 'iresxen',
'iresxcyu' => 'iresxcyu',
'iresxcyete' => 'iresxcyete',
'iresxcyesx' => 'iresxcyesx',
'iresxcyemo' => 'iresxcyemo',
'iresxcye' => 'iresxcye',
'iresti' => 'iresti',
'irest' => 'irest',
'iresite' => 'iresite',
'iresem' => 'iresem',
'irese' => 'irese',
'iresavsxi' => 'iresavsxi',
'iresati' => 'iresati',
'iresat' => 'iresat',
'iresasxe' => 'iresasxe',
'iresaste' => 'iresaste',
'iresasmo' => 'iresasmo',
'iresao' => 'iresao',
'iresano' => 'iresano',
'iresani' => 'iresani',
'iresane' => 'iresane',
'iresana' => 'iresana',
'iresan' => 'iresan',
'iresalo' => 'iresalo',
'iresali' => 'iresali',
'iresale' => 'iresale',
'iresala' => 'iresala',
'iresahu' => 'iresahu',
'iresah' => 'iresah',
'iresacyu' => 'iresacyu',
'iresacyete' => 'iresacyete',
'iresacyesx' => 'iresacyesx',
'iresacyemo' => 'iresacyemo',
'iresacye' => 'iresacye',
'iresa' => 'iresa',
'irenye' => 'enye',
'iremiste' => 'iremiste',
'iremi' => 'iremi',
'ireme' => 'ireme',
'irelyeno' => 'irelyeno',
'irelyeni' => 'irelyeni',
'irelyene' => 'irelyene',
'irelyena' => 'irelyena',
'irelyen' => 'irelyen',
'irelte' => 'irelte',
'irelmo' => 'irelmo',
'ireliti' => 'ireliti',
'irelite' => 'irelite',
'irelit' => 'irelit',
'irelisx' => 'irelisx',
'irelio' => 'irelio',
'irelimo' => 'irelimo',
'irelim' => 'irelim',
'irelilo' => 'irelilo',
'irelili' => 'irelili',
'irelile' => 'irelile',
'irelila' => 'irelila',
'irelicyu' => 'irelicyu',
'irelicyete' => 'irelicyete',
'irelicyesx' => 'irelicyesx',
'irelicyemo' => 'irelicyemo',
'irelicye' => 'irelicye',
'irel' => 'irel',
'irega' => 'irega',
'ireg' => 'ireg',
'irebte' => 'irebte',
'irebmo' => 'irebmo',
'ireblyuju' => 'ireblyuju',
'ireblyujete' => 'ireblyujete',
'ireblyujesx' => 'ireblyujesx',
'ireblyujemo' => 'ireblyujemo',
'ireblyujem' => 'ireblyujem',
'ireblyuje' => 'ireblyuje',
'ireblyivavsxi' => 'ireblyivavsxi',
'ireblyivati' => 'ireblyivati',
'ireblyivat' => 'ireblyivat',
'ireblyivasxe' => 'ireblyivasxe',
'ireblyivaste' => 'ireblyivaste',
'ireblyivasmo' => 'ireblyivasmo',
'ireblyivao' => 'ireblyivao',
'ireblyivano' => 'ireblyivano',
'ireblyivani' => 'ireblyivani',
'ireblyivane' => 'ireblyivane',
'ireblyivana' => 'ireblyivana',
'ireblyivan' => 'ireblyivan',
'ireblyivalo' => 'ireblyivalo',
'ireblyivali' => 'ireblyivali',
'ireblyivale' => 'ireblyivale',
'ireblyivala' => 'ireblyivala',
'ireblyivahu' => 'ireblyivahu',
'ireblyivah' => 'ireblyivah',
'ireblyivacyu' => 'ireblyivacyu',
'ireblyivacyete' => 'ireblyivacyete',
'ireblyivacyesx' => 'ireblyivacyesx',
'ireblyivacyemo' => 'ireblyivacyemo',
'ireblyivacye' => 'ireblyivacye',
'ireblyeno' => 'ireblyeno',
'ireblyeni' => 'ireblyeni',
'ireblyene' => 'ireblyene',
'ireblyena' => 'ireblyena',
'ireblyen' => 'ireblyen',
'irebivsxi' => 'irebivsxi',
'irebiti' => 'irebiti',
'irebite' => 'irebite',
'irebit' => 'irebit',
'irebisxe' => 'irebisxe',
'irebisx' => 'irebisx',
'irebiste' => 'irebiste',
'irebismo' => 'irebismo',
'irebio' => 'irebio',
'irebimo' => 'irebimo',
'irebim' => 'irebim',
'irebilo' => 'irebilo',
'irebili' => 'irebili',
'irebile' => 'irebile',
'irebila' => 'irebila',
'irebih' => 'irebih',
'irebicyu' => 'irebicyu',
'irebicyete' => 'irebicyete',
'irebicyesx' => 'irebicyesx',
'irebicyemo' => 'irebicyemo',
'irebicye' => 'irebicye',
'ircxite' => 'ircxite',
'ircxisx' => 'ircxisx',
'ircximo' => 'ircximo',
'ircxim' => 'ircxim',
'ircxi' => 'ircxi',
'ircxe' => 'cxe',
'ircxavsxi' => 'ircxavsxi',
'ircxavavsxi' => 'ircxavavsxi',
'ircxavati' => 'ircxavati',
'ircxavate' => 'ircxavate',
'ircxavat' => 'ircxavat',
'ircxavasxe' => 'ircxavasxe',
'ircxavasx' => 'ircxavasx',
'ircxavaste' => 'ircxavaste',
'ircxavasmo' => 'ircxavasmo',
'ircxavao' => 'ircxavao',
'ircxavano' => 'ircxavano',
'ircxavani' => 'ircxavani',
'ircxavane' => 'ircxavane',
'ircxavana' => 'ircxavana',
'ircxavan' => 'ircxavan',
'ircxavamo' => 'ircxavamo',
'ircxavam' => 'ircxavam',
'ircxavalo' => 'ircxavalo',
'ircxavali' => 'ircxavali',
'ircxavale' => 'ircxavale',
'ircxavala' => 'ircxavala',
'ircxavaju' => 'ircxavaju',
'ircxavajte' => 'ircxavajte',
'ircxavajmo' => 'ircxavajmo',
'ircxavaj' => 'ircxavaj',
'ircxavahu' => 'ircxavahu',
'ircxavah' => 'ircxavah',
'ircxavacyu' => 'ircxavacyu',
'ircxavacyete' => 'ircxavacyete',
'ircxavacyesx' => 'ircxavacyesx',
'ircxavacyemo' => 'ircxavacyemo',
'ircxavacye' => 'ircxavacye',
'ircxava' => 'ircxava',
'ircxati' => 'ircxati',
'ircxat' => 'ircxat',
'ircxasxe' => 'ircxasxe',
'ircxaste' => 'ircxaste',
'ircxasmo' => 'ircxasmo',
'ircxao' => 'ircxao',
'ircxano' => 'ircxano',
'ircxani' => 'ircxani',
'ircxane' => 'ircxane',
'ircxana' => 'ircxana',
'ircxan' => 'ircxan',
'ircxalo' => 'ircxalo',
'ircxali' => 'ircxali',
'ircxale' => 'ircxale',
'ircxala' => 'ircxala',
'ircxah' => 'ircxah',
'ircxacyu' => 'ircxacyu',
'ircxacyete' => 'ircxacyete',
'ircxacyesx' => 'ircxacyesx',
'ircxacyemo' => 'ircxacyemo',
'ircxacye' => 'ircxacye',
'ircxa' => 'ircxa',
'irazxu' => 'u',
'irazxte' => 'irazxte',
'irazxmo' => 'irazxmo',
'irazxivsxi' => 'irazxivsxi',
'irazxivacxku' => 'irazxivacxku',
'irazxivacxkomu' => 'irazxivacxkomu',
'irazxivacxkom' => 'irazxivacxkom',
'irazxivacxkoj' => 'irazxivacxkoj',
'irazxivacxkoga' => 'irazxivacxkoga',
'irazxivacxkog' => 'irazxivacxkog',
'irazxivacxko' => 'irazxivacxko',
'irazxivacxkim' => 'irazxivacxkim',
'irazxivacxkih' => 'irazxivacxkih',
'irazxivacxki' => 'irazxivacxki',
'irazxivacxke' => 'irazxivacxke',
'irazxivacxka' => 'irazxivacxka',
'irazxiti' => 'irazxiti',
'irazxite' => 'irazxite',
'irazxit' => 'irazxit',
'irazxisxe' => 'irazxisxe',
'irazxisx' => 'irazxisx',
'irazxiste' => 'irazxiste',
'irazxismo' => 'irazxismo',
'irazxio' => 'irazxio',
'irazximo' => 'irazximo',
'irazxim' => 'irazxim',
'irazxilo' => 'irazxilo',
'irazxili' => 'irazxili',
'irazxile' => 'irazxile',
'irazxila' => 'irazxila',
'irazxih' => 'irazxih',
'irazxicyu' => 'irazxicyu',
'irazxicyete' => 'irazxicyete',
'irazxicyesx' => 'irazxicyesx',
'irazxicyemo' => 'irazxicyemo',
'irazxicye' => 'irazxicye',
'irazxeno' => 'irazxeno',
'irazxeni' => 'irazxeni',
'irazxene' => 'irazxene',
'irazxena' => 'irazxena',
'irazxen' => 'irazxen',
'irazx' => 'irazx',
'irazi' => 'irazi',
'irasxte' => 'irasxte',
'irasxmo' => 'irasxmo',
'irasxlyivu' => 'irasxlyivu',
'irasxlyivomu' => 'irasxlyivomu',
'irasxlyivom' => 'irasxlyivom',
'irasxlyivoj' => 'irasxlyivoj',
'irasxlyivoga' => 'irasxlyivoga',
'irasxlyivog' => 'irasxlyivog',
'irasxlyivo' => 'irasxlyivo',
'irasxlyivim' => 'irasxlyivim',
'irasxlyivih' => 'irasxlyivih',
'irasxlyivi' => 'irasxlyivi',
'irasxlyive' => 'irasxlyive',
'irasxlyiva' => 'irasxlyiva',
'irasxlyiv' => 'irasxlyiv',
'irasxivsxi' => 'irasxivsxi',
'irasxiva' => 'irasxiva',
'irasxiti' => 'irasxiti',
'irasxite' => 'irasxite',
'irasxit' => 'irasxit',
'irasxisxe' => 'irasxisxe',
'irasxisx' => 'irasxisx',
'irasxiste' => 'irasxiste',
'irasxismo' => 'irasxismo',
'irasxio' => 'irasxio',
'irasximo' => 'irasximo',
'irasxim' => 'irasxim',
'irasxilo' => 'irasxilo',
'irasxili' => 'irasxili',
'irasxile' => 'irasxile',
'irasxila' => 'irasxila',
'irasxih' => 'irasxih',
'irasxicyu' => 'irasxicyu',
'irasxicyete' => 'irasxicyete',
'irasxicyesx' => 'irasxicyesx',
'irasxicyemo' => 'irasxicyemo',
'irasxicye' => 'irasxicye',
'irasxi' => 'irasxi',
'irasxeno' => 'irasxeno',
'irasxeni' => 'irasxeni',
'irasxene' => 'irasxene',
'irasxena' => 'irasxena',
'irasxen' => 'irasxen',
'iranyenosxcyu' => 'iranyenosxcyu',
'iranyenostima' => 'iranyenostima',
'iranyenosti' => 'iranyenosti',
'irantu' => 'u',
'irantom' => 'om',
'irantima' => 'ima',
'iranti' => 'i',
'iranta' => 'a',
'irant' => '',
'iranstvu' => 'iranstvu',
'iranstvom' => 'iranstvom',
'iranstvo' => 'iranstvo',
'iranstvima' => 'iranstvima',
'iranstva' => 'iranstva',
'iranstava' => 'iranstava',
'iransku' => 'u',
'iranskomu' => 'omu',
'iranskom' => 'om',
'iranskoj' => 'oj',
'iranskoga' => 'oga',
'iranskog' => 'og',
'iransko' => 'o',
'iranskim' => 'im',
'iranskih' => 'ih',
'iranski' => 'i',
'iranske' => 'e',
'iranska' => 'a',
'iranku' => 'iranku',
'irankom' => 'irankom',
'iranko' => 'iranko',
'iranke' => 'iranke',
'irankama' => 'irankama',
'iranka' => 'iranka',
'iranci' => 'iranci',
'iranaka' => 'iranaka',
'iranacxku' => 'iranacxku',
'iranacxkomu' => 'iranacxkomu',
'iranacxkom' => 'iranacxkom',
'iranacxkoj' => 'iranacxkoj',
'iranacxkoga' => 'iranacxkoga',
'iranacxkog' => 'iranacxkog',
'iranacxko' => 'iranacxko',
'iranacxkim' => 'iranacxkim',
'iranacxkih' => 'iranacxkih',
'iranacxki' => 'iranacxki',
'iranacxke' => 'iranacxke',
'iranacxka' => 'iranacxka',
'iralu' => 'lu',
'iralom' => 'lom',
'iralama' => 'lama',
'iraktu' => 'iraktu',
'iraktom' => 'iraktom',
'irakte' => 'irakte',
'irakta' => 'irakta',
'irakt' => 'irakt',
'iraju' => 'ju',
'irajnosxcyu' => 'irajnosxcyu',
'irajnostima' => 'irajnostima',
'irajnosti' => 'irajnosti',
'irajite' => 'irajite',
'irajimo' => 'irajimo',
'iraji' => 'iraji',
'irajete' => 'irajete',
'irajesx' => 'irajesx',
'irajemo' => 'irajemo',
'irajem' => 'irajem',
'iraje' => 'iraje',
'irajavsxi' => 'irajavsxi',
'irajati' => 'irajati',
'irajat' => 'irajat',
'irajasxe' => 'irajasxe',
'irajaste' => 'irajaste',
'irajasmo' => 'irajasmo',
'irajao' => 'irajao',
'irajano' => 'irajano',
'irajani' => 'irajani',
'irajane' => 'irajane',
'irajana' => 'irajana',
'irajan' => 'irajan',
'irajalo' => 'irajalo',
'irajali' => 'irajali',
'irajale' => 'irajale',
'irajala' => 'irajala',
'irajah' => 'irajah',
'irajacyu' => 'irajacyu',
'irajacyete' => 'irajacyete',
'irajacyesx' => 'irajacyesx',
'irajacyemo' => 'irajacyemo',
'irajacye' => 'irajacye',
'iraja' => 'iraja',
'irahovavsxi' => 'irahovavsxi',
'irahovati' => 'irahovati',
'irahovat' => 'irahovat',
'irahovasxe' => 'irahovasxe',
'irahovaste' => 'irahovaste',
'irahovasmo' => 'irahovasmo',
'irahovao' => 'irahovao',
'irahovanye' => 'irahovanye',
'irahovano' => 'irahovano',
'irahovani' => 'irahovani',
'irahovane' => 'irahovane',
'irahovana' => 'irahovana',
'irahovan' => 'irahovan',
'irahovalo' => 'irahovalo',
'irahovali' => 'irahovali',
'irahovale' => 'irahovale',
'irahovala' => 'irahovala',
'irahovahu' => 'irahovahu',
'irahovah' => 'irahovah',
'irahovacyu' => 'irahovacyu',
'irahovacyete' => 'irahovacyete',
'irahovacyesx' => 'irahovacyesx',
'irahovacyemo' => 'irahovacyemo',
'irahovacye' => 'irahovacye',
'irahova' => 'irahova',
'irahiravsxi' => 'irahiravsxi',
'irahirati' => 'irahirati',
'irahirate' => 'irahirate',
'irahirat' => 'irahirat',
'irahirasxe' => 'irahirasxe',
'irahirasx' => 'irahirasx',
'irahiraste' => 'irahiraste',
'irahirasmo' => 'irahirasmo',
'irahirao' => 'irahirao',
'irahiranye' => 'irahiranye',
'irahirano' => 'irahirano',
'irahirani' => 'irahirani',
'irahirane' => 'irahirane',
'irahirana' => 'irahirana',
'irahiran' => 'irahiran',
'irahiramo' => 'irahiramo',
'irahiram' => 'irahiram',
'irahiralo' => 'irahiralo',
'irahirali' => 'irahirali',
'irahirale' => 'irahirale',
'irahirala' => 'irahirala',
'irahirajucyi' => 'irahirajucyi',
'irahiraju' => 'irahiraju',
'irahirajte' => 'irahirajte',
'irahirajmo' => 'irahirajmo',
'irahiraj' => 'irahiraj',
'irahirahu' => 'irahirahu',
'irahirah' => 'irahirah',
'irahiracyu' => 'irahiracyu',
'irahiracyete' => 'irahiracyete',
'irahiracyesx' => 'irahiracyesx',
'irahiracyemo' => 'irahiracyemo',
'irahiracye' => 'irahiracye',
'irahira' => 'irahira',
'iragu' => 'iragu',
'iragom' => 'iragom',
'irago' => 'irago',
'irage' => 'irage',
'iragama' => 'iragama',
'iraga' => 'iraga',
'ioiju' => 'ioiju',
'ioijom' => 'ioijom',
'ioijima' => 'ioijima',
'ioiji' => 'ioiji',
'ioije' => 'ioije',
'ioija' => 'ioija',
'imu' => 'u',
'imom' => 'om',
'imi' => 'i',
'ilyte' => 'lyte',
'ilymo' => 'lymo',
'ilyiviju' => 'ilyiviju',
'ilyivijomu' => 'ilyivijomu',
'ilyivijom' => 'ilyivijom',
'ilyivijoj' => 'ilyivijoj',
'ilyivijim' => 'ilyivijim',
'ilyivijih' => 'ilyivijih',
'ilyiviji' => 'ilyiviji',
'ilyivijemu' => 'ilyivijemu',
'ilyivijem' => 'ilyivijem',
'ilyivijega' => 'ilyivijega',
'ilyivijeg' => 'ilyivijeg',
'ilyivije' => 'ilyivije',
'ilyivija' => 'ilyivija',
'ilyite' => 'lyite',
'ilyisx' => 'lyisx',
'ilyimo' => 'lyimo',
'ilyim' => 'lyim',
'ilyi' => 'i',
'ilye' => 'e',
'ily' => '',
'ilou' => 'ilou',
'iloima' => 'iloima',
'iloi' => 'iloi',
'iloe' => 'iloe',
'iloa' => 'iloa',
'iko' => 'ko',
'ikama' => 'kama',
'ik' => 'k',
'ijo' => 'o',
'ijevavsxi' => 'vsxi',
'ijevati' => 'ti',
'ijevat' => 't',
'ijevasxe' => 'sxe',
'ijevaste' => 'ste',
'ijevasmo' => 'smo',
'ijevao' => 'o',
'ijevano' => 'no',
'ijevani' => 'ni',
'ijevane' => 'ne',
'ijevana' => 'na',
'ijevan' => 'n',
'ijevalo' => 'lo',
'ijevali' => 'li',
'ijevale' => 'le',
'ijevala' => 'la',
'ijevahu' => 'hu',
'ijevah' => 'h',
'ijevacyu' => 'cyu',
'ijevacyete' => 'cyete',
'ijevacyesx' => 'cyesx',
'ijevacyemo' => 'cyemo',
'ijevacye' => 'cye',
'ijeva' => '',
'ijetomu' => 'ijetomu',
'ijetoj' => 'ijetoj',
'ijetoga' => 'ijetoga',
'ijetog' => 'ijetog',
'ijetim' => 'tim',
'ijetih' => 'tih',
'ijeruju' => 'ijeruju',
'ijerujite' => 'ijerujite',
'ijerujimo' => 'ijerujimo',
'ijeruji' => 'ijeruji',
'ijerujete' => 'ijerujete',
'ijerujesx' => 'ijerujesx',
'ijerujemo' => 'ijerujemo',
'ijerujem' => 'ijerujem',
'ijeruje' => 'ijeruje',
'ijerivavsxi' => 'ijerivavsxi',
'ijerivati' => 'ijerivati',
'ijerivat' => 'ijerivat',
'ijerivasxe' => 'ijerivasxe',
'ijerivaste' => 'ijerivaste',
'ijerivasmo' => 'ijerivasmo',
'ijerivao' => 'ijerivao',
'ijerivano' => 'ijerivano',
'ijerivani' => 'ijerivani',
'ijerivane' => 'ijerivane',
'ijerivana' => 'ijerivana',
'ijerivan' => 'ijerivan',
'ijerivalo' => 'ijerivalo',
'ijerivali' => 'ijerivali',
'ijerivale' => 'ijerivale',
'ijerivala' => 'ijerivala',
'ijerivahu' => 'ijerivahu',
'ijerivah' => 'ijerivah',
'ijerivacyu' => 'ijerivacyu',
'ijerivacyete' => 'ijerivacyete',
'ijerivacyesx' => 'ijerivacyesx',
'ijerivacyemo' => 'ijerivacyemo',
'ijerivacye' => 'ijerivacye',
'ijeriva' => 'ijeriva',
'ijeravsxi' => 'ijeravsxi',
'ijerati' => 'ijerati',
'ijerate' => 'ijerate',
'ijerat' => 'ijerat',
'ijerasxe' => 'ijerasxe',
'ijerasx' => 'ijerasx',
'ijeraste' => 'ijeraste',
'ijerasmo' => 'ijerasmo',
'ijerao' => 'ijerao',
'ijerano' => 'ijerano',
'ijerani' => 'ijerani',
'ijerane' => 'ijerane',
'ijerana' => 'ijerana',
'ijeran' => 'ijeran',
'ijeramo' => 'ijeramo',
'ijeram' => 'ijeram',
'ijeralo' => 'ijeralo',
'ijerali' => 'ijerali',
'ijerale' => 'ijerale',
'ijerala' => 'ijerala',
'ijeraju' => 'ijeraju',
'ijerajte' => 'ijerajte',
'ijerajmo' => 'ijerajmo',
'ijeraj' => 'ijeraj',
'ijerah' => 'ijerah',
'ijeracyu' => 'ijeracyu',
'ijeracyete' => 'ijeracyete',
'ijeracyesx' => 'ijeracyesx',
'ijeracyemo' => 'ijeracyemo',
'ijeracye' => 'ijeracye',
'ijera' => 'a',
'ijeih' => 'ijeih',
'ijegosxe' => 'ijegosxe',
'ijegoste' => 'ijegoste',
'ijegosmo' => 'ijegosmo',
'ijegoh' => 'ijegoh',
'ijego' => 'ijego',
'ijegavsxi' => 'gavsxi',
'ijecyi' => 'cyi',
'ijecy' => 'ijecy',
'ijecxu' => 'cxu',
'ijecxite' => 'ite',
'ijecximo' => 'imo',
'ijecxi' => 'i',
'ijecxete' => 'cxete',
'ijecxemo' => 'cxemo',
'ijecxem' => 'cxem',
'ijecxe' => 'e',
'ijecavsxi' => 'vsxi',
'ijecati' => 'ti',
'ijecat' => 't',
'ijecasxe' => 'sxe',
'ijecaste' => 'ste',
'ijecasmo' => 'smo',
'ijecao' => 'o',
'ijecano' => 'no',
'ijecani' => 'ni',
'ijecane' => 'ne',
'ijecana' => 'na',
'ijecan' => 'n',
'ijecalo' => 'lo',
'ijecali' => 'li',
'ijecale' => 'le',
'ijecala' => 'la',
'ijecahu' => 'hu',
'ijecah' => 'h',
'ijecacyu' => 'cyu',
'ijecacyete' => 'cyete',
'ijecacyesx' => 'cyesx',
'ijecacyemo' => 'cyemo',
'ijecacye' => 'cye',
'ijeca' => '',
'ijama' => 'ama',
'ignutu' => 'ignutu',
'ignutomu' => 'ignutomu',
'ignutom' => 'ignutom',
'ignutoj' => 'ignutoj',
'ignutoga' => 'ignutoga',
'ignutog' => 'ignutog',
'ignutim' => 'ignutim',
'ignutih' => 'ignutih',
'id' => '',
'hute' => 'ute',
'humo' => 'umo',
'hujite' => 'ujite',
'hujimo' => 'ujimo',
'huji' => 'uji',
'hate' => 'te',
'hasx' => 'sx',
'hanyu' => 'nyu',
'hanyima' => 'nyima',
'hanyem' => 'nyem',
'hanye' => 'nye',
'hanya' => 'nya',
'hamo' => 'mo',
'ham' => 'm',
'hajucyi' => 'hajucyi',
'haju' => 'ju',
'hajte' => 'jte',
'hajmo' => 'jmo',
'haj' => 'j',
'hahu' => 'hu',
'gusx' => '',
'gte' => '',
'gosavsxi' => 'gosavsxi',
'gosati' => 'gosati',
'gosat' => 'gosat',
'gosasxe' => 'gosasxe',
'gosaste' => 'gosaste',
'gosasmo' => 'gosasmo',
'gosao' => 'gosao',
'gosalo' => 'gosalo',
'gosali' => 'gosali',
'gosale' => 'gosale',
'gosala' => 'gosala',
'gosahu' => 'gosahu',
'gosah' => 'gosah',
'gosacyu' => 'gosacyu',
'gosacyete' => 'gosacyete',
'gosacyesx' => 'gosacyesx',
'gosacyemo' => 'gosacyemo',
'gosacye' => 'gosacye',
'gnucyima' => 'ucyima',
'gnucyem' => 'ucyem',
'gnucya' => 'ucya',
'gima' => 'ima',
'gbte' => 'gbte',
'gbmo' => 'gbmo',
'gbio' => 'gbio',
'gbi' => 'gbi',
'gbe' => 'gbe',
'gb' => 'gb',
'gazxu' => 'u',
'gazxite' => 'gazxite',
'gazximo' => 'gazximo',
'gazxi' => 'gazxi',
'ezxim' => 'im',
'ezxa' => 'a',
'ezima' => 'ima',
'ev' => '',
'etjevsxi' => 'tjevsxi',
'etjeti' => 'tjeti',
'etjet' => 'tjet',
'etjesxe' => 'tjesxe',
'etjeste' => 'tjeste',
'etjesmo' => 'tjesmo',
'etjelo' => 'tjelo',
'etjeli' => 'tjeli',
'etjele' => 'tjele',
'etjela' => 'tjela',
'etjeh' => 'tjeh',
'etjecyu' => 'tjecyu',
'etjecyete' => 'tjecyete',
'etjecyesx' => 'tjecyesx',
'etjecyemo' => 'tjecyemo',
'etjecye' => 'tjecye',
'etje' => 'tje',
'etivsxi' => 'tivsxi',
'etiti' => 'titi',
'etit' => 'tit',
'etisxe' => 'tisxe',
'etiste' => 'tiste',
'etismo' => 'tismo',
'etilo' => 'tilo',
'etili' => 'tili',
'etile' => 'tile',
'etila' => 'tila',
'etiju' => 'etiju',
'etijomu' => 'etijomu',
'etijom' => 'etijom',
'etijoj' => 'etijoj',
'etijim' => 'etijim',
'etijih' => 'etijih',
'etiji' => 'etiji',
'etijemu' => 'etijemu',
'etijem' => 'etijem',
'etijega' => 'etijega',
'etijeg' => 'etijeg',
'etija' => 'etija',
'eticyu' => 'ticyu',
'eticyete' => 'ticyete',
'eticyesx' => 'ticyesx',
'eticyemo' => 'ticyemo',
'eticye' => 'ticye',
'etevsxi' => 'tevsxi',
'eteti' => 'teti',
'etet' => 'tet',
'etesxe' => 'tesxe',
'eteste' => 'teste',
'etesmo' => 'tesmo',
'eteo' => 'teo',
'etelo' => 'telo',
'eteli' => 'teli',
'etele' => 'tele',
'etela' => 'tela',
'eteh' => 'teh',
'etecyu' => 'tecyu',
'etecyete' => 'tecyete',
'etecyesx' => 'tecyesx',
'etecyemo' => 'tecyemo',
'etecye' => 'tecye',
'etama' => 'ama',
'etahu' => 'tahu',
'esxivsxi' => 'ivsxi',
'esxisxe' => 'isxe',
'esxiste' => 'iste',
'esxismo' => 'ismo',
'esxih' => 'ih',
'esxcyeno' => 'xcyeno',
'esxcyeni' => 'xcyeni',
'esxcyene' => 'xcyene',
'esxcyena' => 'xcyena',
'esxcyen' => 'xcyen',
'esxasxe' => 'sxe',
'esxaste' => 'ste',
'esxasmo' => 'smo',
'esxahu' => 'xahu',
'esxah' => 'h',
'estivsxi' => 'tivsxi',
'estiti' => 'titi',
'estite' => 'tite',
'estit' => 'tit',
'estisxe' => 'tisxe',
'estisx' => 'tisx',
'estiste' => 'tiste',
'estismo' => 'tismo',
'estio' => 'tio',
'estimo' => 'timo',
'estim' => 'im',
'estilo' => 'tilo',
'estili' => 'tili',
'estile' => 'tile',
'estila' => 'tila',
'estih' => 'ih',
'esticyu' => 'ticyu',
'esticyete' => 'ticyete',
'esticyesx' => 'ticyesx',
'esticyemo' => 'ticyemo',
'esticye' => 'ticye',
'essxe' => 'ssxe',
'esosxe' => 'sosxe',
'esoste' => 'soste',
'esosmo' => 'sosmo',
'esoh' => 'soh',
'eslo' => 'slo',
'esli' => 'sli',
'esle' => 'sle',
'esla' => 'sla',
'esivsxi' => 'ivsxi',
'esisxe' => 'isxe',
'esisx' => 'isx',
'esiste' => 'iste',
'esismo' => 'ismo',
'esio' => 'io',
'esim' => 'im',
'esilo' => 'ilo',
'esili' => 'ili',
'esile' => 'ile',
'esila' => 'ila',
'esicyu' => 'icyu',
'esicyete' => 'icyete',
'esicyesx' => 'icyesx',
'esicyemo' => 'icyemo',
'esicye' => 'icye',
'esahu' => 'ahu',
'erte' => 'te',
'ermo' => 'mo',
'erima' => 'ima',
'eravsxi' => 'vsxi',
'erati' => 'ati',
'erat' => 't',
'erasxe' => 'asxe',
'eraste' => 'aste',
'erasmo' => 'asmo',
'erao' => 'o',
'eralo' => 'lo',
'erali' => 'li',
'erale' => 'le',
'erala' => 'la',
'erah' => 'ah',
'eracyu' => 'cyu',
'eracyete' => 'cyete',
'eracyesx' => 'cyesx',
'eracyemo' => 'cyemo',
'eracye' => 'cye',
'ente' => 'te',
'enmo' => 'mo',
'emlyeno' => 'lyeno',
'emlyeni' => 'lyeni',
'emlyene' => 'lyene',
'emlyena' => 'lyena',
'emlyen' => 'lyen',
'emiti' => 'iti',
'emite' => 'ite',
'emit' => 'it',
'emisx' => 'isx',
'emio' => 'io',
'emimo' => 'imo',
'emim' => 'im',
'emilo' => 'ilo',
'emili' => 'ili',
'emile' => 'ile',
'emila' => 'ila',
'emicyu' => 'icyu',
'emicyete' => 'icyete',
'emicyesx' => 'icyesx',
'emicyemo' => 'icyemo',
'emicye' => 'icye',
'emi' => 'i',
'emete' => 'te',
'emesx' => 'emesx',
'ememo' => 'ememo',
'emem' => 'emem',
'ema' => 'a',
'elyomu' => 'omu',
'elyoj' => 'oj',
'elyim' => 'im',
'elyih' => 'ih',
'elyemu' => 'elyemu',
'elyega' => 'elyega',
'elyeg' => 'elyeg',
'elyasxe' => 'yasxe',
'elyaste' => 'yaste',
'elyasmo' => 'yasmo',
'elyahu' => 'yahu',
'elyah' => 'yah',
'elima' => 'lima',
'eko' => 'ko',
'eknuvsxi' => 'uvsxi',
'eknuto' => 'uto',
'eknuti' => 'uti',
'eknuta' => 'uta',
'eknut' => 'ut',
'eknusxe' => 'usxe',
'eknuste' => 'uste',
'eknusmo' => 'usmo',
'eknuo' => 'uo',
'eknulo' => 'ulo',
'eknuli' => 'uli',
'eknule' => 'ule',
'eknula' => 'ula',
'eknuh' => 'uh',
'eknucyu' => 'ucyu',
'eknucyete' => 'ucyete',
'eknucyesx' => 'ucyesx',
'eknucyemo' => 'ucyemo',
'eknucye' => 'ucye',
'ekni' => 'i',
'eganye' => 'ganye',
'egama' => 'gama',
'ee' => 'e',
'ednem' => 'dnem',
'edne' => 'e',
'ecxeno' => 'eno',
'ecxeni' => 'eni',
'ecxene' => 'ene',
'ecxena' => 'ena',
'ecxen' => 'en',
'ebi' => 'i',
'ebe' => 'e',
'dyenyu' => 'u',
'dyemo' => 'yemo',
'dxavsxi' => 'vsxi',
'dxati' => 'ti',
'dxate' => 'te',
'dxat' => 't',
'dxasxe' => 'sxe',
'dxasx' => 'sx',
'dxaste' => 'ste',
'dxasmo' => 'smo',
'dxao' => 'o',
'dxano' => 'no',
'dxani' => 'ni',
'dxane' => 'ne',
'dxana' => 'na',
'dxan' => 'n',
'dxamo' => 'mo',
'dxam' => 'm',
'dxalo' => 'lo',
'dxali' => 'li',
'dxale' => 'le',
'dxala' => 'la',
'dxaju' => 'ju',
'dxajte' => 'jte',
'dxajmo' => 'jmo',
'dxaj' => 'j',
'dxahu' => 'ahu',
'dxah' => 'h',
'dxacyu' => 'cyu',
'dxacyete' => 'cyete',
'dxacyesx' => 'cyesx',
'dxacyemo' => 'cyemo',
'dxacye' => 'cye',
'dnusx' => 'dnusx',
'dnumo' => 'dnumo',
'dnte' => 'te',
'dnosxe' => 'dnosxe',
'dnoste' => 'te',
'dnosmo' => 'mo',
'dnomu' => 'omu',
'dnom' => 'om',
'dnoj' => 'oj',
'dnoh' => 'dnoh',
'dnoga' => 'oga',
'dnog' => 'og',
'dno' => 'o',
'dnmo' => 'mo',
'dnim' => 'im',
'dnih' => 'ih',
'dna' => 'a',
'dn' => '',
'dmu' => 'dmu',
'dme' => 'dme',
'dlo' => 'lo',
'dli' => 'li',
'dle' => 'le',
'dla' => 'la',
'djeti' => 'jeti',
'djet' => 'jet',
'djelo' => 'jelo',
'djeli' => 'jeli',
'djele' => 'jele',
'djela' => 'jela',
'djecyu' => 'jecyu',
'djecyete' => 'jecyete',
'djecyesx' => 'jecyesx',
'djecyemo' => 'jecyemo',
'djecye' => 'jecye',
'dima' => 'ima',
'dicyi' => 'icyi',
'dicy' => 'icy',
'dgodisxnyim' => 'dgodisxnyim',
'dgodisxnyih' => 'dgodisxnyih',
'dgodisxnyie' => 'dgodisxnyie',
'dgodisxnyi' => 'dgodisxnyi',
'desxe' => 'esxe',
'deste' => 'este',
'desmo' => 'esmo',
'denye' => 'e',
'denu' => 'u',
'deh' => 'eh',
'decyi' => 'ecyi',
'cyisxe' => 'isxe',
'cyiste' => 'iste',
'cyismo' => 'ismo',
'cyih' => 'h',
'cyate' => 'te',
'cyanye' => 'e',
'cyamo' => 'mo',
'cyam' => 'm',
'cyaju' => 'ju',
'cyajte' => 'jte',
'cyajmo' => 'jmo',
'cyaj' => 'j',
'cxuju' => 'uju',
'cxujete' => 'ujete',
'cxujesx' => 'ujesx',
'cxujemo' => 'ujemo',
'cxujem' => 'ujem',
'cxuje' => 'uje',
'cxnyacxu' => 'cxnyacxu',
'cxnyacxom' => 'cxnyacxom',
'cxnyacxo' => 'cxnyacxo',
'cxnyacxi' => 'cxnyacxi',
'cxnyacxe' => 'cxe',
'cxnyacxama' => 'cxnyacxama',
'cxnyacxa' => 'a',
'cxnicu' => 'u',
'cxnicom' => 'om',
'cxnico' => 'o',
'cxnice' => 'e',
'cxnicama' => 'ama',
'cxnica' => 'a',
'cxkama' => 'kama',
'cxilu' => 'ilu',
'cxilom' => 'ilom',
'cxilima' => 'ilima',
'cxie' => 'e',
'cxetima' => 'cxetima',
'cxeti' => 'eti',
'cxanyu' => 'u',
'cxanyima' => 'ima',
'cxanyem' => 'em',
'cxanya' => 'a',
'cxacima' => 'cima',
'cxaci' => 'ci',
'cou' => 'u',
'coi' => 'i',
'coe' => 'e',
'coama' => 'oama',
'coa' => 'a',
'cku' => 'u',
'ckom' => 'om',
'cko' => 'o',
'cke' => 'e',
'ckama' => 'kama',
'cka' => '',
'civsxi' => 'ivsxi',
'citi' => 'iti',
'cit' => 'it',
'cisxe' => 'isxe',
'ciste' => 'iste',
'cismo' => 'ismo',
'cio' => 'io',
'cilo' => 'ilo',
'cili' => 'ili',
'cile' => 'ile',
'cila' => 'ila',
'cih' => 'ih',
'cicyu' => 'icyu',
'cicyete' => 'icyete',
'cicyesx' => 'icyesx',
'cicyemo' => 'icyemo',
'cicye' => 'icye',
'canyu' => 'u',
'canyima' => 'ima',
'canyem' => 'em',
'canya' => 'a',
'caka' => 'aka',
'cajucyi' => 'jucyi',
'bute' => 'ute',
'bumo' => 'umo',
'bujucyi' => 'ujucyi',
'buju' => 'uju',
'bujte' => 'ujte',
'bujmo' => 'ujmo',
'bujete' => 'ujete',
'bujesx' => 'ujesx',
'bujemo' => 'ujemo',
'bujem' => 'ujem',
'buje' => 'uje',
'buj' => 'uj',
'bovavsxi' => 'ovavsxi',
'bovati' => 'ovati',
'bovat' => 'ovat',
'bovasxe' => 'ovasxe',
'bovaste' => 'ovaste',
'bovasmo' => 'ovasmo',
'bovao' => 'ovao',
'bovano' => 'ovano',
'bovani' => 'ovani',
'bovane' => 'ovane',
'bovana' => 'ovana',
'bovan' => 'ovan',
'bovalo' => 'ovalo',
'bovali' => 'ovali',
'bovale' => 'ovale',
'bovala' => 'ovala',
'bovahu' => 'ovahu',
'bovah' => 'ovah',
'bovacyu' => 'ovacyu',
'bovacyete' => 'ovacyete',
'bovacyesx' => 'ovacyesx',
'bovacyemo' => 'ovacyemo',
'bovacye' => 'ovacye',
'blo' => 'lo',
'bli' => 'li',
'ble' => 'le',
'bla' => 'la',
'bivsxi' => 'ivsxi',
'bisxe' => 'isxe',
'biste' => 'iste',
'bismo' => 'ismo',
'bih' => 'ih',
'banyu' => 'u',
'banyima' => 'anyima',
'banyem' => 'anyem',
'banya' => 'a',
'baka' => 'ka',
'avomu' => 'omu',
'avoj' => 'oj',
'avoga' => 'oga',
'avog' => 'og',
'avim' => 'im',
'avanya' => 'a',
'atute' => 'ute',
'atumo' => 'umo',
'atujucyi' => 'ujucyi',
'atuju' => 'uju',
'atujte' => 'ujte',
'atujmo' => 'ujmo',
'atujete' => 'ujete',
'atujesx' => 'ujesx',
'atujemo' => 'ujemo',
'atujem' => 'ujem',
'atuje' => 'uje',
'atuj' => 'uj',
'atimte' => 'atimte',
'atimlyeno' => 'atimlyeno',
'atimlyeni' => 'atimlyeni',
'atimlyene' => 'atimlyene',
'atimlyena' => 'atimlyena',
'atimlyen' => 'atimlyen',
'atimiti' => 'atimiti',
'atimite' => 'atimite',
'atimit' => 'atimit',
'atimisx' => 'atimisx',
'atimio' => 'atimio',
'atimimo' => 'atimimo',
'atimim' => 'atimim',
'atimilo' => 'atimilo',
'atimili' => 'atimili',
'atimile' => 'atimile',
'atimila' => 'atimila',
'atimicyu' => 'atimicyu',
'atimicyete' => 'atimicyete',
'atimicyesx' => 'atimicyesx',
'atimicyemo' => 'atimicyemo',
'atimicye' => 'atimicye',
'atimi' => 'atimi',
'atime' => 'atime',
'atavsxi' => 'tavsxi',
'atati' => 'tati',
'atate' => 'te',
'atat' => 'tat',
'atasxe' => 'sxe',
'atasx' => 'sx',
'ataste' => 'ste',
'atasmo' => 'smo',
'atao' => 'tao',
'atano' => 'tano',
'atani' => 'tani',
'atane' => 'tane',
'atana' => 'tana',
'atan' => 'tan',
'atamo' => 'mo',
'atam' => 'm',
'atalo' => 'talo',
'atali' => 'tali',
'atale' => 'tale',
'atala' => 'tala',
'ataju' => 'ju',
'atajte' => 'jte',
'atajmo' => 'jmo',
'ataj' => 'j',
'atahu' => 'tahu',
'atah' => 'tah',
'atacyu' => 'cyu',
'atacyete' => 'cyete',
'atacyesx' => 'cyesx',
'atacyemo' => 'cyemo',
'atacye' => 'cye',
'asxisxe' => 'isxe',
'asxiste' => 'iste',
'asxismo' => 'ismo',
'asxih' => 'ih',
'astiju' => 'iju',
'astijomu' => 'ijomu',
'astijom' => 'ijom',
'astijoj' => 'ijoj',
'astijim' => 'ijim',
'astijih' => 'ijih',
'astiji' => 'iji',
'astijemu' => 'ijemu',
'astijem' => 'ijem',
'astijega' => 'ijega',
'astijeg' => 'ijeg',
'astije' => 'ije',
'astija' => 'ija',
'as' => '',
'arte' => 'te',
'armo' => 'mo',
'arim' => 'im',
'arih' => 'ih',
'aravsxi' => 'vsxi',
'arati' => 'ti',
'arate' => 'te',
'arat' => 't',
'arasxe' => 'asxe',
'arasx' => 'sx',
'araste' => 'aste',
'arasmo' => 'asmo',
'arao' => 'o',
'arano' => 'no',
'arani' => 'ni',
'arane' => 'ne',
'arana' => 'na',
'aran' => 'n',
'aramo' => 'mo',
'aram' => 'm',
'aralo' => 'lo',
'arali' => 'li',
'arale' => 'le',
'arala' => 'la',
'araju' => 'ju',
'arajte' => 'jte',
'arajmo' => 'jmo',
'araj' => 'j',
'arah' => 'ah',
'aracyu' => 'cyu',
'aracyete' => 'cyete',
'aracyesx' => 'cyesx',
'aracyemo' => 'cyemo',
'aracye' => 'cye',
'anyete' => 'anyete',
'anyesx' => 'anyesx',
'anyeno' => 'yeno',
'anyeni' => 'yeni',
'anyene' => 'yene',
'anyena' => 'yena',
'anyen' => 'yen',
'anyemo' => 'anyemo',
'anyama' => 'ama',
'ante' => 'e',
'anmo' => 'mo',
'aniti' => 'iti',
'anite' => 'ite',
'anit' => 'it',
'anio' => 'io',
'animo' => 'imo',
'anilo' => 'ilo',
'anili' => 'ili',
'anile' => 'ile',
'anila' => 'ila',
'anicyu' => 'icyu',
'anicyete' => 'icyete',
'anicyesx' => 'icyesx',
'anicyemo' => 'icyemo',
'anicye' => 'icye',
'anete' => 'ete',
'anesx' => 'esx',
'anemo' => 'emo',
'anem' => 'em',
'anasxe' => 'asxe',
'anaste' => 'aste',
'anasmo' => 'asmo',
'anahu' => 'ahu',
'anah' => 'ah',
'amivsxi' => 'ivsxi',
'amisxe' => 'isxe',
'amiste' => 'iste',
'amismo' => 'ismo',
'amih' => 'ih',
'alyu' => 'u',
'alyom' => 'om',
'alyi' => 'i',
'alye' => 'e',
'alim' => 'im',
'alih' => 'ih',
'aknucyima' => 'aknucyima',
'aknucyem' => 'aknucyem',
'aknucya' => 'aknucya',
'ajanye' => 'nye',
'agati' => 'ti',
'agat' => 't',
'agasxe' => 'sxe',
'agaste' => 'ste',
'agasmo' => 'smo',
'agao' => 'o',
'agano' => 'no',
'agani' => 'ni',
'agane' => 'ne',
'agana' => 'na',
'agan' => 'n',
'agalo' => 'lo',
'agali' => 'li',
'agale' => 'le',
'agala' => 'la',
'agahu' => 'hu',
'agah' => 'h',
'agacyu' => 'cyu',
'agacyete' => 'cyete',
'agacyesx' => 'cyesx',
'agacyemo' => 'cyemo',
'agacye' => 'cye',
'aerete' => 'erete',
'aeresx' => 'eresx',
'aeremo' => 'eremo',
'aerem' => 'erem',
'aere' => 'ere',
'adyete' => 'adyete',
'adyesx' => 'dyesx',
'adyemo' => 'adyemo',
'adyem' => 'dyem',
'adye' => 'e',
'adu' => 'u',
'adte' => 'te',
'admo' => 'mo',
'ade' => 'e',
'acyavsxi' => 'vsxi',
'acyati' => 'ti',
'acyate' => 'te',
'acyat' => 't',
'acyasx' => 'sx',
'acyao' => 'o',
'acyano' => 'no',
'acyani' => 'ni',
'acyane' => 'ne',
'acyana' => 'na',
'acyan' => 'n',
'acyamo' => 'mo',
'acyam' => 'm',
'acyalo' => 'lo',
'acyali' => 'li',
'acyale' => 'le',
'acyala' => 'la',
'acyaju' => 'ju',
'acyajte' => 'jte',
'acyajmo' => 'jmo',
'acyaj' => 'j',
'acyacyu' => 'cyu',
'acyacyete' => 'cyete',
'acyacyesx' => 'cyesx',
'acyacyemo' => 'cyemo',
'acyacye' => 'cye',
'acxete' => 'cxete',
'acxemo' => 'cxemo',
'zxujete' => 'ujete',
'zxujesx' => 'ujesx',
'zxujemo' => 'ujemo',
'zxujem' => 'ujem',
'zxuje' => 'uje',
'zxucyi' => 'i',
'zxomu' => 'omu',
'zxoj' => 'oj',
'zxlyedu' => 'zxlyedu',
'zxlyedom' => 'zxlyedom',
'zxlyedo' => 'zxlyedo',
'zxlyedi' => 'zxlyedi',
'zxlyede' => 'zxlyede',
'zxlyedama' => 'zxlyedama',
'zxlyeda' => 'zxlyeda',
'zxivavsxi' => 'ivavsxi',
'zxivati' => 'ivati',
'zxivat' => 'ivat',
'zxivasxe' => 'ivasxe',
'zxivaste' => 'ivaste',
'zxivasmo' => 'ivasmo',
'zxivao' => 'ivao',
'zxivano' => 'ivano',
'zxivani' => 'ivani',
'zxivane' => 'ivane',
'zxivana' => 'ivana',
'zxivan' => 'ivan',
'zxivalo' => 'ivalo',
'zxivali' => 'ivali',
'zxivale' => 'ivale',
'zxivala' => 'ivala',
'zxivahu' => 'ivahu',
'zxivah' => 'ivah',
'zxivacyu' => 'ivacyu',
'zxivacyete' => 'ivacyete',
'zxivacyesx' => 'ivacyesx',
'zxivacyemo' => 'ivacyemo',
'zxivacye' => 'ivacye',
'zxiva' => 'iva',
'zxitu' => 'u',
'zxitomu' => 'omu',
'zxitom' => 'om',
'zxitoj' => 'oj',
'zxitoga' => 'oga',
'zxitog' => 'og',
'zxito' => 'o',
'zxitim' => 'im',
'zxitih' => 'ih',
'zxita' => 'a',
'zxilu' => 'u',
'zxilom' => 'om',
'zxilima' => 'zxilima',
'zxicyom' => 'om',
'zxicyima' => 'ima',
'zxicyi' => 'i',
'zxicya' => 'a',
'zxicy' => '',
'zxevima' => 'xevima',
'zxevi' => 'xevi',
'zxeve' => 'xeve',
'zxeva' => 'xeva',
'zxetu' => 'etu',
'zxetom' => 'etom',
'zxeta' => 'eta',
'zxesxe' => 'esxe',
'zxeste' => 'este',
'zxesmo' => 'esmo',
'zxemu' => 'emu',
'zxeih' => 'eih',
'zxegosxe' => 'egosxe',
'zxegoste' => 'egoste',
'zxegosmo' => 'egosmo',
'zxegoh' => 'egoh',
'zxego' => 'go',
'zxegnutu' => 'zxegnutu',
'zxegnutomu' => 'zxegnutomu',
'zxegnutom' => 'zxegnutom',
'zxegnutoj' => 'zxegnutoj',
'zxegnutoga' => 'zxegnutoga',
'zxegnutog' => 'zxegnutog',
'zxegnuto' => 'zxegnuto',
'zxegnutim' => 'zxegnutim',
'zxegnutih' => 'zxegnutih',
'zxegnuti' => 'zxegnuti',
'zxegnute' => 'egnute',
'zxegnuta' => 'zxegnuta',
'zxegnut' => 'zxegnut',
'zxegnusx' => 'egnusx',
'zxegnumo' => 'egnumo',
'zxegnu' => 'egnu',
'zxegnte' => 'egnte',
'zxegnmo' => 'egnmo',
'zxegnem' => 'egnem',
'zxegne' => 'egne',
'zxegn' => 'egn',
'zxeglo' => 'eglo',
'zxegli' => 'egli',
'zxegle' => 'egle',
'zxegla' => 'egla',
'zxegavsxi' => 'egavsxi',
'zxegao' => 'egao',
'zxega' => 'ga',
'zxeg' => 'g',
'zxecyu' => 'ecyu',
'zxecyete' => 'ecyete',
'zxecyesx' => 'ecyesx',
'zxecyemo' => 'ecyemo',
'zxecye' => 'ecye',
'zxecy' => 'ecy',
'zxate' => 'te',
'zxasx' => 'sx',
'zxanye' => 'nye',
'zxamo' => 'mo',
'zxam' => 'm',
'zxaju' => 'ju',
'zxajte' => 'jte',
'zxajmo' => 'jmo',
'zxaj' => 'j',
'zxadima' => 'adima',
'zxadi' => 'i',
'zxad' => 'ad',
'zuite' => 'e',
'zuimo' => 'zuimo',
'zue' => 'zue',
'zou' => 'ou',
'zoima' => 'oima',
'zoi' => 'oi',
'zoe' => 'oe',
'zoa' => 'oa',
'znuto' => 'uto',
'znuti' => 'uti',
'znute' => 'ute',
'znuta' => 'uta',
'znut' => 'ut',
'znu' => 'u',
'znite' => 'ite',
'znimo' => 'imo',
'zni' => 'i',
'znete' => 'ete',
'znesx' => 'esx',
'znemo' => 'emo',
'znem' => 'em',
'zne' => 'e',
'zledu' => 'u',
'zledom' => 'om',
'zledo' => 'o',
'zledi' => 'i',
'zlede' => 'e',
'zledama' => 'ama',
'zleda' => '',
'zku' => 'zku',
'zkom' => 'zkom',
'zke' => 'zke',
'zka' => 'zka',
'zisxlo' => 'sxlo',
'zisxli' => 'sxli',
'zisxle' => 'sxle',
'zisxla' => 'sxla',
'zisxe' => 'isxe',
'zisxao' => 'sxao',
'ziste' => 'iste',
'zismo' => 'ismo',
'zimte' => 'te',
'zimlyeno' => 'lyeno',
'zimlyeni' => 'lyeni',
'zimlyene' => 'lyene',
'zimlyena' => 'lyena',
'zimlyen' => 'lyen',
'zimivsxi' => 'ivsxi',
'zimiti' => 'iti',
'zimite' => 'ite',
'zimit' => 'it',
'zimisxe' => 'isxe',
'zimisx' => 'isx',
'zimiste' => 'iste',
'zimismo' => 'ismo',
'zimio' => 'io',
'zimimo' => 'imo',
'zimim' => 'im',
'zimilo' => 'ilo',
'zimili' => 'ili',
'zimile' => 'ile',
'zimila' => 'ila',
'zimih' => 'ih',
'zimicyu' => 'icyu',
'zimicyete' => 'icyete',
'zimicyesx' => 'icyesx',
'zimicyemo' => 'icyemo',
'zimicye' => 'icye',
'zimi' => 'i',
'zime' => 'e',
'zih' => 'ih',
'zigosxe' => 'gosxe',
'zigoste' => 'goste',
'zigosmo' => 'gosmo',
'zigoh' => 'goh',
'zigo' => 'go',
'zigavsxi' => 'gavsxi',
'zidyute' => 'ute',
'zidyusx' => 'dyusx',
'zidyumo' => 'umo',
'zidyu' => 'u',
'zidyte' => 'dyte',
'zidymo' => 'dymo',
'zidyem' => 'dyem',
'zidye' => 'dye',
'zidy' => 'dy',
'zicyi' => 'cyi',
'zicy' => 'cy',
'zgu' => 'gu',
'zgom' => 'gom',
'zge' => 'ge',
'zgama' => 'gama',
'zga' => '',
'zetu' => 'u',
'zetom' => 'om',
'zeto' => 'o',
'zeti' => 'eti',
'zetama' => 'ama',
'zeta' => 'a',
'zdu' => 'du',
'zdite' => 'dite',
'zdimo' => 'dimo',
'zdiksijsku' => 'zdiksijsku',
'zdiksijskomu' => 'zdiksijskomu',
'zdiksijskom' => 'zdiksijskom',
'zdiksijskoj' => 'zdiksijskoj',
'zdiksijskoga' => 'zdiksijskoga',
'zdiksijskog' => 'zdiksijskog',
'zdiksijsko' => 'zdiksijsko',
'zdiksijskim' => 'zdiksijskim',
'zdiksijskih' => 'zdiksijskih',
'zdiksijski' => 'zdiksijski',
'zdiksijske' => 'zdiksijske',
'zdiksijska' => 'zdiksijska',
'zdikciju' => 'zdikciju',
'zdikcijom' => 'zdikcijom',
'zdikcijo' => 'zdikcijo',
'zdikciji' => 'zdikciji',
'zdikcije' => 'zdikcije',
'zdikcijama' => 'zdikcijama',
'zdikcija' => 'zdikcija',
'zdi' => 'di',
'zdete' => 'dete',
'zdesx' => 'desx',
'zdeno' => 'zdeno',
'zdeni' => 'i',
'zdene' => 'e',
'zdena' => 'zdena',
'zden' => '',
'zdemo' => 'demo',
'zcima' => 'zcima',
'zci' => 'zci',
'zbirou' => 'zbirou',
'zbiroom' => 'zbiroom',
'zbiroima' => 'zbiroima',
'zbiroi' => 'zbiroi',
'zbiroe' => 'zbiroe',
'zbiroa' => 'zbiroa',
'zbiro' => 'zbiro',
'zarada' => 'a',
'zanimanye' => 'nye',
'zajucyi' => 'ajucyi',
'zaga' => 'aga',
'yusxkavsxi' => 'vsxi',
'yusxkati' => 'ti',
'yusxkate' => 'te',
'yusxkat' => 't',
'yusxkasxe' => 'sxe',
'yusxkasx' => 'sx',
'yusxkaste' => 'ste',
'yusxkasmo' => 'smo',
'yusxkao' => 'o',
'yusxkanyu' => 'yusxkanyu',
'yusxkano' => 'no',
'yusxkani' => 'ni',
'yusxkane' => 'ne',
'yusxkana' => 'na',
'yusxkan' => 'n',
'yusxkamo' => 'mo',
'yusxkam' => 'm',
'yusxkalo' => 'lo',
'yusxkali' => 'li',
'yusxkale' => 'le',
'yusxkala' => 'la',
'yusxkaju' => 'ju',
'yusxkajte' => 'jte',
'yusxkajmo' => 'jmo',
'yusxkaj' => 'j',
'yusxkahu' => 'kahu',
'yusxkah' => 'h',
'yusxkacyu' => 'cyu',
'yusxkacyete' => 'cyete',
'yusxkacyesx' => 'cyesx',
'yusxkacyemo' => 'cyemo',
'yusxkacye' => 'cye',
'yusxka' => 'ka',
'yucyi' => 'yucyi',
'yisxe' => 'isxe',
'yiste' => 'iste',
'yismo' => 'ismo',
'yima' => '',
'yevu' => 'u',
'yevomu' => 'omu',
'yevom' => 'om',
'yevoj' => 'oj',
'yevoga' => 'oga',
'yevog' => 'og',
'yevo' => 'o',
'yevim' => 'im',
'yevih' => 'ih',
'yev' => '',
'yeninogu' => 'yeninogu',
'yeninogom' => 'yeninogom',
'yeninogima' => 'yeninogima',
'yeninogi' => 'yeninogi',
'yeninoge' => 'yeninoge',
'yeninoga' => 'yeninoga',
'yelyu' => 'u',
'yelyte' => '',
'yelymo' => '',
'yelyete' => 'yelyete',
'yelyesx' => 'yelyesx',
'yelyemo' => 'yelyemo',
'yelyem' => 'em',
'yelye' => 'e',
'yely' => '',
'yecyi' => '',
'yavavsxi' => 'avavsxi',
'yavati' => 'avati',
'yavat' => 'avat',
'yavasxe' => 'avasxe',
'yavaste' => 'avaste',
'yavasmo' => 'avasmo',
'yavao' => 'avao',
'yavano' => 'avano',
'yavani' => 'avani',
'yavane' => 'avane',
'yavana' => 'avana',
'yavan' => 'avan',
'yavalo' => 'avalo',
'yavali' => 'avali',
'yavale' => 'avale',
'yavala' => 'avala',
'yavahu' => 'avahu',
'yavah' => 'avah',
'yavacyu' => 'avacyu',
'yavacyete' => 'avacyete',
'yavacyesx' => 'avacyesx',
'yavacyemo' => 'avacyemo',
'yavacye' => 'avacye',
'yava' => 'ava',
'yasxu' => 'u',
'yasxom' => 'om',
'yasxima' => 'ima',
'yasxi' => 'i',
'yasxa' => 'a',
'yastu' => 'u',
'yastomu' => 'omu',
'yastom' => 'om',
'yastoj' => 'oj',
'yastoga' => 'oga',
'yastog' => 'og',
'yasto' => 'o',
'yastim' => 'im',
'yastiju' => 'iju',
'yastijomu' => 'ijomu',
'yastijom' => 'ijom',
'yastijoj' => 'ijoj',
'yastijim' => 'ijim',
'yastijih' => 'ijih',
'yastiji' => 'iji',
'yastijemu' => 'ijemu',
'yastijem' => 'ijem',
'yastijega' => 'ijega',
'yastijeg' => 'ijeg',
'yastije' => 'ije',
'yastija' => 'ija',
'yastih' => 'ih',
'yasti' => 'i',
'yasta' => 'a',
'yast' => '',
'yajucyi' => '',
'xucyiu' => 'xucyiu',
'xucyiomu' => 'xucyiomu',
'xucyiom' => 'xucyiom',
'xucyioj' => 'xucyioj',
'xucyim' => 'xucyim',
'xucyih' => 'xucyih',
'xucyiemu' => 'xucyiemu',
'xucyiem' => 'xucyiem',
'xucyiega' => 'xucyiega',
'xucyieg' => 'xucyieg',
'xucyie' => 'xucyie',
'xucyia' => 'xucyia',
'xtite' => '',
'xtisx' => '',
'xtimo' => '',
'xtim' => '',
'xti' => '',
'xtavsxi' => 'vsxi',
'xtati' => 'ti',
'xtat' => 't',
'xtasxe' => 'sxe',
'xtaste' => 'ste',
'xtasmo' => 'smo',
'xtao' => 'o',
'xtanyu' => 'u',
'xtanyima' => 'ima',
'xtanyem' => 'em',
'xtanye' => 'e',
'xtanya' => 'a',
'xtano' => 'no',
'xtani' => 'ni',
'xtane' => 'ne',
'xtana' => 'na',
'xtan' => 'n',
'xtalo' => 'lo',
'xtali' => 'li',
'xtale' => 'le',
'xtala' => 'la',
'xtahu' => 'hu',
'xtah' => 'h',
'xtacyu' => 'cyu',
'xtacyete' => 'cyete',
'xtacyesx' => 'cyesx',
'xtacyemo' => 'cyemo',
'xtacye' => 'cye',
'xta' => '',
'xovima' => 'ima',
'xovi' => 'i',
'xove' => 'e',
'xova' => 'ova',
'xou' => 'ou',
'xoima' => 'oima',
'xoi' => 'oi',
'xoga' => 'oga',
'xog' => 'og',
'xoe' => 'oe',
'xoama' => 'oama',
'xoa' => 'oa',
'xnyu' => 'nyu',
'xnyomu' => 'omu',
'xnyom' => 'nyom',
'xnyoj' => 'oj',
'xnyim' => 'm',
'xnyikavu' => 'xnyikavu',
'xnyikavomu' => 'xnyikavomu',
'xnyikavom' => 'xnyikavom',
'xnyikavoj' => 'xnyikavoj',
'xnyikavoga' => 'xnyikavoga',
'xnyikavog' => 'xnyikavog',
'xnyikavo' => 'xnyikavo',
'xnyikavim' => 'xnyikavim',
'xnyikavih' => 'xnyikavih',
'xnyikavi' => 'xnyikavi',
'xnyikave' => 'xnyikave',
'xnyikava' => 'xnyikava',
'xnyikav' => 'xnyikav',
'xnyih' => 'h',
'xnyi' => '',
'xnyezxuju' => 'xnyezxuju',
'xnyezxujite' => 'xnyezxujite',
'xnyezxujimo' => 'xnyezxujimo',
'xnyezxuji' => 'xnyezxuji',
'xnyezxujete' => 'xnyezxujete',
'xnyezxujesx' => 'xnyezxujesx',
'xnyezxujemo' => 'xnyezxujemo',
'xnyezxujem' => 'xnyezxujem',
'xnyezxuje' => 'xnyezxuje',
'xnyezxte' => 'xnyezxte',
'xnyezxmo' => 'xnyezxmo',
'xnyezxivsxi' => 'xnyezxivsxi',
'xnyezxivavsxi' => 'xnyezxivavsxi',
'xnyezxivati' => 'xnyezxivati',
'xnyezxivat' => 'xnyezxivat',
'xnyezxivasxe' => 'xnyezxivasxe',
'xnyezxivaste' => 'xnyezxivaste',
'xnyezxivasmo' => 'xnyezxivasmo',
'xnyezxivao' => 'xnyezxivao',
'xnyezxivano' => 'xnyezxivano',
'xnyezxivani' => 'xnyezxivani',
'xnyezxivane' => 'xnyezxivane',
'xnyezxivana' => 'xnyezxivana',
'xnyezxivan' => 'xnyezxivan',
'xnyezxivalo' => 'xnyezxivalo',
'xnyezxivali' => 'xnyezxivali',
'xnyezxivale' => 'xnyezxivale',
'xnyezxivala' => 'xnyezxivala',
'xnyezxivahu' => 'xnyezxivahu',
'xnyezxivah' => 'xnyezxivah',
'xnyezxivacyu' => 'xnyezxivacyu',
'xnyezxivacyete' => 'xnyezxivacyete',
'xnyezxivacyesx' => 'xnyezxivacyesx',
'xnyezxivacyemo' => 'xnyezxivacyemo',
'xnyezxivacye' => 'xnyezxivacye',
'xnyezxiva' => 'xnyezxiva',
'xnyezxiti' => 'xnyezxiti',
'xnyezxite' => 'xnyezxite',
'xnyezxit' => 'xnyezxit',
'xnyezxisxe' => 'xnyezxisxe',
'xnyezxisx' => 'xnyezxisx',
'xnyezxiste' => 'xnyezxiste',
'xnyezxismo' => 'xnyezxismo',
'xnyezxio' => 'xnyezxio',
'xnyezximo' => 'xnyezximo',
'xnyezxim' => 'xnyezxim',
'xnyezxilo' => 'xnyezxilo',
'xnyezxili' => 'xnyezxili',
'xnyezxile' => 'xnyezxile',
'xnyezxila' => 'xnyezxila',
'xnyezxih' => 'xnyezxih',
'xnyezxicyu' => 'xnyezxicyu',
'xnyezxicyete' => 'xnyezxicyete',
'xnyezxicyesx' => 'xnyezxicyesx',
'xnyezxicyemo' => 'xnyezxicyemo',
'xnyezxicye' => 'xnyezxicye',
'xnyezxicu' => 'xnyezxicu',
'xnyezxicom' => 'xnyezxicom',
'xnyezxico' => 'xnyezxico',
'xnyezxici' => 'xnyezxici',
'xnyezxice' => 'xnyezxice',
'xnyezxicama' => 'xnyezxicama',
'xnyezxica' => 'xnyezxica',
'xnyezxi' => 'xnyezxi',
'xnyezxeno' => 'xnyezxeno',
'xnyezxeni' => 'xnyezxeni',
'xnyezxene' => 'xnyezxene',
'xnyezxena' => 'xnyezxena',
'xnyezxen' => 'xnyezxen',
'xnyezxe' => 'xnyezxe',
'xnyezxavavsxi' => 'xnyezxavavsxi',
'xnyezxavati' => 'xnyezxavati',
'xnyezxavat' => 'xnyezxavat',
'xnyezxavasxe' => 'xnyezxavasxe',
'xnyezxavaste' => 'xnyezxavaste',
'xnyezxavasmo' => 'xnyezxavasmo',
'xnyezxavao' => 'xnyezxavao',
'xnyezxavano' => 'xnyezxavano',
'xnyezxavani' => 'xnyezxavani',
'xnyezxavane' => 'xnyezxavane',
'xnyezxavana' => 'xnyezxavana',
'xnyezxavan' => 'xnyezxavan',
'xnyezxavalo' => 'xnyezxavalo',
'xnyezxavali' => 'xnyezxavali',
'xnyezxavale' => 'xnyezxavale',
'xnyezxavala' => 'xnyezxavala',
'xnyezxavahu' => 'xnyezxavahu',
'xnyezxavah' => 'xnyezxavah',
'xnyezxavacyu' => 'xnyezxavacyu',
'xnyezxavacyete' => 'xnyezxavacyete',
'xnyezxavacyesx' => 'xnyezxavacyesx',
'xnyezxavacyemo' => 'xnyezxavacyemo',
'xnyezxavacye' => 'xnyezxavacye',
'xnyezxava' => 'xnyezxava',
'xnyezx' => 'xnyezx',
'xnyevsxi' => 'yevsxi',
'xnyesxe' => 'yesxe',
'xnyeste' => 'yeste',
'xnyesmo' => 'yesmo',
'xnyemu' => 'emu',
'xnyem' => 'yem',
'xnyelu' => 'xnyelu',
'xnyelomu' => 'xnyelomu',
'xnyelom' => 'xnyelom',
'xnyeloj' => 'xnyeloj',
'xnyeloga' => 'xnyeloga',
'xnyelog' => 'xnyelog',
'xnyelim' => 'xnyelim',
'xnyelih' => 'xnyelih',
'xnyeh' => 'yeh',
'xnyega' => 'ega',
'xnyeg' => 'eg',
'xnya' => 'nya',
'xny' => 'y',
'xmu' => 'mu',
'xmom' => 'mom',
'xmi' => 'mi',
'xme' => 'me',
'xmama' => 'mama',
'xma' => 'ma',
'xlyutmo' => 'xlyutmo',
'xlyutivsxi' => 'xlyutivsxi',
'xlyutiti' => 'xlyutiti',
'xlyutite' => 'xlyutite',
'xlyutit' => 'xlyutit',
'xlyutisxe' => 'xlyutisxe',
'xlyutisx' => 'xlyutisx',
'xlyutiste' => 'xlyutiste',
'xlyutismo' => 'xlyutismo',
'xlyutio' => 'xlyutio',
'xlyutimo' => 'xlyutimo',
'xlyutim' => 'xlyutim',
'xlyutilo' => 'xlyutilo',
'xlyutili' => 'xlyutili',
'xlyutile' => 'xlyutile',
'xlyutila' => 'xlyutila',
'xlyutih' => 'xlyutih',
'xlyuticyu' => 'xlyuticyu',
'xlyuticyete' => 'xlyuticyete',
'xlyuticyesx' => 'xlyuticyesx',
'xlyuticyemo' => 'xlyuticyemo',
'xlyuticye' => 'xlyuticye',
'xlyuti' => 'xlyuti',
'xlyute' => 'xlyute',
'xlyut' => 'xlyut',
'xlyucyeno' => 'xlyucyeno',
'xlyucyeni' => 'xlyucyeni',
'xlyucyene' => 'xlyucyene',
'xlyucyena' => 'xlyucyena',
'xlyucyen' => 'xlyucyen',
'xlyite' => 'ite',
'xlyimo' => 'imo',
'xlyi' => 'i',
'xlyete' => 'ete',
'xlyesx' => 'esx',
'xlyepodnevnu' => 'xlyepodnevnu',
'xlyepodnevnomu' => 'xlyepodnevnomu',
'xlyepodnevnom' => 'xlyepodnevnom',
'xlyepodnevnoj' => 'xlyepodnevnoj',
'xlyepodnevnoga' => 'xlyepodnevnoga',
'xlyepodnevnog' => 'xlyepodnevnog',
'xlyepodnevno' => 'xlyepodnevno',
'xlyepodnevnim' => 'xlyepodnevnim',
'xlyepodnevnih' => 'xlyepodnevnih',
'xlyepodnevni' => 'xlyepodnevni',
'xlyepodnevne' => 'xlyepodnevne',
'xlyepodnevna' => 'xlyepodnevna',
'xlyeplyujucyu' => 'xlyeplyujucyu',
'xlyeplyujucyomu' => 'xlyeplyujucyomu',
'xlyeplyujucyom' => 'xlyeplyujucyom',
'xlyeplyujucyoj' => 'xlyeplyujucyoj',
'xlyeplyujucyoga' => 'xlyeplyujucyoga',
'xlyeplyujucyog' => 'xlyeplyujucyog',
'xlyeplyujucyo' => 'xlyeplyujucyo',
'xlyeplyujucyim' => 'xlyeplyujucyim',
'xlyeplyujucyih' => 'xlyeplyujucyih',
'xlyeplyujucyi' => 'xlyeplyujucyi',
'xlyeplyujucye' => 'xlyeplyujucye',
'xlyeplyujucya' => 'xlyeplyujucya',
'xlyeplyuju' => 'xlyeplyuju',
'xlyeplyujite' => 'xlyeplyujite',
'xlyeplyujimo' => 'xlyeplyujimo',
'xlyeplyuji' => 'xlyeplyuji',
'xlyeplyujete' => 'xlyeplyujete',
'xlyeplyujesx' => 'xlyeplyujesx',
'xlyeplyujemo' => 'xlyeplyujemo',
'xlyeplyujem' => 'xlyeplyujem',
'xlyeplyuje' => 'xlyeplyuje',
'xlyeplyivavsxi' => 'xlyeplyivavsxi',
'xlyeplyivati' => 'xlyeplyivati',
'xlyeplyivat' => 'xlyeplyivat',
'xlyeplyivasxe' => 'xlyeplyivasxe',
'xlyeplyivaste' => 'xlyeplyivaste',
'xlyeplyivasmo' => 'xlyeplyivasmo',
'xlyeplyivao' => 'xlyeplyivao',
'xlyeplyivano' => 'xlyeplyivano',
'xlyeplyivani' => 'xlyeplyivani',
'xlyeplyivane' => 'xlyeplyivane',
'xlyeplyivana' => 'xlyeplyivana',
'xlyeplyivan' => 'xlyeplyivan',
'xlyeplyivalo' => 'xlyeplyivalo',
'xlyeplyivali' => 'xlyeplyivali',
'xlyeplyivale' => 'xlyeplyivale',
'xlyeplyivala' => 'xlyeplyivala',
'xlyeplyivahu' => 'xlyeplyivahu',
'xlyeplyivah' => 'xlyeplyivah',
'xlyeplyivacyu' => 'xlyeplyivacyu',
'xlyeplyivacyete' => 'xlyeplyivacyete',
'xlyeplyivacyesx' => 'xlyeplyivacyesx',
'xlyeplyivacyemo' => 'xlyeplyivacyemo',
'xlyeplyivacye' => 'xlyeplyivacye',
'xlyeplyiva' => 'xlyeplyiva',
'xlyeplyenosxcyu' => 'xlyeplyenosxcyu',
'xlyeplyenostima' => 'xlyeplyenostima',
'xlyeplyenosti' => 'xlyeplyenosti',
'xlyemo' => 'emo',
'xlyem' => 'em',
'xlyedyute' => 'xlyedyute',
'xlyedyumo' => 'xlyedyumo',
'xlyedyujucyi' => 'xlyedyujucyi',
'xlyedyujte' => 'xlyedyujte',
'xlyedyujmo' => 'xlyedyujmo',
'xlyedyujite' => 'xlyedyujite',
'xlyedyujimo' => 'xlyedyujimo',
'xlyedyuji' => 'xlyedyuji',
'xlyedyuj' => 'xlyedyuj',
'xlyedyu' => 'xlyedyu',
'xlyedyima' => 'xlyedyima',
'xlyedyem' => 'xlyedyem',
'xlyedye' => 'xlyedye',
'xlyedya' => 'xlyedya',
'xlyedstvu' => 'xlyedstvu',
'xlyedstvom' => 'xlyedstvom',
'xlyedstvo' => 'xlyedstvo',
'xlyedstvima' => 'xlyedstvima',
'xlyedstva' => 'xlyedstva',
'xlyedstava' => 'xlyedstava',
'xlyednu' => 'xlyednu',
'xlyednomu' => 'xlyednomu',
'xlyednom' => 'xlyednom',
'xlyednoj' => 'xlyednoj',
'xlyednoga' => 'xlyednoga',
'xlyednog' => 'xlyednog',
'xlyedno' => 'xlyedno',
'xlyednim' => 'xlyednim',
'xlyednih' => 'xlyednih',
'xlyednicxku' => 'xlyednicxku',
'xlyednicxkomu' => 'xlyednicxkomu',
'xlyednicxkom' => 'xlyednicxkom',
'xlyednicxkoj' => 'xlyednicxkoj',
'xlyednicxkoga' => 'xlyednicxkoga',
'xlyednicxkog' => 'xlyednicxkog',
'xlyednicxko' => 'xlyednicxko',
'xlyednicxkim' => 'xlyednicxkim',
'xlyednicxkih' => 'xlyednicxkih',
'xlyednicxki' => 'xlyednicxki',
'xlyednicxke' => 'xlyednicxke',
'xlyednicxka' => 'xlyednicxka',
'xlyednicu' => 'xlyednicu',
'xlyednicom' => 'xlyednicom',
'xlyednico' => 'xlyednico',
'xlyednice' => 'xlyednice',
'xlyednicama' => 'xlyednicama',
'xlyednica' => 'xlyednica',
'xlyedni' => 'xlyedni',
'xlyedne' => 'xlyedne',
'xlyedna' => 'xlyedna',
'xlyedicu' => 'xlyedicu',
'xlyedicom' => 'xlyedicom',
'xlyedico' => 'xlyedico',
'xlyedici' => 'xlyedici',
'xlyedice' => 'xlyedice',
'xlyedicama' => 'xlyedicama',
'xlyedica' => 'xlyedica',
'xlyecxivu' => 'xlyecxivu',
'xlyecxivomu' => 'xlyecxivomu',
'xlyecxivom' => 'xlyecxivom',
'xlyecxivoj' => 'xlyecxivoj',
'xlyecxivoga' => 'xlyecxivoga',
'xlyecxivog' => 'xlyecxivog',
'xlyecxivo' => 'xlyecxivo',
'xlyecxivim' => 'xlyecxivim',
'xlyecxivih' => 'xlyecxivih',
'xlyecxivi' => 'xlyecxivi',
'xlyecxive' => 'xlyecxive',
'xlyecxiva' => 'xlyecxiva',
'xlyecxiv' => 'xlyecxiv',
'xlye' => 'e',
'xlyavsxi' => 'vsxi',
'xlyati' => 'ti',
'xlyate' => 'te',
'xlyat' => 't',
'xlyasx' => 'sx',
'xlyao' => 'o',
'xlyano' => 'no',
'xlyani' => 'ni',
'xlyane' => 'ne',
'xlyana' => 'na',
'xlyan' => 'n',
'xlyamo' => 'mo',
'xlyam' => 'm',
'xlyalu' => 'xlyalu',
'xlyalom' => 'xlyalom',
'xlyalo' => 'lo',
'xlyalima' => 'xlyalima',
'xlyali' => 'li',
'xlyale' => 'le',
'xlyala' => 'la',
'xlyaju' => 'ju',
'xlyajte' => 'jte',
'xlyajmo' => 'jmo',
'xlyaj' => 'j',
'xlyacyu' => 'cyu',
'xlyacyete' => 'cyete',
'xlyacyesx' => 'cyesx',
'xlyacyemo' => 'cyemo',
'xlyacye' => 'cye',
'xlya' => '',
'xkomu' => 'omu',
'xkoj' => 'oj',
'xkoga' => 'oga',
'xkog' => 'og',
'xko' => 'o',
'xkim' => 'im',
'xkih' => 'ih',
'xki' => 'i',
'xjte' => 'xjte',
'xjmo' => 'xjmo',
'xj' => 'xj',
'ximu' => 'u',
'ximom' => 'om',
'ximima' => 'ima',
'ximi' => 'i',
'xime' => '',
'xevavsxi' => 'avsxi',
'xevati' => 'ati',
'xevat' => 'at',
'xevasxe' => 'asxe',
'xevaste' => 'aste',
'xevasmo' => 'asmo',
'xevao' => 'ao',
'xevano' => 'ano',
'xevani' => 'ani',
'xevane' => 'ane',
'xevana' => 'ana',
'xevan' => 'an',
'xevalo' => 'alo',
'xevali' => 'ali',
'xevale' => 'ale',
'xevala' => 'ala',
'xevajuju' => 'xevajuju',
'xevajujite' => 'xevajujite',
'xevajujimo' => 'xevajujimo',
'xevajuji' => 'xevajuji',
'xevajujete' => 'xevajujete',
'xevajujesx' => 'xevajujesx',
'xevajujemo' => 'xevajujemo',
'xevajujem' => 'xevajujem',
'xevajuje' => 'xevajuje',
'xevahu' => 'ahu',
'xevah' => 'ah',
'xevacyu' => 'acyu',
'xevacyete' => 'acyete',
'xevacyesx' => 'acyesx',
'xevacyemo' => 'acyemo',
'xevacye' => 'acye',
'xeu' => 'u',
'xetu' => 'etu',
'xetom' => 'etom',
'xeta' => 'eta',
'xesxu' => 'u',
'xesxom' => 'xesxom',
'xesxite' => 'ite',
'xesximo' => 'imo',
'xesxi' => 'i',
'xesxevima' => 'xesxevima',
'xesxevi' => 'xesxevi',
'xesxeve' => 'xesxeve',
'xesxeva' => 'xesxeva',
'xesxete' => 'ete',
'xesxesx' => 'esx',
'xesxemo' => 'emo',
'xesxem' => 'em',
'xesxe' => 'sxe',
'xesxavsxi' => 'avsxi',
'xesxati' => 'ati',
'xesxat' => 'at',
'xesxasxe' => 'asxe',
'xesxaste' => 'aste',
'xesxasmo' => 'asmo',
'xesxao' => 'ao',
'xesxano' => 'ano',
'xesxani' => 'ani',
'xesxane' => 'ane',
'xesxana' => 'ana',
'xesxan' => 'an',
'xesxalo' => 'alo',
'xesxali' => 'ali',
'xesxale' => 'ale',
'xesxala' => 'ala',
'xesxahu' => 'ahu',
'xesxah' => 'ah',
'xesxacyu' => 'acyu',
'xesxacyete' => 'acyete',
'xesxacyesx' => 'acyesx',
'xesxacyemo' => 'acyemo',
'xesxacye' => 'acye',
'xesxa' => 'a',
'xeom' => 'om',
'xemu' => 'u',
'xeima' => 'ima',
'xei' => 'i',
'xega' => '',
'xeg' => 'g',
'xee' => 'e',
'xea' => 'a',
'xdyenye' => 'xdyenye',
'xdyanu' => 'xdyanu',
'xdyanomu' => 'xdyanomu',
'xdyanom' => 'xdyanom',
'xdyanoj' => 'xdyanoj',
'xdyanoga' => 'xdyanoga',
'xdyanog' => 'xdyanog',
'xdyano' => 'xdyano',
'xdyanim' => 'xdyanim',
'xdyanih' => 'xdyanih',
'xdyani' => 'xdyani',
'xdyane' => 'xdyane',
'xdyana' => 'xdyana',
'xcyute' => '',
'xcyumo' => '',
'xcyujucyi' => '',
'xcyuju' => '',
'xcyujte' => '',
'xcyujmo' => '',
'xcyujete' => '',
'xcyujesx' => '',
'xcyujemo' => '',
'xcyujem' => '',
'xcyuje' => '',
'xcyuj' => '',
'xcyivavsxi' => '',
'xcyivati' => '',
'xcyivat' => '',
'xcyivasxe' => '',
'xcyivaste' => '',
'xcyivasmo' => '',
'xcyivao' => '',
'xcyivano' => '',
'xcyivani' => '',
'xcyivane' => '',
'xcyivana' => '',
'xcyivan' => '',
'xcyivalo' => '',
'xcyivali' => '',
'xcyivale' => '',
'xcyivala' => '',
'xcyivahu' => '',
'xcyivah' => '',
'xcyivacyu' => '',
'xcyivacyete' => '',
'xcyivacyesx' => '',
'xcyivacyemo' => '',
'xcyivacye' => '',
'xcyiva' => '',
'xcyenyu' => 'u',
'xcyenyima' => 'ima',
'xcyenyem' => 'em',
'xcyenya' => 'a',
'xcxu' => '',
'xcxomu' => '',
'xcxom' => '',
'xcxoj' => '',
'xcxlanyivanyu' => 'xcxlanyivanyu',
'xcxlanyivanyima' => 'xcxlanyivanyima',
'xcxlanyivanyem' => 'xcxlanyivanyem',
'xcxlanyivanye' => 'xcxlanyivanye',
'xcxlanyivanya' => 'xcxlanyivanya',
'xcxlanyenyu' => 'xcxlanyenyu',
'xcxlanyenyima' => 'xcxlanyenyima',
'xcxlanyenyem' => 'xcxlanyenyem',
'xcxlanyenye' => 'xcxlanyenye',
'xcxlanyenya' => 'xcxlanyenya',
'xcxim' => '',
'xcxih' => '',
'xcxi' => '',
'xcxemu' => '',
'xcxem' => '',
'xcxega' => '',
'xcxeg' => '',
'xcxa' => '',
'xcx' => 'xcx',
'xastu' => 'u',
'xastomu' => 'omu',
'xastom' => 'om',
'xastoj' => 'oj',
'xastoga' => 'oga',
'xastog' => 'og',
'xasto' => 'o',
'xastim' => 'im',
'xastih' => 'ih',
'xasti' => 'i',
'xasta' => 'a',
'xast' => '',
'xalyu' => 'u',
'xalyimo' => '',
'xalyi' => 'i',
'xalyete' => '',
'xalyesx' => '',
'xalyemo' => '',
'xalyem' => 'em',
'xalye' => 'e',
'xalu' => 'u',
'xalom' => 'om',
'xalima' => 'alima',
'xajom' => 'om',
'xajo' => 'o',
'xaji' => 'i',
'xaje' => 'e',
'xajama' => 'ama',
'xaja' => 'aja',
'xadima' => 'adima',
'xadi' => 'adi',
'xad' => 'ad',
'vusxe' => 'usxe',
'vuste' => 'uste',
'vusmo' => 'usmo',
'vukute' => 'ukute',
'vukusx' => 'ukusx',
'vukumo' => 'ukumo',
'vuku' => 'uku',
'vukte' => 'ukte',
'vukmo' => 'ukmo',
'vuklo' => 'uklo',
'vukli' => 'ukli',
'vukle' => 'ukle',
'vukla' => 'ukla',
'vukao' => 'ukao',
'vuk' => 'uk',
'vuju' => 'uju',
'vujite' => 'ujite',
'vujimo' => 'ujimo',
'vuji' => 'uji',
'vujete' => 'ujete',
'vujesx' => 'ujesx',
'vujemo' => 'ujemo',
'vujem' => 'ujem',
'vuje' => 'uje',
'vuih' => 'uih',
'vugosxe' => 'ugosxe',
'vugoste' => 'ugoste',
'vugosmo' => 'ugosmo',
'vugoh' => 'ugoh',
'vugo' => 'ugo',
'vugavsxi' => 'ugavsxi',
'vucyu' => 'ucyu',
'vucyi' => 'ucyi',
'vucyete' => 'ucyete',
'vucyesx' => 'ucyesx',
'vucyemo' => 'ucyemo',
'vucye' => 'ucye',
'vucy' => 'ucy',
'vucxem' => 'ucxem',
'vucxe' => 'ucxe',
'vru' => 'u',
'vrte' => 'te',
'vrtavsxi' => 'tavsxi',
'vrtati' => 'tati',
'vrtat' => 'tat',
'vrtasxe' => 'tasxe',
'vrtaste' => 'taste',
'vrtasmo' => 'tasmo',
'vrtao' => 'tao',
'vrtano' => 'tano',
'vrtani' => 'tani',
'vrtane' => 'tane',
'vrtana' => 'tana',
'vrtan' => 'tan',
'vrtalo' => 'talo',
'vrtali' => 'tali',
'vrtale' => 'tale',
'vrtala' => 'tala',
'vrtahu' => 'tahu',
'vrtah' => 'tah',
'vrtacyu' => 'tacyu',
'vrtacyete' => 'tacyete',
'vrtacyesx' => 'tacyesx',
'vrtacyemo' => 'tacyemo',
'vrtacye' => 'tacye',
'vrta' => 'ta',
'vrsxte' => 'te',
'vrsxmo' => 'mo',
'vrsxivsxi' => 'ivsxi',
'vrsxiti' => 'iti',
'vrsxite' => 'ite',
'vrsxit' => 'it',
'vrsxisxe' => 'isxe',
'vrsxisx' => 'isx',
'vrsxiste' => 'iste',
'vrsxismo' => 'ismo',
'vrsxio' => 'io',
'vrsximo' => 'imo',
'vrsxim' => 'im',
'vrsxilo' => 'ilo',
'vrsxili' => 'ili',
'vrsxile' => 'ile',
'vrsxila' => 'ila',
'vrsxih' => 'ih',
'vrsxicyu' => 'icyu',
'vrsxicyete' => 'icyete',
'vrsxicyesx' => 'icyesx',
'vrsxicyemo' => 'icyemo',
'vrsxicye' => 'icye',
'vrsxi' => 'i',
'vrsxeno' => 'eno',
'vrsxeni' => 'eni',
'vrsxene' => 'ene',
'vrsxena' => 'ena',
'vrsxen' => 'en',
'vrsxe' => 'e',
'vrsx' => '',
'vrste' => 'te',
'vrsmo' => 'rsmo',
'vrmo' => 'mo',
'vrih' => 'rih',
'vrgosxe' => 'rgosxe',
'vrgoste' => 'rgoste',
'vrgosmo' => 'rgosmo',
'vrgoh' => 'rgoh',
'vrgo' => 'rgo',
'vrgnuvsxi' => 'rgnuvsxi',
'vrgnuto' => 'rgnuto',
'vrgnuti' => 'rgnuti',
'vrgnute' => 'rgnute',
'vrgnuta' => 'rgnuta',
'vrgnut' => 'rgnut',
'vrgnusxe' => 'rgnusxe',
'vrgnusx' => 'rgnusx',
'vrgnuste' => 'rgnuste',
'vrgnusmo' => 'rgnusmo',
'vrgnuo' => 'rgnuo',
'vrgnumo' => 'rgnumo',
'vrgnulo' => 'rgnulo',
'vrgnuli' => 'rgnuli',
'vrgnule' => 'rgnule',
'vrgnula' => 'rgnula',
'vrgnuh' => 'rgnuh',
'vrgnucyu' => 'rgnucyu',
'vrgnucyete' => 'rgnucyete',
'vrgnucyesx' => 'rgnucyesx',
'vrgnucyemo' => 'rgnucyemo',
'vrgnucye' => 'rgnucye',
'vrgnu' => 'rgnu',
'vrgnte' => 'rgnte',
'vrgnmo' => 'rgnmo',
'vrgnite' => 'rgnite',
'vrgnimo' => 'rgnimo',
'vrgni' => 'rgni',
'vrgnete' => 'rgnete',
'vrgnesx' => 'rgnesx',
'vrgnemo' => 'rgnemo',
'vrgnem' => 'rgnem',
'vrgne' => 'rgne',
'vrgn' => 'rgn',
'vrglo' => 'rglo',
'vrgli' => 'rgli',
'vrgle' => 'rgle',
'vrgla' => 'rgla',
'vrgavsxi' => 'rgavsxi',
'vrgao' => 'rgao',
'vrevsxi' => 'evsxi',
'vreti' => 'eti',
'vrete' => 'ete',
'vret' => 'et',
'vresxe' => 'esxe',
'vresx' => 'esx',
'vreste' => 'este',
'vresmo' => 'esmo',
'vreo' => 'eo',
'vreno' => 'eno',
'vreni' => 'eni',
'vrene' => 'ene',
'vrena' => 'ena',
'vren' => 'en',
'vremo' => 'emo',
'vrem' => 'em',
'vrelu' => 'elu',
'vrelomu' => 'elomu',
'vrelom' => 'elom',
'vreloj' => 'eloj',
'vreloga' => 'eloga',
'vrelog' => 'elog',
'vrelo' => 'elo',
'vrelim' => 'elim',
'vrelih' => 'elih',
'vreli' => 'eli',
'vrele' => 'ele',
'vrela' => 'ela',
'vreh' => 'eh',
'vrecyu' => 'ecyu',
'vrecyete' => 'ecyete',
'vrecyesx' => 'ecyesx',
'vrecyemo' => 'ecyemo',
'vrecye' => 'ecye',
'vre' => 'e',
'vrcyu' => 'cyu',
'vrcyite' => 'cyite',
'vrcyimo' => 'cyimo',
'vrcyi' => 'cyi',
'vrcyete' => 'cyete',
'vrcyesx' => 'cyesx',
'vrcyemo' => 'cyemo',
'vrcyem' => 'cyem',
'vrcye' => 'cye',
'vrcy' => 'rcy',
'vr' => '',
'vomu' => 'omu',
'vome' => 'e',
'voju' => 'u',
'vojom' => 'om',
'vojoj' => 'joj',
'vojo' => 'o',
'vojima' => 'vojima',
'vojim' => 'im',
'vojih' => 'ih',
'voji' => 'i',
'vojemu' => 'jemu',
'vojem' => 'jem',
'vojega' => 'jega',
'voje' => 'e',
'vojama' => 'ama',
'voja' => 'a',
'voga' => 'oga',
'vm' => 'vm',
'vlyenye' => 'e',
'vlyenya' => 'a',
'vlyasxe' => 'lyasxe',
'vlyaste' => 'lyaste',
'vlyasmo' => 'lyasmo',
'vlyahu' => 'lyahu',
'vlyah' => 'lyah',
'vku' => 'ku',
'vkom' => 'kom',
'vke' => 'ke',
'vka' => 'ka',
'vivsxi' => 'ivsxi',
'viveno' => 'iveno',
'viveni' => 'iveni',
'vivene' => 'ivene',
'vivena' => 'ivena',
'viven' => 'iven',
'vite' => 'ite',
'visxe' => 'isxe',
'visx' => 'isx',
'viste' => 'iste',
'vismo' => 'ismo',
'vimo' => 'imo',
'viju' => 'iju',
'vijte' => 'ijte',
'vijmo' => 'ijmo',
'vijete' => 'ijete',
'vijesx' => 'ijesx',
'vijemo' => 'ijemo',
'vijem' => 'ijem',
'vije' => 'ije',
'vij' => 'ij',
'veu' => 'u',
'veom' => 'om',
'vemu' => 'vemu',
'vekara' => 'vekara',
'vekar' => 'vekar',
'veima' => 'ima',
'vei' => 'i',
'vecyi' => 'ecyi',
'vea' => 'a',
'vcxe' => 'cxe',
'vcu' => 'cu',
'vcima' => 'cima',
'vci' => 'ci',
'vcem' => 'cem',
'vce' => 'ce',
'vca' => 'ca',
'vatu' => 'u',
'vatomu' => 'omu',
'vatom' => 'om',
'vatoj' => 'oj',
'vatoga' => 'oga',
'vatog' => 'og',
'vato' => 'o',
'vatim' => 'tim',
'vatih' => 'tih',
'vata' => 'a',
'vastu' => 'u',
'vastomu' => 'omu',
'vastom' => 'om',
'vastoj' => 'oj',
'vastoga' => 'oga',
'vastog' => 'og',
'vasto' => 'o',
'vastim' => 'im',
'vastih' => 'ih',
'vasti' => 'i',
'vasta' => 'a',
'vast' => '',
'vanye' => 'e',
'vangelistu' => 'vangelistu',
'vangelistom' => 'vangelistom',
'vangelistima' => 'vangelistima',
'vangelisti' => 'vangelisti',
'vangeliste' => 'vangeliste',
'vangelista' => 'vangelista',
'vajucyi' => 'jucyi',
'vaca' => 'aca',
'vac' => 'ac',
'utmo' => 'tmo',
'utkavsxi' => 'vsxi',
'utkati' => 'ti',
'utkate' => 'te',
'utkat' => 't',
'utkasxe' => 'sxe',
'utkasx' => 'sx',
'utkaste' => 'ste',
'utkasmo' => 'smo',
'utkao' => 'o',
'utkano' => 'no',
'utkani' => 'ni',
'utkane' => 'ne',
'utkana' => 'na',
'utkan' => 'n',
'utkamo' => 'mo',
'utkam' => 'm',
'utkalo' => 'lo',
'utkali' => 'li',
'utkale' => 'le',
'utkala' => 'la',
'utkaju' => 'ju',
'utkajte' => 'jte',
'utkajmo' => 'jmo',
'utkaj' => 'j',
'utkah' => 'h',
'utkacyu' => 'cyu',
'utkacyete' => 'cyete',
'utkacyesx' => 'cyesx',
'utkacyemo' => 'cyemo',
'utkacye' => 'cye',
'utka' => 'tka',
'utjevsxi' => 'tjevsxi',
'utjeti' => 'tjeti',
'utjet' => 'tjet',
'utjesxe' => 'tjesxe',
'utjeste' => 'tjeste',
'utjesmo' => 'tjesmo',
'utjelo' => 'tjelo',
'utjeli' => 'tjeli',
'utjele' => 'tjele',
'utjela' => 'tjela',
'utjeh' => 'tjeh',
'utjecyu' => 'tjecyu',
'utjecyete' => 'tjecyete',
'utjecyesx' => 'tjecyesx',
'utjecyemo' => 'tjecyemo',
'utjecye' => 'tjecye',
'utje' => 'tje',
'utite' => 'tite',
'utisx' => 'tisx',
'utio' => 'tio',
'utimo' => 'timo',
'utima' => 'ima',
'utevsxi' => 'tevsxi',
'utet' => 'tet',
'utesxe' => 'tesxe',
'uteste' => 'teste',
'utesmo' => 'tesmo',
'uteh' => 'teh',
'utecyu' => 'tecyu',
'utecyete' => 'tecyete',
'utecyesx' => 'tecyesx',
'utecyemo' => 'tecyemo',
'utecye' => 'tecye',
'utati' => 'ti',
'utao' => 'o',
'utama' => 'ama',
'utalo' => 'lo',
'utali' => 'li',
'utale' => 'le',
'utala' => 'la',
'usxcyeno' => 'xcyeno',
'usxcyeni' => 'xcyeni',
'usxcyene' => 'xcyene',
'usxcyena' => 'xcyena',
'usxcyen' => 'xcyen',
'ustivsxi' => 'tivsxi',
'ustiti' => 'titi',
'ustite' => 'tite',
'ustit' => 'tit',
'ustisxe' => 'tisxe',
'ustisx' => 'tisx',
'ustiste' => 'tiste',
'ustismo' => 'tismo',
'ustio' => 'tio',
'ustimo' => 'timo',
'ustim' => 'tim',
'ustilo' => 'tilo',
'ustili' => 'tili',
'ustile' => 'tile',
'ustila' => 'tila',
'ustih' => 'tih',
'usticyu' => 'ticyu',
'usticyete' => 'ticyete',
'usticyesx' => 'ticyesx',
'usticyemo' => 'ticyemo',
'usticye' => 'ticye',
'usti' => 'ti',
'upu' => 'u',
'upte' => 'te',
'upmo' => 'mo',
'uplyeno' => 'lyeno',
'uplyeni' => 'lyeni',
'uplyene' => 'lyene',
'uplyena' => 'lyena',
'uplyen' => 'lyen',
'upivsxi' => 'ivsxi',
'upiti' => 'iti',
'upite' => 'ite',
'upit' => 'it',
'upisxe' => 'isxe',
'upisx' => 'isx',
'upiste' => 'iste',
'upismo' => 'ismo',
'upio' => 'io',
'upimo' => 'imo',
'upim' => 'im',
'upilo' => 'ilo',
'upili' => 'ili',
'upile' => 'ile',
'upila' => 'ila',
'upih' => 'ih',
'upiecyi' => 'upiecyi',
'upie' => 'upie',
'upicyu' => 'icyu',
'upicyete' => 'icyete',
'upicyesx' => 'icyesx',
'upicyemo' => 'icyemo',
'upicye' => 'icye',
'upi' => 'i',
'upete' => 'ete',
'upesx' => 'upesx',
'upemo' => 'upemo',
'upem' => 'upem',
'upe' => 'e',
'upasxe' => 'sxe',
'upaste' => 'ste',
'upasmo' => 'smo',
'upahu' => 'ahu',
'upah' => 'h',
'up' => '',
'umski' => 'i',
'ulima' => 'ima',
'ukom' => 'kom',
'uko' => 'ko',
'uknuvsxi' => 'uvsxi',
'uknuto' => 'uto',
'uknuti' => 'uti',
'uknute' => 'ute',
'uknuta' => 'uta',
'uknut' => 'ut',
'uknusxe' => 'usxe',
'uknusx' => 'knusx',
'uknuste' => 'uste',
'uknusmo' => 'usmo',
'uknuo' => 'uo',
'uknumo' => 'uknumo',
'uknulo' => 'ulo',
'uknuli' => 'uli',
'uknule' => 'ule',
'uknula' => 'ula',
'uknuh' => 'uh',
'uknucyu' => 'ucyu',
'uknucyete' => 'ucyete',
'uknucyesx' => 'ucyesx',
'uknucyemo' => 'ucyemo',
'uknucye' => 'ucye',
'uknu' => 'u',
'uknte' => 'uknte',
'uknmo' => 'uknmo',
'ukni' => 'i',
'uknete' => 'ete',
'uknesx' => 'esx',
'uknemo' => 'emo',
'uknem' => 'em',
'ukne' => 'e',
'ukn' => 'ukn',
'uke' => 'ke',
'ukama' => 'kama',
'ujom' => 'om',
'ujo' => 'o',
'ujmte' => 'te',
'ujmlyeno' => 'lyeno',
'ujmlyeni' => 'lyeni',
'ujmlyene' => 'lyene',
'ujmlyena' => 'lyena',
'ujmlyen' => 'lyen',
'ujmivsxi' => 'ivsxi',
'ujmiti' => 'iti',
'ujmite' => 'ite',
'ujmit' => 'it',
'ujmisxe' => 'isxe',
'ujmisx' => 'isx',
'ujmiste' => 'iste',
'ujmismo' => 'ismo',
'ujmio' => 'io',
'ujmimo' => 'imo',
'ujmim' => 'im',
'ujmilo' => 'ilo',
'ujmili' => 'ili',
'ujmile' => 'ile',
'ujmila' => 'ila',
'ujmih' => 'ih',
'ujmicyu' => 'icyu',
'ujmicyete' => 'icyete',
'ujmicyesx' => 'icyesx',
'ujmicyemo' => 'icyemo',
'ujmicye' => 'icye',
'ujmi' => 'i',
'ujme' => 'e',
'ujm' => '',
'ujama' => 'ama',
'uja' => 'a',
'uete' => 'e',
'uesx' => 'uesx',
'uemo' => 'uemo',
'uem' => 'uem',
'ue' => 'e',
'ucyeno' => 'cyeno',
'ucyeni' => 'cyeni',
'ucyene' => 'cyene',
'ucyena' => 'cyena',
'ucyen' => 'cyen',
'ucite' => 'cite',
'ucimo' => 'cimo',
'tzgotina' => 'tzgotina',
'tusxe' => 'e',
'tuste' => 'ste',
'tusmo' => 'smo',
'tukute' => 'kute',
'tukusx' => 'kusx',
'tukumo' => 'kumo',
'tuku' => 'ku',
'tukte' => 'kte',
'tukmo' => 'kmo',
'tuklo' => 'klo',
'tukli' => 'kli',
'tukle' => 'kle',
'tukla' => 'kla',
'tukao' => 'kao',
'tuk' => 'k',
'tuih' => 'ih',
'tugosxe' => 'gosxe',
'tugoste' => 'goste',
'tugosmo' => 'gosmo',
'tugoh' => 'goh',
'tugo' => 'go',
'tugavsxi' => 'gavsxi',
'tucyu' => 'cyu',
'tucyiu' => 'u',
'tucyiomu' => 'omu',
'tucyiom' => 'om',
'tucyioj' => 'oj',
'tucyim' => 'm',
'tucyih' => 'h',
'tucyiemu' => 'emu',
'tucyiem' => 'em',
'tucyiega' => 'ega',
'tucyieg' => 'eg',
'tucyie' => 'e',
'tucyia' => 'a',
'tucyete' => 'cyete',
'tucyesx' => 'cyesx',
'tucyemo' => 'cyemo',
'tucye' => 'cye',
'tucy' => 'cy',
'tucxem' => 'cxem',
'tucxe' => 'cxe',
'tra' => 'ra',
'tpadniku' => 'ku',
'tpadnikom' => 'kom',
'tpadnike' => 'ke',
'tpadnika' => 'ka',
'tpadnik' => '',
'tpadnicxe' => 'cxe',
'tpadnicima' => 'cima',
'tpadnici' => 'ci',
'tovama' => 'tovama',
'toom' => 'toom',
'tomte' => 'te',
'tomomu' => 'tomomu',
'tomom' => 'om',
'tomoj' => 'tomoj',
'tomoga' => 'tomoga',
'tomog' => 'tomog',
'tomo' => 'o',
'tomlyeno' => 'lyeno',
'tomlyeni' => 'lyeni',
'tomlyene' => 'lyene',
'tomlyena' => 'lyena',
'tomlyen' => 'lyen',
'tomlyasxe' => 'tomlyasxe',
'tomlyaste' => 'tomlyaste',
'tomlyasmo' => 'tomlyasmo',
'tomlyahu' => 'tomlyahu',
'tomlyah' => 'tomlyah',
'tomiti' => 'iti',
'tomite' => 'ite',
'tomit' => 'it',
'tomisx' => 'x',
'tomio' => 'io',
'tomimo' => 'o',
'tomim' => 'im',
'tomilo' => 'ilo',
'tomili' => 'ili',
'tomile' => 'ile',
'tomila' => 'ila',
'tomih' => 'ih',
'tomicyu' => 'icyu',
'tomicyete' => 'icyete',
'tomicyesx' => 'icyesx',
'tomicyemo' => 'icyemo',
'tomicye' => 'icye',
'tomi' => 'i',
'tome' => 'e',
'toma' => 'a',
'tnyu' => 'nyu',
'tnyom' => 'nyom',
'tnyo' => 'nyo',
'tnyi' => 'nyi',
'tnye' => 'nye',
'tnyama' => 'nyama',
'tnya' => 'nya',
'tmete' => 'mete',
'tmesx' => 'mesx',
'tmemo' => 'memo',
'tmem' => 'mem',
'tme' => 'me',
'tlyiv' => '',
'tlu' => 'lu',
'tlom' => 'lom',
'tlama' => 'lama',
'tkie' => 'tkie',
'tkavsxi' => 'vsxi',
'tkati' => 'ti',
'tkate' => 'te',
'tkat' => 't',
'tkasxe' => 'sxe',
'tkasx' => 'sx',
'tkastu' => 'u',
'tkastomu' => 'omu',
'tkastom' => 'om',
'tkastoj' => 'oj',
'tkastoga' => 'oga',
'tkastog' => 'og',
'tkasto' => 'o',
'tkastim' => 'im',
'tkastih' => 'ih',
'tkasti' => 'i',
'tkaste' => 'ste',
'tkasta' => 'a',
'tkast' => '',
'tkasmo' => 'smo',
'tkao' => 'o',
'tkanye' => 'nye',
'tkamo' => 'mo',
'tkam' => 'm',
'tkalo' => 'lo',
'tkali' => 'li',
'tkale' => 'le',
'tkala' => 'la',
'tkaju' => 'ju',
'tkajte' => 'jte',
'tkajmo' => 'jmo',
'tkaj' => 'j',
'tkahu' => 'hu',
'tkah' => 'h',
'tkacyu' => 'cyu',
'tkacyete' => 'cyete',
'tkacyesx' => 'cyesx',
'tkacyemo' => 'cyemo',
'tkacye' => 'cye',
'tjte' => 'tjte',
'tjmo' => 'tjmo',
'tjeveno' => 'tjeveno',
'tjeveni' => 'tjeveni',
'tjevene' => 'tjevene',
'tjevena' => 'tjevena',
'tjeven' => 'tjeven',
'tjedyeno' => 'jedyeno',
'tjedyeni' => 'jedyeni',
'tjedyene' => 'jedyene',
'tjedyena' => 'jedyena',
'tjedyen' => 'jedyen',
'tjedyasxe' => 'jedyasxe',
'tjedyaste' => 'jedyaste',
'tjedyasmo' => 'jedyasmo',
'tjedyahu' => 'jedyahu',
'tjedyah' => 'jedyah',
'tjedte' => 'jedte',
'tjedmo' => 'jedmo',
'tjedite' => 'jedite',
'tjedisx' => 'jedisx',
'tjedimo' => 'jedimo',
'tjedim' => 'jedim',
'tjedi' => 'jedi',
'tjede' => 'jede',
'tjed' => 'jed',
'tj' => 'tj',
'tiu' => 'u',
'titu' => 'u',
'titomu' => 'omu',
'titom' => 'om',
'titoj' => 'oj',
'titoga' => 'oga',
'titog' => 'og',
'tito' => 'o',
'titim' => 'im',
'titih' => 'ih',
'tita' => 'a',
'tisxucyi' => 'xucyi',
'tisxte' => 'te',
'tisxo' => 'o',
'tisxmo' => 'xmo',
'tisxete' => 'xete',
'tisxesx' => 'xesx',
'tisxeno' => 'xeno',
'tisxeni' => 'xeni',
'tisxene' => 'xene',
'tisxena' => 'xena',
'tisxen' => 'xen',
'tisxemo' => 'xemo',
'tisxem' => 'xem',
'tisavsxi' => 'avsxi',
'tisati' => 'ati',
'tisat' => 'at',
'tisasxe' => 'asxe',
'tisaste' => 'aste',
'tisasmo' => 'asmo',
'tisao' => 'ao',
'tisalo' => 'alo',
'tisali' => 'ali',
'tisale' => 'ale',
'tisala' => 'ala',
'tisahu' => 'ahu',
'tisah' => 'ah',
'tisacyu' => 'acyu',
'tisacyete' => 'acyete',
'tisacyesx' => 'acyesx',
'tisacyemo' => 'acyemo',
'tisacye' => 'acye',
'tirte' => 'irte',
'tirmo' => 'irmo',
'tirite' => 'irite',
'tirisx' => 'irisx',
'tirimo' => 'irimo',
'tirim' => 'irim',
'tiri' => 'i',
'tireno' => 'ireno',
'tireni' => 'ireni',
'tirene' => 'irene',
'tirena' => 'irena',
'tiren' => 'iren',
'tire' => 'e',
'tirasxe' => 'sxe',
'tiraste' => 'ste',
'tirasmo' => 'smo',
'tirahu' => 'hu',
'tirah' => 'h',
'tir' => '',
'tiomu' => 'omu',
'tiom' => 'om',
'tioj' => 'oj',
'timu' => 'u',
'timom' => 'om',
'timima' => 'ima',
'timi' => 'i',
'time' => 'e',
'tijete' => 'tijete',
'tijesx' => 'tijesx',
'tijemo' => 'o',
'tijelu' => 'u',
'tijelomu' => 'tijelomu',
'tijelom' => 'om',
'tijeloj' => 'tijeloj',
'tijeloga' => 'tijeloga',
'tijelog' => 'tijelog',
'tijelim' => 'tijelim',
'tijelih' => 'tijelih',
'tijasxe' => 'e',
'tijaste' => 'e',
'tijasmo' => 'smo',
'tijahu' => 'tijahu',
'tijah' => 'h',
'tiemu' => 'emu',
'tiem' => 'em',
'tiega' => 'ega',
'tieg' => 'eg',
'tia' => 'a',
'tezxu' => 'u',
'tezxite' => 'xite',
'tezximo' => 'ximo',
'tezxi' => 'i',
'tezxete' => 'xete',
'tezxesx' => 'xesx',
'tezxemo' => 'xemo',
'tezxem' => 'xem',
'tezxe' => 'zxe',
'tezima' => 'zima',
'tezavsxi' => 'vsxi',
'tezati' => 'ti',
'tezat' => 't',
'tezasxe' => 'sxe',
'tezaste' => 'ste',
'tezasmo' => 'smo',
'tezao' => 'o',
'tezano' => 'no',
'tezani' => 'ni',
'tezane' => 'ne',
'tezana' => 'na',
'tezan' => 'n',
'tezalo' => 'lo',
'tezali' => 'li',
'tezale' => 'le',
'tezala' => 'la',
'tezahu' => 'hu',
'tezah' => 'h',
'tezacyu' => 'cyu',
'tezacyete' => 'cyete',
'tezacyesx' => 'cyesx',
'tezacyemo' => 'cyemo',
'tezacye' => 'cye',
'teza' => 'a',
'testu' => 'tu',
'testom' => 'tom',
'testima' => 'tima',
'testi' => 'testi',
'testa' => 'ta',
'test' => 't',
'tenya' => 'a',
'temte' => 'temte',
'teklu' => 'teklu',
'teklomu' => 'teklomu',
'teklom' => 'teklom',
'tekloj' => 'tekloj',
'tekloga' => 'tekloga',
'teklog' => 'teklog',
'teklim' => 'teklim',
'teklih' => 'teklih',
'tecyomu' => 'tecyomu',
'tecyom' => 'tecyom',
'tecyoj' => 'tecyoj',
'tecyoga' => 'tecyoga',
'tecyog' => 'tecyog',
'tecyo' => 'tecyo',
'tecyim' => 'm',
'tecyih' => 'h',
'tecya' => 'tecya',
'tcxe' => 'tcxe',
'tcxasovni' => 'tcxasovni',
'tcima' => 'cima',
'tci' => 'ci',
'tbuk-racxunar' => 'tbuk-racxunar',
'tbiro' => 'tbiro',
'tasxu' => 'u',
'tasxom' => 'om',
'tasxima' => 'ima',
'tasxi' => 'i',
'tasxa' => 'a',
'tante' => 'e',
'tansx' => 'tansx',
'tanmo' => 'nmo',
'tanm' => 'tanm',
'tanite' => 'nite',
'tanimo' => 'nimo',
'tanete' => 'nete',
'tanesx' => 'nesx',
'tanemo' => 'nemo',
'tanem' => 'nem',
'talomu' => 'lomu',
'taloj' => 'loj',
'taloga' => 'ga',
'talog' => 'g',
'talim' => 'im',
'talih' => 'ih',
'taknutu' => 'u',
'taknutomu' => 'omu',
'taknutom' => 'om',
'taknutoj' => 'oj',
'taknutoga' => 'oga',
'taknutog' => 'og',
'taknutim' => 'im',
'taknutih' => 'ih',
'takcyu' => 'takcyu',
'takcyite' => 'takcyite',
'takcyimo' => 'takcyimo',
'takcyi' => 'takcyi',
'takcyete' => 'takcyete',
'takcyesx' => 'takcyesx',
'takcyemo' => 'takcyemo',
'takcyem' => 'takcyem',
'takcye' => 'takcye',
'tajucyi' => 'jucyi',
'sxute' => 'ute',
'sxumo' => 'umo',
'sxujucyi' => 'ujucyi',
'sxuju' => 'uju',
'sxujte' => 'ujte',
'sxujmo' => 'ujmo',
'sxujete' => 'ujete',
'sxujesx' => 'ujesx',
'sxujemo' => 'ujemo',
'sxujem' => 'ujem',
'sxuje' => 'uje',
'sxuj' => 'uj',
'sxtu' => 'tu',
'sxtomu' => 'omu',
'sxtom' => 'tom',
'sxtoj' => 'oj',
'sxtoga' => 'oga',
'sxtog' => 'og',
'sxtiti' => 'titi',
'sxtite' => 'tite',
'sxtit' => 'tit',
'sxtisx' => 'tisx',
'sxtio' => 'tio',
'sxtimo' => 'timo',
'sxtim' => 'tim',
'sxtilo' => 'tilo',
'sxtili' => 'tili',
'sxtile' => 'tile',
'sxtila' => 'tila',
'sxtih' => 'tih',
'sxticyu' => 'ticyu',
'sxticyete' => 'ticyete',
'sxticyesx' => 'ticyesx',
'sxticyemo' => 'ticyemo',
'sxticye' => 'ticye',
'sxti' => 'ti',
'sxteu' => 'sxteu',
'sxteom' => 'sxteom',
'sxteima' => 'sxteima',
'sxtei' => 'sxtei',
'sxtea' => 'sxtea',
'sxt' => 't',
'sxovavsxi' => 'ovavsxi',
'sxovati' => 'ovati',
'sxovat' => 'ovat',
'sxovasxe' => 'ovasxe',
'sxovaste' => 'ovaste',
'sxovasmo' => 'ovasmo',
'sxovao' => 'ovao',
'sxovano' => 'ovano',
'sxovani' => 'ovani',
'sxovane' => 'ovane',
'sxovana' => 'ovana',
'sxovan' => 'ovan',
'sxovalo' => 'ovalo',
'sxovali' => 'ovali',
'sxovale' => 'ovale',
'sxovala' => 'ovala',
'sxovahu' => 'ovahu',
'sxovah' => 'ovah',
'sxovacyu' => 'ovacyu',
'sxovacyete' => 'ovacyete',
'sxovacyesx' => 'ovacyesx',
'sxovacyemo' => 'ovacyemo',
'sxovacye' => 'ovacye',
'sxova' => 'ova',
'sxivenyu' => 'ivenyu',
'sxivenye' => 'e',
'sxitu' => 'u',
'sxitomu' => 'tomu',
'sxitom' => 'om',
'sxitoj' => 'toj',
'sxitoga' => 'toga',
'sxitog' => 'tog',
'sxito' => 'to',
'sxitim' => 'tim',
'sxitih' => 'tih',
'sxita' => 'a',
'sxeu' => 'u',
'sxetu' => 'u',
'sxetom' => 'om',
'sxeta' => '',
'sxeom' => 'om',
'sxenu' => 'u',
'sxenomu' => 'omu',
'sxenom' => 'om',
'sxenoj' => 'oj',
'sxenoga' => 'ga',
'sxenog' => 'g',
'sxenim' => 'im',
'sxenih' => 'ih',
'sxemu' => 'u',
'sxeima' => 'ima',
'sxei' => 'i',
'sxega' => 'ga',
'sxeg' => 'eg',
'sxee' => 'e',
'sxea' => 'a',
'sxcyute' => 'xcyute',
'sxcyumo' => 'xcyumo',
'sxcyujucyi' => 'xcyujucyi',
'sxcyuju' => 'uju',
'sxcyujte' => 'xcyujte',
'sxcyujmo' => 'xcyujmo',
'sxcyujete' => 'ujete',
'sxcyujesx' => 'ujesx',
'sxcyujemo' => 'ujemo',
'sxcyujem' => 'ujem',
'sxcyuje' => 'uje',
'sxcyuj' => 'xcyuj',
'sxcyivavsxi' => 'ivavsxi',
'sxcyivati' => 'ivati',
'sxcyivat' => 'ivat',
'sxcyivasxe' => 'ivasxe',
'sxcyivaste' => 'ivaste',
'sxcyivasmo' => 'ivasmo',
'sxcyivao' => 'ivao',
'sxcyivano' => 'ivano',
'sxcyivani' => 'ivani',
'sxcyivane' => 'ivane',
'sxcyivana' => 'ivana',
'sxcyivan' => 'ivan',
'sxcyivalo' => 'ivalo',
'sxcyivali' => 'ivali',
'sxcyivale' => 'ivale',
'sxcyivala' => 'ivala',
'sxcyivahu' => 'ivahu',
'sxcyivah' => 'ivah',
'sxcyivacyu' => 'ivacyu',
'sxcyivacyete' => 'ivacyete',
'sxcyivacyesx' => 'ivacyesx',
'sxcyivacyemo' => 'ivacyemo',
'sxcyivacye' => 'ivacye',
'sxcyiva' => 'iva',
'sxcyima' => 'cyima',
'sxcyem' => 'cyem',
'sxcya' => 'cya',
'sxcxu' => 'cxu',
'sxcxomu' => 'cxomu',
'sxcxom' => 'cxom',
'sxcxoj' => 'cxoj',
'sxcxim' => 'im',
'sxcxih' => 'cxih',
'sxcxi' => 'cxi',
'sxcxemu' => 'cxemu',
'sxcxem' => 'cxem',
'sxcxega' => 'cxega',
'sxcxeg' => 'cxeg',
'sxcxa' => 'cxa',
'sxalyu' => 'xalyu',
'sxalyite' => 'xalyite',
'sxalyimo' => 'xalyimo',
'sxalyi' => 'xalyi',
'sxalyete' => 'xalyete',
'sxalyesx' => 'xalyesx',
'sxalyemo' => 'xalyemo',
'sxalyem' => 'xalyem',
'sxalye' => 'xalye',
'sxaka' => 'aka',
'sxak' => 'ak',
'sxadima' => 'adima',
'sxadi' => 'adi',
'sxad' => 'ad',
'sxacya' => 'acya',
'svecyenyu' => 'u',
'svecyenyima' => 'ima',
'svecyenyem' => 'em',
'svecyenye' => '',
'svecyenya' => 'a',
'suvsxi' => 'uvsxi',
'suti' => 'uti',
'sute' => 'ute',
'sut' => 'ut',
'susxte' => 'usxte',
'susxmo' => 'usxmo',
'susxivsxi' => 'usxivsxi',
'susxiti' => 'iti',
'susxite' => 'usxite',
'susxit' => 'it',
'susxisxe' => 'usxisxe',
'susxisx' => 'usxisx',
'susxiste' => 'usxiste',
'susxismo' => 'usxismo',
'susxio' => 'io',
'susximo' => 'usximo',
'susxim' => 'usxim',
'susxilo' => 'ilo',
'susxili' => 'ili',
'susxile' => 'ile',
'susxila' => 'ila',
'susxih' => 'usxih',
'susxicyu' => 'icyu',
'susxicyete' => 'icyete',
'susxicyesx' => 'icyesx',
'susxicyemo' => 'icyemo',
'susxicye' => 'icye',
'susxi' => 'usxi',
'susxeno' => 'eno',
'susxeni' => 'eni',
'susxene' => 'ene',
'susxena' => 'ena',
'susxen' => 'en',
'susxe' => 'usxe',
'susx' => 'usx',
'suste' => 'uste',
'susmo' => 'usmo',
'suo' => 'uo',
'sumo' => 'umo',
'sulo' => 'ulo',
'suli' => 'uli',
'sule' => 'ule',
'sula' => 'ula',
'sujucyi' => 'ujucyi',
'suju' => 'uju',
'sujte' => 'ujte',
'sujmo' => 'ujmo',
'sujete' => 'ujete',
'sujesx' => 'ujesx',
'sujemo' => 'ujemo',
'sujem' => 'ujem',
'suje' => 'uje',
'suj' => 'uj',
'suh' => 'uh',
'sucyu' => 'ucyu',
'sucyete' => 'ucyete',
'sucyesx' => 'ucyesx',
'sucyemo' => 'ucyemo',
'sucye' => 'ucye',
'stovima' => 'ovima',
'stovi' => 'ovi',
'stove' => 'ove',
'stova' => 'ova',
'stou' => 'stou',
'stoima' => 'stoima',
'stoi' => 'stoi',
'stoe' => 'stoe',
'stoama' => 'stoama',
'stoa' => 'stoa',
'stiu' => 'stiu',
'stiomu' => 'stiomu',
'stiom' => 'stiom',
'stioj' => 'stioj',
'stigosxe' => 'tigosxe',
'stigoste' => 'tigoste',
'stigosmo' => 'tigosmo',
'stigoh' => 'tigoh',
'stigo' => 'tigo',
'stignuvsxi' => 'tignuvsxi',
'stignuto' => 'tignuto',
'stignuti' => 'tignuti',
'stignute' => 'tignute',
'stignuta' => 'tignuta',
'stignut' => 'tignut',
'stignusxe' => 'tignusxe',
'stignusx' => 'tignusx',
'stignuste' => 'tignuste',
'stignusmo' => 'tignusmo',
'stignuo' => 'tignuo',
'stignumo' => 'tignumo',
'stignulo' => 'tignulo',
'stignuli' => 'tignuli',
'stignule' => 'tignule',
'stignula' => 'tignula',
'stignuh' => 'tignuh',
'stignucyu' => 'tignucyu',
'stignucyete' => 'tignucyete',
'stignucyesx' => 'tignucyesx',
'stignucyemo' => 'tignucyemo',
'stignucye' => 'tignucye',
'stignu' => 'tignu',
'stignte' => 'tignte',
'stignmo' => 'tignmo',
'stignite' => 'tignite',
'stignimo' => 'tignimo',
'stigni' => 'tigni',
'stignete' => 'tignete',
'stignesx' => 'tignesx',
'stignemo' => 'tignemo',
'stignem' => 'tignem',
'stigne' => 'tigne',
'stign' => 'tign',
'stiglo' => 'tiglo',
'stigli' => 'tigli',
'stigle' => 'tigle',
'stigla' => 'tigla',
'stigavsxi' => 'tigavsxi',
'stigao' => 'tigao',
'stiemu' => 'stiemu',
'stiem' => 'stiem',
'stiega' => 'stiega',
'stieg' => 'stieg',
'stie' => '',
'sticyi' => 'ticyi',
'sticy' => 'ticy',
'stia' => 'stia',
'stasxcyu' => 'stasxcyu',
'stasxcyite' => 'stasxcyite',
'stasxcyimo' => 'stasxcyimo',
'stasxcyi' => 'stasxcyi',
'stasxcyete' => 'stasxcyete',
'stasxcyesx' => 'stasxcyesx',
'stasxcyemo' => 'stasxcyemo',
'stasxcyem' => 'stasxcyem',
'stasxcye' => 'stasxcye',
'spu' => 'pu',
'spte' => 'pte',
'spmo' => 'pmo',
'spete' => 'pete',
'spesx' => 'pesx',
'spemo' => 'pemo',
'spem' => 'pem',
'spe' => 'pe',
'sp' => 'p',
'sovavsxi' => 'ovavsxi',
'sovati' => 'ovati',
'sovat' => 'ovat',
'sovasxe' => 'ovasxe',
'sovaste' => 'ovaste',
'sovasmo' => 'ovasmo',
'sovao' => 'ovao',
'sovano' => 'ovano',
'sovani' => 'ovani',
'sovane' => 'ovane',
'sovana' => 'ovana',
'sovan' => 'ovan',
'sovalo' => 'ovalo',
'sovali' => 'ovali',
'sovale' => 'ovale',
'sovala' => 'ovala',
'sovahu' => 'ovahu',
'sovah' => 'ovah',
'sovacyu' => 'ovacyu',
'sovacyete' => 'ovacyete',
'sovacyesx' => 'ovacyesx',
'sovacyemo' => 'ovacyemo',
'sovacye' => 'ovacye',
'somu' => 'omu',
'soj' => 'oj',
'soga' => 'oga',
'sog' => 'og',
'snu' => 'u',
'snomu' => 'omu',
'snom' => 'om',
'snoj' => 'oj',
'snoga' => 'oga',
'snog' => 'og',
'sno' => 'o',
'snim' => 'im',
'snih' => 'ih',
'sni' => 'i',
'sne' => 'e',
'sna' => 'a',
'smima' => 'mima',
'smi' => 'mi',
'sme' => 'me',
'smama' => 'mama',
'slobodilacxku' => 'u',
'slobodilacxkomu' => 'omu',
'slobodilacxkom' => 'om',
'slobodilacxkoj' => 'oj',
'slobodilacxkoga' => 'oga',
'slobodilacxkog' => 'og',
'slobodilacxko' => 'o',
'slobodilacxkim' => 'im',
'slobodilacxkih' => 'ih',
'slobodilacxki' => '',
'slobodilacxke' => 'e',
'slobodilacxka' => 'a',
'skriptum' => 'skriptum',
'skiju' => 'u',
'skijomu' => 'ijomu',
'skijom' => 'om',
'skijoj' => 'ijoj',
'skijim' => 'ijim',
'skijih' => 'ijih',
'skiji' => 'i',
'skijemu' => 'ijemu',
'skijem' => 'ijem',
'skijega' => 'ijega',
'skijeg' => 'ijeg',
'skije' => 'e',
'skija' => 'a',
'skanye' => 'kanye',
'skajucyi' => 'jucyi',
'sjetlyivu' => 'u',
'sjetlyivomu' => 'omu',
'sjetlyivom' => 'om',
'sjetlyivoj' => 'oj',
'sjetlyivoga' => 'oga',
'sjetlyivog' => 'og',
'sjetlyivo' => 'o',
'sjetlyivim' => 'im',
'sjetlyivih' => 'ih',
'sjetlyivi' => 'i',
'sjetlyive' => 'e',
'sjetlyiva' => 'a',
'sjetlyiv' => '',
'siu' => 'siu',
'sitru' => 'ru',
'sitrom' => 'rom',
'sitrima' => 'rima',
'sitri' => 'ri',
'sitre' => 're',
'sitra' => 'ra',
'sitara' => 'ara',
'sitar' => 'ar',
'siom' => '',
'silou' => 'silou',
'silom' => 'om',
'siloima' => 'siloima',
'siloi' => 'siloi',
'siloe' => 'siloe',
'siloa' => 'siloa',
'siju' => 'u',
'sijom' => 'om',
'sijima' => 'jima',
'siji' => 'i',
'sije' => 'e',
'sija' => 'a',
'sie' => 'sie',
'sia' => 'sia',
'setu' => 'u',
'setom' => 'om',
'setima' => 'ima',
'seti' => 'i',
'seta' => 'a',
'set' => '',
'sesxe' => 'esxe',
'seste' => 'este',
'sesmo' => 'esmo',
'senya' => 'a',
'sekute' => 'ekute',
'sekusx' => 'ekusx',
'sekumo' => 'ekumo',
'seku' => 'eku',
'sekte' => 'ekte',
'sekom' => 'kom',
'seko' => 'ko',
'sekmo' => 'ekmo',
'seklo' => 'eklo',
'sekli' => 'ekli',
'sekle' => 'ekle',
'sekla' => 'ekla',
'seke' => 'ke',
'sekao' => 'ekao',
'sekama' => 'kama',
'seka' => 'ka',
'sek' => 'ek',
'seih' => 'eih',
'segosxe' => 'egosxe',
'segoste' => 'egoste',
'segosmo' => 'egosmo',
'segoh' => 'egoh',
'sego' => 'ego',
'segavsxi' => 'egavsxi',
'secyu' => 'ecyu',
'secyete' => 'ecyete',
'secyesx' => 'ecyesx',
'secyemo' => 'ecyemo',
'secye' => 'ecye',
'secy' => 'ecy',
'secxem' => 'ecxem',
'secxe' => 'cxe',
'secima' => 'cima',
'seci' => 'ci',
'sdiksijski' => 'sdiksijski',
'sdikcija' => 'sdikcija',
'sbiro' => 'sbiro',
'satomu' => 'omu',
'satoj' => 'oj',
'satoga' => 'oga',
'satog' => 'og',
'sato' => 'o',
'satima' => 'ima',
'satim' => 'im',
'satih' => 'ih',
'sanye' => 'anye',
'sakacyenyu' => 'u',
'sakacyenyima' => 'ima',
'sakacyenyem' => 'em',
'sakacyenye' => 'cyenye',
'sakacyenya' => 'a',
'sajucyi' => 'ajucyi',
'rvsxi' => 'vsxi',
'rvski' => 'i',
'rvlye' => 'lye',
'rvlyanka' => 'rvlyanka',
'rvka' => 'ka',
'rvce' => 'ce',
'rva' => 'va',
'rute' => 'ute',
'ruoznost' => 'ruoznost',
'rumo' => 'umo',
'rumentovati' => 'rumentovati',
'rumentirati' => 'rumentirati',
'rumentar' => 'rumentar',
'rumentalnost' => 'rumentalnost',
'rumentalni' => 'rumentalni',
'rumentalista' => 'rumentalista',
'rumentalist' => 'rumentalist',
'rumentacija' => 'rumentacija',
'rumenat' => 'rumenat',
'rum' => '',
'ruliti' => 'iti',
'ruktura' => 'a',
'ruktorski' => 'ruktorski',
'ruktorka' => 'ruktorka',
'ruktorica' => 'ruktorica',
'ruktivnost' => 't',
'ruktivno' => 'ruktivno',
'ruktivizam' => 'ruktivizam',
'rukcioni' => 'rukcioni',
'rukcijski' => 'rukcijski',
'rujucyi' => 'ujucyi',
'ruju' => 'uju',
'rujte' => 'ujte',
'rujmo' => 'ujmo',
'rujete' => 'ujete',
'rujesx' => 'ujesx',
'rujemo' => 'ujemo',
'rujem' => 'ujem',
'ruje' => 'uje',
'rujati' => 'ti',
'ruja' => '',
'ruj' => 'uj',
'rugivati' => 'rugivati',
'rugasx' => '',
'rugar' => '',
'rug' => 'g',
'ruentni' => 'ruentni',
'rucxnost' => 't',
'rucxenye' => 'e',
'rucxavanye' => 'nye',
'ruckati' => 'ti',
'rublyivati' => 'ivati',
'rubiti' => 'iti',
'rualni' => 'rualni',
'ruacija' => 'ruacija',
'rtost' => 't',
'rtmo' => 'tmo',
'rtlyati' => 'ti',
'rtjevsxi' => 'tjevsxi',
'rtjeti' => 'tjeti',
'rtjet' => 'tjet',
'rtjesxe' => 'tjesxe',
'rtjeste' => 'tjeste',
'rtjesmo' => 'tjesmo',
'rtjelo' => 'tjelo',
'rtjeli' => 'tjeli',
'rtjele' => 'tjele',
'rtjela' => 'tjela',
'rtjeh' => 'tjeh',
'rtjecyu' => 'tjecyu',
'rtjecyete' => 'tjecyete',
'rtjecyesx' => 'tjecyesx',
'rtjecyemo' => 'tjecyemo',
'rtjecye' => 'tjecye',
'rtje' => 'tje',
'rtite' => 'tite',
'rtisx' => 'tisx',
'rtio' => 'tio',
'rtimo' => 'timo',
'rtim' => 'tim',
'rtevsxi' => 'tevsxi',
'rteti' => 'teti',
'rtet' => 'tet',
'rtesxe' => 'tesxe',
'rteste' => 'teste',
'rtesmo' => 'tesmo',
'rteo' => 'teo',
'rtelo' => 'telo',
'rteli' => 'teli',
'rtele' => 'tele',
'rtela' => 'tela',
'rteh' => 'teh',
'rtecyu' => 'tecyu',
'rtecyete' => 'tecyete',
'rtecyesx' => 'tecyesx',
'rtecyemo' => 'tecyemo',
'rtecye' => 'tecye',
'rstu' => 'u',
'rstom' => 'om',
'rsto' => 'to',
'rsti' => 'ti',
'rstama' => 'tama',
'rsta' => 'a',
'rsata' => 'ata',
'rpjeti' => 'jeti',
'rpeti' => 'eti',
'rozxnost' => 'rozxnost',
'rovima' => 'ovima',
'rovi' => 'ovi',
'roverzija' => 'a',
'rove' => 'ove',
'rovavsxi' => 'ovavsxi',
'rovavati' => 'rovavati',
'rovat' => 'ovat',
'rovasxe' => 'ovasxe',
'rovaste' => 'ovaste',
'rovasmo' => 'ovasmo',
'rovao' => 'ovao',
'rovano' => 'ovano',
'rovani' => 'ovani',
'rovane' => 'ovane',
'rovana' => 'ovana',
'rovan' => 'ovan',
'rovalo' => 'ovalo',
'rovali' => 'ovali',
'rovale' => 'ovale',
'rovala' => 'ovala',
'rovahu' => 'ovahu',
'rovah' => 'ovah',
'rovacyu' => 'ovacyu',
'rovacyete' => 'ovacyete',
'rovacyesx' => 'ovacyesx',
'rovacyemo' => 'ovacyemo',
'rovacye' => 'ovacye',
'roumlye' => 'lye',
'rou' => 'ou',
'rot' => '',
'rorista' => 'orista',
'rook' => 'ok',
'ronautski' => 'ronautski',
'ronautika' => 'ka',
'ronauticxki' => 'i',
'ronaut' => '',
'rolosxki' => 'i',
'rologija' => 'a',
'rolog' => 'g',
'rojte' => 'te',
'rojmo' => 'mo',
'rojivsxi' => 'ivsxi',
'rojite' => 'ite',
'rojit' => 'it',
'rojisxe' => 'isxe',
'rojisx' => 'isx',
'rojiste' => 'iste',
'rojismo' => 'ismo',
'rojio' => 'io',
'rojimo' => 'imo',
'rojim' => 'im',
'rojilo' => 'ilo',
'rojili' => 'ili',
'rojile' => 'ile',
'rojila' => 'ila',
'rojih' => 'ih',
'rojicyu' => 'icyu',
'rojicyete' => 'icyete',
'rojicyesx' => 'icyesx',
'rojicyemo' => 'icyemo',
'rojicye' => 'icye',
'roji' => 'i',
'rojenost' => 'rojenost',
'rojeno' => 'eno',
'rojeni' => 'eni',
'rojene' => 'ene',
'rojena' => 'ena',
'rojen' => 'en',
'roje' => 'e',
'rojba' => 'ba',
'rojavanye' => 'nye',
'rojarski' => 'i',
'rointestinalni' => 'rointestinalni',
'roima' => 'ima',
'roi' => 'oi',
'rogot' => 'rogot',
'rofizika' => 'rofizika',
'rofizicxki' => 'rofizicxki',
'rofizicxar' => 'rofizicxar',
'rofirati' => 'rofirati',
'rofija' => 'a',
'rofa' => 'a',
'rof' => '',
'roe' => 'oe',
'roama' => 'oama',
'roa' => 'oa',
'rnyu' => 'u',
'rnyom' => 'om',
'rnyima' => 'nyima',
'rnyi' => 'i',
'rnye' => 'e',
'rnya' => 'a',
'rmka' => 'rmka',
'rma' => 'ma',
'rlyanin' => 'rlyanin',
'rknuti' => 'uti',
'rivsxi' => 'ivsxi',
'rivavsxi' => 'ivavsxi',
'rivat' => 'ivat',
'rivasxe' => 'ivasxe',
'rivaste' => 'ivaste',
'rivasmo' => 'ivasmo',
'rivao' => 'ivao',
'rivano' => 'ivano',
'rivani' => 'ivani',
'rivane' => 'ivane',
'rivana' => 'ivana',
'rivan' => 'ivan',
'rivalo' => 'ivalo',
'rivali' => 'ivali',
'rivale' => 'ivale',
'rivala' => 'ivala',
'rivahu' => 'ivahu',
'rivah' => 'ivah',
'rivacyu' => 'ivacyu',
'rivacyete' => 'ivacyete',
'rivacyesx' => 'ivacyesx',
'rivacyemo' => 'ivacyemo',
'rivacye' => 'ivacye',
'riva' => 'iva',
'ritis' => '',
'risxe' => 'isxe',
'riste' => 'iste',
'rismo' => 'ismo',
'rionski' => 'i',
'riktni' => 'riktni',
'rikt' => 'rikt',
'rikcija' => 'a',
'rika' => 'ka',
'rijom' => 'om',
'rijima' => 'jima',
'riji' => 'i',
'rijezniti' => 'niti',
'rije' => 'e',
'rijanka' => 'rijanka',
'rijalizovati' => 'ovati',
'rijalizirati' => 'ti',
'rijalizacija' => 'a',
'riga' => 'ga',
'rifikacija' => 'a',
'ricxki' => 'i',
'ricificirati' => 'ricificirati',
'rica' => 'a',
'ribuisati' => 'ribuisati',
'ribuirati' => 'ribuirati',
'ribuirani' => 'ribuirani',
'ribucioni' => 'ribucioni',
'ribucija' => 'a',
'riblovavsxi' => 'ovavsxi',
'riblovati' => 'ovati',
'riblovat' => 'ovat',
'riblovasxe' => 'ovasxe',
'riblovaste' => 'ovaste',
'riblovasmo' => 'ovasmo',
'riblovao' => 'ovao',
'riblovanye' => 'riblovanye',
'riblovano' => 'ovano',
'riblovani' => 'ovani',
'riblovane' => 'ovane',
'riblovana' => 'ovana',
'riblovan' => 'ovan',
'riblovalo' => 'ovalo',
'riblovali' => 'ovali',
'riblovale' => 'ovale',
'riblovala' => 'ovala',
'riblovahu' => 'ovahu',
'riblovah' => 'ovah',
'riblovacyu' => 'ovacyu',
'riblovacyete' => 'ovacyete',
'riblovacyesx' => 'ovacyesx',
'riblovacyemo' => 'ovacyemo',
'riblovacye' => 'ovacye',
'riblova' => 'ova',
'rgnvsxi' => 'rgnvsxi',
'rgnucyima' => 'ucyima',
'rgnucyem' => 'ucyem',
'rgnucya' => 'ucya',
'rgnsxe' => 'rgnsxe',
'rgnste' => 'rgnste',
'rgnsmo' => 'rgnsmo',
'rgno' => 'rgno',
'rgnlo' => 'rgnlo',
'rgnli' => 'rgnli',
'rgnle' => 'rgnle',
'rgnla' => 'rgnla',
'rgnh' => 'rgnh',
'rgncyu' => 'rgncyu',
'rgncyete' => 'rgncyete',
'rgncyesx' => 'rgncyesx',
'rgncyemo' => 'rgncyemo',
'rgncye' => 'rgncye',
'rganost' => 'rganost',
'rganizmu' => 'mu',
'rganizmom' => 'mom',
'rganizmima' => 'mima',
'rganizmi' => 'mi',
'rganizme' => 'me',
'rganizma' => 'ma',
'rganizama' => 'ama',
'rganizam' => '',
'rezxajivati' => 'rezxajivati',
'rezniti' => 'niti',
'rezgosxe' => 'zgosxe',
'rezgoste' => 'zgoste',
'rezgosmo' => 'zgosmo',
'rezgoh' => 'zgoh',
'rezgo' => 'zgo',
'rezgavsxi' => 'zgavsxi',
'revsxi' => 'evsxi',
'rete' => 'ete',
'resxte' => 'te',
'resxmo' => 'mo',
'resxje' => 'resxje',
'resxite' => 'xite',
'resxit' => 'it',
'resxisx' => 'isx',
'resxio' => 'io',
'resximo' => 'ximo',
'resxim' => 'im',
'resxilo' => 'ilo',
'resxili' => 'ili',
'resxile' => 'ile',
'resxila' => 'ila',
'resxicyu' => 'icyu',
'resxicyete' => 'icyete',
'resxicyesx' => 'icyesx',
'resxicyemo' => 'icyemo',
'resxicye' => 'icye',
'resxica' => 'resxica',
'resxi' => 'xi',
'resxenost' => 'resxenost',
'resxeno' => 'eno',
'resxeni' => 'eni',
'resxene' => 'ene',
'resxena' => 'ena',
'resxen' => 'en',
'resxcyu' => 'sxcyu',
'resxcyete' => 'sxcyete',
'resxcyesx' => 'sxcyesx',
'resxcyemo' => 'sxcyemo',
'resxcye' => 'sxcye',
'resxasxe' => 'xasxe',
'resxaste' => 'xaste',
'resxasmo' => 'xasmo',
'resxahu' => 'xahu',
'resxah' => 'xah',
'resx' => 'esx',
'restant' => 'restant',
'rest' => 'st',
'ressxe' => 'ssxe',
'reslo' => 'slo',
'resli' => 'sli',
'resle' => 'sle',
'resla' => 'sla',
'resit' => 'esit',
'resih' => 'sih',
'resao' => 'ao',
'res' => '',
'reptati' => 'tati',
'repski' => 'repski',
'repjeti' => 'jeti',
'repeti' => 'ti',
'renyima' => 'ima',
'renyem' => 'em',
'renya' => 'a',
'renuvsxi' => 'uvsxi',
'renuto' => 'uto',
'renuti' => 'uti',
'renute' => 'ute',
'renuta' => 'uta',
'renut' => 'ut',
'renusxe' => 'usxe',
'renuste' => 'uste',
'renusmo' => 'usmo',
'renuo' => 'uo',
'renulo' => 'ulo',
'renuli' => 'uli',
'renule' => 'ule',
'renula' => 'ula',
'renuh' => 'uh',
'renucyu' => 'ucyu',
'renucyete' => 'ucyete',
'renucyesx' => 'ucyesx',
'renucyemo' => 'ucyemo',
'renucye' => 'ucye',
'renomu' => 'omu',
'renom' => 'om',
'renoj' => 'oj',
'renoga' => 'oga',
'renog' => 'og',
'renite' => 'ite',
'renirati' => 'ti',
'renimo' => 'imo',
'renim' => 'im',
'renije' => '',
'renih' => 'ih',
'renete' => 'ete',
'renesx' => 'esx',
'renemo' => 'emo',
'renem' => 'em',
'removima' => 'ovima',
'removi' => 'ovi',
'remove' => 'ove',
'remova' => 'ova',
'remom' => 'om',
'remo' => 'emo',
'remizam' => 'remizam',
'remiti' => 'iti',
'remitet' => 'remitet',
'remisticxki' => 'remisticxki',
'remista' => 'remista',
'remist' => 'remist',
'remi' => 'i',
'reme' => 'e',
'remavsxi' => 'vsxi',
'remati' => 'ti',
'remate' => 'te',
'remat' => 't',
'remasxe' => 'sxe',
'remasx' => 'sx',
'remaste' => 'ste',
'remasmo' => 'smo',
'remao' => 'o',
'remanyu' => 'anyu',
'remanyima' => 'anyima',
'remanyem' => 'anyem',
'remanye' => 'anye',
'remanya' => 'anya',
'remano' => 'no',
'remani' => 'ni',
'remane' => 'ne',
'remana' => 'na',
'reman' => 'n',
'remamo' => 'mo',
'remama' => 'ama',
'remam' => 'm',
'remalu' => 'remalu',
'remalom' => 'remalom',
'remalo' => 'lo',
'remalima' => 'remalima',
'remali' => 'li',
'remale' => 'le',
'remala' => 'la',
'remaju' => 'ju',
'remajte' => 'jte',
'remajmo' => 'jmo',
'remaj' => 'j',
'remahu' => 'ahu',
'remah' => 'h',
'remacyu' => 'cyu',
'remacyete' => 'cyete',
'remacyesx' => 'cyesx',
'remacyemo' => 'cyemo',
'remacye' => 'cye',
'rema' => 'a',
'reknuti' => 'uti',
'rekacx' => 'rekacx',
'rek' => 'k',
'reih' => 'ih',
'reh' => 'eh',
'regosxe' => 'gosxe',
'regoste' => 'goste',
'regosmo' => 'gosmo',
'regoh' => 'goh',
'rego' => 'go',
'regnuvsxi' => 'uvsxi',
'regnuto' => 'uto',
'regnuti' => 'uti',
'regnute' => 'ute',
'regnuta' => 'uta',
'regnut' => 'ut',
'regnusxe' => 'usxe',
'regnusx' => 'gnusx',
'regnuste' => 'uste',
'regnusmo' => 'usmo',
'regnuo' => 'uo',
'regnumo' => 'gnumo',
'regnulo' => 'ulo',
'regnuli' => 'uli',
'regnule' => 'ule',
'regnula' => 'ula',
'regnuh' => 'uh',
'regnucyu' => 'ucyu',
'regnucyete' => 'ucyete',
'regnucyesx' => 'ucyesx',
'regnucyemo' => 'ucyemo',
'regnucye' => 'ucye',
'regnu' => 'u',
'regnte' => 'gnte',
'regnmo' => 'gnmo',
'regnite' => 'ite',
'regnimo' => 'imo',
'regni' => 'i',
'regnete' => 'ete',
'regnesx' => 'esx',
'regnemo' => 'emo',
'regnem' => 'em',
'regne' => 'e',
'regn' => 'gn',
'reglo' => 'glo',
'regli' => 'gli',
'regle' => 'gle',
'regla' => 'gla',
'regavsxi' => 'gavsxi',
'regao' => 'gao',
'redyivavsxi' => 'ivavsxi',
'redyivati' => 'ivati',
'redyivat' => 'ivat',
'redyivasxe' => 'ivasxe',
'redyivaste' => 'ivaste',
'redyivasmo' => 'ivasmo',
'redyivao' => 'ivao',
'redyivano' => 'ivano',
'redyivani' => 'ivani',
'redyivane' => 'ivane',
'redyivana' => 'ivana',
'redyivan' => 'ivan',
'redyivalo' => 'ivalo',
'redyivali' => 'ivali',
'redyivale' => 'ivale',
'redyivala' => 'ivala',
'redyivahu' => 'ivahu',
'redyivah' => 'ivah',
'redyivacyu' => 'ivacyu',
'redyivacyete' => 'ivacyete',
'redyivacyesx' => 'ivacyesx',
'redyivacyemo' => 'ivacyemo',
'redyivacye' => 'ivacye',
'redyiva' => 'iva',
'redem' => 'dem',
'rede' => 'e',
'recy' => 'cy',
'rebov' => 'rebov',
'reblyivacxki' => 'reblyivacxki',
'reblyivacx' => 'reblyivacx',
'reblyiv' => '',
'reblyenye' => 'e',
'reblyavati' => 'avati',
'rebast' => 'rebast',
'reb' => '',
'rdyeno' => 'yeno',
'rdyeni' => 'yeni',
'rdyene' => 'yene',
'rdyena' => 'yena',
'rdyen' => 'yen',
'rcyeno' => 'cyeno',
'rcyeni' => 'cyeni',
'rcyene' => 'cyene',
'rcyena' => 'cyena',
'rcyen' => 'cyen',
'rcati' => 'ti',
'razxni' => 'i',
'razxivati' => 'ivati',
'razxivanye' => 'e',
'razxivalac' => 'razxivalac',
'razxivacx' => '',
'razxitely' => '',
'razxar' => '',
'razxa' => 'a',
'ravati' => 'ti',
'ravagantnost' => 'ravagantnost',
'ravagancija' => 'ravagancija',
'ratu' => 'u',
'ratorka' => 'ratorka',
'ratom' => 'om',
'rato' => 'o',
'rativsxi' => 'tivsxi',
'rativni' => 'i',
'ratisxe' => 'tisxe',
'ratiste' => 'tiste',
'ratismo' => 'tismo',
'ratih' => 'tih',
'ratama' => 'ama',
'rata' => 'a',
'rasxujucyi' => 'rasxujucyi',
'rasxtiti' => 'rasxtiti',
'rasxtite' => 'rasxtite',
'rasxtit' => 'rasxtit',
'rasxtisx' => 'rasxtisx',
'rasxtio' => 'rasxtio',
'rasxtimo' => 'rasxtimo',
'rasxtim' => 'rasxtim',
'rasxtilo' => 'rasxtilo',
'rasxtili' => 'rasxtili',
'rasxtile' => 'rasxtile',
'rasxtila' => 'rasxtila',
'rasxticyu' => 'rasxticyu',
'rasxticyete' => 'rasxticyete',
'rasxticyesx' => 'rasxticyesx',
'rasxticyemo' => 'rasxticyemo',
'rasxticye' => 'rasxticye',
'rasxti' => 'rasxti',
'rasxt' => 'rasxt',
'rasxni' => 'rasxni',
'rasxivost' => 'rasxivost',
'rasxivati' => 'ivati',
'rasxivanye' => 'rasxivanye',
'rasxiv' => 'rasxiv',
'rasxenye' => '',
'rasxenost' => 'rasxenost',
'rasxcyenye' => 'e',
'rasxcyeno' => 'rasxcyeno',
'rasxcyeni' => 'rasxcyeni',
'rasxcyene' => 'rasxcyene',
'rasxcyena' => 'rasxcyena',
'rasxcyen' => 'rasxcyen',
'rasxcyasxe' => 'rasxcyasxe',
'rasxcyaste' => 'rasxcyaste',
'rasxcyasmo' => 'rasxcyasmo',
'rasxcyahu' => 'rasxcyahu',
'rasxcyah' => 'rasxcyah',
'rasxavati' => 'ti',
'rastenyu' => 'stenyu',
'rasnik' => 'rasnik',
'rasicyom' => 'rasicyom',
'rasicyima' => 'rasicyima',
'rasicyi' => 'rasicyi',
'rasicya' => 'rasicya',
'rasicy' => 'rasicy',
'rasetu' => 'rasetu',
'rasetom' => 'rasetom',
'raseta' => 'raseta',
'rasadima' => 'rasadima',
'rasadi' => 'i',
'rasad' => '',
'ranyivanye' => 'ranyivanye',
'ranyenye' => 'e',
'ranyeno' => 'yeno',
'ranyeni' => 'yeni',
'ranyene' => 'yene',
'ranyena' => 'yena',
'ranyen' => 'yen',
'ranu' => 'u',
'rantkinya' => 'a',
'rante' => 'te',
'ransxirati' => 'ti',
'ranom' => 'om',
'ranmo' => 'mo',
'ranivsxi' => 'ivsxi',
'ranite' => 'ite',
'ranit' => 'it',
'ranisxe' => 'isxe',
'ranisx' => 'isx',
'raniste' => 'iste',
'ranismo' => 'ismo',
'ranio' => 'io',
'ranin' => '',
'ranimo' => 'imo',
'ranim' => 'im',
'ranilo' => 'ilo',
'ranili' => 'ili',
'ranile' => 'ile',
'ranila' => 'ila',
'ranih' => 'ih',
'ranicyu' => 'icyu',
'ranicyete' => 'icyete',
'ranicyesx' => 'icyesx',
'ranicyemo' => 'icyemo',
'ranicye' => 'icye',
'ranama' => 'ama',
'ralski' => 'i',
'ralni' => 'i',
'ralka' => 'ka',
'ralijski' => 'ralijski',
'ralijanski' => 'ralijanski',
'ralijanka' => 'ralijanka',
'ralija' => 'a',
'raktnost' => 'raktnost',
'raktno' => 'o',
'raktan' => 'tan',
'rakizam' => 'rakizam',
'rajavsxi' => 'vsxi',
'rajat' => 't',
'rajasxe' => 'sxe',
'rajaste' => 'ste',
'rajasmo' => 'smo',
'rajao' => 'o',
'rajanye' => 'e',
'rajano' => 'no',
'rajani' => 'ni',
'rajane' => 'ne',
'rajana' => 'na',
'rajan' => 'n',
'rajalo' => 'lo',
'rajali' => 'li',
'rajale' => 'le',
'rajala' => 'la',
'rajah' => 'h',
'rajacyu' => 'cyu',
'rajacyete' => 'cyete',
'rajacyesx' => 'cyesx',
'rajacyemo' => 'cyemo',
'rajacye' => 'cye',
'raja' => 'aja',
'rahovima' => 'hovima',
'rahovi' => 'hovi',
'rahove' => 'hove',
'rahova' => 'ova',
'rahom' => 'hom',
'raha' => 'ha',
'ragusxa' => 'ragusxa',
'radirati' => 'ti',
'radicija' => 'a',
'radati' => 'ti',
'racyiti' => 'iti',
'racyasxe' => 'sxe',
'racyaste' => 'ste',
'racyasmo' => 'smo',
'racyahu' => 'hu',
'racyah' => 'h',
'racizam' => 'racizam',
'pzbu' => 'pzbu',
'pzbite' => 'pzbite',
'pzbimo' => 'pzbimo',
'pzbi' => 'pzbi',
'pzbete' => 'pzbete',
'pzbesx' => 'pzbesx',
'pzbenye' => 'pzbenye',
'pzbeno' => 'pzbeno',
'pzbeni' => 'pzbeni',
'pzbene' => 'pzbene',
'pzbena' => 'pzbena',
'pzben' => 'pzben',
'pzbemo' => 'pzbemo',
'pzbem' => 'pzbem',
'pzbe' => 'pzbe',
'ptu' => 'u',
'ptom' => 'om',
'ptima' => 'ima',
'pti' => 'ti',
'pta' => 'ta',
'psxe' => 'xe',
'psvsxi' => 'svsxi',
'pso' => 'so',
'psih' => 'ih',
'psh' => 'psh',
'predjelyenyu' => 'u',
'predjelyenyima' => 'ima',
'predjelyenyem' => 'em',
'predjelyenye' => '',
'predjelyenya' => 'a',
'predelyenyu' => 'u',
'predelyenyima' => 'ima',
'predelyenyem' => 'em',
'predelyenye' => '',
'predelyenya' => 'a',
'pozicija' => 'a',
'povima' => 'ovima',
'povi' => 'ovi',
'pove' => 'ove',
'pova' => 'ova',
'ponovati' => 'ovati',
'ponirati' => 'ti',
'plyasxe' => 'lyasxe',
'plyaste' => 'lyaste',
'plyasmo' => 'lyasmo',
'plyahu' => 'lyahu',
'plyah' => 'lyah',
'plu' => 'lu',
'plomu' => 'u',
'plom' => 'lom',
'ploj' => 'ploj',
'ploga' => 'ploga',
'plog' => 'plog',
'plodyivanyu' => 'u',
'plodyivanyima' => 'ima',
'plodyivanyem' => 'em',
'plodyivanye' => 'e',
'plodyivanya' => 'a',
'plodyenyu' => 'u',
'plodyenyima' => 'ima',
'plodyenyem' => 'em',
'plodyenye' => 'e',
'plodyenya' => 'a',
'plodnyu' => 'nyu',
'plodnyom' => 'nyom',
'plodnyo' => 'nyo',
'plodnyi' => 'nyi',
'plodnye' => 'nye',
'plodnyama' => 'nyama',
'plodnya' => '',
'plodanya' => 'anya',
'plim' => 'lim',
'plih' => 'lih',
'pkomu' => 'komu',
'pkoj' => 'koj',
'pkoga' => 'koga',
'pkog' => 'kog',
'pkim' => 'kim',
'pkih' => 'kih',
'pki' => 'ki',
'pjevenye' => 'pjevenye',
'pjesima' => 'sima',
'pjesi' => 'si',
'pjehu' => 'hu',
'pjehom' => 'hom',
'pjehe' => 'he',
'pjeha' => 'ha',
'piti' => 'iti',
'pit' => 'it',
'pilo' => 'ilo',
'pili' => 'ili',
'pile' => 'ile',
'pila' => 'ila',
'picyu' => 'icyu',
'picyete' => 'icyete',
'picyesx' => 'icyesx',
'picyemo' => 'icyemo',
'picye' => 'icye',
'pesxte' => 'te',
'pesxmo' => 'sxmo',
'pesxivsxi' => 'sxivsxi',
'pesxiti' => 'sxiti',
'pesxite' => 'sxite',
'pesxit' => 'sxit',
'pesxisxe' => 'pesxisxe',
'pesxisx' => 'sxisx',
'pesxiste' => 'pesxiste',
'pesxismo' => 'pesxismo',
'pesxio' => 'sxio',
'pesximo' => 'sximo',
'pesxim' => 'sxim',
'pesxilo' => 'sxilo',
'pesxili' => 'sxili',
'pesxile' => 'sxile',
'pesxila' => 'sxila',
'pesxih' => 'pesxih',
'pesxicyu' => 'sxicyu',
'pesxicyete' => 'sxicyete',
'pesxicyesx' => 'sxicyesx',
'pesxicyemo' => 'sxicyemo',
'pesxicye' => 'sxicye',
'pesxi' => 'sxi',
'pesxeno' => 'sxeno',
'pesxeni' => 'sxeni',
'pesxene' => 'sxene',
'pesxena' => 'sxena',
'pesxen' => 'sxen',
'pesima' => 'sima',
'pesi' => 'si',
'pelu' => 'u',
'pelom' => 'om',
'pelima' => 'ima',
'peju' => 'u',
'pejte' => 'ejte',
'pejmo' => 'ejmo',
'pej' => 'ej',
'pehu' => 'hu',
'pehom' => 'hom',
'pehe' => 'he',
'peha' => 'ha',
'pecyima' => 'ecyima',
'pecyem' => 'cyem',
'pecya' => 'ecya',
'pcxomu' => 'cxomu',
'pcxoj' => 'cxoj',
'pcxo' => 'pcxo',
'pcxite' => 'ite',
'pcxisx' => 'isx',
'pcximo' => 'imo',
'pcxih' => 'cxih',
'pcxetu' => 'etu',
'pcxetom' => 'etom',
'pcxeta' => 'eta',
'pcxemu' => 'cxemu',
'pcxem' => 'cxem',
'pcxega' => 'cxega',
'pcxeg' => 'cxeg',
'pcxate' => 'te',
'pcxasx' => 'sx',
'pcxastu' => 'u',
'pcxastomu' => 'omu',
'pcxastom' => 'om',
'pcxastoj' => 'oj',
'pcxastoga' => 'oga',
'pcxastog' => 'og',
'pcxasto' => 'o',
'pcxastim' => 'im',
'pcxastih' => 'ih',
'pcxasti' => 'i',
'pcxasta' => 'a',
'pcxast' => '',
'pcxamo' => 'mo',
'pcxama' => 'pcxama',
'pcxam' => 'm',
'pcxaju' => 'ju',
'pcxajte' => 'jte',
'pcxajmo' => 'jmo',
'pcxaj' => 'j',
'pcxadima' => 'adima',
'pcxadi' => 'adi',
'pcxad' => 'ad',
'panyu' => 'anyu',
'panyima' => 'anyima',
'panyem' => 'anyem',
'panya' => 'anya',
'pacxu' => 'u',
'pacxima' => 'ima',
'pacxi' => 'i',
'pacxem' => 'em',
'pacxe' => 'e',
'pacxa' => 'a',
'pacx' => '',
'paca' => 'aca',
'pac' => 'ac',
'ozxte' => 'te',
'ozxmo' => 'mo',
'ozxivsxi' => 'ivsxi',
'ozxiti' => 'iti',
'ozxite' => 'ite',
'ozxit' => 'it',
'ozxisxe' => 'isxe',
'ozxisx' => 'isx',
'ozxiste' => 'iste',
'ozxismo' => 'ismo',
'ozxio' => 'io',
'ozximo' => 'imo',
'ozxim' => 'im',
'ozxilo' => 'ilo',
'ozxili' => 'ili',
'ozxile' => 'ile',
'ozxila' => 'ila',
'ozxih' => 'ih',
'ozxicyu' => 'icyu',
'ozxicyete' => 'icyete',
'ozxicyesx' => 'icyesx',
'ozxicyemo' => 'icyemo',
'ozxicye' => 'icye',
'ozxi' => 'i',
'ozxeno' => 'eno',
'ozxeni' => 'eni',
'ozxene' => 'ene',
'ozxena' => 'ena',
'ozxen' => 'en',
'ozxe' => 'zxe',
'ozx' => '',
'ozlyeda' => 'a',
'ozleda' => 'a',
'ozima' => 'zima',
'ovucyi' => 'ucyi',
'ovte' => 'te',
'ovmo' => 'mo',
'ovjevsxi' => 'ovjevsxi',
'ovjeti' => 'i',
'ovjet' => '',
'ovjesxe' => 'ovjesxe',
'ovjeste' => 'ovjeste',
'ovjesmo' => 'mo',
'ovjelo' => 'ovjelo',
'ovjeli' => 'ovjeli',
'ovjele' => 'ovjele',
'ovjela' => 'ovjela',
'ovjeh' => 'ovjeh',
'ovjecyu' => 'ovjecyu',
'ovjecyete' => 'ovjecyete',
'ovjecyesx' => 'ovjecyesx',
'ovjecyemo' => 'ovjecyemo',
'ovjecye' => 'ovjecye',
'ovje' => 'ovje',
'ovio' => 'io',
'ovevsxi' => 'vsxi',
'oveti' => 'ti',
'ovet' => 't',
'ovesxe' => 'ovesxe',
'oveste' => 'ste',
'ovesmo' => 'smo',
'oveo' => 'o',
'ovelo' => 'o',
'oveli' => 'i',
'ovele' => 'e',
'ovela' => 'a',
'oveh' => 'oveh',
'ovecyu' => 'cyu',
'ovecyete' => 'ovecyete',
'ovecyesx' => 'ovecyesx',
'ovecyemo' => 'ovecyemo',
'ovecye' => 'ovecye',
'ovasxu' => 'ovasxu',
'ovasxte' => 'ovasxte',
'ovasxom' => 'ovasxom',
'ovasxmo' => 'ovasxmo',
'ovasxiti' => 'ovasxiti',
'ovasxite' => 'ovasxite',
'ovasxit' => 'ovasxit',
'ovasxisx' => 'ovasxisx',
'ovasxio' => 'ovasxio',
'ovasximo' => 'ovasximo',
'ovasxima' => 'ovasxima',
'ovasxim' => 'ovasxim',
'ovasxilo' => 'ovasxilo',
'ovasxili' => 'ovasxili',
'ovasxile' => 'ovasxile',
'ovasxila' => 'ovasxila',
'ovasxicyu' => 'ovasxicyu',
'ovasxicyete' => 'ovasxicyete',
'ovasxicyesx' => 'ovasxicyesx',
'ovasxicyemo' => 'ovasxicyemo',
'ovasxicye' => 'ovasxicye',
'ovasxi' => 'ovasxi',
'ovasxenye' => 'ovasxenye',
'ovasxeno' => 'ovasxeno',
'ovasxeni' => 'ovasxeni',
'ovasxene' => 'ovasxene',
'ovasxena' => 'ovasxena',
'ovasxen' => 'ovasxen',
'ovasxasxe' => 'ovasxasxe',
'ovasxaste' => 'ovasxaste',
'ovasxasmo' => 'ovasxasmo',
'ovasxahu' => 'ovasxahu',
'ovasxah' => 'ovasxah',
'ovasxa' => 'ovasxa',
'ovasx' => 'ovasx',
'ovanije' => '',
'ovadute' => 'dute',
'ovadumo' => 'dumo',
'ovadujucyi' => 'dujucyi',
'ovaduju' => 'duju',
'ovadujte' => 'dujte',
'ovadujmo' => 'dujmo',
'ovadujete' => 'dujete',
'ovadujesx' => 'dujesx',
'ovadujemo' => 'dujemo',
'ovadujem' => 'dujem',
'ovaduje' => 'duje',
'ovaduj' => 'duj',
'ovadu' => 'du',
'otpadnik' => 'k',
'osxlo' => 'o',
'osxli' => 'i',
'osxle' => 'e',
'osxla' => 'a',
'osxcyu' => 'xcyu',
'osxcyete' => 'sxcyete',
'osxcyesx' => 'sxcyesx',
'osxcyemo' => 'sxcyemo',
'osxcye' => 'sxcye',
'osxao' => 'sxao',
'osvecyenye' => 'e',
'osti' => 'ti',
'osni' => 'i',
'oslobodilacxki' => 'i',
'osjetlyiv' => '',
'osakacyenye' => 'e',
'oristu' => 'u',
'oristom' => 'om',
'oristima' => 'ima',
'oristi' => 'i',
'oriste' => 'iste',
'oristama' => 'ama',
'orista' => 'a',
'orist' => '',
'organizam' => 'am',
'opredjelyenye' => 'e',
'opredelyenye' => 'e',
'oplodyivanye' => 'plodyivanye',
'oplodyenye' => 'yenye',
'oplodnya' => 'nya',
'omomu' => 'omu',
'omoj' => 'oj',
'omoga' => 'oga',
'omog' => 'og',
'omama' => 'ama',
'omaka' => 'aka',
'omak' => 'ak',
'olyom' => 'om',
'olyeno' => 'yeno',
'olyeni' => 'yeni',
'olyene' => 'yene',
'olyena' => 'yena',
'olyen' => 'yen',
'oly' => '',
'olu' => 'u',
'olte' => 'te',
'olom' => 'om',
'olo' => 'o',
'olmo' => 'mo',
'olivsxi' => 'ivsxi',
'oliti' => 'iti',
'olite' => 'ite',
'olit' => 'it',
'olisxe' => 'isxe',
'olisx' => 'isx',
'oliste' => 'iste',
'olismo' => 'ismo',
'olio' => 'io',
'olimo' => 'imo',
'olima' => 'ima',
'olim' => 'im',
'olilo' => 'ilo',
'olili' => 'ili',
'olile' => 'ile',
'olila' => 'ila',
'olih' => 'ih',
'olicyu' => 'icyu',
'olicyete' => 'icyete',
'olicyesx' => 'icyesx',
'olicyemo' => 'icyemo',
'olicye' => 'icye',
'ol' => '',
'okeanski' => 'i',
'okast' => '',
'ojte' => 'te',
'ojmo' => 'mo',
'ojivsxi' => 'ivsxi',
'ojiti' => 'iti',
'ojit' => 'it',
'ojisxe' => 'isxe',
'ojiste' => 'iste',
'ojismo' => 'ismo',
'ojio' => 'io',
'ojilo' => 'ilo',
'ojili' => 'ili',
'ojile' => 'ile',
'ojila' => 'ila',
'ojih' => 'ih',
'ojicyu' => 'icyu',
'ojicyete' => 'icyete',
'ojicyesx' => 'icyesx',
'ojicyemo' => 'icyemo',
'ojicye' => 'icye',
'ojeno' => 'eno',
'ojeni' => 'eni',
'ojene' => 'ene',
'ojena' => 'ena',
'ojen' => 'en',
'ojavsxi' => 'avsxi',
'ojati' => 'ati',
'ojat' => 'at',
'ojasxe' => 'asxe',
'ojaste' => 'aste',
'ojasmo' => 'asmo',
'ojao' => 'ao',
'ojano' => 'ano',
'ojani' => 'ani',
'ojane' => 'ane',
'ojana' => 'ana',
'ojan' => 'an',
'ojalo' => 'alo',
'ojali' => 'ali',
'ojale' => 'ale',
'ojala' => 'ala',
'ojahu' => 'ahu',
'ojah' => 'ah',
'ojacyu' => 'acyu',
'ojacyete' => 'acyete',
'ojacyesx' => 'acyesx',
'ojacyemo' => 'acyemo',
'ojacye' => 'acye',
'oja' => 'a',
'ogranicxenye' => 'e',
'ogaoni' => 'gaoni',
'odyute' => 'ute',
'odyusx' => 'dyusx',
'odyumo' => 'umo',
'odyu' => 'u',
'odyte' => 'yte',
'odymo' => 'ymo',
'odyem' => 'yem',
'odye' => 'e',
'ody' => '',
'odu' => 'u',
'odrzxavanye' => 'e',
'odrzxanye' => 'e',
'odricanye' => 'e',
'odosxe' => 'dosxe',
'odoste' => 'doste',
'odosmo' => 'dosmo',
'odoh' => 'doh',
'odite' => 'ite',
'odimo' => 'imo',
'odi' => 'i',
'odete' => 'dete',
'odesx' => 'desx',
'odeno' => 'deno',
'odeni' => 'deni',
'odene' => 'dene',
'odena' => 'dena',
'oden' => 'den',
'odemo' => 'demo',
'odem' => 'dem',
'ode' => 'e',
'odbrana' => 'rana',
'od' => '',
'ocxnik' => 'k',
'ocxica' => 'a',
'ocom' => 'om',
'oceanski' => 'i',
'oc' => '',
'obu' => 'u',
'obrtnik' => 'k',
'obrazovanye' => 'e',
'obozxavanye' => 'e',
'obovima' => 'ovima',
'obovi' => 'ovi',
'obove' => 'ove',
'obovavsxi' => 'ovavsxi',
'obovati' => 'ovati',
'obovat' => 'ovat',
'obovasxe' => 'ovasxe',
'obovaste' => 'ovaste',
'obovasmo' => 'ovasmo',
'obovao' => 'ovao',
'obovano' => 'ovano',
'obovani' => 'ovani',
'obovane' => 'ovane',
'obovana' => 'ovana',
'obovan' => 'ovan',
'obovalo' => 'ovalo',
'obovali' => 'ovali',
'obovale' => 'ovale',
'obovala' => 'ovala',
'obovah' => 'ovah',
'obovacyu' => 'ovacyu',
'obovacyete' => 'ovacyete',
'obovacyesx' => 'ovacyesx',
'obovacyemo' => 'ovacyemo',
'obovacye' => 'ovacye',
'obo' => 'o',
'obmana' => 'a',
'obi' => 'i',
'obe' => 'e',
'obama' => 'ama',
'oba' => 'a',
'ob' => '',
'nyuju' => 'uju',
'nyujite' => 'ujite',
'nyujimo' => 'ujimo',
'nyuji' => 'uji',
'nyujete' => 'ujete',
'nyujesx' => 'ujesx',
'nyujemo' => 'ujemo',
'nyujem' => 'ujem',
'nyuje' => 'uje',
'nyiu' => 'u',
'nyite' => 'ite',
'nyiomu' => 'omu',
'nyiom' => 'om',
'nyioj' => 'oj',
'nyimo' => 'imo',
'nyikav' => '',
'nyiemu' => 'emu',
'nyiem' => 'em',
'nyiega' => 'ega',
'nyieg' => 'eg',
'nyie' => 'e',
'nyia' => 'a',
'nyezxivati' => 'nyezxivati',
'nyezxiti' => 'nyezxiti',
'nyezxica' => 'nyezxica',
'nyezxavati' => 'nyezxavati',
'nyevsxi' => 'yevsxi',
'nyete' => 'ete',
'nyesxe' => 'yesxe',
'nyesx' => 'esx',
'nyeste' => 'yeste',
'nyesmo' => 'yesmo',
'nyemo' => 'emo',
'nyelu' => 'yelu',
'nyelomu' => 'yelomu',
'nyelom' => 'yelom',
'nyeloj' => 'yeloj',
'nyeloga' => 'yeloga',
'nyelog' => 'yelog',
'nyelim' => 'yelim',
'nyelih' => 'yelih',
'nyeh' => 'yeh',
'nyalu' => 'lu',
'nyalom' => 'lom',
'nyalima' => 'lima',
'nyajucyi' => '',
'nvsxi' => 'nvsxi',
'nutu' => 'utu',
'nutomu' => 'utomu',
'nutom' => 'utom',
'nutoj' => 'utoj',
'nutoga' => 'utoga',
'nutog' => 'utog',
'nutim' => 'utim',
'nutiju' => 'utiju',
'nutijomu' => 'utijomu',
'nutijom' => 'utijom',
'nutijoj' => 'utijoj',
'nutijim' => 'utijim',
'nutijih' => 'utijih',
'nutiji' => 'utiji',
'nutijemu' => 'utijemu',
'nutijem' => 'utijem',
'nutijega' => 'utijega',
'nutijeg' => 'utijeg',
'nutije' => 'utije',
'nutija' => 'utija',
'nutih' => 'utih',
'nucyima' => 'ucyima',
'nucyem' => 'ucyem',
'nucya' => 'ucya',
'nsxe' => 'sxe',
'nste' => 'e',
'nsmo' => 'nsmo',
'nlo' => 'nlo',
'nli' => 'nli',
'nle' => 'nle',
'nla' => 'nla',
'niu' => 'u',
'niomu' => 'omu',
'niom' => 'om',
'nioj' => 'oj',
'nimlyeno' => 'lyeno',
'nimlyeni' => 'lyeni',
'nimlyene' => 'lyene',
'nimlyena' => 'lyena',
'nimlyen' => 'lyen',
'nimivsxi' => 'ivsxi',
'nimiti' => 'iti',
'nimite' => 'ite',
'nimit' => 'it',
'nimisxe' => 'isxe',
'nimisx' => 'isx',
'nimiste' => 'iste',
'nimismo' => 'ismo',
'nimio' => 'io',
'nimimo' => 'imo',
'nimim' => 'im',
'nimilo' => 'ilo',
'nimili' => 'ili',
'nimile' => 'ile',
'nimila' => 'ila',
'nimih' => 'ih',
'nimicyu' => 'icyu',
'nimicyete' => 'icyete',
'nimicyesx' => 'icyesx',
'nimicyemo' => 'icyemo',
'nimicye' => 'icye',
'nimi' => 'i',
'nime' => 'e',
'nilu' => 'u',
'nilom' => 'om',
'nilima' => 'ilima',
'niju' => 'u',
'nijte' => 'nijte',
'nijmo' => 'nijmo',
'nij' => 'nij',
'niemu' => 'emu',
'niem' => 'em',
'niega' => 'ega',
'nieg' => 'eg',
'nica' => 'a',
'nia' => 'a',
'nh' => 'nh',
'nelu' => 'u',
'nelomu' => 'omu',
'nelom' => 'om',
'neloj' => 'oj',
'neloga' => 'oga',
'nelog' => 'og',
'nelim' => 'im',
'nelih' => 'ih',
'ndete' => 'e',
'ndesx' => 'ndesx',
'ndeno' => 'ndeno',
'ndeni' => 'ndeni',
'ndene' => 'ndene',
'ndena' => 'ndena',
'nden' => 'nden',
'ndemo' => 'ndemo',
'ndem' => '',
'nde' => 'de',
'ncyu' => 'ncyu',
'ncyete' => 'ncyete',
'ncyesx' => 'ncyesx',
'ncyemo' => 'ncyemo',
'ncye' => 'ncye',
'nastavni' => 'i',
'nacxavavsxi' => 'avavsxi',
'nacxavati' => 'avati',
'nacxavat' => 'avat',
'nacxavasxe' => 'avasxe',
'nacxavaste' => 'avaste',
'nacxavasmo' => 'avasmo',
'nacxavao' => 'avao',
'nacxavano' => 'avano',
'nacxavani' => 'avani',
'nacxavane' => 'avane',
'nacxavana' => 'avana',
'nacxavan' => 'avan',
'nacxavalo' => 'avalo',
'nacxavali' => 'avali',
'nacxavale' => 'avale',
'nacxavala' => 'avala',
'nacxavahu' => 'avahu',
'nacxavah' => 'avah',
'nacxavacyu' => 'avacyu',
'nacxavacyete' => 'avacyete',
'nacxavacyesx' => 'avacyesx',
'nacxavacyemo' => 'avacyemo',
'nacxavacye' => 'avacye',
'nacxava' => 'ava',
'mute' => 'ute',
'mumo' => 'umo',
'mujucyi' => 'ujucyi',
'muju' => 'uju',
'mujte' => 'ujte',
'mujmo' => 'ujmo',
'mujete' => 'ujete',
'mujesx' => 'ujesx',
'mujemo' => 'ujemo',
'mujem' => 'ujem',
'muje' => 'uje',
'muj' => 'uj',
'msku' => 'u',
'mskomu' => 'omu',
'mskom' => 'om',
'mskoj' => 'oj',
'mskoga' => 'oga',
'mskog' => 'og',
'msko' => 'o',
'mskim' => 'im',
'mskih' => 'ih',
'mski' => 'i',
'mske' => 'e',
'mska' => 'a',
'movavsxi' => 'ovavsxi',
'movati' => 'ovati',
'movat' => 'ovat',
'movasxe' => 'ovasxe',
'movaste' => 'ovaste',
'movasmo' => 'ovasmo',
'movao' => 'ovao',
'movanye' => 'ovanye',
'movano' => 'ovano',
'movani' => 'ovani',
'movane' => 'ovane',
'movana' => 'ovana',
'movan' => 'ovan',
'movalo' => 'ovalo',
'movali' => 'ovali',
'movale' => 'ovale',
'movala' => 'ovala',
'movahu' => 'ovahu',
'movah' => 'ovah',
'movacyu' => 'ovacyu',
'movacyete' => 'ovacyete',
'movacyesx' => 'ovacyesx',
'movacyemo' => 'ovacyemo',
'movacye' => 'ovacye',
'mova' => 'ova',
'mosxe' => 'osxe',
'moste' => 'oste',
'mosmo' => 'osmo',
'moih' => 'oih',
'mogosxe' => 'ogosxe',
'mogoste' => 'ogoste',
'mogosmo' => 'ogosmo',
'mogoh' => 'ogoh',
'mogo' => 'ogo',
'mognute' => 'ognute',
'mognusx' => 'ognusx',
'mognumo' => 'ognumo',
'mognu' => 'ognu',
'mognte' => 'ognte',
'mognmo' => 'ognmo',
'mognem' => 'ognem',
'mogne' => 'ogne',
'mogn' => 'ogn',
'moglo' => 'oglo',
'mogli' => 'ogli',
'mogle' => 'ogle',
'mogla' => 'ogla',
'mogavsxi' => 'ogavsxi',
'mogao' => 'ogao',
'mocyu' => 'ocyu',
'mocyi' => 'i',
'mocyete' => 'ocyete',
'mocyesx' => 'ocyesx',
'mocyemo' => 'ocyemo',
'mocye' => 'ocye',
'mocy' => 'ocy',
'mlyu' => 'lyu',
'mlyomu' => 'mlyomu',
'mlyom' => 'lyom',
'mlyoj' => 'mlyoj',
'mlyim' => 'im',
'mlyih' => 'lyih',
'mlyi' => 'lyi',
'mlyenye' => 'e',
'mlyemu' => 'mlyemu',
'mlyem' => 'lyem',
'mlyega' => 'mlyega',
'mlyeg' => 'mlyeg',
'mlye' => 'lye',
'mlya' => 'lya',
'mjte' => 'mjte',
'mjmo' => 'mjmo',
'mj' => 'mj',
'mitu' => 'u',
'mitom' => 'om',
'mito' => 'o',
'mitavsxi' => 'mitavsxi',
'mitati' => 'mitati',
'mitate' => 'mitate',
'mitat' => 'mitat',
'mitasxe' => 'e',
'mitasx' => '',
'mitaste' => 'mitaste',
'mitasmo' => 'mitasmo',
'mitao' => 'mitao',
'mitanye' => 'mitanye',
'mitano' => 'mitano',
'mitani' => 'mitani',
'mitane' => 'mitane',
'mitana' => 'mitana',
'mitan' => 'mitan',
'mitamo' => 'mitamo',
'mitama' => 'ama',
'mitam' => 'mitam',
'mitalo' => 'mitalo',
'mitali' => 'mitali',
'mitale' => 'mitale',
'mitala' => 'mitala',
'mitaju' => 'mitaju',
'mitajte' => 'mitajte',
'mitajmo' => 'mitajmo',
'mitaj' => 'mitaj',
'mitahu' => 'mitahu',
'mitah' => 'mitah',
'mitacyu' => 'mitacyu',
'mitacyete' => 'mitacyete',
'mitacyesx' => 'mitacyesx',
'mitacyemo' => 'mitacyemo',
'mitacye' => 'mitacye',
'mita' => 'a',
'miju' => 'u',
'mijomu' => 'mijomu',
'mijom' => 'om',
'mijoj' => 'mijoj',
'mijim' => 'mijim',
'mijih' => 'mijih',
'miji' => 'i',
'mijemu' => 'mijemu',
'mijem' => 'ijem',
'mijega' => 'mijega',
'mijeg' => 'mijeg',
'mije' => 'e',
'mija' => 'a',
'matik' => 'k',
'maticxki' => 'i',
'maticxar' => '',
'manye' => 'nye',
'maju' => 'ju',
'majte' => 'jte',
'majmo' => 'jmo',
'maj' => 'j',
'lyutiti' => 'titi',
'lyucyi' => 'lyucyi',
'lyoga' => 'oga',
'lyog' => 'og',
'lyku' => 'ku',
'lykom' => 'kom',
'lyko' => 'ko',
'lyke' => 'ke',
'lykama' => 'kama',
'lyka' => 'ka',
'lyivu' => 'u',
'lyivsxi' => 'ivsxi',
'lyivost' => 't',
'lyivomu' => 'omu',
'lyivom' => 'om',
'lyivoj' => 'oj',
'lyivoga' => 'oga',
'lyivog' => 'og',
'lyivo' => 'o',
'lyivim' => 'im',
'lyivih' => 'ih',
'lyivi' => 'i',
'lyive' => 'e',
'lyiva' => 'a',
'lyisxe' => 'isxe',
'lyiste' => 'iste',
'lyismo' => 'ismo',
'lyepodnevni' => 'lyepodnevni',
'lyeplyujucyi' => 'ujucyi',
'lyeplyivati' => 'ivati',
'lyeplyenost' => 'lyeplyenost',
'lyeo' => 'lyeo',
'lyenome' => 'lyenome',
'lyenama' => 'ama',
'lyelyu' => 'yelyu',
'lyelyte' => 'yelyte',
'lyelymo' => 'yelymo',
'lyely' => 'yely',
'lyedye' => 'lyedye',
'lyedstvo' => 'lyedstvo',
'lyednicxki' => 'lyednicxki',
'lyednica' => 'lyednica',
'lyedni' => 'lyedni',
'lyedica' => 'lyedica',
'lyecxiv' => 'lyecxiv',
'lyci' => 'ci',
'lyavavsxi' => 'avavsxi',
'lyavati' => 'avati',
'lyavat' => 'avat',
'lyavasxe' => 'avasxe',
'lyavaste' => 'avaste',
'lyavasmo' => 'avasmo',
'lyavao' => 'avao',
'lyavanye' => 'e',
'lyavano' => 'avano',
'lyavani' => 'avani',
'lyavane' => 'avane',
'lyavana' => 'avana',
'lyavan' => 'avan',
'lyavalo' => 'avalo',
'lyavali' => 'avali',
'lyavale' => 'avale',
'lyavala' => 'avala',
'lyavahu' => 'avahu',
'lyavah' => 'avah',
'lyavacyu' => 'avacyu',
'lyavacyete' => 'avacyete',
'lyavacyesx' => 'avacyesx',
'lyavacyemo' => 'avacyemo',
'lyavacye' => 'avacye',
'lyava' => 'ava',
'lyastu' => 'u',
'lyastomu' => 'omu',
'lyastom' => 'om',
'lyastoj' => 'oj',
'lyastoga' => 'oga',
'lyastog' => 'og',
'lyasto' => 'o',
'lyastim' => 'im',
'lyastih' => 'ih',
'lyasti' => 'i',
'lyasta' => 'a',
'lyast' => '',
'lyaka' => 'aka',
'lyak' => 'ak',
'lyajucyi' => 'jucyi',
'lvsxi' => 'lvsxi',
'lto' => 'to',
'ltama' => 'tama',
'lsxe' => 'e',
'lste' => 'lste',
'lsmo' => 'lsmo',
'lmu' => 'u',
'lmom' => 'om',
'lmi' => 'i',
'lme' => 'e',
'lmama' => 'mama',
'lma' => 'a',
'lki' => 'lki',
'litu' => 'u',
'litomu' => 'omu',
'litom' => 'om',
'litoj' => 'oj',
'litoga' => 'oga',
'litog' => 'og',
'lito' => 'o',
'litim' => 'tim',
'litih' => 'tih',
'lita' => 'a',
'liovma' => 'liovma',
'lijomu' => 'lijomu',
'lijoj' => 'lijoj',
'lijima' => 'jima',
'lijim' => 'm',
'lijih' => 'h',
'lijemu' => 'lijemu',
'lijega' => 'ga',
'lijeg' => 'lijeg',
'lh' => 'lh',
'lecyomu' => 'lecyomu',
'lecyom' => 'om',
'lecyoj' => 'lecyoj',
'lecyoga' => 'lecyoga',
'lecyog' => 'lecyog',
'lecyo' => 'cyo',
'lecyima' => 'ima',
'lecyim' => 'm',
'lecyih' => 'h',
'lecyem' => 'cyem',
'lcyu' => 'lcyu',
'lcyete' => 'lcyete',
'lcyesx' => 'lcyesx',
'lcyemo' => 'lcyemo',
'lcye' => 'lcye',
'lazxeno' => 'xeno',
'lazxeni' => 'xeni',
'lazxene' => 'xene',
'lazxena' => 'xena',
'lazxen' => 'xen',
'lazxasxe' => 'xasxe',
'lazxaste' => 'xaste',
'lazxasmo' => 'xasmo',
'lazxahu' => 'xahu',
'lazxah' => 'xah',
'lazte' => 'te',
'lazmo' => 'mo',
'laziti' => 'iti',
'lazite' => 'ite',
'lazit' => 'it',
'lazisx' => 'isx',
'laziste' => 'iste',
'lazismo' => 'ismo',
'lazio' => 'io',
'lazimo' => 'imo',
'lazim' => 'im',
'lazilo' => 'ilo',
'lazili' => 'ili',
'lazile' => 'ile',
'lazila' => 'ila',
'lazih' => 'ih',
'lazicyu' => 'icyu',
'lazicyete' => 'icyete',
'lazicyesx' => 'icyesx',
'lazicyemo' => 'icyemo',
'lazicye' => 'icye',
'lazi' => 'i',
'laze' => 'e',
'laz' => '',
'latu' => 'u',
'latomu' => 'omu',
'latom' => 'om',
'latoj' => 'oj',
'latoga' => 'oga',
'latog' => 'og',
'lato' => 'o',
'lativsxi' => 'tivsxi',
'latisxe' => 'tisxe',
'latiste' => 'tiste',
'latismo' => 'tismo',
'lastu' => 'u',
'lastomu' => 'omu',
'lastom' => 'om',
'lastoj' => 'oj',
'lastoga' => 'oga',
'lastog' => 'og',
'lasto' => 'o',
'lastim' => 'im',
'lastih' => 'ih',
'lasti' => 'i',
'lasta' => 'a',
'last' => '',
'lanyavsxi' => 'vsxi',
'lanyati' => 'ti',
'lanyate' => 'te',
'lanyat' => 't',
'lanyasxe' => 'sxe',
'lanyasx' => 'sx',
'lanyaste' => 'ste',
'lanyasmo' => 'smo',
'lanyao' => 'o',
'lanyanye' => 'e',
'lanyano' => 'no',
'lanyani' => 'ni',
'lanyane' => 'ne',
'lanyana' => 'na',
'lanyan' => 'n',
'lanyamo' => 'mo',
'lanyam' => 'm',
'lanyalo' => 'lo',
'lanyali' => 'li',
'lanyale' => 'le',
'lanyala' => 'la',
'lanyaju' => 'ju',
'lanyajte' => 'jte',
'lanyajmo' => 'jmo',
'lanyaj' => 'j',
'lanyahu' => 'hu',
'lanyah' => 'h',
'lanyacyu' => 'cyu',
'lanyacyete' => 'cyete',
'lanyacyesx' => 'cyesx',
'lanyacyemo' => 'cyemo',
'lanyacye' => 'cye',
'lamu' => 'u',
'lamom' => 'om',
'lami' => 'i',
'lame' => 'e',
'lamama' => 'ama',
'lacyasxe' => 'cyasxe',
'lacyaste' => 'cyaste',
'lacyasmo' => 'cyasmo',
'lacyahu' => 'cyahu',
'lacyah' => 'cyah',
'lacxucyi' => 'cxucyi',
'ksxe' => 'xe',
'kste' => 'e',
'ksmo' => 'ksmo',
'kovatu' => 'kovatu',
'kovatom' => 'kovatom',
'kovatima' => 'kovatima',
'kovate' => 'kovate',
'kovata' => 'kovata',
'kovanye' => 'ovanye',
'kovanya' => 'a',
'komte' => 'komte',
'komlyeno' => 'mlyeno',
'komlyeni' => 'mlyeni',
'komlyene' => 'mlyene',
'komlyena' => 'mlyena',
'komlyen' => 'mlyen',
'komivsxi' => 'komivsxi',
'komitu' => 'mitu',
'komitomu' => 'komitomu',
'komitom' => 'mitom',
'komitoj' => 'komitoj',
'komitoga' => 'komitoga',
'komitog' => 'komitog',
'komito' => 'mito',
'komitim' => 'komitim',
'komitih' => 'komitih',
'komiti' => 'miti',
'komite' => 'mite',
'komita' => 'mita',
'komit' => 'mit',
'komisxe' => 'komisxe',
'komisx' => 'misx',
'komiste' => 'komiste',
'komismo' => 'komismo',
'komio' => 'mio',
'komimo' => 'mimo',
'komim' => 'mim',
'komilo' => 'milo',
'komili' => 'mili',
'komile' => 'mile',
'komila' => 'mila',
'komih' => 'omih',
'komicyu' => 'micyu',
'komicyete' => 'micyete',
'komicyesx' => 'micyesx',
'komicyemo' => 'micyemo',
'komicye' => 'micye',
'komi' => 'i',
'knutu' => 'utu',
'knutomu' => 'utomu',
'knutom' => 'utom',
'knutoj' => 'utoj',
'knutoga' => 'utoga',
'knutog' => 'utog',
'knutim' => 'utim',
'knutih' => 'utih',
'knima' => 'nima',
'knama' => 'nama',
'klu' => 'lu',
'klomu' => 'omu',
'klom' => 'lom',
'kloj' => 'oj',
'kloga' => 'oga',
'klog' => 'og',
'klim' => 'im',
'klih' => 'ih',
'kite' => 'te',
'kimo' => 'kimo',
'kie' => 'ie',
'kgrub' => 'kgrub',
'keu' => 'u',
'keom' => 'om',
'keima' => 'ima',
'kei' => 'i',
'keansku' => 'u',
'keanskomu' => 'omu',
'keanskom' => 'om',
'keanskoj' => 'oj',
'keanskoga' => 'oga',
'keanskog' => 'og',
'keansko' => 'o',
'keanskim' => 'im',
'keanskih' => 'ih',
'keanski' => '',
'keanske' => 'e',
'keanska' => 'a',
'kea' => 'a',
'kcyu' => 'cyu',
'kcyite' => 'cyite',
'kcyimo' => 'cyimo',
'kcyi' => 'cyi',
'kcyete' => 'cyete',
'kcyesx' => 'cyesx',
'kcyemo' => 'cyemo',
'kcyem' => 'cyem',
'kcye' => 'cye',
'kcxe' => 'cxe',
'kcu' => 'cu',
'kcima' => 'cima',
'kciju' => 'u',
'kcijom' => 'om',
'kcijo' => 'o',
'kciji' => 'i',
'kcije' => 'e',
'kcijama' => 'ama',
'kcija' => 'a',
'kci' => 'ci',
'kcem' => 'cem',
'kce' => 'ce',
'kca' => 'ca',
'kbreher' => 'kbreher',
'kbjeti' => 'kbjeti',
'kbiti' => 'kbiti',
'katmo' => 'tmo',
'katiti' => 'titi',
'katite' => 'tite',
'katit' => 'tit',
'katisx' => 'tisx',
'katio' => 'tio',
'katimo' => 'timo',
'katima' => 'ima',
'katilo' => 'tilo',
'katili' => 'tili',
'katile' => 'tile',
'katila' => 'tila',
'katicyu' => 'ticyu',
'katicyete' => 'ticyete',
'katicyesx' => 'ticyesx',
'katicyemo' => 'ticyemo',
'katicye' => 'ticye',
'katecyi' => 'katecyi',
'kasxu' => 'u',
'kasxom' => 'om',
'kasxima' => 'ima',
'kasxi' => 'i',
'kasxa' => 'a',
'karavsxi' => 'vsxi',
'karati' => 'ti',
'karat' => 't',
'karasxe' => 'asxe',
'karaste' => 'aste',
'karasmo' => 'asmo',
'karao' => 'o',
'karanye' => 'e',
'karano' => 'no',
'karani' => 'ni',
'karane' => 'ne',
'karana' => 'na',
'karan' => 'n',
'karalu' => 'lu',
'karalom' => 'lom',
'karalo' => 'lo',
'karalima' => 'lima',
'karali' => 'li',
'karale' => 'le',
'karala' => 'la',
'karahu' => 'ahu',
'karah' => 'ah',
'karacyu' => 'cyu',
'karacyete' => 'cyete',
'karacyesx' => 'cyesx',
'karacyemo' => 'cyemo',
'karacye' => 'cye',
'kara' => 'a',
'kacyom' => 'kacyom',
'kacyite' => 'cyite',
'kacyimo' => 'cyimo',
'kacyima' => 'kacyima',
'kacyenye' => 'kacyenye',
'kacyeno' => 'cyeno',
'kacyeni' => 'cyeni',
'kacyene' => 'cyene',
'kacyena' => 'cyena',
'kacyen' => 'cyen',
'kacyem' => 'cyem',
'kacyasxe' => 'cyasxe',
'kacyaste' => 'cyaste',
'kacyasmo' => 'cyasmo',
'kacyahu' => 'cyahu',
'kacyah' => 'cyah',
'kacya' => 'kacya',
'kacy' => 'kacy',
'kacxima' => 'ima',
'kacxa' => 'a',
'kacx' => '',
'jujucyi' => 'ujucyi',
'jucyomu' => 'omu',
'jucyoj' => 'oj',
'jucyoga' => 'oga',
'jucyog' => 'og',
'jucyama' => 'ama',
'jmte' => 'te',
'jmoo' => 'jmoo',
'jmlyeno' => 'lyeno',
'jmlyeni' => 'lyeni',
'jmlyene' => 'lyene',
'jmlyena' => 'lyena',
'jmlyen' => 'lyen',
'jmivsxi' => 'ivsxi',
'jmiti' => 'iti',
'jmite' => 'ite',
'jmit' => 'it',
'jmisxe' => 'isxe',
'jmisx' => 'isx',
'jmiste' => 'iste',
'jmismo' => 'ismo',
'jmio' => 'io',
'jmimo' => 'imo',
'jmim' => 'im',
'jmilo' => 'ilo',
'jmili' => 'ili',
'jmile' => 'ile',
'jmila' => 'ila',
'jmih' => 'ih',
'jmicyu' => 'icyu',
'jmicyete' => 'icyete',
'jmicyesx' => 'icyesx',
'jmicyemo' => 'icyemo',
'jmicye' => 'icye',
'jmi' => 'i',
'jme' => 'e',
'jm' => '',
'jivsxi' => 'ivsxi',
'jisxe' => 'xe',
'jiste' => 'iste',
'jismo' => 'ismo',
'jetmo' => 'tmo',
'jetivsxi' => 'tivsxi',
'jetiti' => 'titi',
'jetite' => 'tite',
'jetit' => 'tit',
'jetisxe' => 'tisxe',
'jetisx' => 'tisx',
'jetiste' => 'tiste',
'jetismo' => 'tismo',
'jetio' => 'tio',
'jetimo' => 'timo',
'jetim' => 'tim',
'jetilo' => 'tilo',
'jetili' => 'tili',
'jetile' => 'tile',
'jetila' => 'tila',
'jetih' => 'tih',
'jeticyu' => 'ticyu',
'jeticyete' => 'ticyete',
'jeticyesx' => 'ticyesx',
'jeticyemo' => 'ticyemo',
'jeticye' => 'ticye',
'jesxte' => 'te',
'jesxmo' => 'mo',
'jesxiti' => 'iti',
'jesxite' => 'ite',
'jesxit' => 'it',
'jesxisx' => 'isx',
'jesxio' => 'io',
'jesximo' => 'imo',
'jesxim' => 'im',
'jesxilo' => 'ilo',
'jesxili' => 'ili',
'jesxile' => 'ile',
'jesxila' => 'ila',
'jesxicyu' => 'icyu',
'jesxicyete' => 'icyete',
'jesxicyesx' => 'icyesx',
'jesxicyemo' => 'icyemo',
'jesxicye' => 'icye',
'jesxi' => 'i',
'jesxeno' => 'eno',
'jesxeni' => 'eni',
'jesxene' => 'ene',
'jesxena' => 'ena',
'jesxen' => 'en',
'jesxcyeno' => 'xcyeno',
'jesxcyeni' => 'xcyeni',
'jesxcyene' => 'xcyene',
'jesxcyena' => 'xcyena',
'jesxcyen' => 'xcyen',
'jesxasxe' => 'sxe',
'jesxaste' => 'ste',
'jesxasmo' => 'smo',
'jesxahu' => 'xahu',
'jesxah' => 'h',
'jestivsxi' => 'tivsxi',
'jestiti' => 'titi',
'jestite' => 'tite',
'jestit' => 'tit',
'jestisxe' => 'tisxe',
'jestisx' => 'tisx',
'jestiste' => 'tiste',
'jestismo' => 'tismo',
'jestio' => 'tio',
'jestimo' => 'timo',
'jestim' => 'tim',
'jestilo' => 'tilo',
'jestili' => 'tili',
'jestile' => 'tile',
'jestila' => 'tila',
'jestih' => 'tih',
'jesticyu' => 'ticyu',
'jesticyete' => 'ticyete',
'jesticyesx' => 'ticyesx',
'jesticyemo' => 'ticyemo',
'jesticye' => 'ticye',
'jesti' => 'ti',
'jest' => 't',
'jerivacx' => 'jerivacx',
'jemovima' => 'ovima',
'jemovi' => 'ovi',
'jemove' => 'ove',
'jemova' => 'ova',
'jemom' => 'om',
'jemlyu' => 'jemlyu',
'jemlyite' => 'jemlyite',
'jemlyimo' => 'jemlyimo',
'jemlyi' => 'jemlyi',
'jemlyete' => 'jemlyete',
'jemlyesx' => 'jemlyesx',
'jemlyemo' => 'jemlyemo',
'jemlyem' => 'jemlyem',
'jemlye' => 'jemlye',
'jemi' => 'i',
'jeme' => 'me',
'jemavsxi' => 'vsxi',
'jemati' => 'ti',
'jemate' => 'te',
'jemat' => 't',
'jemasxe' => 'sxe',
'jemasx' => 'sx',
'jemaste' => 'ste',
'jemasmo' => 'smo',
'jemao' => 'o',
'jemano' => 'no',
'jemani' => 'ni',
'jemane' => 'ne',
'jemana' => 'na',
'jeman' => 'n',
'jemamo' => 'mo',
'jemama' => 'ama',
'jemam' => 'm',
'jemalu' => 'jemalu',
'jemalom' => 'jemalom',
'jemalo' => 'lo',
'jemalima' => 'jemalima',
'jemali' => 'li',
'jemale' => 'le',
'jemala' => 'la',
'jemaju' => 'ju',
'jemajte' => 'jte',
'jemajmo' => 'jmo',
'jemajite' => 'jemajite',
'jemajimo' => 'jemajimo',
'jemaji' => 'jemaji',
'jemaj' => 'j',
'jemahu' => 'hu',
'jemah' => 'h',
'jemaete' => 'jemaete',
'jemaesx' => 'jemaesx',
'jemaemo' => 'jemaemo',
'jemaem' => 'jemaem',
'jemae' => 'jemae',
'jemacyu' => 'cyu',
'jemacyete' => 'cyete',
'jemacyesx' => 'cyesx',
'jemacyemo' => 'cyemo',
'jemacye' => 'cye',
'jelyeno' => 'yeno',
'jelyeni' => 'yeni',
'jelyene' => 'yene',
'jelyena' => 'yena',
'jelyen' => 'yen',
'jelyasxe' => 'yasxe',
'jelyaste' => 'yaste',
'jelyasmo' => 'yasmo',
'jelyahu' => 'yahu',
'jelyah' => 'yah',
'jelte' => 'te',
'jelovlyenye' => 'e',
'jelovima' => 'ima',
'jelovi' => 'i',
'jelove' => 'e',
'jelova' => 'ova',
'jelmo' => 'mo',
'jeliti' => 'iti',
'jelite' => 'ite',
'jelit' => 'it',
'jelisx' => 'isx',
'jeliogu' => 'jeliogu',
'jeliogom' => 'jeliogom',
'jeliogima' => 'jeliogima',
'jeliogi' => 'jeliogi',
'jelioge' => 'jelioge',
'jelioga' => 'jelioga',
'jelio' => 'io',
'jelimo' => 'imo',
'jelilo' => 'ilo',
'jelili' => 'ili',
'jelile' => 'ile',
'jelila' => 'ila',
'jelicyu' => 'icyu',
'jelicyete' => 'icyete',
'jelicyesx' => 'icyesx',
'jelicyemo' => 'icyemo',
'jelicye' => 'icye',
'jelama' => 'ama',
'jel' => '',
'jeih' => 'ih',
'jehu' => 'hu',
'jehovima' => 'hovima',
'jehovi' => 'hovi',
'jehove' => 'hove',
'jehova' => 'hova',
'jehom' => 'hom',
'jeha' => 'ha',
'jegosxe' => 'gosxe',
'jegoste' => 'goste',
'jegosmo' => 'gosmo',
'jegoh' => 'goh',
'jego' => 'go',
'jegnusx' => 'gnusx',
'jegnumo' => 'gnumo',
'jegnte' => 'gnte',
'jegnmo' => 'gnmo',
'jegn' => 'gn',
'jeglo' => 'glo',
'jegli' => 'gli',
'jegle' => 'gle',
'jegla' => 'gla',
'jegavsxi' => 'gavsxi',
'jegao' => 'gao',
'jecyeno' => 'cyeno',
'jecyeni' => 'cyeni',
'jecyene' => 'cyene',
'jecyena' => 'cyena',
'jecyen' => 'cyen',
'jecu' => 'jecu',
'jecom' => 'jecom',
'jeco' => 'jeco',
'jeci' => 'ci',
'jece' => 'jece',
'jecanye' => 'e',
'jecama' => 'jecama',
'jeca' => '',
'jcyi' => 'jcyi',
'javate' => 'te',
'javasx' => 'sx',
'javamo' => 'mo',
'javam' => 'm',
'javaju' => 'ju',
'javajte' => 'jte',
'javajmo' => 'jmo',
'javaj' => 'j',
'java' => '',
'janyu' => 'nyu',
'janyima' => 'ima',
'janyem' => 'em',
'janya' => 'a',
'jak' => 'k',
'jajucyi' => 'jucyi',
'izxu' => 'xu',
'izxom' => 'om',
'izxo' => 'o',
'izxi' => 'xi',
'izxem' => 'xem',
'izxe' => 'xe',
'izxama' => 'ama',
'izxa' => 'a',
'izavsxi' => 'avsxi',
'izati' => 'ati',
'izat' => 'at',
'izasxe' => 'asxe',
'izaste' => 'aste',
'izasmo' => 'asmo',
'izao' => 'ao',
'izano' => 'ano',
'izani' => 'ani',
'izane' => 'ane',
'izana' => 'ana',
'izan' => 'an',
'izama' => 'ama',
'izam' => 'am',
'izalo' => 'alo',
'izali' => 'ali',
'izale' => 'ale',
'izala' => 'ala',
'izahu' => 'ahu',
'izah' => 'ah',
'izacyu' => 'acyu',
'izacyete' => 'acyete',
'izacyesx' => 'acyesx',
'izacyemo' => 'acyemo',
'izacye' => 'acye',
'iza' => 'a',
'ivenye' => 'venye',
'ivenije' => '',
'ivauju' => 'uju',
'ivaujite' => 'ujite',
'ivaujimo' => 'ujimo',
'ivauji' => 'uji',
'ivanyu' => 'u',
'ivanyima' => 'ima',
'ivanyem' => 'em',
'ivanya' => 'a',
'ivalyute' => 'ivalyute',
'ivalyumo' => 'ivalyumo',
'ivalyujucyi' => 'ivalyujucyi',
'ivalyuju' => 'lyuju',
'ivalyujte' => 'ivalyujte',
'ivalyujmo' => 'ivalyujmo',
'ivalyujete' => 'lyujete',
'ivalyujesx' => 'lyujesx',
'ivalyujemo' => 'lyujemo',
'ivalyujem' => 'lyujem',
'ivalyuje' => 'lyuje',
'ivalyuj' => 'ivalyuj',
'ivalyu' => 'ivalyu',
'ivajete' => 'ivajete',
'ivajesx' => 'ivajesx',
'ivajemo' => 'ivajemo',
'ivajem' => 'ivajem',
'ivajecyi' => 'ivajecyi',
'ivaje' => 'ivaje',
'itute' => 'ute',
'itumo' => 'umo',
'itujucyi' => 'ujucyi',
'ituju' => 'uju',
'itujte' => 'ujte',
'itujmo' => 'ujmo',
'itujete' => 'ujete',
'itujesx' => 'ujesx',
'itujemo' => 'ujemo',
'itujem' => 'ujem',
'ituje' => 'uje',
'ituj' => 'uj',
'itovavsxi' => 'ovavsxi',
'itovati' => 'ovati',
'itovat' => 'ovat',
'itovasxe' => 'ovasxe',
'itovaste' => 'ovaste',
'itovasmo' => 'ovasmo',
'itovao' => 'ovao',
'itovano' => 'ovano',
'itovani' => 'ovani',
'itovane' => 'ovane',
'itovana' => 'ovana',
'itovan' => 'ovan',
'itovalo' => 'ovalo',
'itovali' => 'ovali',
'itovale' => 'ovale',
'itovala' => 'ovala',
'itovah' => 'ovah',
'itovacyu' => 'ovacyu',
'itovacyete' => 'ovacyete',
'itovacyesx' => 'ovacyesx',
'itovacyemo' => 'ovacyemo',
'itovacye' => 'ovacye',
'itova' => 'ova',
'itomte' => 'tomte',
'itomo' => 'tomo',
'itomlyeno' => 'tomlyeno',
'itomlyeni' => 'tomlyeni',
'itomlyene' => 'tomlyene',
'itomlyena' => 'tomlyena',
'itomlyen' => 'tomlyen',
'itomivsxi' => 'itomivsxi',
'itomiti' => 'tomiti',
'itomite' => 'tomite',
'itomit' => 'tomit',
'itomisxe' => 'itomisxe',
'itomisx' => 'tomisx',
'itomiste' => 'itomiste',
'itomismo' => 'itomismo',
'itomio' => 'tomio',
'itomimo' => 'tomimo',
'itomim' => 'tomim',
'itomilo' => 'tomilo',
'itomili' => 'tomili',
'itomile' => 'tomile',
'itomila' => 'tomila',
'itomih' => 'tomih',
'itomicyu' => 'tomicyu',
'itomicyete' => 'tomicyete',
'itomicyesx' => 'tomicyesx',
'itomicyemo' => 'tomicyemo',
'itomicye' => 'tomicye',
'itomi' => 'tomi',
'itome' => 'tome',
'itivsxi' => 'tivsxi',
'itivavsxi' => 'ivavsxi',
'itivati' => 'ivati',
'itivat' => 'ivat',
'itivasxe' => 'ivasxe',
'itivaste' => 'ivaste',
'itivasmo' => 'ivasmo',
'itivao' => 'ivao',
'itivano' => 'ivano',
'itivani' => 'ivani',
'itivane' => 'ivane',
'itivana' => 'ivana',
'itivan' => 'ivan',
'itivalo' => 'ivalo',
'itivali' => 'ivali',
'itivale' => 'ivale',
'itivala' => 'ivala',
'itivahu' => 'ivahu',
'itivah' => 'ivah',
'itivacyu' => 'ivacyu',
'itivacyete' => 'ivacyete',
'itivacyesx' => 'ivacyesx',
'itivacyemo' => 'ivacyemo',
'itivacye' => 'ivacye',
'itiva' => 'a',
'ititi' => 'titi',
'itit' => 'tit',
'itisxe' => 'tisxe',
'itiste' => 'tiste',
'itismo' => 'tismo',
'itio' => 'tio',
'itilo' => 'tilo',
'itili' => 'tili',
'itile' => 'tile',
'itila' => 'tila',
'iticyu' => 'ticyu',
'iticyete' => 'ticyete',
'iticyesx' => 'ticyesx',
'iticyemo' => 'ticyemo',
'iticye' => 'ticye',
'itavsxi' => 'tavsxi',
'itati' => 'tati',
'itat' => 'tat',
'itasxe' => 'tasxe',
'itaste' => 'taste',
'itasmo' => 'tasmo',
'itao' => 'tao',
'itano' => 'tano',
'itani' => 'tani',
'itane' => 'tane',
'itana' => 'tana',
'itan' => 'tan',
'italo' => 'talo',
'italicyu' => 'licyu',
'italicyite' => 'licyite',
'italicyimo' => 'licyimo',
'italicyi' => 'licyi',
'italicyete' => 'licyete',
'italicyesx' => 'licyesx',
'italicyemo' => 'licyemo',
'italicyem' => 'licyem',
'italicye' => 'licye',
'itali' => 'tali',
'itale' => 'tale',
'itala' => 'tala',
'itahu' => 'tahu',
'itah' => 'tah',
'itacyu' => 'tacyu',
'itacyete' => 'tacyete',
'itacyesx' => 'tacyesx',
'itacyemo' => 'tacyemo',
'itacye' => 'tacye',
'isxo' => 'o',
'isxenye' => 'xenye',
'isxavsxi' => 'vsxi',
'isxati' => 'ti',
'isxate' => 'te',
'isxat' => 't',
'isxasxe' => 'sxe',
'isxasx' => 'sx',
'isxaste' => 'ste',
'isxasmo' => 'smo',
'isxanye' => 'nye',
'isxano' => 'no',
'isxani' => 'ni',
'isxane' => 'ne',
'isxana' => 'na',
'isxan' => 'n',
'isxamo' => 'mo',
'isxama' => 'ama',
'isxam' => 'm',
'isxalo' => 'lo',
'isxali' => 'li',
'isxale' => 'le',
'isxala' => 'la',
'isxaju' => 'ju',
'isxajte' => 'jte',
'isxajmo' => 'jmo',
'isxaj' => 'j',
'isxahu' => 'hu',
'isxah' => 'h',
'isxacyu' => 'cyu',
'isxacyete' => 'cyete',
'isxacyesx' => 'cyesx',
'isxacyemo' => 'cyemo',
'isxacye' => 'cye',
'isku' => 'ku',
'iskriptumu' => 'iskriptumu',
'iskriptumom' => 'iskriptumom',
'iskriptumima' => 'iskriptumima',
'iskriptumi' => 'iskriptumi',
'iskriptume' => 'iskriptume',
'iskriptuma' => 'iskriptuma',
'iskriptum' => 'iskriptum',
'iskomu' => 'omu',
'iskom' => 'kom',
'iskoj' => 'oj',
'iskoga' => 'oga',
'iskog' => 'og',
'isko' => 'ko',
'iskim' => 'im',
'iskih' => 'ih',
'iski' => 'i',
'iske' => 'ke',
'iska' => 'ka',
'irvsxi' => 'irvsxi',
'irvsku' => 'irvsku',
'irvskomu' => 'irvskomu',
'irvskom' => 'irvskom',
'irvskoj' => 'irvskoj',
'irvskoga' => 'irvskoga',
'irvskog' => 'irvskog',
'irvsko' => 'irvsko',
'irvskim' => 'irvskim',
'irvskih' => 'irvskih',
'irvski' => 'irvski',
'irvske' => 'irvske',
'irvska' => 'irvska',
'irvlyu' => 'irvlyu',
'irvlyima' => 'irvlyima',
'irvlyem' => 'irvlyem',
'irvlye' => 'irvlye',
'irvlyanku' => 'irvlyanku',
'irvlyankom' => 'irvlyankom',
'irvlyanko' => 'irvlyanko',
'irvlyanke' => 'irvlyanke',
'irvlyankama' => 'irvlyankama',
'irvlyanka' => 'irvlyanka',
'irvlyanci' => 'irvlyanci',
'irvlyanaka' => 'irvlyanaka',
'irvlya' => 'irvlya',
'irvku' => 'irvku',
'irvkom' => 'irvkom',
'irvko' => 'irvko',
'irvke' => 'irvke',
'irvkama' => 'irvkama',
'irvka' => 'irvka',
'irvi' => 'irvi',
'irve' => 'irve',
'irvci' => 'irvci',
'irvcetu' => 'irvcetu',
'irvcetom' => 'irvcetom',
'irvceta' => 'irvceta',
'irvce' => 'irvce',
'irvcadima' => 'irvcadima',
'irvcadi' => 'irvcadi',
'irvcad' => 'irvcad',
'irvama' => 'irvama',
'irvalya' => 'irvalya',
'irvaka' => 'irvaka',
'iruzima' => 'iruzima',
'iruoznosxcyu' => 'iruoznosxcyu',
'iruoznostima' => 'iruoznostima',
'iruoznosti' => 'iruoznosti',
'irumu' => 'irumu',
'irumom' => 'irumom',
'irumima' => 'irumima',
'irumi' => 'irumi',
'irumentute' => 'irumentute',
'irumentumo' => 'irumentumo',
'irumentujucyi' => 'irumentujucyi',
'irumentuju' => 'irumentuju',
'irumentujte' => 'irumentujte',
'irumentujmo' => 'irumentujmo',
'irumentujete' => 'irumentujete',
'irumentujesx' => 'irumentujesx',
'irumentujemo' => 'irumentujemo',
'irumentujem' => 'irumentujem',
'irumentuje' => 'irumentuje',
'irumentuj' => 'irumentuj',
'irumentovavsxi' => 'irumentovavsxi',
'irumentovati' => 'irumentovati',
'irumentovat' => 'irumentovat',
'irumentovasxe' => 'irumentovasxe',
'irumentovaste' => 'irumentovaste',
'irumentovasmo' => 'irumentovasmo',
'irumentovao' => 'irumentovao',
'irumentovanye' => 'irumentovanye',
'irumentovano' => 'irumentovano',
'irumentovani' => 'irumentovani',
'irumentovane' => 'irumentovane',
'irumentovana' => 'irumentovana',
'irumentovan' => 'irumentovan',
'irumentovalo' => 'irumentovalo',
'irumentovali' => 'irumentovali',
'irumentovale' => 'irumentovale',
'irumentovala' => 'irumentovala',
'irumentovahu' => 'irumentovahu',
'irumentovah' => 'irumentovah',
'irumentovacyu' => 'irumentovacyu',
'irumentovacyete' => 'irumentovacyete',
'irumentovacyesx' => 'irumentovacyesx',
'irumentovacyemo' => 'irumentovacyemo',
'irumentovacye' => 'irumentovacye',
'irumentova' => 'irumentova',
'irumentiravsxi' => 'irumentiravsxi',
'irumentirati' => 'irumentirati',
'irumentirate' => 'irumentirate',
'irumentirat' => 'irumentirat',
'irumentirasxe' => 'irumentirasxe',
'irumentirasx' => 'irumentirasx',
'irumentiraste' => 'irumentiraste',
'irumentirasmo' => 'irumentirasmo',
'irumentirao' => 'irumentirao',
'irumentirano' => 'irumentirano',
'irumentirani' => 'irumentirani',
'irumentirane' => 'irumentirane',
'irumentirana' => 'irumentirana',
'irumentiran' => 'irumentiran',
'irumentiramo' => 'irumentiramo',
'irumentiram' => 'irumentiram',
'irumentiralo' => 'irumentiralo',
'irumentirali' => 'irumentirali',
'irumentirale' => 'irumentirale',
'irumentirala' => 'irumentirala',
'irumentirajucyi' => 'irumentirajucyi',
'irumentiraju' => 'irumentiraju',
'irumentirajte' => 'irumentirajte',
'irumentirajmo' => 'irumentirajmo',
'irumentiraj' => 'irumentiraj',
'irumentirahu' => 'irumentirahu',
'irumentirah' => 'irumentirah',
'irumentiracyu' => 'irumentiracyu',
'irumentiracyete' => 'irumentiracyete',
'irumentiracyesx' => 'irumentiracyesx',
'irumentiracyemo' => 'irumentiracyemo',
'irumentiracye' => 'irumentiracye',
'irumentira' => 'irumentira',
'irumentaru' => 'irumentaru',
'irumentaromu' => 'irumentaromu',
'irumentarom' => 'irumentarom',
'irumentaroj' => 'irumentaroj',
'irumentaroga' => 'irumentaroga',
'irumentarog' => 'irumentarog',
'irumentaro' => 'irumentaro',
'irumentarim' => 'irumentarim',
'irumentarih' => 'irumentarih',
'irumentari' => 'irumentari',
'irumentare' => 'irumentare',
'irumentara' => 'irumentara',
'irumentar' => 'irumentar',
'irumentalnu' => 'irumentalnu',
'irumentalnosxcyu' => 'irumentalnosxcyu',
'irumentalnostima' => 'irumentalnostima',
'irumentalnosti' => 'irumentalnosti',
'irumentalnomu' => 'irumentalnomu',
'irumentalnom' => 'irumentalnom',
'irumentalnoj' => 'irumentalnoj',
'irumentalnoga' => 'irumentalnoga',
'irumentalnog' => 'irumentalnog',
'irumentalno' => 'irumentalno',
'irumentalnim' => 'irumentalnim',
'irumentalnih' => 'irumentalnih',
'irumentalni' => 'irumentalni',
'irumentalne' => 'irumentalne',
'irumentalna' => 'irumentalna',
'irumentalistu' => 'irumentalistu',
'irumentalistom' => 'irumentalistom',
'irumentalistima' => 'irumentalistima',
'irumentalisti' => 'irumentalisti',
'irumentaliste' => 'irumentaliste',
'irumentalistama' => 'irumentalistama',
'irumentalista' => 'irumentalista',
'irumentaciju' => 'irumentaciju',
'irumentacijom' => 'irumentacijom',
'irumentacijo' => 'irumentacijo',
'irumentaciji' => 'irumentaciji',
'irumentacije' => 'irumentacije',
'irumentacijama' => 'irumentacijama',
'irumentacija' => 'irumentacija',
'irumenatu' => 'irumenatu',
'irumenatom' => 'irumenatom',
'irumenatima' => 'irumenatima',
'irumenati' => 'irumenati',
'irumenate' => 'irumenate',
'irumenata' => 'irumenata',
'irumenat' => 'irumenat',
'irume' => 'irume',
'iruma' => 'iruma',
'irum' => 'irum',
'irulyeno' => 'irulyeno',
'irulyeni' => 'irulyeni',
'irulyene' => 'irulyene',
'irulyena' => 'irulyena',
'irulyen' => 'irulyen',
'irulte' => 'irulte',
'irulmo' => 'irulmo',
'irulivsxi' => 'irulivsxi',
'iruliti' => 'iruliti',
'irulite' => 'irulite',
'irulit' => 'irulit',
'irulisxe' => 'irulisxe',
'irulisx' => 'irulisx',
'iruliste' => 'iruliste',
'irulismo' => 'irulismo',
'irulio' => 'irulio',
'irulimo' => 'irulimo',
'irulim' => 'irulim',
'irulilo' => 'irulilo',
'irulili' => 'irulili',
'irulile' => 'irulile',
'irulila' => 'irulila',
'irulih' => 'irulih',
'irulicyu' => 'irulicyu',
'irulicyete' => 'irulicyete',
'irulicyesx' => 'irulicyesx',
'irulicyemo' => 'irulicyemo',
'irulicye' => 'irulicye',
'iruli' => 'iruli',
'irule' => 'irule',
'irul' => 'irul',
'irukturu' => 'irukturu',
'irukturom' => 'irukturom',
'irukturo' => 'irukturo',
'irukturi' => 'irukturi',
'irukture' => 'irukture',
'irukturama' => 'irukturama',
'iruktura' => 'iruktura',
'iruktorsku' => 'iruktorsku',
'iruktorskomu' => 'iruktorskomu',
'iruktorskom' => 'iruktorskom',
'iruktorskoj' => 'iruktorskoj',
'iruktorskoga' => 'iruktorskoga',
'iruktorskog' => 'iruktorskog',
'iruktorsko' => 'iruktorsko',
'iruktorskim' => 'iruktorskim',
'iruktorskih' => 'iruktorskih',
'iruktorski' => 'iruktorski',
'iruktorske' => 'iruktorske',
'iruktorska' => 'iruktorska',
'iruktorku' => 'iruktorku',
'iruktorkom' => 'iruktorkom',
'iruktorko' => 'iruktorko',
'iruktorke' => 'iruktorke',
'iruktorkama' => 'iruktorkama',
'iruktorka' => 'iruktorka',
'iruktoricu' => 'iruktoricu',
'iruktoricom' => 'iruktoricom',
'iruktorico' => 'iruktorico',
'iruktorici' => 'iruktorici',
'iruktorice' => 'iruktorice',
'iruktoricama' => 'iruktoricama',
'iruktorica' => 'iruktorica',
'iruktorci' => 'iruktorci',
'iruktoraka' => 'iruktoraka',
'iruktivnosxcyu' => 'iruktivnosxcyu',
'iruktivnostima' => 'iruktivnostima',
'iruktivnosti' => 'iruktivnosti',
'iruktivno' => 'iruktivno',
'iruktivnije' => '',
'iruktivizmu' => 'iruktivizmu',
'iruktivizmom' => 'iruktivizmom',
'iruktivizmima' => 'iruktivizmima',
'iruktivizmi' => 'iruktivizmi',
'iruktivizme' => 'iruktivizme',
'iruktivizma' => 'iruktivizma',
'iruktivizama' => 'iruktivizama',
'iruktivizam' => 'iruktivizam',
'irukcionu' => 'irukcionu',
'irukcionomu' => 'irukcionomu',
'irukcionom' => 'irukcionom',
'irukcionoj' => 'irukcionoj',
'irukcionoga' => 'irukcionoga',
'irukcionog' => 'irukcionog',
'irukciono' => 'irukciono',
'irukcionim' => 'irukcionim',
'irukcionih' => 'irukcionih',
'irukcioni' => 'irukcioni',
'irukcione' => 'irukcione',
'irukciona' => 'irukciona',
'irukcijsku' => 'irukcijsku',
'irukcijskomu' => 'irukcijskomu',
'irukcijskom' => 'irukcijskom',
'irukcijskoj' => 'irukcijskoj',
'irukcijskoga' => 'irukcijskoga',
'irukcijskog' => 'irukcijskog',
'irukcijsko' => 'irukcijsko',
'irukcijskim' => 'irukcijskim',
'irukcijskih' => 'irukcijskih',
'irukcijski' => 'irukcijski',
'irukcijske' => 'irukcijske',
'irukcijska' => 'irukcijska',
'irujom' => 'irujom',
'irujo' => 'irujo',
'irujisx' => 'irujisx',
'irujim' => 'irujim',
'irujavsxi' => 'irujavsxi',
'irujati' => 'irujati',
'irujat' => 'irujat',
'irujasxe' => 'irujasxe',
'irujaste' => 'irujaste',
'irujasmo' => 'irujasmo',
'irujao' => 'irujao',
'irujano' => 'irujano',
'irujani' => 'irujani',
'irujane' => 'irujane',
'irujana' => 'irujana',
'irujan' => 'irujan',
'irujama' => 'irujama',
'irujalo' => 'irujalo',
'irujali' => 'irujali',
'irujale' => 'irujale',
'irujala' => 'irujala',
'irujah' => 'irujah',
'irujacyu' => 'irujacyu',
'irujacyete' => 'irujacyete',
'irujacyesx' => 'irujacyesx',
'irujacyemo' => 'irujacyemo',
'irujacye' => 'irujacye',
'iruguju' => 'iruguju',
'irugujite' => 'irugujite',
'irugujimo' => 'irugujimo',
'iruguji' => 'iruguji',
'irugujete' => 'irugujete',
'irugujesx' => 'irugujesx',
'irugujemo' => 'irugujemo',
'irugujem' => 'irugujem',
'iruguje' => 'iruguje',
'irugivavsxi' => 'irugivavsxi',
'irugivati' => 'irugivati',
'irugivat' => 'irugivat',
'irugivasxe' => 'irugivasxe',
'irugivaste' => 'irugivaste',
'irugivasmo' => 'irugivasmo',
'irugivao' => 'irugivao',
'irugivano' => 'irugivano',
'irugivani' => 'irugivani',
'irugivane' => 'irugivane',
'irugivana' => 'irugivana',
'irugivan' => 'irugivan',
'irugivalo' => 'irugivalo',
'irugivali' => 'irugivali',
'irugivale' => 'irugivale',
'irugivala' => 'irugivala',
'irugivahu' => 'irugivahu',
'irugivah' => 'irugivah',
'irugivacyu' => 'irugivacyu',
'irugivacyete' => 'irugivacyete',
'irugivacyesx' => 'irugivacyesx',
'irugivacyemo' => 'irugivacyemo',
'irugivacye' => 'irugivacye',
'irugiva' => 'irugiva',
'irugasxu' => 'irugasxu',
'irugasxom' => 'irugasxom',
'irugasxima' => 'irugasxima',
'irugasxi' => 'irugasxi',
'irugasxa' => 'irugasxa',
'irugaru' => 'irugaru',
'irugarom' => 'irugarom',
'irugarima' => 'irugarima',
'irugari' => 'irugari',
'irugare' => 'irugare',
'irugara' => 'irugara',
'irugar' => 'irugar',
'iruganye' => 'iruganye',
'irug' => 'irug',
'iruentnu' => 'iruentnu',
'iruentnomu' => 'iruentnomu',
'iruentnom' => 'iruentnom',
'iruentnoj' => 'iruentnoj',
'iruentnoga' => 'iruentnoga',
'iruentnog' => 'iruentnog',
'iruentno' => 'iruentno',
'iruentnim' => 'iruentnim',
'iruentnih' => 'iruentnih',
'iruentni' => 'iruentni',
'iruentne' => 'iruentne',
'iruentna' => 'iruentna',
'irucyi' => '',
'irucxnosxcyu' => 'irucxnosxcyu',
'irucxnostima' => 'irucxnostima',
'irucxnosti' => 'irucxnosti',
'irucxenyu' => 'irucxenyu',
'irucxenyima' => 'irucxenyima',
'irucxenyem' => 'irucxenyem',
'irucxenye' => 'irucxenye',
'irucxenya' => 'irucxenya',
'irucxavate' => 'irucxavate',
'irucxavasx' => 'irucxavasx',
'irucxavanyu' => 'irucxavanyu',
'irucxavanyima' => 'irucxavanyima',
'irucxavanyem' => 'irucxavanyem',
'irucxavanye' => 'irucxavanye',
'irucxavanya' => 'irucxavanya',
'irucxavamo' => 'irucxavamo',
'irucxavam' => 'irucxavam',
'irucxavaju' => 'irucxavaju',
'irucxavajte' => 'irucxavajte',
'irucxavajmo' => 'irucxavajmo',
'irucxavaj' => 'irucxavaj',
'iruckavsxi' => 'iruckavsxi',
'iruckati' => 'iruckati',
'iruckate' => 'iruckate',
'iruckat' => 'iruckat',
'iruckasxe' => 'iruckasxe',
'iruckasx' => 'iruckasx',
'iruckaste' => 'iruckaste',
'iruckasmo' => 'iruckasmo',
'iruckao' => 'iruckao',
'iruckano' => 'iruckano',
'iruckani' => 'iruckani',
'iruckane' => 'iruckane',
'iruckana' => 'iruckana',
'iruckan' => 'iruckan',
'iruckamo' => 'iruckamo',
'iruckam' => 'iruckam',
'iruckalo' => 'iruckalo',
'iruckali' => 'iruckali',
'iruckale' => 'iruckale',
'iruckala' => 'iruckala',
'iruckaju' => 'iruckaju',
'iruckajte' => 'iruckajte',
'iruckajmo' => 'iruckajmo',
'iruckaj' => 'iruckaj',
'iruckah' => 'iruckah',
'iruckacyu' => 'iruckacyu',
'iruckacyete' => 'iruckacyete',
'iruckacyesx' => 'iruckacyesx',
'iruckacyemo' => 'iruckacyemo',
'iruckacye' => 'iruckacye',
'irucka' => 'irucka',
'irubte' => 'irubte',
'irubmo' => 'irubmo',
'irublyuju' => 'irublyuju',
'irublyujite' => 'irublyujite',
'irublyujimo' => 'irublyujimo',
'irublyuji' => 'irublyuji',
'irublyujete' => 'irublyujete',
'irublyujesx' => 'irublyujesx',
'irublyujemo' => 'irublyujemo',
'irublyujem' => 'irublyujem',
'irublyuje' => 'irublyuje',
'irublyivavsxi' => 'irublyivavsxi',
'irublyivati' => 'irublyivati',
'irublyivat' => 'irublyivat',
'irublyivasxe' => 'irublyivasxe',
'irublyivaste' => 'irublyivaste',
'irublyivasmo' => 'irublyivasmo',
'irublyivao' => 'irublyivao',
'irublyivano' => 'irublyivano',
'irublyivani' => 'irublyivani',
'irublyivane' => 'irublyivane',
'irublyivana' => 'irublyivana',
'irublyivan' => 'irublyivan',
'irublyivalo' => 'irublyivalo',
'irublyivali' => 'irublyivali',
'irublyivale' => 'irublyivale',
'irublyivala' => 'irublyivala',
'irublyivahu' => 'irublyivahu',
'irublyivah' => 'irublyivah',
'irublyivacyu' => 'irublyivacyu',
'irublyivacyete' => 'irublyivacyete',
'irublyivacyesx' => 'irublyivacyesx',
'irublyivacyemo' => 'irublyivacyemo',
'irublyivacye' => 'irublyivacye',
'irublyiva' => 'irublyiva',
'irublyeno' => 'irublyeno',
'irublyeni' => 'irublyeni',
'irublyene' => 'irublyene',
'irublyena' => 'irublyena',
'irublyen' => 'irublyen',
'irubivsxi' => 'irubivsxi',
'irubiti' => 'irubiti',
'irubite' => 'irubite',
'irubit' => 'irubit',
'irubisxe' => 'irubisxe',
'irubisx' => 'irubisx',
'irubiste' => 'irubiste',
'irubismo' => 'irubismo',
'irubio' => 'irubio',
'irubimo' => 'irubimo',
'irubim' => 'irubim',
'irubilo' => 'irubilo',
'irubili' => 'irubili',
'irubile' => 'irubile',
'irubila' => 'irubila',
'irubih' => 'irubih',
'irubicyu' => 'irubicyu',
'irubicyete' => 'irubicyete',
'irubicyesx' => 'irubicyesx',
'irubicyemo' => 'irubicyemo',
'irubicye' => 'irubicye',
'irubi' => 'irubi',
'irube' => 'irube',
'irub' => 'irub',
'irualnu' => 'irualnu',
'irualnomu' => 'irualnomu',
'irualnom' => 'irualnom',
'irualnoj' => 'irualnoj',
'irualnoga' => 'irualnoga',
'irualnog' => 'irualnog',
'irualno' => 'irualno',
'irualnim' => 'irualnim',
'irualnih' => 'irualnih',
'irualni' => 'irualni',
'irualne' => 'irualne',
'irualna' => 'irualna',
'iruaciju' => 'iruaciju',
'iruacijom' => 'iruacijom',
'iruacijo' => 'iruacijo',
'iruaciji' => 'iruaciji',
'iruacije' => 'iruacije',
'iruacijama' => 'iruacijama',
'iruacija' => 'iruacija',
'irtosxcyu' => 'irtosxcyu',
'irtostima' => 'irtostima',
'irtosti' => 'irtosti',
'irtlyavsxi' => 'irtlyavsxi',
'irtlyati' => 'irtlyati',
'irtlyate' => 'irtlyate',
'irtlyat' => 'irtlyat',
'irtlyasxe' => 'irtlyasxe',
'irtlyasx' => 'irtlyasx',
'irtlyaste' => 'irtlyaste',
'irtlyasmo' => 'irtlyasmo',
'irtlyao' => 'irtlyao',
'irtlyano' => 'irtlyano',
'irtlyani' => 'irtlyani',
'irtlyane' => 'irtlyane',
'irtlyana' => 'irtlyana',
'irtlyan' => 'irtlyan',
'irtlyamo' => 'irtlyamo',
'irtlyam' => 'irtlyam',
'irtlyalo' => 'irtlyalo',
'irtlyali' => 'irtlyali',
'irtlyale' => 'irtlyale',
'irtlyala' => 'irtlyala',
'irtlyaju' => 'irtlyaju',
'irtlyajte' => 'irtlyajte',
'irtlyajmo' => 'irtlyajmo',
'irtlyaj' => 'irtlyaj',
'irtlyah' => 'irtlyah',
'irtlyacyu' => 'irtlyacyu',
'irtlyacyete' => 'irtlyacyete',
'irtlyacyesx' => 'irtlyacyesx',
'irtlyacyemo' => 'irtlyacyemo',
'irtlyacye' => 'irtlyacye',
'irtlya' => 'irtlya',
'irsxe' => 'irsxe',
'irste' => 'irste',
'irsmo' => 'irsmo',
'irpte' => 'irpte',
'irpmo' => 'irpmo',
'irplyeno' => 'irplyeno',
'irplyeni' => 'irplyeni',
'irplyene' => 'irplyene',
'irplyena' => 'irplyena',
'irplyen' => 'irplyen',
'irpjevsxi' => 'irpjevsxi',
'irpjeti' => 'irpjeti',
'irpjet' => 'irpjet',
'irpjesxe' => 'irpjesxe',
'irpjeste' => 'irpjeste',
'irpjesmo' => 'irpjesmo',
'irpjelo' => 'irpjelo',
'irpjeli' => 'irpjeli',
'irpjele' => 'irpjele',
'irpjela' => 'irpjela',
'irpjeh' => 'irpjeh',
'irpjecyu' => 'irpjecyu',
'irpjecyete' => 'irpjecyete',
'irpjecyesx' => 'irpjecyesx',
'irpjecyemo' => 'irpjecyemo',
'irpjecye' => 'irpjecye',
'irpje' => 'irpje',
'irpite' => 'irpite',
'irpisx' => 'irpisx',
'irpio' => 'irpio',
'irpimo' => 'irpimo',
'irpim' => 'irpim',
'irpi' => 'irpi',
'irpevsxi' => 'irpevsxi',
'irpeti' => 'irpeti',
'irpet' => 'irpet',
'irpesxe' => 'irpesxe',
'irpeste' => 'irpeste',
'irpesmo' => 'irpesmo',
'irpeo' => 'irpeo',
'irpelo' => 'irpelo',
'irpeli' => 'irpeli',
'irpele' => 'irpele',
'irpela' => 'irpela',
'irpeh' => 'irpeh',
'irpecyu' => 'irpecyu',
'irpecyete' => 'irpecyete',
'irpecyesx' => 'irpecyesx',
'irpecyemo' => 'irpecyemo',
'irpecye' => 'irpecye',
'irpe' => 'irpe',
'irp' => 'irp',
'irozxnosxcyu' => 'irozxnosxcyu',
'irozxnostima' => 'irozxnostima',
'irozxnosti' => 'irozxnosti',
'iroverziju' => 'iroverziju',
'iroverzijom' => 'iroverzijom',
'iroverzijo' => 'iroverzijo',
'iroverziji' => 'iroverziji',
'iroverzije' => 'iroverzije',
'iroverzijama' => 'iroverzijama',
'iroverzija' => 'iroverzija',
'irovavavsxi' => 'irovavavsxi',
'irovavati' => 'irovavati',
'irovavate' => 'irovavate',
'irovavat' => 'irovavat',
'irovavasxe' => 'irovavasxe',
'irovavasx' => 'irovavasx',
'irovavaste' => 'irovavaste',
'irovavasmo' => 'irovavasmo',
'irovavao' => 'irovavao',
'irovavano' => 'irovavano',
'irovavani' => 'irovavani',
'irovavane' => 'irovavane',
'irovavana' => 'irovavana',
'irovavan' => 'irovavan',
'irovavamo' => 'irovavamo',
'irovavam' => 'irovavam',
'irovavalo' => 'irovavalo',
'irovavali' => 'irovavali',
'irovavale' => 'irovavale',
'irovavala' => 'irovavala',
'irovavaju' => 'irovavaju',
'irovavajte' => 'irovavajte',
'irovavajmo' => 'irovavajmo',
'irovavaj' => 'irovavaj',
'irovavahu' => 'irovavahu',
'irovavah' => 'irovavah',
'irovavacyu' => 'irovavacyu',
'irovavacyete' => 'irovavacyete',
'irovavacyesx' => 'irovavacyesx',
'irovavacyemo' => 'irovavacyemo',
'irovavacye' => 'irovavacye',
'irovava' => 'irovava',
'irovanye' => 'e',
'iroumlyu' => 'iroumlyu',
'iroumlyima' => 'iroumlyima',
'iroumlyem' => 'iroumlyem',
'iroumlye' => 'iroumlye',
'iroumlya' => 'iroumlya',
'iroumalya' => 'iroumalya',
'irou' => 'u',
'irotu' => 'u',
'irotom' => 'om',
'irotima' => 'irotima',
'iroti' => 'i',
'irote' => 'e',
'irota' => 'a',
'irot' => '',
'iroom' => 'om',
'ironautu' => 'ironautu',
'ironautsku' => 'ironautsku',
'ironautskomu' => 'ironautskomu',
'ironautskom' => 'ironautskom',
'ironautskoj' => 'ironautskoj',
'ironautskoga' => 'ironautskoga',
'ironautskog' => 'ironautskog',
'ironautsko' => 'ironautsko',
'ironautskim' => 'ironautskim',
'ironautskih' => 'ironautskih',
'ironautski' => 'ironautski',
'ironautske' => 'ironautske',
'ironautska' => 'ironautska',
'ironautom' => 'ironautom',
'ironautima' => 'ironautima',
'ironautiku' => 'ironautiku',
'ironautikom' => 'ironautikom',
'ironautiko' => 'ironautiko',
'ironautike' => 'ironautike',
'ironautikama' => 'ironautikama',
'ironautika' => 'ironautika',
'ironauticxku' => 'ironauticxku',
'ironauticxkomu' => 'ironauticxkomu',
'ironauticxkom' => 'ironauticxkom',
'ironauticxkoj' => 'ironauticxkoj',
'ironauticxkoga' => 'ironauticxkoga',
'ironauticxkog' => 'ironauticxkog',
'ironauticxko' => 'ironauticxko',
'ironauticxkim' => 'ironauticxkim',
'ironauticxkih' => 'ironauticxkih',
'ironauticxki' => 'ironauticxki',
'ironauticxke' => 'ironauticxke',
'ironauticxka' => 'ironauticxka',
'ironautici' => 'ironautici',
'ironauti' => 'ironauti',
'ironaute' => 'ironaute',
'ironauta' => 'ironauta',
'ironaut' => 'ironaut',
'irolozxe' => 'irolozxe',
'irolozima' => 'irolozima',
'irolozi' => 'irolozi',
'irolosxku' => 'irolosxku',
'irolosxkomu' => 'irolosxkomu',
'irolosxkom' => 'irolosxkom',
'irolosxkoj' => 'irolosxkoj',
'irolosxkoga' => 'irolosxkoga',
'irolosxkog' => 'irolosxkog',
'irolosxko' => 'irolosxko',
'irolosxkim' => 'irolosxkim',
'irolosxkih' => 'irolosxkih',
'irolosxki' => 'irolosxki',
'irolosxke' => 'irolosxke',
'irolosxka' => 'irolosxka',
'irologu' => 'irologu',
'irologom' => 'irologom',
'irologiju' => 'u',
'irologijom' => 'om',
'irologijo' => 'o',
'irologiji' => 'i',
'irologije' => 'e',
'irologijama' => 'ama',
'irologija' => 'a',
'irologe' => 'irologe',
'irologa' => 'irologa',
'irolog' => 'irolog',
'iroku' => 'u',
'irokomu' => 'omu',
'irokom' => 'om',
'irokoj' => 'oj',
'irokoga' => 'oga',
'irokog' => 'og',
'iroko' => 'o',
'irokim' => 'im',
'irokih' => 'ih',
'iroki' => 'i',
'iroke' => 'e',
'iroka' => 'a',
'irok' => '',
'irojenosxcyu' => 'irojenosxcyu',
'irojenostima' => 'irojenostima',
'irojenosti' => 'irojenosti',
'irojbu' => 'irojbu',
'irojbom' => 'irojbom',
'irojbo' => 'irojbo',
'irojbi' => 'irojbi',
'irojbe' => 'irojbe',
'irojbama' => 'irojbama',
'irojba' => 'irojba',
'irojavanyu' => 'irojavanyu',
'irojavanyima' => 'irojavanyima',
'irojavanyem' => 'irojavanyem',
'irojavanye' => 'irojavanye',
'irojavanya' => 'irojavanya',
'irojavajucyi' => 'irojavajucyi',
'irojarsku' => 'irojarsku',
'irojarskomu' => 'irojarskomu',
'irojarskom' => 'irojarskom',
'irojarskoj' => 'irojarskoj',
'irojarskoga' => 'irojarskoga',
'irojarskog' => 'irojarskog',
'irojarsko' => 'irojarsko',
'irojarskim' => 'irojarskim',
'irojarskih' => 'irojarskih',
'irojarski' => 'irojarski',
'irojarske' => 'irojarske',
'irojarska' => 'irojarska',
'irojaba' => 'irojaba',
'irointestinalnu' => 'irointestinalnu',
'irointestinalnomu' => 'irointestinalnomu',
'irointestinalnom' => 'irointestinalnom',
'irointestinalnoj' => 'irointestinalnoj',
'irointestinalnoga' => 'irointestinalnoga',
'irointestinalnog' => 'irointestinalnog',
'irointestinalno' => 'irointestinalno',
'irointestinalnim' => 'irointestinalnim',
'irointestinalnih' => 'irointestinalnih',
'irointestinalni' => 'irointestinalni',
'irointestinalne' => 'irointestinalne',
'irointestinalna' => 'irointestinalna',
'iroima' => 'ima',
'iroi' => 'i',
'irogotu' => 'irogotu',
'irogotom' => 'irogotom',
'irogotima' => 'irogotima',
'irogoti' => 'irogoti',
'irogote' => 'irogote',
'irogota' => 'irogota',
'irogot' => 'irogot',
'irofo' => 'irofo',
'irofiziku' => 'irofiziku',
'irofizikom' => 'irofizikom',
'irofiziko' => 'irofiziko',
'irofizike' => 'irofizike',
'irofizikama' => 'irofizikama',
'irofizika' => 'irofizika',
'irofizicxku' => 'irofizicxku',
'irofizicxkomu' => 'irofizicxkomu',
'irofizicxkom' => 'irofizicxkom',
'irofizicxkoj' => 'irofizicxkoj',
'irofizicxkoga' => 'irofizicxkoga',
'irofizicxkog' => 'irofizicxkog',
'irofizicxko' => 'irofizicxko',
'irofizicxkim' => 'irofizicxkim',
'irofizicxkih' => 'irofizicxkih',
'irofizicxki' => 'irofizicxki',
'irofizicxke' => 'irofizicxke',
'irofizicxka' => 'irofizicxka',
'irofizicxaru' => 'irofizicxaru',
'irofizicxarom' => 'irofizicxarom',
'irofizicxarima' => 'irofizicxarima',
'irofizicxari' => 'irofizicxari',
'irofizicxare' => 'irofizicxare',
'irofizicxara' => 'irofizicxara',
'irofizicxar' => 'irofizicxar',
'irofizici' => 'irofizici',
'irofiravsxi' => 'irofiravsxi',
'irofirati' => 'irofirati',
'irofirate' => 'irofirate',
'irofirat' => 'irofirat',
'irofirasxe' => 'irofirasxe',
'irofirasx' => 'irofirasx',
'irofiraste' => 'irofiraste',
'irofirasmo' => 'irofirasmo',
'irofirao' => 'irofirao',
'irofirano' => 'irofirano',
'irofirani' => 'irofirani',
'irofirane' => 'irofirane',
'irofirana' => 'irofirana',
'irofiran' => 'irofiran',
'irofiramo' => 'irofiramo',
'irofiram' => 'irofiram',
'irofiralo' => 'irofiralo',
'irofirali' => 'irofirali',
'irofirale' => 'irofirale',
'irofirala' => 'irofirala',
'irofirajucyi' => 'irofirajucyi',
'irofiraju' => 'irofiraju',
'irofirajte' => 'irofirajte',
'irofirajmo' => 'irofirajmo',
'irofiraj' => 'irofiraj',
'irofirahu' => 'irofirahu',
'irofirah' => 'irofirah',
'irofiracyu' => 'irofiracyu',
'irofiracyete' => 'irofiracyete',
'irofiracyesx' => 'irofiracyesx',
'irofiracyemo' => 'irofiracyemo',
'irofiracye' => 'irofiracye',
'irofira' => 'irofira',
'irofima' => 'irofima',
'irofiju' => 'irofiju',
'irofijom' => 'irofijom',
'irofiji' => 'irofiji',
'irofije' => 'irofije',
'irofijama' => 'irofijama',
'irofija' => 'irofija',
'irofama' => 'irofama',
'irof' => 'irof',
'iroe' => 'e',
'iroa' => 'a',
'irmu' => 'mu',
'irmom' => 'mom',
'irmku' => 'irmku',
'irmkom' => 'irmkom',
'irmko' => 'irmko',
'irmke' => 'irmke',
'irmkama' => 'irmkama',
'irmka' => 'irmka',
'irmi' => 'mi',
'irme' => 'me',
'irmci' => 'irmci',
'irmama' => 'mama',
'irmaka' => 'irmaka',
'irma' => 'ma',
'irlyaninu' => 'irlyaninu',
'irlyaninom' => 'irlyaninom',
'irlyanine' => 'irlyanine',
'irlyanina' => 'irlyanina',
'irlyanin' => 'irlyanin',
'irlo' => 'irlo',
'irli' => 'irli',
'irle' => 'irle',
'irla' => 'irla',
'irknuvsxi' => 'irknuvsxi',
'irknuto' => 'irknuto',
'irknuti' => 'irknuti',
'irknute' => 'irknute',
'irknuta' => 'irknuta',
'irknut' => 'irknut',
'irknusxe' => 'irknusxe',
'irknuste' => 'irknuste',
'irknusmo' => 'irknusmo',
'irknuo' => 'irknuo',
'irknulo' => 'irknulo',
'irknuli' => 'irknuli',
'irknule' => 'irknule',
'irknula' => 'irknula',
'irknuh' => 'irknuh',
'irknucyu' => 'irknucyu',
'irknucyete' => 'irknucyete',
'irknucyesx' => 'irknucyesx',
'irknucyemo' => 'irknucyemo',
'irknucye' => 'irknucye',
'irknu' => 'irknu',
'irknite' => 'irknite',
'irknimo' => 'irknimo',
'irkni' => 'irkni',
'irknete' => 'irknete',
'irknesx' => 'irknesx',
'irknemo' => 'irknemo',
'irknem' => 'irknem',
'irkne' => 'irkne',
'irizajucyi' => 'irizajucyi',
'irivsxi' => 'ivsxi',
'irivavsxi' => 'ivavsxi',
'irivati' => 'ivati',
'irivat' => 'ivat',
'irivasxe' => 'ivasxe',
'irivaste' => 'ivaste',
'irivasmo' => 'ivasmo',
'irivao' => 'ivao',
'irivano' => 'ivano',
'irivani' => 'ivani',
'irivane' => 'ivane',
'irivana' => 'ivana',
'irivan' => 'ivan',
'irivalo' => 'ivalo',
'irivali' => 'ivali',
'irivale' => 'ivale',
'irivala' => 'ivala',
'irivahu' => 'ivahu',
'irivah' => 'ivah',
'irivacyu' => 'ivacyu',
'irivacyete' => 'ivacyete',
'irivacyesx' => 'ivacyesx',
'irivacyemo' => 'ivacyemo',
'irivacye' => 'ivacye',
'iriva' => 'iva',
'iritisu' => 'iritisu',
'iritisom' => 'iritisom',
'iritisima' => 'iritisima',
'iritisi' => 'iritisi',
'iritise' => 'iritise',
'iritisa' => 'iritisa',
'iritis' => 'iritis',
'irionsku' => 'irionsku',
'irionskomu' => 'irionskomu',
'irionskom' => 'irionskom',
'irionskoj' => 'irionskoj',
'irionskoga' => 'irionskoga',
'irionskog' => 'irionskog',
'irionsko' => 'irionsko',
'irionskim' => 'irionskim',
'irionskih' => 'irionskih',
'irionski' => 'irionski',
'irionske' => 'irionske',
'irionska' => 'irionska',
'iriku' => 'ku',
'iriktu' => 'iriktu',
'iriktom' => 'iriktom',
'iriktnu' => 'iriktnu',
'iriktnomu' => 'iriktnomu',
'iriktnom' => 'iriktnom',
'iriktnoj' => 'iriktnoj',
'iriktnoga' => 'iriktnoga',
'iriktnog' => 'iriktnog',
'iriktno' => 'iriktno',
'iriktnim' => 'iriktnim',
'iriktnih' => 'iriktnih',
'iriktni' => 'iriktni',
'iriktne' => 'iriktne',
'iriktna' => 'iriktna',
'iriktima' => 'iriktima',
'irikti' => 'irikti',
'irikte' => 'irikte',
'irikta' => 'irikta',
'irikt' => 'irikt',
'irikom' => 'kom',
'iriko' => 'ko',
'irike' => 'ke',
'irikciju' => 'irikciju',
'irikcijom' => 'irikcijom',
'irikcijo' => 'irikcijo',
'irikciji' => 'irikciji',
'irikcije' => 'irikcije',
'irikcijama' => 'irikcijama',
'irikcija' => 'irikcija',
'irikama' => 'kama',
'irika' => 'ka',
'irijima' => 'ijima',
'irijezxnyeno' => 'irijezxnyeno',
'irijezxnyeni' => 'irijezxnyeni',
'irijezxnyene' => 'irijezxnyene',
'irijezxnyena' => 'irijezxnyena',
'irijezxnyen' => 'irijezxnyen',
'irijeznte' => 'irijeznte',
'irijeznmo' => 'irijeznmo',
'irijeznivsxi' => 'irijeznivsxi',
'irijezniti' => 'irijezniti',
'irijeznite' => 'irijeznite',
'irijeznit' => 'irijeznit',
'irijeznisxe' => 'irijeznisxe',
'irijeznisx' => 'irijeznisx',
'irijezniste' => 'irijezniste',
'irijeznismo' => 'irijeznismo',
'irijeznio' => 'irijeznio',
'irijeznimo' => 'irijeznimo',
'irijeznim' => 'irijeznim',
'irijeznilo' => 'irijeznilo',
'irijeznili' => 'irijeznili',
'irijeznile' => 'irijeznile',
'irijeznila' => 'irijeznila',
'irijeznih' => 'irijeznih',
'irijeznicyu' => 'irijeznicyu',
'irijeznicyete' => 'irijeznicyete',
'irijeznicyesx' => 'irijeznicyesx',
'irijeznicyemo' => 'irijeznicyemo',
'irijeznicye' => 'irijeznicye',
'irijezni' => 'irijezni',
'irijezne' => 'irijezne',
'irijezn' => 'irijezn',
'irijesxte' => 'irijesxte',
'irijesxmo' => 'irijesxmo',
'irijesxite' => 'irijesxite',
'irijesxisx' => 'irijesxisx',
'irijesximo' => 'irijesximo',
'irijesxim' => 'irijesxim',
'irijesxicxte' => 'irijesxicxte',
'irijesxicxmo' => 'irijesxicxmo',
'irijesxicxite' => 'irijesxicxite',
'irijesxicxisx' => 'irijesxicxisx',
'irijesxicximo' => 'irijesxicximo',
'irijesxicxim' => 'irijesxicxim',
'irijesxicxi' => 'irijesxicxi',
'irijesxicxeno' => 'irijesxicxeno',
'irijesxicxeni' => 'irijesxicxeni',
'irijesxicxene' => 'irijesxicxene',
'irijesxicxena' => 'irijesxicxena',
'irijesxicxen' => 'irijesxicxen',
'irijesxicxe' => 'irijesxicxe',
'irijesxicx' => 'irijesxicx',
'irijesxeno' => 'irijesxeno',
'irijesxeni' => 'irijesxeni',
'irijesxene' => 'irijesxene',
'irijesxena' => 'irijesxena',
'irijesxen' => 'irijesxen',
'irijesx' => 'irijesx',
'irijanku' => 'irijanku',
'irijankom' => 'irijankom',
'irijanko' => 'irijanko',
'irijanke' => 'irijanke',
'irijankama' => 'irijankama',
'irijanka' => 'irijanka',
'irijanci' => 'irijanci',
'irijanaka' => 'irijanaka',
'irijalizute' => 'irijalizute',
'irijalizumo' => 'irijalizumo',
'irijalizujucyi' => 'irijalizujucyi',
'irijalizuju' => 'irijalizuju',
'irijalizujte' => 'irijalizujte',
'irijalizujmo' => 'irijalizujmo',
'irijalizujete' => 'irijalizujete',
'irijalizujesx' => 'irijalizujesx',
'irijalizujemo' => 'irijalizujemo',
'irijalizujem' => 'irijalizujem',
'irijalizuje' => 'irijalizuje',
'irijalizuj' => 'irijalizuj',
'irijalizu' => 'irijalizu',
'irijalizovavsxi' => 'irijalizovavsxi',
'irijalizovati' => 'irijalizovati',
'irijalizovat' => 'irijalizovat',
'irijalizovasxe' => 'irijalizovasxe',
'irijalizovaste' => 'irijalizovaste',
'irijalizovasmo' => 'irijalizovasmo',
'irijalizovao' => 'irijalizovao',
'irijalizovano' => 'irijalizovano',
'irijalizovani' => 'irijalizovani',
'irijalizovane' => 'irijalizovane',
'irijalizovana' => 'irijalizovana',
'irijalizovan' => 'irijalizovan',
'irijalizovalo' => 'irijalizovalo',
'irijalizovali' => 'irijalizovali',
'irijalizovale' => 'irijalizovale',
'irijalizovala' => 'irijalizovala',
'irijalizovahu' => 'irijalizovahu',
'irijalizovah' => 'irijalizovah',
'irijalizovacyu' => 'irijalizovacyu',
'irijalizovacyete' => 'irijalizovacyete',
'irijalizovacyesx' => 'irijalizovacyesx',
'irijalizovacyemo' => 'irijalizovacyemo',
'irijalizovacye' => 'irijalizovacye',
'irijalizova' => 'irijalizova',
'irijaliziravsxi' => 'irijaliziravsxi',
'irijalizirati' => 'irijalizirati',
'irijalizirate' => 'irijalizirate',
'irijalizirat' => 'irijalizirat',
'irijalizirasxe' => 'irijalizirasxe',
'irijalizirasx' => 'irijalizirasx',
'irijaliziraste' => 'irijaliziraste',
'irijalizirasmo' => 'irijalizirasmo',
'irijalizirao' => 'irijalizirao',
'irijalizirano' => 'irijalizirano',
'irijalizirani' => 'irijalizirani',
'irijalizirane' => 'irijalizirane',
'irijalizirana' => 'irijalizirana',
'irijaliziran' => 'irijaliziran',
'irijaliziramo' => 'irijaliziramo',
'irijaliziram' => 'irijaliziram',
'irijaliziralo' => 'irijaliziralo',
'irijalizirali' => 'irijalizirali',
'irijalizirale' => 'irijalizirale',
'irijalizirala' => 'irijalizirala',
'irijalizirajucyi' => 'irijalizirajucyi',
'irijaliziraju' => 'irijaliziraju',
'irijalizirajte' => 'irijalizirajte',
'irijalizirajmo' => 'irijalizirajmo',
'irijaliziraj' => 'irijaliziraj',
'irijalizirahu' => 'irijalizirahu',
'irijalizirah' => 'irijalizirah',
'irijaliziracyu' => 'irijaliziracyu',
'irijaliziracyete' => 'irijaliziracyete',
'irijaliziracyesx' => 'irijaliziracyesx',
'irijaliziracyemo' => 'irijaliziracyemo',
'irijaliziracye' => 'irijaliziracye',
'irijalizira' => 'irijalizira',
'irijalizaciju' => 'irijalizaciju',
'irijalizacijom' => 'irijalizacijom',
'irijalizacijo' => 'irijalizacijo',
'irijalizaciji' => 'irijalizaciji',
'irijalizacije' => 'irijalizacije',
'irijalizacijama' => 'irijalizacijama',
'irijalizacija' => 'irijalizacija',
'irigama' => 'irigama',
'irifikaciju' => 'irifikaciju',
'irifikacijom' => 'irifikacijom',
'irifikacijo' => 'irifikacijo',
'irifikaciji' => 'irifikaciji',
'irifikacije' => 'irifikacije',
'irifikacijama' => 'irifikacijama',
'irifikacija' => 'irifikacija',
'iricyom' => 'om',
'iricyima' => 'ima',
'iricya' => 'a',
'iricxku' => 'u',
'iricxkomu' => 'omu',
'iricxkom' => 'om',
'iricxkoj' => 'oj',
'iricxkoga' => 'oga',
'iricxkog' => 'og',
'iricxko' => 'o',
'iricxkim' => 'im',
'iricxkih' => 'ih',
'iricxki' => 'i',
'iricxke' => 'e',
'iricxka' => 'a',
'iricu' => 'u',
'iricom' => 'om',
'irico' => 'o',
'iricificiravsxi' => 'iricificiravsxi',
'iricificirati' => 'iricificirati',
'iricificirate' => 'iricificirate',
'iricificirat' => 'iricificirat',
'iricificirasxe' => 'iricificirasxe',
'iricificirasx' => 'iricificirasx',
'iricificiraste' => 'iricificiraste',
'iricificirasmo' => 'iricificirasmo',
'iricificirao' => 'iricificirao',
'iricificirano' => 'iricificirano',
'iricificirani' => 'iricificirani',
'iricificirane' => 'iricificirane',
'iricificirana' => 'iricificirana',
'iricificiran' => 'iricificiran',
'iricificiramo' => 'iricificiramo',
'iricificiram' => 'iricificiram',
'iricificiralo' => 'iricificiralo',
'iricificirali' => 'iricificirali',
'iricificirale' => 'iricificirale',
'iricificirala' => 'iricificirala',
'iricificirajucyi' => 'iricificirajucyi',
'iricificiraju' => 'iricificiraju',
'iricificirajte' => 'iricificirajte',
'iricificirajmo' => 'iricificirajmo',
'iricificiraj' => 'iricificiraj',
'iricificirahu' => 'iricificirahu',
'iricificirah' => 'iricificirah',
'iricificiracyu' => 'iricificiracyu',
'iricificiracyete' => 'iricificiracyete',
'iricificiracyesx' => 'iricificiracyesx',
'iricificiracyemo' => 'iricificiracyemo',
'iricificiracye' => 'iricificiracye',
'iricificira' => 'iricificira',
'irice' => 'e',
'iricama' => 'ama',
'irica' => 'a',
'iribuisxucyi' => 'iribuisxucyi',
'iribuisxu' => 'iribuisxu',
'iribuisxte' => 'iribuisxte',
'iribuisxmo' => 'iribuisxmo',
'iribuisxete' => 'iribuisxete',
'iribuisxesx' => 'iribuisxesx',
'iribuisxeno' => 'iribuisxeno',
'iribuisxeni' => 'iribuisxeni',
'iribuisxene' => 'iribuisxene',
'iribuisxena' => 'iribuisxena',
'iribuisxen' => 'iribuisxen',
'iribuisxemo' => 'iribuisxemo',
'iribuisxem' => 'iribuisxem',
'iribuisxe' => 'iribuisxe',
'iribuisx' => 'iribuisx',
'iribuisavsxi' => 'iribuisavsxi',
'iribuisati' => 'iribuisati',
'iribuisat' => 'iribuisat',
'iribuisasxe' => 'iribuisasxe',
'iribuisaste' => 'iribuisaste',
'iribuisasmo' => 'iribuisasmo',
'iribuisao' => 'iribuisao',
'iribuisalo' => 'iribuisalo',
'iribuisali' => 'iribuisali',
'iribuisale' => 'iribuisale',
'iribuisala' => 'iribuisala',
'iribuisahu' => 'iribuisahu',
'iribuisah' => 'iribuisah',
'iribuisacyu' => 'iribuisacyu',
'iribuisacyete' => 'iribuisacyete',
'iribuisacyesx' => 'iribuisacyesx',
'iribuisacyemo' => 'iribuisacyemo',
'iribuisacye' => 'iribuisacye',
'iribuiravsxi' => 'iribuiravsxi',
'iribuirati' => 'iribuirati',
'iribuirate' => 'iribuirate',
'iribuirat' => 'iribuirat',
'iribuirasxe' => 'iribuirasxe',
'iribuirasx' => 'iribuirasx',
'iribuiraste' => 'iribuiraste',
'iribuirasmo' => 'iribuirasmo',
'iribuirao' => 'iribuirao',
'iribuiranu' => 'iribuiranu',
'iribuiranomu' => 'iribuiranomu',
'iribuiranom' => 'iribuiranom',
'iribuiranoj' => 'iribuiranoj',
'iribuiranoga' => 'iribuiranoga',
'iribuiranog' => 'iribuiranog',
'iribuirano' => 'iribuirano',
'iribuiranim' => 'iribuiranim',
'iribuiranih' => 'iribuiranih',
'iribuirani' => 'iribuirani',
'iribuirane' => 'iribuirane',
'iribuirana' => 'iribuirana',
'iribuiran' => 'iribuiran',
'iribuiramo' => 'iribuiramo',
'iribuiram' => 'iribuiram',
'iribuiralo' => 'iribuiralo',
'iribuirali' => 'iribuirali',
'iribuirale' => 'iribuirale',
'iribuirala' => 'iribuirala',
'iribuirajucyi' => 'iribuirajucyi',
'iribuiraju' => 'iribuiraju',
'iribuirajte' => 'iribuirajte',
'iribuirajmo' => 'iribuirajmo',
'iribuiraj' => 'iribuiraj',
'iribuirahu' => 'iribuirahu',
'iribuirah' => 'iribuirah',
'iribuiracyu' => 'iribuiracyu',
'iribuiracyete' => 'iribuiracyete',
'iribuiracyesx' => 'iribuiracyesx',
'iribuiracyemo' => 'iribuiracyemo',
'iribuiracye' => 'iribuiracye',
'iribuira' => 'iribuira',
'iribucionu' => 'iribucionu',
'iribucionomu' => 'iribucionomu',
'iribucionom' => 'iribucionom',
'iribucionoj' => 'iribucionoj',
'iribucionoga' => 'iribucionoga',
'iribucionog' => 'iribucionog',
'iribuciono' => 'iribuciono',
'iribucionim' => 'iribucionim',
'iribucionih' => 'iribucionih',
'iribucioni' => 'iribucioni',
'iribucione' => 'iribucione',
'iribuciona' => 'iribuciona',
'iribuciju' => 'iribuciju',
'iribucijom' => 'iribucijom',
'iribucijo' => 'iribucijo',
'iribuciji' => 'iribuciji',
'iribucije' => 'iribucije',
'iribucijama' => 'iribucijama',
'iribucija' => 'iribucija',
'irh' => 'irh',
'irganosxcyu' => 'irganosxcyu',
'irganostima' => 'irganostima',
'irganosti' => 'irganosti',
'irezxnyeno' => 'irezxnyeno',
'irezxnyeni' => 'irezxnyeni',
'irezxnyene' => 'irezxnyene',
'irezxnyena' => 'irezxnyena',
'irezxnyen' => 'irezxnyen',
'irezxajivavsxi' => 'irezxajivavsxi',
'irezxajivati' => 'irezxajivati',
'irezxajivat' => 'irezxajivat',
'irezxajivasxe' => 'irezxajivasxe',
'irezxajivaste' => 'irezxajivaste',
'irezxajivasmo' => 'irezxajivasmo',
'irezxajivao' => 'irezxajivao',
'irezxajivanyuju' => 'irezxajivanyuju',
'irezxajivanyujite' => 'irezxajivanyujite',
'irezxajivanyujimo' => 'irezxajivanyujimo',
'irezxajivanyuji' => 'irezxajivanyuji',
'irezxajivanyujete' => 'irezxajivanyujete',
'irezxajivanyujesx' => 'irezxajivanyujesx',
'irezxajivanyujemo' => 'irezxajivanyujemo',
'irezxajivanyujem' => 'irezxajivanyujem',
'irezxajivanyuje' => 'irezxajivanyuje',
'irezxajivanye' => 'irezxajivanye',
'irezxajivano' => 'irezxajivano',
'irezxajivani' => 'irezxajivani',
'irezxajivane' => 'irezxajivane',
'irezxajivana' => 'irezxajivana',
'irezxajivan' => 'irezxajivan',
'irezxajivalo' => 'irezxajivalo',
'irezxajivali' => 'irezxajivali',
'irezxajivale' => 'irezxajivale',
'irezxajivala' => 'irezxajivala',
'irezxajivahu' => 'irezxajivahu',
'irezxajivah' => 'irezxajivah',
'irezxajivacyu' => 'irezxajivacyu',
'irezxajivacyete' => 'irezxajivacyete',
'irezxajivacyesx' => 'irezxajivacyesx',
'irezxajivacyemo' => 'irezxajivacyemo',
'irezxajivacye' => 'irezxajivacye',
'irezxajiva' => 'irezxajiva',
'ireznte' => 'ireznte',
'ireznmo' => 'ireznmo',
'ireznivsxi' => 'ireznivsxi',
'irezniti' => 'irezniti',
'ireznite' => 'ireznite',
'ireznit' => 'ireznit',
'ireznisxe' => 'ireznisxe',
'ireznisx' => 'ireznisx',
'irezniste' => 'irezniste',
'ireznismo' => 'ireznismo',
'ireznio' => 'ireznio',
'ireznimo' => 'ireznimo',
'ireznim' => 'ireznim',
'ireznilo' => 'ireznilo',
'ireznili' => 'ireznili',
'ireznile' => 'ireznile',
'ireznila' => 'ireznila',
'ireznih' => 'ireznih',
'ireznicyu' => 'ireznicyu',
'ireznicyete' => 'ireznicyete',
'ireznicyesx' => 'ireznicyesx',
'ireznicyemo' => 'ireznicyemo',
'ireznicye' => 'ireznicye',
'irezni' => 'irezni',
'irezne' => 'irezne',
'irezn' => 'irezn',
'irezgosxe' => 'irezgosxe',
'irezgoste' => 'irezgoste',
'irezgosmo' => 'irezgosmo',
'irezgoh' => 'irezgoh',
'irezgo' => 'irezgo',
'irezgavsxi' => 'irezgavsxi',
'iretima' => 'ima',
'iresxu' => 'iresxu',
'iresxju' => 'iresxju',
'iresxjima' => 'iresxjima',
'iresxjem' => 'iresxjem',
'iresxje' => 'iresxje',
'iresxja' => 'iresxja',
'iresxicu' => 'iresxicu',
'iresxicom' => 'iresxicom',
'iresxico' => 'iresxico',
'iresxici' => 'iresxici',
'iresxice' => 'iresxice',
'iresxicama' => 'iresxicama',
'iresxica' => 'iresxica',
'iresxete' => 'iresxete',
'iresxesx' => 'iresxesx',
'iresxenosxcyu' => 'iresxenosxcyu',
'iresxenostima' => 'iresxenostima',
'iresxenosti' => 'iresxenosti',
'iresxemo' => 'iresxemo',
'iresxem' => 'iresxem',
'iresxaja' => 'iresxaja',
'iresu' => 'iresu',
'irestantu' => 'irestantu',
'irestantom' => 'irestantom',
'irestantima' => 'irestantima',
'irestanti' => 'irestanti',
'irestante' => 'irestante',
'irestanta' => 'irestanta',
'irestant' => 'irestant',
'iressxe' => 'iressxe',
'iresosxe' => 'iresosxe',
'iresoste' => 'iresoste',
'iresosmo' => 'iresosmo',
'iresoh' => 'iresoh',
'ireslo' => 'ireslo',
'iresli' => 'iresli',
'iresle' => 'iresle',
'iresla' => 'iresla',
'iresitu' => 'iresitu',
'iresitomu' => 'iresitomu',
'iresitom' => 'iresitom',
'iresitoj' => 'iresitoj',
'iresitoga' => 'iresitoga',
'iresitog' => 'iresitog',
'iresito' => 'iresito',
'iresitim' => 'iresitim',
'iresitih' => 'iresitih',
'iresiti' => 'iresiti',
'iresita' => 'iresita',
'iresit' => 'iresit',
'iresimo' => 'iresimo',
'iresih' => 'iresih',
'iresi' => 'iresi',
'iresete' => 'iresete',
'iresesx' => 'iresesx',
'iresenya' => 'iresenya',
'ireseno' => 'ireseno',
'ireseni' => 'ireseni',
'iresene' => 'iresene',
'iresena' => 'iresena',
'iresen' => 'iresen',
'iresemo' => 'iresemo',
'iresate' => 'iresate',
'iresasx' => 'iresasx',
'iresamo' => 'iresamo',
'iresam' => 'iresam',
'iresaju' => 'iresaju',
'iresajte' => 'iresajte',
'iresajmo' => 'iresajmo',
'iresaj' => 'iresaj',
'ires' => 'ires',
'irepte' => 'irepte',
'ireptavsxi' => 'ireptavsxi',
'ireptati' => 'ireptati',
'ireptat' => 'ireptat',
'ireptasxe' => 'ireptasxe',
'ireptaste' => 'ireptaste',
'ireptasmo' => 'ireptasmo',
'ireptao' => 'ireptao',
'ireptano' => 'ireptano',
'ireptani' => 'ireptani',
'ireptane' => 'ireptane',
'ireptana' => 'ireptana',
'ireptan' => 'ireptan',
'ireptalo' => 'ireptalo',
'ireptali' => 'ireptali',
'ireptale' => 'ireptale',
'ireptala' => 'ireptala',
'ireptah' => 'ireptah',
'ireptacyu' => 'ireptacyu',
'ireptacyete' => 'ireptacyete',
'ireptacyesx' => 'ireptacyesx',
'ireptacyemo' => 'ireptacyemo',
'ireptacye' => 'ireptacye',
'irepta' => 'irepta',
'irepsku' => 'irepsku',
'irepskomu' => 'irepskomu',
'irepskom' => 'irepskom',
'irepskoj' => 'irepskoj',
'irepskoga' => 'irepskoga',
'irepskog' => 'irepskog',
'irepsko' => 'irepsko',
'irepskim' => 'irepskim',
'irepskih' => 'irepskih',
'irepski' => 'irepski',
'irepske' => 'irepske',
'irepska' => 'irepska',
'irepmo' => 'irepmo',
'ireplyeno' => 'ireplyeno',
'ireplyeni' => 'ireplyeni',
'ireplyene' => 'ireplyene',
'ireplyena' => 'ireplyena',
'ireplyen' => 'ireplyen',
'irepjevsxi' => 'irepjevsxi',
'irepjeti' => 'irepjeti',
'irepjet' => 'irepjet',
'irepjesxe' => 'irepjesxe',
'irepjeste' => 'irepjeste',
'irepjesmo' => 'irepjesmo',
'irepjelo' => 'irepjelo',
'irepjeli' => 'irepjeli',
'irepjele' => 'irepjele',
'irepjela' => 'irepjela',
'irepjeh' => 'irepjeh',
'irepjecyu' => 'irepjecyu',
'irepjecyete' => 'irepjecyete',
'irepjecyesx' => 'irepjecyesx',
'irepjecyemo' => 'irepjecyemo',
'irepjecye' => 'irepjecye',
'irepje' => 'irepje',
'irepite' => 'irepite',
'irepisx' => 'irepisx',
'irepio' => 'irepio',
'irepimo' => 'irepimo',
'irepim' => 'im',
'irepi' => 'i',
'irepevsxi' => 'irepevsxi',
'irepeti' => 'irepeti',
'irepet' => 'irepet',
'irepesxe' => 'irepesxe',
'irepeste' => 'irepeste',
'irepesmo' => 'irepesmo',
'irepeo' => 'irepeo',
'irepelo' => 'irepelo',
'irepeli' => 'irepeli',
'irepele' => 'irepele',
'irepela' => 'irepela',
'irepeh' => 'irepeh',
'irepecyu' => 'irepecyu',
'irepecyete' => 'irepecyete',
'irepecyesx' => 'irepecyesx',
'irepecyemo' => 'irepecyemo',
'irepecye' => 'irepecye',
'irepe' => 'e',
'irepcyu' => 'irepcyu',
'irepcyite' => 'irepcyite',
'irepcyimo' => 'irepcyimo',
'irepcyi' => 'irepcyi',
'irepcyete' => 'irepcyete',
'irepcyesx' => 'irepcyesx',
'irepcyemo' => 'irepcyemo',
'irepcyem' => 'irepcyem',
'irepcye' => 'irepcye',
'irep' => '',
'irenyu' => 'enyu',
'irenyima' => 'ima',
'irenyem' => 'em',
'irenya' => 'a',
'ireniravsxi' => 'ireniravsxi',
'irenirati' => 'irenirati',
'irenirate' => 'irenirate',
'irenirat' => 'irenirat',
'irenirasxe' => 'irenirasxe',
'irenirasx' => 'irenirasx',
'ireniraste' => 'ireniraste',
'irenirasmo' => 'irenirasmo',
'irenirao' => 'irenirao',
'ireniranye' => 'ireniranye',
'irenirano' => 'irenirano',
'irenirani' => 'irenirani',
'irenirane' => 'irenirane',
'irenirana' => 'irenirana',
'ireniran' => 'ireniran',
'ireniramo' => 'ireniramo',
'ireniram' => 'ireniram',
'ireniralo' => 'ireniralo',
'irenirali' => 'irenirali',
'irenirale' => 'irenirale',
'irenirala' => 'irenirala',
'ireniraju' => 'ireniraju',
'irenirajte' => 'irenirajte',
'irenirajmo' => 'irenirajmo',
'ireniraj' => 'ireniraj',
'irenirah' => 'irenirah',
'ireniracyu' => 'ireniracyu',
'ireniracyete' => 'ireniracyete',
'ireniracyesx' => 'ireniracyesx',
'ireniracyemo' => 'ireniracyemo',
'ireniracye' => 'ireniracye',
'irenira' => 'irenira',
'iremte' => 'iremte',
'iremom' => 'iremom',
'iremlyeno' => 'iremlyeno',
'iremlyeni' => 'iremlyeni',
'iremlyene' => 'iremlyene',
'iremlyena' => 'iremlyena',
'iremlyen' => 'iremlyen',
'iremizmu' => 'iremizmu',
'iremizmom' => 'iremizmom',
'iremizmima' => 'iremizmima',
'iremizmi' => 'iremizmi',
'iremizme' => 'iremizme',
'iremizma' => 'iremizma',
'iremizama' => 'iremizama',
'iremizam' => 'iremizam',
'iremivsxi' => 'iremivsxi',
'iremiti' => 'iremiti',
'iremitetu' => 'iremitetu',
'iremitetom' => 'iremitetom',
'iremitetima' => 'iremitetima',
'iremiteti' => 'iremiteti',
'iremitete' => 'iremitete',
'iremiteta' => 'iremiteta',
'iremitet' => 'iremitet',
'iremite' => 'iremite',
'iremit' => 'iremit',
'iremisxe' => 'iremisxe',
'iremisx' => 'iremisx',
'iremistu' => 'iremistu',
'iremistom' => 'iremistom',
'iremisto' => 'iremisto',
'iremistima' => 'iremistima',
'iremisticxku' => 'iremisticxku',
'iremisticxkomu' => 'iremisticxkomu',
'iremisticxkom' => 'iremisticxkom',
'iremisticxkoj' => 'iremisticxkoj',
'iremisticxkoga' => 'iremisticxkoga',
'iremisticxkog' => 'iremisticxkog',
'iremisticxko' => 'iremisticxko',
'iremisticxkim' => 'iremisticxkim',
'iremisticxkih' => 'iremisticxkih',
'iremisticxki' => 'iremisticxki',
'iremisticxke' => 'iremisticxke',
'iremisticxka' => 'iremisticxka',
'iremisti' => 'iremisti',
'iremistama' => 'iremistama',
'iremista' => 'iremista',
'iremismo' => 'iremismo',
'iremisata' => 'iremisata',
'iremio' => 'iremio',
'iremimo' => 'iremimo',
'iremima' => 'iremima',
'iremim' => 'iremim',
'iremilo' => 'iremilo',
'iremili' => 'iremili',
'iremile' => 'iremile',
'iremila' => 'iremila',
'iremih' => 'iremih',
'iremicyu' => 'iremicyu',
'iremicyete' => 'iremicyete',
'iremicyesx' => 'iremicyesx',
'iremicyemo' => 'iremicyemo',
'iremicye' => 'iremicye',
'irema' => 'irema',
'irelyasxe' => 'irelyasxe',
'irelyaste' => 'irelyaste',
'irelyasmo' => 'irelyasmo',
'irelyahu' => 'irelyahu',
'irelyah' => 'irelyah',
'irelivsxi' => 'irelivsxi',
'irelisxe' => 'irelisxe',
'ireliste' => 'ireliste',
'irelismo' => 'irelismo',
'irelih' => 'irelih',
'ireku' => 'ku',
'irekom' => 'kom',
'ireknuvsxi' => 'ireknuvsxi',
'ireknuto' => 'ireknuto',
'ireknuti' => 'ireknuti',
'ireknute' => 'ireknute',
'ireknuta' => 'ireknuta',
'ireknut' => 'ireknut',
'ireknusxe' => 'ireknusxe',
'ireknuste' => 'ireknuste',
'ireknusmo' => 'ireknusmo',
'ireknuo' => 'ireknuo',
'ireknulo' => 'ireknulo',
'ireknuli' => 'ireknuli',
'ireknule' => 'ireknule',
'ireknula' => 'ireknula',
'ireknuh' => 'ireknuh',
'ireknucyu' => 'ireknucyu',
'ireknucyete' => 'ireknucyete',
'ireknucyesx' => 'ireknucyesx',
'ireknucyemo' => 'ireknucyemo',
'ireknucye' => 'ireknucye',
'ireknu' => 'ireknu',
'ireknite' => 'ireknite',
'ireknimo' => 'ireknimo',
'irekni' => 'irekni',
'ireknete' => 'ireknete',
'ireknesx' => 'ireknesx',
'ireknemo' => 'ireknemo',
'ireknem' => 'ireknem',
'irekne' => 'irekne',
'ireke' => 'ke',
'irekacxu' => 'irekacxu',
'irekacxima' => 'irekacxima',
'irekacxi' => 'irekacxi',
'irekacxem' => 'irekacxem',
'irekacxe' => 'irekacxe',
'irekacxa' => 'irekacxa',
'irekacx' => 'irekacx',
'ireka' => 'ka',
'irek' => 'k',
'irecyi' => '',
'irecxe' => 'cxe',
'irecima' => 'cima',
'ireci' => 'ci',
'irebu' => 'irebu',
'irebovu' => 'irebovu',
'irebovomu' => 'irebovomu',
'irebovom' => 'irebovom',
'irebovoj' => 'irebovoj',
'irebovoga' => 'irebovoga',
'irebovog' => 'irebovog',
'irebovo' => 'irebovo',
'irebovima' => 'irebovima',
'irebovim' => 'irebovim',
'irebovih' => 'irebovih',
'irebovi' => 'irebovi',
'irebove' => 'irebove',
'irebova' => 'irebova',
'irebov' => 'irebov',
'irebom' => 'irebom',
'ireblyute' => 'ireblyute',
'ireblyumo' => 'ireblyumo',
'ireblyujucyi' => 'ireblyujucyi',
'ireblyujte' => 'ireblyujte',
'ireblyujmo' => 'ireblyujmo',
'ireblyujite' => 'ireblyujite',
'ireblyujimo' => 'ireblyujimo',
'ireblyuji' => 'ireblyuji',
'ireblyuj' => 'ireblyuj',
'ireblyu' => 'ireblyu',
'ireblyivu' => 'ireblyivu',
'ireblyivomu' => 'ireblyivomu',
'ireblyivom' => 'ireblyivom',
'ireblyivoj' => 'ireblyivoj',
'ireblyivoga' => 'ireblyivoga',
'ireblyivog' => 'ireblyivog',
'ireblyivo' => 'ireblyivo',
'ireblyivim' => 'ireblyivim',
'ireblyivih' => 'ireblyivih',
'ireblyivi' => 'ireblyivi',
'ireblyive' => 'ireblyive',
'ireblyivacxu' => 'ireblyivacxu',
'ireblyivacxku' => 'ireblyivacxku',
'ireblyivacxkomu' => 'ireblyivacxkomu',
'ireblyivacxkom' => 'ireblyivacxkom',
'ireblyivacxkoj' => 'ireblyivacxkoj',
'ireblyivacxkoga' => 'ireblyivacxkoga',
'ireblyivacxkog' => 'ireblyivacxkog',
'ireblyivacxko' => 'ireblyivacxko',
'ireblyivacxkim' => 'ireblyivacxkim',
'ireblyivacxkih' => 'ireblyivacxkih',
'ireblyivacxki' => 'ireblyivacxki',
'ireblyivacxke' => 'ireblyivacxke',
'ireblyivacxka' => 'ireblyivacxka',
'ireblyivacxima' => 'ireblyivacxima',
'ireblyivacxi' => 'ireblyivacxi',
'ireblyivacxem' => 'ireblyivacxem',
'ireblyivacxe' => 'ireblyivacxe',
'ireblyivacxa' => 'ireblyivacxa',
'ireblyivacx' => 'ireblyivacx',
'ireblyiv' => 'ireblyiv',
'ireblyenyu' => 'ireblyenyu',
'ireblyenyima' => 'ireblyenyima',
'ireblyenyem' => 'ireblyenyem',
'ireblyenye' => 'ireblyenye',
'ireblyenya' => 'ireblyenya',
'ireblyavavsxi' => 'ireblyavavsxi',
'ireblyavati' => 'ireblyavati',
'ireblyavat' => 'ireblyavat',
'ireblyavasxe' => 'ireblyavasxe',
'ireblyavaste' => 'ireblyavaste',
'ireblyavasmo' => 'ireblyavasmo',
'ireblyavao' => 'ireblyavao',
'ireblyavano' => 'ireblyavano',
'ireblyavani' => 'ireblyavani',
'ireblyavane' => 'ireblyavane',
'ireblyavana' => 'ireblyavana',
'ireblyavan' => 'ireblyavan',
'ireblyavalo' => 'ireblyavalo',
'ireblyavali' => 'ireblyavali',
'ireblyavale' => 'ireblyavale',
'ireblyavala' => 'ireblyavala',
'ireblyavahu' => 'ireblyavahu',
'ireblyavah' => 'ireblyavah',
'ireblyavacyu' => 'ireblyavacyu',
'ireblyavacyete' => 'ireblyavacyete',
'ireblyavacyesx' => 'ireblyavacyesx',
'ireblyavacyemo' => 'ireblyavacyemo',
'ireblyavacye' => 'ireblyavacye',
'ireblyava' => 'ireblyava',
'irebima' => 'irebima',
'irebastu' => 'irebastu',
'irebastomu' => 'irebastomu',
'irebastom' => 'irebastom',
'irebastoj' => 'irebastoj',
'irebastoga' => 'irebastoga',
'irebastog' => 'irebastog',
'irebasto' => 'irebasto',
'irebastim' => 'irebastim',
'irebastih' => 'irebastih',
'irebasti' => 'irebasti',
'irebaste' => 'irebaste',
'irebasta' => 'irebasta',
'ireba' => 'ireba',
'ircyu' => 'ircyu',
'ircyete' => 'te',
'ircyesx' => 'ircyesx',
'ircyemo' => 'ircyemo',
'ircye' => 'e',
'ircxavanyu' => 'ircxavanyu',
'ircxavanya' => 'ircxavanya',
'ircavsxi' => 'vsxi',
'ircati' => 'ti',
'ircate' => 'te',
'ircat' => 't',
'ircasxe' => 'sxe',
'ircasx' => 'sx',
'ircaste' => 'ste',
'ircasmo' => 'smo',
'ircao' => 'o',
'ircano' => 'no',
'ircani' => 'ni',
'ircane' => 'ne',
'ircana' => 'na',
'ircan' => 'n',
'ircamo' => 'mo',
'ircam' => 'm',
'ircalo' => 'lo',
'ircali' => 'li',
'ircale' => 'le',
'ircala' => 'la',
'ircaju' => 'ju',
'ircajte' => 'jte',
'ircajmo' => 'jmo',
'ircaj' => 'j',
'ircah' => 'h',
'ircacyu' => 'cyu',
'ircacyete' => 'cyete',
'ircacyesx' => 'cyesx',
'ircacyemo' => 'cyemo',
'ircacye' => 'cye',
'irca' => 'ca',
'irazxute' => 'irazxute',
'irazxumo' => 'irazxumo',
'irazxujucyi' => 'irazxujucyi',
'irazxuju' => 'irazxuju',
'irazxujte' => 'irazxujte',
'irazxujmo' => 'irazxujmo',
'irazxujete' => 'irazxujete',
'irazxujesx' => 'irazxujesx',
'irazxujemo' => 'irazxujemo',
'irazxujem' => 'irazxujem',
'irazxuje' => 'irazxuje',
'irazxuj' => 'irazxuj',
'irazxom' => 'om',
'irazxo' => 'o',
'irazxnu' => 'irazxnu',
'irazxnomu' => 'irazxnomu',
'irazxnom' => 'irazxnom',
'irazxnoj' => 'irazxnoj',
'irazxnoga' => 'irazxnoga',
'irazxnog' => 'irazxnog',
'irazxno' => 'irazxno',
'irazxnim' => 'irazxnim',
'irazxnih' => 'irazxnih',
'irazxni' => 'irazxni',
'irazxne' => 'irazxne',
'irazxna' => 'irazxna',
'irazxivavsxi' => 'irazxivavsxi',
'irazxivati' => 'irazxivati',
'irazxivat' => 'irazxivat',
'irazxivasxe' => 'irazxivasxe',
'irazxivaste' => 'irazxivaste',
'irazxivasmo' => 'irazxivasmo',
'irazxivaocxe' => 'irazxivaocxe',
'irazxivaocu' => 'irazxivaocu',
'irazxivaocima' => 'irazxivaocima',
'irazxivaoci' => 'irazxivaoci',
'irazxivaocem' => 'irazxivaocem',
'irazxivaoce' => 'irazxivaoce',
'irazxivaoca' => 'irazxivaoca',
'irazxivao' => 'irazxivao',
'irazxivanyu' => 'irazxivanyu',
'irazxivanyima' => 'irazxivanyima',
'irazxivanyem' => 'irazxivanyem',
'irazxivanye' => 'irazxivanye',
'irazxivanya' => 'irazxivanya',
'irazxivano' => 'irazxivano',
'irazxivani' => 'irazxivani',
'irazxivane' => 'irazxivane',
'irazxivana' => 'irazxivana',
'irazxivan' => 'irazxivan',
'irazxivalo' => 'irazxivalo',
'irazxivali' => 'irazxivali',
'irazxivale' => 'irazxivale',
'irazxivalaca' => 'irazxivalaca',
'irazxivalac' => 'irazxivalac',
'irazxivala' => 'irazxivala',
'irazxivahu' => 'irazxivahu',
'irazxivah' => 'irazxivah',
'irazxivacyu' => 'irazxivacyu',
'irazxivacyete' => 'irazxivacyete',
'irazxivacyesx' => 'irazxivacyesx',
'irazxivacyemo' => 'irazxivacyemo',
'irazxivacye' => 'irazxivacye',
'irazxivacxu' => 'irazxivacxu',
'irazxivacxima' => 'irazxivacxima',
'irazxivacxi' => 'irazxivacxi',
'irazxivacxem' => 'irazxivacxem',
'irazxivacxe' => 'irazxivacxe',
'irazxivacxa' => 'irazxivacxa',
'irazxivacx' => 'irazxivacx',
'irazxiva' => 'irazxiva',
'irazxitelyu' => 'irazxitelyu',
'irazxitelyom' => 'irazxitelyom',
'irazxitelyima' => 'irazxitelyima',
'irazxitelyi' => 'irazxitelyi',
'irazxitelye' => 'irazxitelye',
'irazxitelya' => 'irazxitelya',
'irazxitely' => 'irazxitely',
'irazxaru' => 'irazxaru',
'irazxarom' => 'irazxarom',
'irazxarima' => 'irazxarima',
'irazxari' => 'irazxari',
'irazxare' => 'irazxare',
'irazxara' => 'irazxara',
'irazxar' => 'irazxar',
'irazxama' => 'ama',
'irazxa' => 'a',
'iravavsxi' => 'vsxi',
'iravati' => 'ti',
'iravate' => 'te',
'iravat' => 't',
'iravasxe' => 'sxe',
'iravasx' => 'sx',
'iravaste' => 'ste',
'iravasmo' => 'smo',
'iravao' => 'o',
'iravano' => 'no',
'iravani' => 'ni',
'iravane' => 'ne',
'iravana' => 'na',
'iravan' => 'n',
'iravamo' => 'mo',
'iravam' => 'm',
'iravalo' => 'lo',
'iravali' => 'li',
'iravale' => 'le',
'iravala' => 'la',
'iravaju' => 'ju',
'iravajte' => 'jte',
'iravajmo' => 'jmo',
'iravaj' => 'j',
'iravahu' => 'hu',
'iravah' => 'h',
'iravagantnosxcyu' => 'iravagantnosxcyu',
'iravagantnostima' => 'iravagantnostima',
'iravagantnosti' => 'iravagantnosti',
'iravaganciju' => 'iravaganciju',
'iravagancijom' => 'iravagancijom',
'iravagancijo' => 'iravagancijo',
'iravaganciji' => 'iravaganciji',
'iravagancije' => 'iravagancije',
'iravagancijama' => 'iravagancijama',
'iravagancija' => 'iravagancija',
'iravacyu' => 'cyu',
'iravacyete' => 'cyete',
'iravacyesx' => 'cyesx',
'iravacyemo' => 'cyemo',
'iravacye' => 'cye',
'iratorku' => 'iratorku',
'iratorkom' => 'iratorkom',
'iratorko' => 'iratorko',
'iratorke' => 'iratorke',
'iratorkama' => 'iratorkama',
'iratorka' => 'iratorka',
'iratorci' => 'iratorci',
'iratoraka' => 'iratoraka',
'irativnu' => 'irativnu',
'irativnomu' => 'irativnomu',
'irativnom' => 'irativnom',
'irativnoj' => 'irativnoj',
'irativnoga' => 'irativnoga',
'irativnog' => 'irativnog',
'irativno' => 'irativno',
'irativnim' => 'irativnim',
'irativnih' => 'irativnih',
'irativni' => 'irativni',
'irativne' => 'irativne',
'irativna' => 'irativna',
'irasxujucyiu' => 'irasxujucyiu',
'irasxujucyiomu' => 'irasxujucyiomu',
'irasxujucyiom' => 'irasxujucyiom',
'irasxujucyioj' => 'irasxujucyioj',
'irasxujucyim' => 'irasxujucyim',
'irasxujucyih' => 'irasxujucyih',
'irasxujucyiemu' => 'irasxujucyiemu',
'irasxujucyiem' => 'irasxujucyiem',
'irasxujucyiega' => 'irasxujucyiega',
'irasxujucyieg' => 'irasxujucyieg',
'irasxujucyie' => 'irasxujucyie',
'irasxujucyia' => 'irasxujucyia',
'irasxujucyi' => 'irasxujucyi',
'irasxuju' => 'irasxuju',
'irasxujite' => 'irasxujite',
'irasxujimo' => 'irasxujimo',
'irasxuji' => 'irasxuji',
'irasxujete' => 'irasxujete',
'irasxujesx' => 'irasxujesx',
'irasxujemo' => 'irasxujemo',
'irasxujem' => 'irasxujem',
'irasxuje' => 'irasxuje',
'irasxnu' => 'irasxnu',
'irasxnomu' => 'irasxnomu',
'irasxnom' => 'irasxnom',
'irasxnoj' => 'irasxnoj',
'irasxnoga' => 'irasxnoga',
'irasxnog' => 'irasxnog',
'irasxno' => 'irasxno',
'irasxnim' => 'irasxnim',
'irasxnih' => 'irasxnih',
'irasxni' => 'irasxni',
'irasxne' => 'irasxne',
'irasxna' => 'irasxna',
'irasxivu' => 'irasxivu',
'irasxivosxcyu' => 'irasxivosxcyu',
'irasxivostima' => 'irasxivostima',
'irasxivosti' => 'irasxivosti',
'irasxivomu' => 'irasxivomu',
'irasxivom' => 'irasxivom',
'irasxivoj' => 'irasxivoj',
'irasxivoga' => 'irasxivoga',
'irasxivog' => 'irasxivog',
'irasxivo' => 'irasxivo',
'irasxivim' => 'irasxivim',
'irasxivih' => 'irasxivih',
'irasxivi' => 'irasxivi',
'irasxive' => 'irasxive',
'irasxivavsxi' => 'irasxivavsxi',
'irasxivati' => 'irasxivati',
'irasxivat' => 'irasxivat',
'irasxivasxe' => 'irasxivasxe',
'irasxivaste' => 'irasxivaste',
'irasxivasmo' => 'irasxivasmo',
'irasxivao' => 'irasxivao',
'irasxivanyu' => 'irasxivanyu',
'irasxivanyima' => 'irasxivanyima',
'irasxivanyem' => 'irasxivanyem',
'irasxivanye' => 'irasxivanye',
'irasxivanya' => 'irasxivanya',
'irasxivano' => 'irasxivano',
'irasxivani' => 'irasxivani',
'irasxivane' => 'irasxivane',
'irasxivana' => 'irasxivana',
'irasxivan' => 'irasxivan',
'irasxivalo' => 'irasxivalo',
'irasxivali' => 'irasxivali',
'irasxivale' => 'irasxivale',
'irasxivala' => 'irasxivala',
'irasxivahu' => 'irasxivahu',
'irasxivah' => 'irasxivah',
'irasxivacyu' => 'irasxivacyu',
'irasxivacyete' => 'irasxivacyete',
'irasxivacyesx' => 'irasxivacyesx',
'irasxivacyemo' => 'irasxivacyemo',
'irasxivacye' => 'irasxivacye',
'irasxiv' => 'irasxiv',
'irasxenosxcyu' => 'irasxenosxcyu',
'irasxenostima' => 'irasxenostima',
'irasxenosti' => 'irasxenosti',
'irasxcyu' => 'sxcyu',
'irasxcyima' => 'irasxcyima',
'irasxcyem' => 'irasxcyem',
'irasxcye' => 'sxcye',
'irasxcya' => 'irasxcya',
'irasxavavsxi' => 'irasxavavsxi',
'irasxavati' => 'irasxavati',
'irasxavat' => 'irasxavat',
'irasxavasxe' => 'irasxavasxe',
'irasxavaste' => 'irasxavaste',
'irasxavasmo' => 'irasxavasmo',
'irasxavao' => 'irasxavao',
'irasxavano' => 'irasxavano',
'irasxavani' => 'irasxavani',
'irasxavane' => 'irasxavane',
'irasxavana' => 'irasxavana',
'irasxavan' => 'irasxavan',
'irasxavalo' => 'irasxavalo',
'irasxavali' => 'irasxavali',
'irasxavale' => 'irasxavale',
'irasxavala' => 'irasxavala',
'irasxavahu' => 'irasxavahu',
'irasxavah' => 'irasxavah',
'irasxavacyu' => 'irasxavacyu',
'irasxavacyete' => 'irasxavacyete',
'irasxavacyesx' => 'irasxavacyesx',
'irasxavacyemo' => 'irasxavacyemo',
'irasxavacye' => 'irasxavacye',
'irasxava' => 'irasxava',
'irasxacya' => 'irasxacya',
'irasniku' => 'irasniku',
'irasnikom' => 'irasnikom',
'irasnike' => 'irasnike',
'irasnika' => 'irasnika',
'irasnik' => 'irasnik',
'irasnicxe' => 'irasnicxe',
'irasnicima' => 'irasnicima',
'irasnici' => 'irasnici',
'iranyivanyu' => 'iranyivanyu',
'iranyivanyima' => 'iranyivanyima',
'iranyivanyem' => 'iranyivanyem',
'iranyivanye' => 'iranyivanye',
'iranyivanya' => 'iranyivanya',
'iranyenyu' => 'iranyenyu',
'iranyenyima' => 'iranyenyima',
'iranyenyem' => 'iranyenyem',
'iranyenye' => 'iranyenye',
'iranyenya' => 'iranyenya',
'irantkinyu' => 'u',
'irantkinyom' => 'om',
'irantkinyo' => 'o',
'irantkinyi' => 'i',
'irantkinye' => 'e',
'irantkinyama' => 'ama',
'irantkinya' => 'a',
'iransxiravsxi' => 'iransxiravsxi',
'iransxirati' => 'iransxirati',
'iransxirate' => 'iransxirate',
'iransxirat' => 'iransxirat',
'iransxirasxe' => 'iransxirasxe',
'iransxirasx' => 'iransxirasx',
'iransxiraste' => 'iransxiraste',
'iransxirasmo' => 'iransxirasmo',
'iransxirao' => 'iransxirao',
'iransxirano' => 'iransxirano',
'iransxirani' => 'iransxirani',
'iransxirane' => 'iransxirane',
'iransxirana' => 'iransxirana',
'iransxiran' => 'iransxiran',
'iransxiramo' => 'iransxiramo',
'iransxiram' => 'iransxiram',
'iransxiralo' => 'iransxiralo',
'iransxirali' => 'iransxirali',
'iransxirale' => 'iransxirale',
'iransxirala' => 'iransxirala',
'iransxirajucyi' => 'iransxirajucyi',
'iransxiraju' => 'iransxiraju',
'iransxirajte' => 'iransxirajte',
'iransxirajmo' => 'iransxirajmo',
'iransxiraj' => 'iransxiraj',
'iransxirahu' => 'iransxirahu',
'iransxirah' => 'iransxirah',
'iransxiracyu' => 'iransxiracyu',
'iransxiracyete' => 'iransxiracyete',
'iransxiracyesx' => 'iransxiracyesx',
'iransxiracyemo' => 'iransxiracyemo',
'iransxiracye' => 'iransxiracye',
'iransxira' => 'iransxira',
'iraninu' => 'u',
'iraninom' => 'om',
'iranine' => 'e',
'iranina' => 'a',
'iranin' => '',
'iranije' => '',
'iramo' => 'mo',
'iram' => 'm',
'iralsku' => 'u',
'iralskomu' => 'omu',
'iralskom' => 'om',
'iralskoj' => 'oj',
'iralskoga' => 'oga',
'iralskog' => 'og',
'iralsko' => 'o',
'iralskim' => 'im',
'iralskih' => 'ih',
'iralski' => 'i',
'iralske' => 'e',
'iralska' => 'a',
'iralnu' => 'iralnu',
'iralnomu' => 'iralnomu',
'iralnom' => 'iralnom',
'iralnoj' => 'iralnoj',
'iralnoga' => 'iralnoga',
'iralnog' => 'iralnog',
'iralno' => 'iralno',
'iralnim' => 'iralnim',
'iralnih' => 'iralnih',
'iralni' => 'iralni',
'iralne' => 'iralne',
'iralna' => 'iralna',
'iralku' => 'iralku',
'iralkom' => 'iralkom',
'iralko' => 'iralko',
'iralke' => 'iralke',
'iralkama' => 'iralkama',
'iralka' => 'iralka',
'iraliju' => 'iraliju',
'iralijsku' => 'iralijsku',
'iralijskomu' => 'iralijskomu',
'iralijskom' => 'iralijskom',
'iralijskoj' => 'iralijskoj',
'iralijskoga' => 'iralijskoga',
'iralijskog' => 'iralijskog',
'iralijsko' => 'iralijsko',
'iralijskim' => 'iralijskim',
'iralijskih' => 'iralijskih',
'iralijski' => 'iralijski',
'iralijske' => 'iralijske',
'iralijska' => 'iralijska',
'iralijom' => 'iralijom',
'iralijo' => 'iralijo',
'iraliji' => 'iraliji',
'iralije' => 'iralije',
'iralijansku' => 'iralijansku',
'iralijanskomu' => 'iralijanskomu',
'iralijanskom' => 'iralijanskom',
'iralijanskoj' => 'iralijanskoj',
'iralijanskoga' => 'iralijanskoga',
'iralijanskog' => 'iralijanskog',
'iralijansko' => 'iralijansko',
'iralijanskim' => 'iralijanskim',
'iralijanskih' => 'iralijanskih',
'iralijanski' => 'iralijanski',
'iralijanske' => 'iralijanske',
'iralijanska' => 'iralijanska',
'iralijanku' => 'iralijanku',
'iralijankom' => 'iralijankom',
'iralijanko' => 'iralijanko',
'iralijanke' => 'iralijanke',
'iralijankama' => 'iralijankama',
'iralijanka' => 'iralijanka',
'iralijanci' => 'iralijanci',
'iralijanaka' => 'iralijanaka',
'iralijama' => 'iralijama',
'iralija' => 'iralija',
'iralci' => 'iralci',
'iralaka' => 'iralaka',
'iraktovima' => 'iraktovima',
'iraktovi' => 'iraktovi',
'iraktove' => 'iraktove',
'iraktova' => 'iraktova',
'iraktnosxcyu' => 'iraktnosxcyu',
'iraktnostima' => 'iraktnostima',
'iraktnosti' => 'iraktnosti',
'iraktno' => 'iraktno',
'iraktnije' => '',
'iraktima' => 'iraktima',
'irakti' => 'irakti',
'irakizmu' => 'irakizmu',
'irakizmom' => 'irakizmom',
'irakizmima' => 'irakizmima',
'irakizmi' => 'irakizmi',
'irakizme' => 'irakizme',
'irakizma' => 'irakizma',
'irakizama' => 'irakizama',
'irakizam' => 'irakizam',
'irajucyi' => 'jucyi',
'irajte' => 'jte',
'irajmo' => 'jmo',
'iraj' => 'j',
'irahute' => 'irahute',
'irahumo' => 'irahumo',
'irahujucyi' => 'irahujucyi',
'irahuju' => 'irahuju',
'irahujte' => 'irahujte',
'irahujmo' => 'irahujmo',
'irahujete' => 'irahujete',
'irahujesx' => 'irahujesx',
'irahujemo' => 'irahujemo',
'irahujem' => 'irahujem',
'irahuje' => 'irahuje',
'irahuj' => 'irahuj',
'irahovadute' => 'irahovadute',
'irahovadumo' => 'irahovadumo',
'irahovadujucyi' => 'irahovadujucyi',
'irahovaduju' => 'irahovaduju',
'irahovadujte' => 'irahovadujte',
'irahovadujmo' => 'irahovadujmo',
'irahovadujete' => 'irahovadujete',
'irahovadujesx' => 'irahovadujesx',
'irahovadujemo' => 'irahovadujemo',
'irahovadujem' => 'irahovadujem',
'irahovaduje' => 'irahovaduje',
'irahovaduj' => 'irahovaduj',
'irahovadu' => 'irahovadu',
'iragusxu' => 'iragusxu',
'iragusxom' => 'iragusxom',
'iragusxo' => 'iragusxo',
'iragusxi' => 'iragusxi',
'iragusxe' => 'iragusxe',
'iragusxama' => 'iragusxama',
'iragusxa' => 'iragusxa',
'iradiravsxi' => 'iradiravsxi',
'iradirati' => 'iradirati',
'iradirate' => 'iradirate',
'iradirat' => 'iradirat',
'iradirasxe' => 'iradirasxe',
'iradirasx' => 'iradirasx',
'iradiraste' => 'iradiraste',
'iradirasmo' => 'iradirasmo',
'iradirao' => 'iradirao',
'iradiranye' => 'iradiranye',
'iradirano' => 'iradirano',
'iradirani' => 'iradirani',
'iradirane' => 'iradirane',
'iradirana' => 'iradirana',
'iradiran' => 'iradiran',
'iradiramo' => 'iradiramo',
'iradiram' => 'iradiram',
'iradiralo' => 'iradiralo',
'iradirali' => 'iradirali',
'iradirale' => 'iradirale',
'iradirala' => 'iradirala',
'iradirajucyi' => 'iradirajucyi',
'iradiraju' => 'iradiraju',
'iradirajte' => 'iradirajte',
'iradirajmo' => 'iradirajmo',
'iradiraj' => 'iradiraj',
'iradirahu' => 'iradirahu',
'iradirah' => 'iradirah',
'iradiracyu' => 'iradiracyu',
'iradiracyete' => 'iradiracyete',
'iradiracyesx' => 'iradiracyesx',
'iradiracyemo' => 'iradiracyemo',
'iradiracye' => 'iradiracye',
'iradira' => 'iradira',
'iradiciju' => 'iradiciju',
'iradicijom' => 'iradicijom',
'iradicijo' => 'iradicijo',
'iradiciji' => 'iradiciji',
'iradicije' => 'iradicije',
'iradicijama' => 'iradicijama',
'iradicija' => 'iradicija',
'iradavsxi' => 'iradavsxi',
'iradati' => 'iradati',
'iradate' => 'iradate',
'iradat' => 'iradat',
'iradasxe' => 'iradasxe',
'iradasx' => 'iradasx',
'iradaste' => 'iradaste',
'iradasmo' => 'iradasmo',
'iradao' => 'iradao',
'iradano' => 'iradano',
'iradani' => 'iradani',
'iradane' => 'iradane',
'iradana' => 'iradana',
'iradan' => 'iradan',
'iradamo' => 'iradamo',
'iradam' => 'iradam',
'iradalo' => 'iradalo',
'iradali' => 'iradali',
'iradale' => 'iradale',
'iradala' => 'iradala',
'iradajucyi' => 'iradajucyi',
'iradaju' => 'iradaju',
'iradajte' => 'iradajte',
'iradajmo' => 'iradajmo',
'iradaj' => 'iradaj',
'iradahu' => 'iradahu',
'iradah' => 'iradah',
'iradacyu' => 'iradacyu',
'iradacyete' => 'iradacyete',
'iradacyesx' => 'iradacyesx',
'iradacyemo' => 'iradacyemo',
'iradacye' => 'iradacye',
'iracyte' => 'iracyte',
'iracymo' => 'iracymo',
'iracyivsxi' => 'iracyivsxi',
'iracyiti' => 'iracyiti',
'iracyite' => 'iracyite',
'iracyit' => 'iracyit',
'iracyisxe' => 'iracyisxe',
'iracyisx' => 'iracyisx',
'iracyiste' => 'iracyiste',
'iracyismo' => 'iracyismo',
'iracyio' => 'iracyio',
'iracyimo' => 'iracyimo',
'iracyim' => 'iracyim',
'iracyilo' => 'iracyilo',
'iracyili' => 'iracyili',
'iracyile' => 'iracyile',
'iracyila' => 'iracyila',
'iracyih' => 'iracyih',
'iracyicyu' => 'iracyicyu',
'iracyicyete' => 'iracyicyete',
'iracyicyesx' => 'iracyicyesx',
'iracyicyemo' => 'iracyicyemo',
'iracyicye' => 'iracyicye',
'iracyi' => 'acyi',
'iracyeno' => 'iracyeno',
'iracyeni' => 'iracyeni',
'iracyene' => 'iracyene',
'iracyena' => 'iracyena',
'iracyen' => 'iracyen',
'iracy' => 'iracy',
'iracizmu' => 'iracizmu',
'iracizmom' => 'iracizmom',
'iracizmima' => 'iracizmima',
'iracizmi' => 'iracizmi',
'iracizme' => 'iracizme',
'iracizma' => 'iracizma',
'iracizama' => 'iracizama',
'iracizam' => 'iracizam',
'ipoziciju' => 'ipoziciju',
'ipozicijom' => 'ipozicijom',
'ipozicijo' => 'ipozicijo',
'ipoziciji' => 'ipoziciji',
'ipozicije' => 'ipozicije',
'ipozicijama' => 'ipozicijama',
'ipozicija' => 'ipozicija',
'iponute' => 'iponute',
'iponumo' => 'iponumo',
'iponujucyi' => 'iponujucyi',
'iponuju' => 'iponuju',
'iponujte' => 'iponujte',
'iponujmo' => 'iponujmo',
'iponujete' => 'iponujete',
'iponujesx' => 'iponujesx',
'iponujemo' => 'iponujemo',
'iponujem' => 'iponujem',
'iponuje' => 'iponuje',
'iponuj' => 'iponuj',
'iponu' => 'iponu',
'iponovavsxi' => 'iponovavsxi',
'iponovati' => 'iponovati',
'iponovat' => 'iponovat',
'iponovasxe' => 'iponovasxe',
'iponovaste' => 'iponovaste',
'iponovasmo' => 'iponovasmo',
'iponovao' => 'iponovao',
'iponovanye' => 'iponovanye',
'iponovano' => 'iponovano',
'iponovani' => 'iponovani',
'iponovane' => 'iponovane',
'iponovana' => 'iponovana',
'iponovan' => 'iponovan',
'iponovalo' => 'iponovalo',
'iponovali' => 'iponovali',
'iponovale' => 'iponovale',
'iponovala' => 'iponovala',
'iponovahu' => 'iponovahu',
'iponovah' => 'iponovah',
'iponovacyu' => 'iponovacyu',
'iponovacyete' => 'iponovacyete',
'iponovacyesx' => 'iponovacyesx',
'iponovacyemo' => 'iponovacyemo',
'iponovacye' => 'iponovacye',
'iponova' => 'iponova',
'iponiravsxi' => 'iponiravsxi',
'iponirati' => 'iponirati',
'iponirate' => 'iponirate',
'iponirat' => 'iponirat',
'iponirasxe' => 'iponirasxe',
'iponirasx' => 'iponirasx',
'iponiraste' => 'iponiraste',
'iponirasmo' => 'iponirasmo',
'iponirao' => 'iponirao',
'iponiranye' => 'iponiranye',
'iponirano' => 'iponirano',
'iponirani' => 'iponirani',
'iponirane' => 'iponirane',
'iponirana' => 'iponirana',
'iponiran' => 'iponiran',
'iponiramo' => 'iponiramo',
'iponiram' => 'iponiram',
'iponiralo' => 'iponiralo',
'iponirali' => 'iponirali',
'iponirale' => 'iponirale',
'iponirala' => 'iponirala',
'iponirajucyi' => 'iponirajucyi',
'iponiraju' => 'iponiraju',
'iponirajte' => 'iponirajte',
'iponirajmo' => 'iponirajmo',
'iponiraj' => 'iponiraj',
'iponirahu' => 'iponirahu',
'iponirah' => 'iponirah',
'iponiracyu' => 'iponiracyu',
'iponiracyete' => 'iponiracyete',
'iponiracyesx' => 'iponiracyesx',
'iponiracyemo' => 'iponiracyemo',
'iponiracye' => 'iponiracye',
'iponira' => 'iponira',
'iogu' => 'ogu',
'iogom' => 'ogom',
'iogima' => 'ogima',
'iogi' => 'ogi',
'ioge' => 'oge',
'ioga' => 'oga',
'iocxe' => 'ocxe',
'iocu' => 'ocu',
'iocima' => 'ocima',
'ioci' => 'oci',
'iocem' => 'ocem',
'ioce' => 'oce',
'ioca' => 'oca',
'inicu' => 'u',
'inicom' => 'om',
'inico' => 'o',
'inici' => 'i',
'inice' => 'e',
'inicama' => 'ama',
'inica' => 'a',
'imte' => 'te',
'imovima' => 'ovima',
'imovi' => 'ovi',
'imove' => 'ove',
'imova' => 'ova',
'imlyeno' => 'lyeno',
'imlyeni' => 'lyeni',
'imlyene' => 'lyene',
'imlyena' => 'lyena',
'imlyen' => 'lyen',
'imivsxi' => 'ivsxi',
'imiti' => 'iti',
'imite' => 'ite',
'imit' => 'it',
'imisxe' => 'isxe',
'imisx' => 'isx',
'imiste' => 'iste',
'imismo' => 'ismo',
'imio' => 'io',
'imimo' => 'imo',
'imim' => 'im',
'imilo' => 'ilo',
'imili' => 'ili',
'imile' => 'ile',
'imila' => 'ila',
'imih' => 'ih',
'imicyu' => 'icyu',
'imicyete' => 'icyete',
'imicyesx' => 'icyesx',
'imicyemo' => 'icyemo',
'imicye' => 'icye',
'imatiku' => 'imatiku',
'imatikom' => 'imatikom',
'imatike' => 'imatike',
'imatika' => 'imatika',
'imatik' => 'imatik',
'imaticxku' => 'imaticxku',
'imaticxkomu' => 'imaticxkomu',
'imaticxkom' => 'imaticxkom',
'imaticxkoj' => 'imaticxkoj',
'imaticxkoga' => 'imaticxkoga',
'imaticxkog' => 'imaticxkog',
'imaticxko' => 'imaticxko',
'imaticxkim' => 'imaticxkim',
'imaticxkih' => 'imaticxkih',
'imaticxki' => 'imaticxki',
'imaticxke' => 'imaticxke',
'imaticxka' => 'imaticxka',
'imaticxe' => 'imaticxe',
'imaticxaru' => 'imaticxaru',
'imaticxarom' => 'imaticxarom',
'imaticxarima' => 'imaticxarima',
'imaticxari' => 'imaticxari',
'imaticxare' => 'imaticxare',
'imaticxara' => 'imaticxara',
'imaticxar' => 'imaticxar',
'imaticima' => 'imaticima',
'imatici' => 'imatici',
'imama' => 'ama',
'ilyivosxcyu' => 'ilyivosxcyu',
'ilyivostima' => 'ilyivostima',
'ilyivosti' => 'ilyivosti',
'ilyeti' => 'yeti',
'ilyet' => 'yet',
'ilyelo' => 'yelo',
'ilyeli' => 'yeli',
'ilyele' => 'yele',
'ilyela' => 'yela',
'ilyecyu' => 'yecyu',
'ilyecyete' => 'yecyete',
'ilyecyesx' => 'yecyesx',
'ilyecyemo' => 'yecyemo',
'ilyecye' => 'yecye',
'iluvijalnu' => 'iluvijalnu',
'iluvijalnomu' => 'iluvijalnomu',
'iluvijalnom' => 'iluvijalnom',
'iluvijalnoj' => 'iluvijalnoj',
'iluvijalnoga' => 'iluvijalnoga',
'iluvijalnog' => 'iluvijalnog',
'iluvijalno' => 'iluvijalno',
'iluvijalnim' => 'iluvijalnim',
'iluvijalnih' => 'iluvijalnih',
'iluvijalni' => '',
'iluvijalne' => 'iluvijalne',
'iluvijalna' => 'iluvijalna',
'ileti' => 'eti',
'ilet' => 'et',
'ileo' => 'eo',
'ilelo' => 'elo',
'ileli' => 'eli',
'ilele' => 'ele',
'ilela' => 'ela',
'ilecyu' => 'ecyu',
'ilecyete' => 'ecyete',
'ilecyesx' => 'ecyesx',
'ilecyemo' => 'ecyemo',
'ilecye' => 'ecye',
'iknutu' => 'u',
'iknutomu' => 'omu',
'iknutom' => 'om',
'iknutoj' => 'oj',
'iknutoga' => 'oga',
'iknutog' => 'og',
'iknutim' => 'im',
'iknutih' => 'ih',
'iklavsxi' => 'lavsxi',
'iklati' => 'lati',
'iklate' => 'iklate',
'iklat' => 'lat',
'iklasxe' => 'lasxe',
'iklasx' => 'iklasx',
'iklaste' => 'laste',
'iklasmo' => 'lasmo',
'iklao' => 'lao',
'iklano' => 'lano',
'iklani' => 'lani',
'iklane' => 'lane',
'iklana' => 'lana',
'iklan' => 'lan',
'iklamo' => 'lamo',
'iklam' => 'iklam',
'iklalo' => 'lalo',
'iklali' => 'lali',
'iklale' => 'lale',
'iklala' => 'lala',
'iklaju' => 'iklaju',
'iklajte' => 'iklajte',
'iklajmo' => 'iklajmo',
'iklaj' => 'iklaj',
'iklah' => 'lah',
'iklacyu' => 'lacyu',
'iklacyete' => 'lacyete',
'iklacyesx' => 'lacyesx',
'iklacyemo' => 'lacyemo',
'iklacye' => 'lacye',
'ikate' => 'e',
'ikasx' => 'sx',
'ikamo' => 'mo',
'ikam' => 'm',
'ikaju' => 'ju',
'ikajte' => 'jte',
'ikajmo' => 'jmo',
'ikaj' => 'j',
'ijru' => 'ijru',
'ijrte' => 'ijrte',
'ijrmo' => 'ijrmo',
'ijr' => 'ijr',
'ijite' => 'ite',
'ijimo' => 'imo',
'ijetetu' => 'u',
'ijetetom' => 'om',
'ijeteta' => 'a',
'ijetama' => 'ama',
'ijesu' => 'u',
'ijesete' => 'jesete',
'ijesesx' => 'jesesx',
'ijesemo' => 'jesemo',
'ijesem' => 'jesem',
'ijese' => 'e',
'ijes' => '',
'ijerivacxu' => 'ijerivacxu',
'ijerivacxima' => 'ijerivacxima',
'ijerivacxi' => 'ijerivacxi',
'ijerivacxem' => 'ijerivacxem',
'ijerivacxe' => 'ijerivacxe',
'ijerivacxa' => 'ijerivacxa',
'ijerivacx' => 'ijerivacx',
'ijeranya' => 'ijeranya',
'ijerajucyi' => 'ijerajucyi',
'ijerahu' => 'ijerahu',
'ijeo' => 'ijeo',
'ijenyu' => 'u',
'ijenyima' => 'ima',
'ijenyem' => 'em',
'ijenye' => 'e',
'ijenya' => 'a',
'ijeme' => 'e',
'ijelovlyenyu' => 'ijelovlyenyu',
'ijelovlyenyima' => 'ijelovlyenyima',
'ijelovlyenyem' => 'ijelovlyenyem',
'ijelovlyenye' => 'ijelovlyenye',
'ijelovlyenya' => 'ijelovlyenya',
'ijekavsxi' => 'kavsxi',
'ijekati' => 'kati',
'ijekat' => 'kat',
'ijekasxe' => 'kasxe',
'ijekaste' => 'kaste',
'ijekasmo' => 'kasmo',
'ijekao' => 'kao',
'ijekano' => 'kano',
'ijekani' => 'kani',
'ijekane' => 'kane',
'ijekana' => 'kana',
'ijekan' => 'kan',
'ijekalo' => 'kalo',
'ijekali' => 'kali',
'ijekale' => 'kale',
'ijekala' => 'kala',
'ijekah' => 'kah',
'ijekacyu' => 'kacyu',
'ijekacyete' => 'kacyete',
'ijekacyesx' => 'kacyesx',
'ijekacyemo' => 'kacyemo',
'ijekacye' => 'kacye',
'ijeka' => 'ka',
'ijehu' => 'hu',
'ijehovima' => 'ehovima',
'ijehovi' => 'ehovi',
'ijehove' => 'ehove',
'ijehova' => 'ehova',
'ijehom' => 'hom',
'ijeha' => 'ha',
'ijeglo' => 'ijeglo',
'ijegli' => 'ijegli',
'ijegle' => 'ijegle',
'ijegla' => 'ijegla',
'ijegao' => 'gao',
'ijecate' => 'te',
'ijecasx' => 'sx',
'ijecanyu' => 'nyu',
'ijecanyima' => 'nyima',
'ijecanyem' => 'nyem',
'ijecanye' => 'nye',
'ijecanya' => 'nya',
'ijecamo' => 'mo',
'ijecam' => 'm',
'ijecaju' => 'ju',
'ijecajte' => 'jte',
'ijecajmo' => 'jmo',
'ijecaj' => 'j',
'ijavsxi' => 'vsxi',
'ijati' => 'ti',
'ijat' => 't',
'ijao' => 'o',
'ijano' => 'no',
'ijani' => 'ni',
'ijane' => 'ne',
'ijana' => 'na',
'ijan' => 'n',
'ijalo' => 'lo',
'ijali' => 'li',
'ijalektu' => 'tu',
'ijalektom' => 'tom',
'ijalektima' => 'tima',
'ijalekti' => 'ti',
'ijalekte' => 'te',
'ijalekta' => 'ta',
'ijalekt' => '',
'ijalekata' => 'ata',
'ijalekat' => '',
'ijale' => 'le',
'ijala' => 'la',
'ijaku' => 'ku',
'ijakom' => 'kom',
'ijake' => 'ke',
'ijaka' => 'aka',
'ijak' => 'k',
'ijacyu' => 'cyu',
'ijacyete' => 'cyete',
'ijacyesx' => 'cyesx',
'ijacyemo' => 'cyemo',
'ijacye' => 'cye',
'ijacxe' => 'e',
'ijacima' => 'cima',
'ijaci' => 'ci',
'ihumnu' => 'ihumnu',
'ihumnomu' => 'ihumnomu',
'ihumnom' => 'ihumnom',
'ihumnoj' => 'ihumnoj',
'ihumnoga' => 'ihumnoga',
'ihumnog' => 'ihumnog',
'ihumno' => 'ihumno',
'ihumnim' => 'ihumnim',
'ihumnih' => 'ihumnih',
'ihumni' => 'ihumni',
'ihumne' => 'ihumne',
'ihumna' => 'ihumna',
'igute' => 'ute',
'igusx' => '',
'igumo' => 'umo',
'igu' => 'gu',
'igte' => 'igte',
'igmo' => 'mo',
'igati' => 'ti',
'igate' => 'te',
'igat' => 't',
'igasxe' => 'e',
'igasx' => '',
'igaste' => 'ste',
'igasmo' => 'smo',
'iganyu' => 'u',
'iganyima' => 'ima',
'iganyem' => 'iganyem',
'iganye' => 'e',
'iganya' => 'anya',
'igano' => 'no',
'igani' => 'ni',
'igane' => 'ne',
'igana' => 'na',
'igan' => 'n',
'igamo' => 'mo',
'igam' => 'm',
'igalo' => 'alo',
'igali' => 'li',
'igale' => 'le',
'igala' => 'ala',
'igaju' => 'ju',
'igajte' => 'jte',
'igajmo' => 'jmo',
'igaj' => 'j',
'igahu' => 'ahu',
'igah' => 'h',
'igacyu' => 'cyu',
'igacyete' => 'cyete',
'igacyesx' => 'cyesx',
'igacyemo' => 'cyemo',
'igacye' => 'cye',
'iga' => 'ga',
'ig' => 'g',
'idute' => 'ute',
'idusx' => 'dusx',
'idumo' => 'umo',
'idu' => 'u',
'idte' => 'te',
'idmo' => 'mo',
'idiplomsku' => 'idiplomsku',
'idiplomskomu' => 'idiplomskomu',
'idiplomskom' => 'idiplomskom',
'idiplomskoj' => 'idiplomskoj',
'idiplomskoga' => 'idiplomskoga',
'idiplomskog' => 'idiplomskog',
'idiplomsko' => 'idiplomsko',
'idiplomskim' => 'idiplomskim',
'idiplomskih' => 'idiplomskih',
'idiplomski' => 'idiplomski',
'idiplomske' => 'idiplomske',
'idiplomska' => 'idiplomska',
'idiplomcxe' => 'idiplomcxe',
'idiplomcu' => 'idiplomcu',
'idiplomcima' => 'idiplomcima',
'idiplomci' => 'idiplomci',
'idiplomcem' => 'idiplomcem',
'idiplomce' => 'idiplomce',
'idiplomca' => 'idiplomca',
'idiplomaca' => 'idiplomaca',
'idiplomac' => 'idiplomac',
'idem' => 'dem',
'ide' => 'e',
'icxna' => 'a',
'icxitu' => 'u',
'icxitomu' => 'omu',
'icxitom' => 'om',
'icxitoj' => 'oj',
'icxitoga' => 'oga',
'icxitog' => 'og',
'icxito' => 'o',
'icxitim' => 'im',
'icxitih' => 'ih',
'icxiti' => 'iti',
'icxita' => 'a',
'icxit' => 'it',
'icanyu' => 'u',
'icanyima' => 'ima',
'icanyem' => 'em',
'icanye' => 'e',
'icanya' => 'a',
'ibifu' => 'ibifu',
'ibifom' => 'ibifom',
'ibifima' => 'ibifima',
'ibifi' => 'ibifi',
'ibife' => 'ibife',
'ibifa' => 'ibifa',
'ibif' => 'ibif',
'iao' => 'ao',
'i-birou' => 'i-birou',
'i-biroom' => 'i-biroom',
'i-biroima' => 'i-biroima',
'i-biroi' => 'i-biroi',
'i-biroe' => 'i-biroe',
'i-biroa' => 'i-biroa',
'i-biro' => 'i-biro',
'husx' => 'husx',
'humni' => 'humni',
'hujucyi' => 'ujucyi',
'hujte' => 'ujte',
'hujmo' => 'ujmo',
'huj' => 'uj',
'hte' => 'te',
'homu' => 'omu',
'hoj' => 'oj',
'hoga' => 'oga',
'hog' => 'og',
'hmo' => 'mo',
'hlo' => 'o',
'hli' => 'hli',
'hle' => 'hle',
'hla' => 'hla',
'hivavsxi' => 'ivavsxi',
'hivati' => 'ivati',
'hivat' => 'ivat',
'hivasxe' => 'ivasxe',
'hivaste' => 'ivaste',
'hivasmo' => 'ivasmo',
'hivao' => 'ivao',
'hivano' => 'ivano',
'hivani' => 'ivani',
'hivane' => 'ivane',
'hivana' => 'ivana',
'hivan' => 'ivan',
'hivalo' => 'ivalo',
'hivali' => 'ivali',
'hivale' => 'ivale',
'hivala' => 'ivala',
'hivahu' => 'ivahu',
'hivah' => 'ivah',
'hivacyu' => 'ivacyu',
'hivacyete' => 'ivacyete',
'hivacyesx' => 'ivacyesx',
'hivacyemo' => 'ivacyemo',
'hivacye' => 'ivacye',
'hiva' => 'iva',
'hima' => 'ima',
'him' => 'im',
'hih' => 'ih',
'hi' => 'i',
'hbrot' => 'hbrot',
'hanyeno' => 'hanyeno',
'hanyeni' => 'hanyeni',
'hanyene' => 'hanyene',
'hanyena' => 'hanyena',
'hanyen' => 'hanyen',
'hanyasxe' => 'hanyasxe',
'hanyaste' => 'hanyaste',
'hanyasmo' => 'hanyasmo',
'hanyahu' => 'hanyahu',
'hanyah' => 'hanyah',
'hanu' => 'u',
'hante' => 'hante',
'hanmo' => 'hanmo',
'haniti' => 'haniti',
'hanite' => 'hanite',
'hanit' => 'hanit',
'hanisx' => 'hanisx',
'hanio' => 'hanio',
'hanimo' => 'hanimo',
'hanim' => 'hanim',
'hanilo' => 'hanilo',
'hanili' => 'hanili',
'hanile' => 'hanile',
'hanila' => 'hanila',
'hanicyu' => 'hanicyu',
'hanicyete' => 'hanicyete',
'hanicyesx' => 'hanicyesx',
'hanicyemo' => 'hanicyemo',
'hanicye' => 'hanicye',
'gucyu' => 'u',
'gucyomu' => 'omu',
'gucyom' => 'om',
'gucyoj' => 'oj',
'gucyiu' => 'gucyiu',
'gucyiomu' => 'gucyiomu',
'gucyiom' => 'gucyiom',
'gucyioj' => 'gucyioj',
'gucyim' => 'im',
'gucyih' => 'ih',
'gucyiemu' => 'gucyiemu',
'gucyiem' => 'gucyiem',
'gucyiega' => 'gucyiega',
'gucyieg' => 'gucyieg',
'gucyie' => 'gucyie',
'gucyia' => 'gucyia',
'gucyi' => 'i',
'gucyemu' => 'emu',
'gucyem' => 'em',
'gucyega' => 'ega',
'gucyeg' => 'eg',
'gucye' => 'e',
'gucya' => 'a',
'gucy' => '',
'granicxenyu' => 'u',
'granicxenyima' => 'ima',
'granicxenyem' => 'em',
'granicxenye' => 'e',
'granicxenya' => 'a',
'gosxeno' => 'gosxeno',
'gosxeni' => 'gosxeni',
'gosxene' => 'gosxene',
'gosxena' => 'gosxena',
'gosxen' => 'gosxen',
'gosano' => 'gosano',
'gosani' => 'gosani',
'gosane' => 'gosane',
'gosana' => 'gosana',
'gosan' => 'gosan',
'gosa' => 'a',
'gnutu' => 'utu',
'gnutomu' => 'utomu',
'gnutom' => 'utom',
'gnutoj' => 'utoj',
'gnutoga' => 'utoga',
'gnutog' => 'utog',
'gnutim' => 'utim',
'gnutih' => 'utih',
'gmu' => 'mu',
'gmte' => 'te',
'gmom' => 'mom',
'gmlyeno' => 'lyeno',
'gmlyeni' => 'lyeni',
'gmlyene' => 'lyene',
'gmlyena' => 'lyena',
'gmlyen' => 'lyen',
'gmlyasxe' => 'gmlyasxe',
'gmlyaste' => 'gmlyaste',
'gmlyasmo' => 'gmlyasmo',
'gmlyahu' => 'gmlyahu',
'gmlyah' => 'gmlyah',
'gmiti' => 'iti',
'gmite' => 'ite',
'gmit' => 'it',
'gmisx' => 'isx',
'gmio' => 'io',
'gmimo' => 'imo',
'gmim' => 'im',
'gmilo' => 'ilo',
'gmili' => 'ili',
'gmile' => 'ile',
'gmila' => 'ila',
'gmicyu' => 'icyu',
'gmicyete' => 'icyete',
'gmicyesx' => 'icyesx',
'gmicyemo' => 'icyemo',
'gmicye' => 'icye',
'gmi' => 'mi',
'gme' => 'me',
'gmama' => 'mama',
'gma' => 'ma',
'gm' => '',
'glu' => 'lu',
'glom' => 'lom',
'glima' => 'lima',
'givavsxi' => 'ivavsxi',
'givati' => 'ivati',
'givat' => 'ivat',
'givasxe' => 'ivasxe',
'givaste' => 'ivaste',
'givasmo' => 'ivasmo',
'givao' => 'ivao',
'givano' => 'ivano',
'givani' => 'ivani',
'givane' => 'ivane',
'givana' => 'ivana',
'givan' => 'ivan',
'givalo' => 'ivalo',
'givali' => 'ivali',
'givale' => 'ivale',
'givala' => 'ivala',
'givahu' => 'ivahu',
'givah' => 'ivah',
'givacyu' => 'ivacyu',
'givacyete' => 'ivacyete',
'givacyesx' => 'ivacyesx',
'givacyemo' => 'ivacyemo',
'givacye' => 'ivacye',
'giva' => 'iva',
'gie' => 'gie',
'ggrubu' => 'ggrubu',
'ggrubom' => 'ggrubom',
'ggrubima' => 'ggrubima',
'ggrubi' => 'ggrubi',
'ggrube' => 'ggrube',
'ggruba' => 'ggruba',
'ggrub' => 'ggrub',
'gbreheru' => 'gbreheru',
'gbreherom' => 'gbreherom',
'gbreherima' => 'gbreherima',
'gbreheri' => 'gbreheri',
'gbrehere' => 'gbrehere',
'gbrehera' => 'gbrehera',
'gbreher' => 'gbreher',
'gblyeno' => 'gblyeno',
'gblyeni' => 'gblyeni',
'gblyene' => 'gblyene',
'gblyena' => 'gblyena',
'gblyen' => 'gblyen',
'gbjevsxi' => 'gbjevsxi',
'gbjeti' => 'gbjeti',
'gbjet' => 'gbjet',
'gbjesxe' => 'gbjesxe',
'gbjeste' => 'gbjeste',
'gbjesmo' => 'gbjesmo',
'gbjelo' => 'gbjelo',
'gbjeli' => 'gbjeli',
'gbjele' => 'gbjele',
'gbjela' => 'gbjela',
'gbjeh' => 'gbjeh',
'gbjecyu' => 'gbjecyu',
'gbjecyete' => 'gbjecyete',
'gbjecyesx' => 'gbjecyesx',
'gbjecyemo' => 'gbjecyemo',
'gbjecye' => 'gbjecye',
'gbje' => 'gbje',
'gbivsxi' => 'gbivsxi',
'gbiveno' => 'gbiveno',
'gbiveni' => 'gbiveni',
'gbivene' => 'gbivene',
'gbivena' => 'gbivena',
'gbiven' => 'gbiven',
'gbiti' => 'gbiti',
'gbite' => 'gbite',
'gbit' => 'gbit',
'gbisxe' => 'gbisxe',
'gbisx' => 'gbisx',
'gbiste' => 'e',
'gbismo' => 'gbismo',
'gbimo' => 'gbimo',
'gbim' => 'gbim',
'gbilo' => 'gbilo',
'gbili' => 'gbili',
'gbile' => 'gbile',
'gbila' => 'gbila',
'gbijete' => 'gbijete',
'gbijesx' => 'gbijesx',
'gbijemo' => 'gbijemo',
'gbijem' => 'gbijem',
'gbije' => 'je',
'gbih' => 'gbih',
'gbicyu' => 'gbicyu',
'gbicyete' => 'gbicyete',
'gbicyesx' => 'gbicyesx',
'gbicyemo' => 'gbicyemo',
'gbicye' => 'gbicye',
'gbete' => 'gbete',
'gbemo' => 'gbemo',
'gazxete' => '',
'gazxesx' => '',
'gazxemo' => '',
'gazxem' => '',
'gazxe' => '',
'gatu' => 'u',
'gatou' => 'gatou',
'gatom' => 'om',
'gatoima' => 'gatoima',
'gatoi' => 'gatoi',
'gatoe' => 'gatoe',
'gatoa' => 'gatoa',
'gato' => 'o',
'gatima' => 'ima',
'gata' => 'a',
'gaonu' => 'u',
'gaonomu' => 'omu',
'gaonom' => 'om',
'gaonoj' => 'oj',
'gaonoga' => 'oga',
'gaonog' => 'og',
'gaono' => 'o',
'gaonim' => 'im',
'gaonih' => 'ih',
'gaoni' => 'i',
'gaone' => 'e',
'gaona' => 'a',
'ganyu' => 'u',
'ganyima' => 'ima',
'ganyem' => 'em',
'ganya' => 'a',
'galama' => 'ama',
'gajucyi' => 'jucyi',
'gaca' => '',
'gac' => 'gac',
'ezxomu' => 'ezxomu',
'ezxom' => 'om',
'ezxoj' => 'ezxoj',
'ezxoga' => 'ezxoga',
'ezxog' => 'ezxog',
'ezxo' => 'o',
'ezxisx' => 'isx',
'ezxih' => 'ih',
'ezxavsxi' => 'vsxi',
'ezxati' => 'ti',
'ezxat' => 't',
'ezxasxe' => 'asxe',
'ezxaste' => 'aste',
'ezxasmo' => 'asmo',
'ezxao' => 'o',
'ezxano' => 'no',
'ezxani' => 'ni',
'ezxane' => 'ne',
'ezxana' => 'na',
'ezxan' => 'n',
'ezxalo' => 'lo',
'ezxali' => 'li',
'ezxale' => 'le',
'ezxala' => 'la',
'ezxah' => 'ah',
'ezxacyu' => 'cyu',
'ezxacyete' => 'cyete',
'ezxacyesx' => 'cyesx',
'ezxacyemo' => 'cyemo',
'ezxacye' => 'cye',
'ezu' => 'u',
'ezom' => 'om',
'ezgosxe' => 'zgosxe',
'ezgoste' => 'zgoste',
'ezgosmo' => 'zgosmo',
'ezgoh' => 'zgoh',
'ezgo' => 'zgo',
'ezgavsxi' => 'zgavsxi',
'eze' => 'e',
'ezavsxi' => 'avsxi',
'ezati' => 'ati',
'ezat' => 'at',
'ezasxe' => 'asxe',
'ezaste' => 'aste',
'ezasmo' => 'asmo',
'ezao' => 'ao',
'ezano' => 'ano',
'ezani' => 'ani',
'ezane' => 'ane',
'ezana' => 'ana',
'ezan' => 'an',
'ezalo' => 'alo',
'ezali' => 'ali',
'ezale' => 'ale',
'ezala' => 'ala',
'ezahu' => 'ahu',
'ezah' => 'ah',
'ezacyu' => 'acyu',
'ezacyete' => 'acyete',
'ezacyesx' => 'acyesx',
'ezacyemo' => 'acyemo',
'ezacye' => 'acye',
'eza' => 'a',
'ez' => '',
'eveno' => 'no',
'eveni' => 'ni',
'evene' => 'ne',
'evena' => 'na',
'even' => 'n',
'evate' => 'te',
'evasx' => 'sx',
'evangelist' => 'evangelist',
'evamo' => 'mo',
'evama' => 'ama',
'evam' => 'm',
'evaju' => 'ju',
'evajte' => 'jte',
'evajmo' => 'jmo',
'evaj' => 'j',
'etiu' => 'etiu',
'etiom' => 'etiom',
'etie' => 'etie',
'etia' => 'etia',
'etanye' => 'nye',
'esxitu' => 'u',
'esxitomu' => 'omu',
'esxitom' => 'om',
'esxitoj' => 'oj',
'esxitoga' => 'oga',
'esxitog' => 'og',
'esxito' => 'o',
'esxitim' => 'im',
'esxitih' => 'ih',
'esxita' => 'a',
'esvsxi' => 'svsxi',
'estu' => 'u',
'estovima' => 'ovima',
'estovi' => 'ovi',
'estove' => 'ove',
'estova' => 'ova',
'estom' => 'om',
'esta' => 'a',
'eso' => 'o',
'esitu' => 'u',
'esitomu' => 'omu',
'esitom' => 'om',
'esitoj' => 'oj',
'esitoga' => 'oga',
'esitog' => 'og',
'esito' => 'o',
'esitim' => 'im',
'esitih' => 'ih',
'esita' => 'a',
'esima' => 'ima',
'esh' => 'sh',
'esanye' => 'anye',
'ertu' => 'tu',
'ertovima' => 'ovima',
'ertovi' => 'ovi',
'ertove' => 'ove',
'ertova' => 'ova',
'ertom' => 'tom',
'erta' => 'ta',
'ert' => '',
'erovima' => 'ovima',
'erovi' => 'ovi',
'erove' => 'ove',
'erova' => 'ova',
'erevima' => 'evima',
'erevi' => 'evi',
'ereve' => 'eve',
'ereva' => 'eva',
'eretu' => 'u',
'eretom' => 'om',
'ereto' => 'o',
'ereti' => 'ti',
'eretama' => 'ama',
'ereta' => 'a',
'ereno' => 'eno',
'ereni' => 'eni',
'erene' => 'ene',
'erena' => 'ena',
'eren' => 'en',
'erano' => 'no',
'erani' => 'ni',
'erane' => 'ne',
'erana' => 'ana',
'eran' => 'n',
'erama' => 'ama',
'erahu' => 'ahu',
'eou' => 'u',
'eomu' => 'eomu',
'eoj' => 'eoj',
'eoima' => 'ima',
'eoi' => 'i',
'eoga' => 'eoga',
'eog' => 'eog',
'eoe' => 'e',
'eoa' => 'a',
'enyeno' => 'yeno',
'enyeni' => 'yeni',
'enyene' => 'yene',
'enyena' => 'yena',
'enyen' => 'yen',
'enivsxi' => 'ivsxi',
'eniti' => 'iti',
'enite' => 'ite',
'enit' => 'it',
'enisxe' => 'isxe',
'enisx' => 'isx',
'eniste' => 'iste',
'enismo' => 'ismo',
'eniogu' => 'eniogu',
'eniogom' => 'eniogom',
'eniogima' => 'eniogima',
'eniogi' => 'eniogi',
'enioge' => 'enioge',
'enioga' => 'enioga',
'enio' => 'io',
'enimo' => 'imo',
'enilo' => 'ilo',
'enili' => 'ili',
'enile' => 'ile',
'enila' => 'ila',
'enicyu' => 'icyu',
'enicyete' => 'icyete',
'enicyesx' => 'icyesx',
'enicyemo' => 'icyemo',
'enicye' => 'icye',
'enete' => 'ete',
'enesx' => 'esx',
'enemo' => 'emo',
'enem' => 'em',
'emom' => 'om',
'emlyasxe' => 'lyasxe',
'emlyaste' => 'lyaste',
'emlyasmo' => 'lyasmo',
'emlyahu' => 'lyahu',
'emlyah' => 'lyah',
'emivsxi' => 'ivsxi',
'emisxe' => 'isxe',
'emiste' => 'iste',
'emismo' => 'ismo',
'emih' => 'ih',
'emenu' => 'u',
'emenom' => 'om',
'emeni' => 'i',
'emene' => 'e',
'emena' => 'a',
'emavsxi' => 'avsxi',
'emati' => 'i',
'emate' => 'e',
'emat' => '',
'emasxe' => 'asxe',
'emasx' => 'asx',
'emaste' => 'aste',
'emasmo' => 'asmo',
'emao' => 'ao',
'emano' => 'ano',
'emani' => 'ani',
'emane' => 'ane',
'emana' => 'ana',
'eman' => 'an',
'emamo' => 'amo',
'emama' => 'ama',
'emam' => 'am',
'emalo' => 'o',
'emali' => 'i',
'emale' => 'e',
'emala' => 'ala',
'emaju' => 'aju',
'emajte' => 'ajte',
'emajmo' => 'ajmo',
'emaj' => 'aj',
'emahu' => 'ahu',
'emah' => 'ah',
'emacyu' => 'acyu',
'emacyete' => 'acyete',
'emacyesx' => 'acyesx',
'emacyemo' => 'acyemo',
'emacye' => 'acye',
'elyo' => 'o',
'elyama' => 'ama',
'elou' => 'u',
'eloima' => 'ima',
'eloi' => 'i',
'eloe' => 'e',
'eloa' => 'a',
'eliogu' => 'eliogu',
'eliogom' => 'eliogom',
'eliogima' => 'eliogima',
'eliogi' => 'eliogi',
'elioge' => 'elioge',
'elioga' => 'elioga',
'elevsxi' => 'evsxi',
'elesxe' => 'esxe',
'eleste' => 'este',
'elesmo' => 'esmo',
'eleh' => 'eh',
'ekosxe' => 'kosxe',
'ekoste' => 'koste',
'ekosmo' => 'kosmo',
'ekoh' => 'koh',
'eklu' => 'u',
'eklom' => 'lom',
'eklima' => 'lima',
'ekavsxi' => 'kavsxi',
'ekama' => 'kama',
'ekala' => 'kala',
'ejucyi' => 'ejucyi',
'eite' => 'eite',
'eimo' => 'eimo',
'eim' => 'eim',
'ehovima' => 'hovima',
'ehovi' => 'hovi',
'ehove' => 'hove',
'ehova' => 'hova',
'ehom' => 'hom',
'eha' => 'ha',
'egute' => 'ute',
'egusx' => 'gusx',
'egumo' => 'umo',
'egte' => 'gte',
'egnutu' => 'utu',
'egnutomu' => 'utomu',
'egnutom' => 'utom',
'egnutoj' => 'utoj',
'egnutoga' => 'utoga',
'egnutog' => 'utog',
'egnutim' => 'utim',
'egnutih' => 'utih',
'egmo' => 'mo',
'egate' => 'e',
'egasx' => 'gasx',
'egamo' => 'gamo',
'egam' => 'gam',
'egaju' => 'gaju',
'egajte' => 'gajte',
'egajmo' => 'gajmo',
'egaj' => 'gaj',
'edosxe' => 'dosxe',
'edoste' => 'doste',
'edosmo' => 'dosmo',
'edoh' => 'doh',
'ednuto' => 'dnuto',
'ednuti' => 'dnuti',
'ednute' => 'dnute',
'ednuta' => 'dnuta',
'ednut' => 'dnut',
'ednu' => 'u',
'ednte' => 'te',
'ednmo' => 'mo',
'ednite' => 'dnite',
'ednimo' => 'dnimo',
'edni' => 'i',
'ednete' => 'dnete',
'ednesx' => 'dnesx',
'ednemo' => 'dnemo',
'edn' => '',
'ede' => 'e',
'ecyom' => 'om',
'ecyo' => 'o',
'ecyama' => 'ama',
'ecxku' => 'u',
'ecxkom' => 'om',
'ecxke' => 'e',
'ecxka' => 'a',
'ecxcima' => 'cxcima',
'ecxci' => 'ci',
'ecxaka' => 'aka',
'ecxak' => 'ak',
'eao' => 'ao',
'dzgotinu' => 'dzgotinu',
'dzgotinom' => 'dzgotinom',
'dzgotino' => 'dzgotino',
'dzgotini' => 'dzgotini',
'dzgotine' => 'dzgotine',
'dzgotinama' => 'dzgotinama',
'dzgotina' => 'dzgotina',
'dyuju' => 'uju',
'dyujite' => 'ujite',
'dyujimo' => 'ujimo',
'dyuji' => 'uji',
'dyujete' => 'ujete',
'dyujesx' => 'ujesx',
'dyujemo' => 'ujemo',
'dyujem' => 'ujem',
'dyuje' => 'uje',
'dyenyima' => 'ima',
'dyenyem' => 'em',
'dyenye' => 'e',
'dyenya' => 'a',
'dybrotu' => 'dybrotu',
'dybrotom' => 'dybrotom',
'dybrotima' => 'dybrotima',
'dybroti' => 'dybroti',
'dybrote' => 'dybrote',
'dybrota' => 'dybrota',
'dybrot' => 'dybrot',
'dyani' => 'ni',
'dxrbu' => 'dxrbu',
'dxrbom' => 'dxrbom',
'dxrbo' => 'dxrbo',
'dxrbi' => 'dxrbi',
'dxrbe' => 'dxrbe',
'dxrbama' => 'dxrbama',
'dxrba' => 'dxrba',
'dxraba' => 'dxraba',
'dxima' => 'ima',
'dxastu' => 'u',
'dxastomu' => 'omu',
'dxastom' => 'om',
'dxastoj' => 'oj',
'dxastoga' => 'oga',
'dxastog' => 'og',
'dxasto' => 'o',
'dxastim' => 'im',
'dxastih' => 'ih',
'dxasti' => 'i',
'dxasta' => 'a',
'dxast' => '',
'dxanye' => 'nye',
'duvsxi' => 'duvsxi',
'dutu' => 'u',
'dutomu' => 'dutomu',
'dutom' => 'om',
'dutoj' => 'dutoj',
'dutoga' => 'dutoga',
'dutog' => 'dutog',
'duto' => 'o',
'dutim' => 'dutim',
'dutih' => 'dutih',
'duti' => 'i',
'duta' => 'a',
'dut' => '',
'dusxe' => 'e',
'dusx' => '',
'duste' => 'duste',
'dusmo' => 'dusmo',
'duo' => 'o',
'dulo' => 'o',
'duli' => 'i',
'dule' => 'e',
'dula' => 'a',
'duite' => 'duite',
'duimo' => 'duimo',
'duh' => 'h',
'ducyu' => 'ducyu',
'ducyiu' => 'u',
'ducyiomu' => 'omu',
'ducyiom' => 'om',
'ducyioj' => 'oj',
'ducyim' => 'm',
'ducyih' => 'h',
'ducyiemu' => 'emu',
'ducyiem' => 'em',
'ducyiega' => 'ega',
'ducyieg' => 'eg',
'ducyie' => 'e',
'ducyia' => 'a',
'ducyi' => '',
'ducyete' => 'ducyete',
'ducyesx' => 'cyesx',
'ducyemo' => 'ducyemo',
'ducye' => 'ducye',
'drzxavanyu' => 'u',
'drzxavanyima' => 'ima',
'drzxavanyem' => 'em',
'drzxavanye' => 'e',
'drzxavanya' => 'a',
'drzxanyu' => 'u',
'drzxanyima' => 'ima',
'drzxanyem' => 'em',
'drzxanye' => 'nye',
'drzxanya' => 'a',
'dricanyu' => 'u',
'dricanyima' => 'ima',
'dricanyem' => 'em',
'dricanye' => '',
'dricanya' => 'a',
'dovanye' => 'e',
'dou' => 'u',
'dosxlo' => 'sxlo',
'dosxli' => 'osxli',
'dosxle' => 'osxle',
'dosxla' => 'osxla',
'dosxao' => 'sxao',
'doima' => 'ima',
'doih' => 'oih',
'doi' => 'i',
'dogosxe' => 'ogosxe',
'dogoste' => 'ogoste',
'dogosmo' => 'ogosmo',
'dogoh' => 'ogoh',
'dogo' => 'o',
'dogavsxi' => 'ogavsxi',
'doe' => 'e',
'dodyute' => 'odyute',
'dodyusx' => 'odyusx',
'dodyumo' => 'odyumo',
'dodyu' => 'odyu',
'dodyte' => 'odyte',
'dodymo' => 'odymo',
'dodyem' => 'odyem',
'dodye' => 'dye',
'dody' => 'ody',
'docyu' => 'u',
'docyi' => 'i',
'docyete' => 'ocyete',
'docyesx' => 'ocyesx',
'docyemo' => 'ocyemo',
'docye' => 'e',
'docy' => 'ocy',
'doa' => 'a',
'dnutu' => 'u',
'dnutomu' => 'omu',
'dnutom' => 'om',
'dnutoj' => 'oj',
'dnutoga' => 'oga',
'dnutog' => 'og',
'dnutim' => 'im',
'dnutih' => 'ih',
'dneno' => 'dneno',
'dneni' => 'dneni',
'dnene' => 'dnene',
'dnena' => 'dnena',
'dnen' => 'dnen',
'dmte' => 'dmte',
'dmoro' => 'dmoro',
'dmomu' => 'dmomu',
'dmom' => 'mom',
'dmoj' => 'dmoj',
'dmoga' => 'dmoga',
'dmog' => 'dmog',
'dmim' => 'dmim',
'dmih' => 'dmih',
'dmi' => 'mi',
'dmga' => 'dmga',
'dmete' => 'e',
'dmesx' => 'dmesx',
'dmemo' => 'dmemo',
'dmem' => 'dmem',
'dma' => 'a',
'dm' => 'dm',
'dku' => 'dku',
'dkom' => 'dkom',
'dko' => 'dko',
'dke' => 'dke',
'dkama' => 'dkama',
'dka' => 'dka',
'djevsxi' => 'jevsxi',
'djesxe' => 'jesxe',
'djeste' => 'jeste',
'djesmo' => 'jesmo',
'djeh' => 'jeh',
'dje' => 'je',
'disxucyi' => 'xucyi',
'disxu' => 'xu',
'disxte' => 'te',
'disxmo' => 'xmo',
'disxete' => 'xete',
'disxesx' => 'xesx',
'disxenye' => 'xenye',
'disxeno' => 'xeno',
'disxeni' => 'xeni',
'disxene' => 'xene',
'disxena' => 'xena',
'disxen' => 'xen',
'disxemo' => 'xemo',
'disxem' => 'xem',
'disavsxi' => 'avsxi',
'disati' => 'ati',
'disat' => 'at',
'disasxe' => 'asxe',
'disaste' => 'aste',
'disasmo' => 'asmo',
'disao' => 'ao',
'disalo' => 'alo',
'disali' => 'ali',
'disale' => 'ale',
'disala' => 'ala',
'disahu' => 'ahu',
'disah' => 'ah',
'disacyu' => 'acyu',
'disacyete' => 'acyete',
'disacyesx' => 'acyesx',
'disacyemo' => 'acyemo',
'disacye' => 'acye',
'diplomski' => 'i',
'diplomac' => 'ac',
'diluvijalni' => 'iluvijalni',
'dijalekt' => 't',
'dijalekat' => 'at',
'digosxe' => 'igosxe',
'digoste' => 'igoste',
'digosmo' => 'igosmo',
'digoh' => 'igoh',
'digo' => 'igo',
'dignuvsxi' => 'ignuvsxi',
'dignuto' => 'ignuto',
'dignuti' => 'ignuti',
'dignute' => 'ignute',
'dignuta' => 'ignuta',
'dignut' => 'ignut',
'dignusxe' => 'ignusxe',
'dignusx' => 'ignusx',
'dignuste' => 'ignuste',
'dignusmo' => 'ignusmo',
'dignuo' => 'ignuo',
'dignumo' => 'ignumo',
'dignulo' => 'ignulo',
'dignuli' => 'ignuli',
'dignule' => 'ignule',
'dignula' => 'ignula',
'dignuh' => 'ignuh',
'dignucyu' => 'ignucyu',
'dignucyete' => 'ignucyete',
'dignucyesx' => 'ignucyesx',
'dignucyemo' => 'ignucyemo',
'dignucye' => 'ignucye',
'dignu' => 'ignu',
'dignte' => 'ignte',
'dignmo' => 'ignmo',
'dignite' => 'ignite',
'dignimo' => 'ignimo',
'digni' => 'igni',
'dignete' => 'ignete',
'dignesx' => 'ignesx',
'dignemo' => 'ignemo',
'dignem' => 'ignem',
'digne' => 'igne',
'dign' => 'ign',
'diglo' => 'iglo',
'digli' => 'igli',
'digle' => 'igle',
'digla' => 'igla',
'digavsxi' => 'igavsxi',
'digao' => 'igao',
'dicyom' => 'icyom',
'dicyima' => 'icyima',
'dicya' => 'icya',
'dicxte' => 'te',
'dicxmo' => 'mo',
'dicxite' => 'ite',
'dicxisx' => 'isx',
'dicximo' => 'imo',
'dicxim' => 'im',
'dicxi' => 'i',
'dicxe' => 'e',
'dicx' => '',
'dgodisxnyu' => 'dgodisxnyu',
'dgodisxnyomu' => 'dgodisxnyomu',
'dgodisxnyom' => 'dgodisxnyom',
'dgodisxnyoj' => 'dgodisxnyoj',
'dgodisxnyoga' => 'dgodisxnyoga',
'dgodisxnyog' => 'dgodisxnyog',
'dgodisxnyo' => 'dgodisxnyo',
'dgodisxnyiu' => 'dgodisxnyiu',
'dgodisxnyiomu' => 'dgodisxnyiomu',
'dgodisxnyiom' => 'dgodisxnyiom',
'dgodisxnyioj' => 'dgodisxnyioj',
'dgodisxnyiju' => 'dgodisxnyiju',
'dgodisxnyijomu' => 'dgodisxnyijomu',
'dgodisxnyijom' => 'dgodisxnyijom',
'dgodisxnyijoj' => 'dgodisxnyijoj',
'dgodisxnyijim' => 'dgodisxnyijim',
'dgodisxnyijih' => 'dgodisxnyijih',
'dgodisxnyiji' => 'dgodisxnyiji',
'dgodisxnyijemu' => 'dgodisxnyijemu',
'dgodisxnyijem' => 'dgodisxnyijem',
'dgodisxnyijega' => 'dgodisxnyijega',
'dgodisxnyijeg' => 'dgodisxnyijeg',
'dgodisxnyije' => 'dgodisxnyije',
'dgodisxnyija' => 'dgodisxnyija',
'dgodisxnyij' => 'dgodisxnyij',
'dgodisxnyiemu' => 'dgodisxnyiemu',
'dgodisxnyiem' => 'dgodisxnyiem',
'dgodisxnyiega' => 'dgodisxnyiega',
'dgodisxnyieg' => 'dgodisxnyieg',
'dgodisxnyia' => 'dgodisxnyia',
'dgodisxnye' => 'dgodisxnye',
'dgodisxnya' => 'dgodisxnya',
'detu' => 'u',
'detom' => 'om',
'deta' => 'a',
'desxcyu' => 'sxcyu',
'desxcyete' => 'sxcyete',
'desxcyesx' => 'sxcyesx',
'desxcyemo' => 'sxcyemo',
'desxcye' => 'sxcye',
'desti' => 'sti',
'dest' => 'st',
'deosxe' => 'osxe',
'deoste' => 'oste',
'deosmo' => 'osmo',
'deoh' => 'oh',
'denuvsxi' => 'uvsxi',
'denuto' => 'uto',
'denuti' => 'uti',
'denute' => 'ute',
'denuta' => 'uta',
'denut' => 'ut',
'denusxe' => 'usxe',
'denuste' => 'uste',
'denusmo' => 'usmo',
'denuo' => 'uo',
'denulo' => 'ulo',
'denuli' => 'uli',
'denule' => 'ule',
'denula' => 'ula',
'denuh' => 'uh',
'denucyu' => 'ucyu',
'denucyete' => 'ucyete',
'denucyesx' => 'ucyesx',
'denucyemo' => 'ucyemo',
'denucye' => 'ucye',
'denomu' => 'omu',
'denom' => 'om',
'denoj' => 'oj',
'denoga' => 'oga',
'denog' => 'og',
'denite' => 'ite',
'denimo' => 'imo',
'denim' => 'im',
'denih' => 'ih',
'denete' => 'ete',
'denesx' => 'esx',
'denemo' => 'emo',
'denem' => 'em',
'delyeno' => 'yeno',
'delyeni' => 'yeni',
'delyene' => 'yene',
'delyena' => 'yena',
'delyen' => 'yen',
'delyavsxi' => 'vsxi',
'delyati' => 'ti',
'delyate' => 'te',
'delyat' => 't',
'delyasxe' => 'yasxe',
'delyasx' => 'sx',
'delyaste' => 'yaste',
'delyasmo' => 'yasmo',
'delyao' => 'o',
'delyano' => 'no',
'delyani' => 'ni',
'delyane' => 'ne',
'delyana' => 'na',
'delyan' => 'n',
'delyamo' => 'mo',
'delyam' => 'm',
'delyalo' => 'lo',
'delyali' => 'li',
'delyale' => 'le',
'delyala' => 'la',
'delyaju' => 'ju',
'delyajte' => 'jte',
'delyajmo' => 'jmo',
'delyaj' => 'j',
'delyahu' => 'yahu',
'delyah' => 'yah',
'delyacyu' => 'cyu',
'delyacyete' => 'cyete',
'delyacyesx' => 'cyesx',
'delyacyemo' => 'cyemo',
'delyacye' => 'cye',
'delya' => 'a',
'delte' => 'te',
'delmo' => 'mo',
'deliti' => 'iti',
'delite' => 'ite',
'delit' => 'it',
'delisx' => 'isx',
'delio' => 'io',
'delimo' => 'imo',
'delim' => 'im',
'delilo' => 'ilo',
'delili' => 'ili',
'delile' => 'ile',
'delila' => 'ila',
'delicyu' => 'icyu',
'delicyete' => 'icyete',
'delicyesx' => 'icyesx',
'delicyemo' => 'icyemo',
'delicye' => 'icye',
'delavsxi' => 'vsxi',
'delati' => 'ti',
'delate' => 'te',
'delat' => 't',
'delasxe' => 'sxe',
'delasx' => 'sx',
'delaste' => 'ste',
'delasmo' => 'smo',
'delao' => 'o',
'delano' => 'no',
'delani' => 'ni',
'delane' => 'ne',
'delana' => 'na',
'delan' => 'n',
'delamo' => 'mo',
'delam' => 'm',
'delalo' => 'lo',
'delali' => 'li',
'delale' => 'le',
'delala' => 'la',
'delaju' => 'ju',
'delajte' => 'jte',
'delajmo' => 'jmo',
'delaj' => 'j',
'delah' => 'h',
'delacyu' => 'cyu',
'delacyete' => 'cyete',
'delacyesx' => 'cyesx',
'delacyemo' => 'cyemo',
'delacye' => 'cye',
'del' => '',
'deju' => 'u',
'dejte' => 'dejte',
'dejmo' => 'dejmo',
'dej' => 'dej',
'dbuk-racxunaru' => 'dbuk-racxunaru',
'dbuk-racxunarom' => 'dbuk-racxunarom',
'dbuk-racxunarima' => 'dbuk-racxunarima',
'dbuk-racxunari' => 'dbuk-racxunari',
'dbuk-racxunare' => 'dbuk-racxunare',
'dbuk-racxunara' => 'dbuk-racxunara',
'dbuk-racxunar' => 'dbuk-racxunar',
'dbranu' => 'ranu',
'dbranom' => 'ranom',
'dbrano' => 'rano',
'dbrani' => 'rani',
'dbrane' => 'rane',
'dbranama' => 'ranama',
'dbrana' => '',
'dbirou' => 'dbirou',
'dbiroom' => 'dbiroom',
'dbiroima' => 'dbiroima',
'dbiroi' => 'dbiroi',
'dbiroe' => 'dbiroe',
'dbiroa' => 'dbiroa',
'dbiro' => 'dbiro',
'dalu' => 'lu',
'dalom' => 'lom',
'dalima' => 'lima',
'daka' => 'ka',
'dadima' => 'adima',
'dadi' => 'adi',
'dad' => 'ad',
'cyute' => 'ute',
'cyumo' => 'umo',
'cyujucyi' => 'ujucyi',
'cyujte' => 'ujte',
'cyujmo' => 'ujmo',
'cyuj' => 'uj',
'cysx' => 'cysx',
'cyoste' => 'cyoste',
'cyosmo' => 'cyosmo',
'cyoh' => 'cyoh',
'cym' => 'cym',
'cyecyi' => 'ecyi',
'cyasxu' => 'cyasxu',
'cyasxom' => 'cyasxom',
'cyasxima' => 'ima',
'cyasxi' => 'i',
'cyasxa' => 'a',
'cyaka' => 'aka',
'cyak' => 'k',
'cxuvsxi' => 'uvsxi',
'cxuveno' => 'uveno',
'cxuveni' => 'uveni',
'cxuvene' => 'uvene',
'cxuvena' => 'uvena',
'cxuven' => 'uven',
'cxuti' => 'uti',
'cxut' => 'ut',
'cxusxe' => 'usxe',
'cxuste' => 'uste',
'cxusmo' => 'usmo',
'cxuo' => 'uo',
'cxulo' => 'ulo',
'cxuli' => 'uli',
'cxule' => 'ule',
'cxula' => 'ula',
'cxujucyi' => 'ujucyi',
'cxujte' => 'ujte',
'cxujmo' => 'ujmo',
'cxujite' => 'ujite',
'cxujimo' => 'ujimo',
'cxuji' => 'uji',
'cxuj' => 'uj',
'cxuh' => 'uh',
'cxucyu' => 'ucyu',
'cxucyete' => 'ucyete',
'cxucyesx' => 'ucyesx',
'cxucyemo' => 'ucyemo',
'cxucye' => 'ucye',
'cxou' => 'u',
'cxoima' => 'ima',
'cxoi' => 'i',
'cxoga' => 'cxoga',
'cxog' => 'cxog',
'cxoe' => 'e',
'cxoama' => 'oama',
'cxoa' => 'a',
'cxnu' => 'u',
'cxnom' => 'om',
'cxno' => 'o',
'cxniku' => 'ku',
'cxnikom' => 'kom',
'cxnike' => 'ke',
'cxnika' => 'ka',
'cxnik' => 'k',
'cxnicxe' => 'cxe',
'cxnicima' => 'cima',
'cxni' => 'i',
'cxne' => 'e',
'cxnama' => 'nama',
'cxna' => 'a',
'cxlanyivanye' => 'cxlanyivanye',
'cxlanyenye' => 'e',
'cxkomu' => 'omu',
'cxkoj' => 'oj',
'cxkoga' => 'oga',
'cxkog' => 'og',
'cxkim' => 'im',
'cxkih' => 'ih',
'cxki' => 'i',
'cxiu' => 'u',
'cxiomu' => 'omu',
'cxiom' => 'om',
'cxioj' => 'oj',
'cxiemu' => 'emu',
'cxiem' => 'em',
'cxiega' => 'ega',
'cxieg' => 'eg',
'cxiecyi' => 'cxiecyi',
'cxicu' => 'u',
'cxicom' => 'om',
'cxico' => 'o',
'cxici' => 'i',
'cxice' => 'e',
'cxicama' => 'ama',
'cxica' => 'a',
'cxia' => 'a',
'cxevavsxi' => 'cxevavsxi',
'cxevati' => 'cxevati',
'cxevat' => 'cxevat',
'cxevasxe' => 'cxevasxe',
'cxevaste' => 'cxevaste',
'cxevasmo' => 'cxevasmo',
'cxevao' => 'cxevao',
'cxevano' => 'cxevano',
'cxevani' => 'cxevani',
'cxevane' => 'cxevane',
'cxevana' => 'cxevana',
'cxevan' => 'cxevan',
'cxevalo' => 'cxevalo',
'cxevali' => 'cxevali',
'cxevale' => 'cxevale',
'cxevala' => 'cxevala',
'cxevahu' => 'cxevahu',
'cxevah' => 'cxevah',
'cxevacyu' => 'cxevacyu',
'cxevacyete' => 'cxevacyete',
'cxevacyesx' => 'cxevacyesx',
'cxevacyemo' => 'cxevacyemo',
'cxevacye' => 'cxevacye',
'cxetavsxi' => 'cxetavsxi',
'cxetati' => 'cxetati',
'cxetate' => 'cxetate',
'cxetat' => 'cxetat',
'cxetasxe' => 'cxetasxe',
'cxetasx' => 'cxetasx',
'cxetaste' => 'cxetaste',
'cxetasmo' => 'cxetasmo',
'cxetao' => 'cxetao',
'cxetano' => 'cxetano',
'cxetani' => 'cxetani',
'cxetane' => 'cxetane',
'cxetana' => 'cxetana',
'cxetan' => 'cxetan',
'cxetamo' => 'cxetamo',
'cxetam' => 'cxetam',
'cxetalo' => 'cxetalo',
'cxetali' => 'cxetali',
'cxetale' => 'cxetale',
'cxetala' => 'cxetala',
'cxetaju' => 'cxetaju',
'cxetajte' => 'cxetajte',
'cxetajmo' => 'cxetajmo',
'cxetaj' => 'cxetaj',
'cxetahu' => 'cxetahu',
'cxetah' => 'cxetah',
'cxetacyu' => 'cxetacyu',
'cxetacyete' => 'cxetacyete',
'cxetacyesx' => 'cxetacyesx',
'cxetacyemo' => 'cxetacyemo',
'cxetacye' => 'cxetacye',
'cxet' => 'et',
'cxbrba' => 'cxbrba',
'cxastiju' => 'cxastiju',
'cxastijomu' => 'cxastijomu',
'cxastijom' => 'cxastijom',
'cxastijoj' => 'cxastijoj',
'cxastijim' => 'cxastijim',
'cxastijih' => 'cxastijih',
'cxastiji' => 'cxastiji',
'cxastijemu' => 'cxastijemu',
'cxastijem' => 'cxastijem',
'cxastijega' => 'cxastijega',
'cxastijeg' => 'cxastijeg',
'cxastije' => 'cxastije',
'cxastija' => 'cxastija',
'cxasovnu' => 'u',
'cxasovnomu' => 'omu',
'cxasovnom' => 'om',
'cxasovnoj' => 'oj',
'cxasovnoga' => 'oga',
'cxasovnog' => 'og',
'cxasovno' => 'o',
'cxasovnim' => 'im',
'cxasovnih' => 'ih',
'cxasovni' => 'i',
'cxasovne' => 'e',
'cxasovna' => 'a',
'cxaku' => 'ku',
'cxakom' => 'kom',
'cxake' => 'ke',
'cxajucyi' => 'jucyi',
'cxacxe' => 'cxe',
'cxacu' => 'u',
'cxacom' => 'om',
'cxace' => 'e',
'cte' => 'te',
'coima' => 'ima',
'cmo' => 'mo',
'ckavsxi' => 'vsxi',
'ckati' => 'ti',
'ckat' => 't',
'ckasxe' => 'sxe',
'ckaste' => 'ste',
'ckasmo' => 'smo',
'ckao' => 'o',
'ckano' => 'no',
'ckani' => 'ni',
'ckane' => 'ne',
'ckana' => 'na',
'ckan' => 'n',
'ckalo' => 'lo',
'ckali' => 'li',
'ckale' => 'le',
'ckala' => 'la',
'ckaju' => 'ju',
'ckajite' => 'ckajite',
'ckajimo' => 'ckajimo',
'ckaji' => 'ckaji',
'ckahu' => 'hu',
'ckah' => 'h',
'ckacyu' => 'cyu',
'ckacyete' => 'cyete',
'ckacyesx' => 'cyesx',
'ckacyemo' => 'cyemo',
'ckacye' => 'cye',
'ckacxete' => 'ckacxete',
'ckacxemo' => 'ckacxemo',
'ckacxem' => 'em',
'ckacxe' => 'e',
'ciu' => 'ciu',
'citara' => 'ara',
'citar' => 'citar',
'cisx' => 'isx',
'ciom' => 'ciom',
'cim' => 'im',
'cie' => 'cie',
'cia' => 'cia',
'ceansku' => 'u',
'ceanskomu' => 'omu',
'ceanskom' => 'om',
'ceanskoj' => 'oj',
'ceanskoga' => 'oga',
'ceanskog' => 'og',
'ceansko' => 'o',
'ceanskim' => 'im',
'ceanskih' => 'ih',
'ceanski' => '',
'ceanske' => 'e',
'ceanska' => 'a',
'calu' => 'u',
'calom' => 'om',
'calima' => 'ima',
'caih' => 'caih',
'bvsxi' => 'bvsxi',
'brtniku' => 'ku',
'brtnikom' => 'kom',
'brtnike' => 'ke',
'brtnika' => 'ka',
'brtnik' => '',
'brtnicxe' => 'cxe',
'brtnicima' => 'cima',
'brtnici' => 'ci',
'brazovanyu' => 'u',
'brazovanyima' => 'ima',
'brazovanyem' => 'em',
'brazovanye' => '',
'brazovanya' => 'a',
'bradyivavsxi' => 'ivavsxi',
'bradyivati' => 'ivati',
'bradyivat' => 'ivat',
'bradyivasxe' => 'ivasxe',
'bradyivaste' => 'ivaste',
'bradyivasmo' => 'ivasmo',
'bradyivao' => 'ivao',
'bradyivano' => 'ivano',
'bradyivani' => 'ivani',
'bradyivane' => 'ivane',
'bradyivana' => 'ivana',
'bradyivan' => 'ivan',
'bradyivalyuju' => 'bradyivalyuju',
'bradyivalyujite' => 'bradyivalyujite',
'bradyivalyujimo' => 'bradyivalyujimo',
'bradyivalyuji' => 'bradyivalyuji',
'bradyivalyujete' => 'bradyivalyujete',
'bradyivalyujesx' => 'bradyivalyujesx',
'bradyivalyujemo' => 'bradyivalyujemo',
'bradyivalyujem' => 'bradyivalyujem',
'bradyivalyuje' => 'bradyivalyuje',
'bradyivalo' => 'ivalo',
'bradyivali' => 'ivali',
'bradyivale' => 'ivale',
'bradyivala' => 'ivala',
'bradyivahu' => 'ivahu',
'bradyivah' => 'ivah',
'bradyivacyu' => 'ivacyu',
'bradyivacyete' => 'ivacyete',
'bradyivacyesx' => 'ivacyesx',
'bradyivacyemo' => 'ivacyemo',
'bradyivacye' => 'ivacye',
'bradyiva' => 'iva',
'bozxavanyu' => 'u',
'bozxavanyima' => 'ima',
'bozxavanyem' => 'em',
'bozxavanye' => '',
'bozxavanya' => 'a',
'bovu' => 'u',
'bovomu' => 'ovomu',
'bovom' => 'om',
'bovoj' => 'ovoj',
'bovoga' => 'ovoga',
'bovog' => 'ovog',
'bovo' => 'o',
'bovima' => 'ovima',
'bovim' => 'ovim',
'bovih' => 'ovih',
'bovi' => 'ovi',
'bove' => 'ove',
'bov' => 'ov',
'bou' => 'u',
'boima' => 'oima',
'boi' => 'i',
'boe' => 'e',
'boama' => 'ama',
'boa' => 'a',
'bmanu' => 'u',
'bmanom' => 'om',
'bmano' => 'o',
'bmani' => 'i',
'bmane' => 'e',
'bmanama' => 'ama',
'bmana' => '',
'blyasxe' => 'lyasxe',
'blyaste' => 'lyaste',
'blyasmo' => 'lyasmo',
'blyahu' => 'lyahu',
'blyah' => 'lyah',
'bif' => 'bif',
'benye' => 'e',
'benastu' => 'u',
'benastomu' => 'omu',
'benastom' => 'om',
'benastoj' => 'oj',
'benastoga' => 'oga',
'benastog' => 'og',
'benasto' => 'o',
'benastim' => 'im',
'benastih' => 'ih',
'benasti' => 'i',
'benasta' => 'a',
'benast' => '',
'benahu' => 'benahu',
'batu' => 'u',
'batom' => 'om',
'batima' => 'ima',
'bata' => 'a',
'baru' => 'u',
'baromu' => 'baromu',
'barom' => 'om',
'baroj' => 'baroj',
'baroga' => 'ga',
'barog' => 'barog',
'baro' => 'o',
'barim' => 'im',
'barih' => 'ih',
'bari' => 'i',
'bare' => 'e',
'bara' => 'a',
'bar' => '',
'azxa' => 'a',
'azu' => 'u',
'azom' => 'om',
'azima' => 'ima',
'azi' => 'i',
'aze' => 'e',
'az' => '',
'avte' => 'te',
'avmo' => 'mo',
'avivsxi' => 'ivsxi',
'avivenyu' => 'ivenyu',
'aviveno' => 'iveno',
'aviveni' => 'iveni',
'avivene' => 'ivene',
'avivena' => 'ivena',
'aviven' => 'iven',
'aviti' => 'iti',
'avit' => 'it',
'avisxe' => 'isxe',
'aviste' => 'iste',
'avismo' => 'ismo',
'avio' => 'io',
'avima' => 'ima',
'avilo' => 'ilo',
'avili' => 'ili',
'avile' => 'ile',
'avila' => 'ila',
'aviju' => 'iju',
'avijte' => 'ijte',
'avijmo' => 'ijmo',
'avijete' => 'ijete',
'avijesx' => 'ijesx',
'avijemo' => 'ijemo',
'avijem' => 'ijem',
'avije' => 'ije',
'avij' => 'ij',
'avicyu' => 'icyu',
'avicyete' => 'icyete',
'avicyesx' => 'icyesx',
'avicyemo' => 'icyemo',
'avicye' => 'icye',
'avanyima' => 'ima',
'avanyem' => 'em',
'avama' => 'ama',
'au' => 'u',
'atovavsxi' => 'ovavsxi',
'atovati' => 'ovati',
'atovat' => 'ovat',
'atovasxe' => 'ovasxe',
'atovaste' => 'ovaste',
'atovasmo' => 'ovasmo',
'atovao' => 'ovao',
'atovano' => 'ovano',
'atovani' => 'ovani',
'atovane' => 'ovane',
'atovana' => 'ovana',
'atovan' => 'ovan',
'atovalo' => 'ovalo',
'atovali' => 'ovali',
'atovale' => 'ovale',
'atovala' => 'ovala',
'atovahu' => 'ovahu',
'atovah' => 'ovah',
'atovacyu' => 'ovacyu',
'atovacyete' => 'ovacyete',
'atovacyesx' => 'ovacyesx',
'atovacyemo' => 'ovacyemo',
'atovacye' => 'ovacye',
'atova' => 'ova',
'atou' => 'u',
'atoi' => 'i',
'atoe' => 'e',
'atoama' => 'oama',
'atoa' => 'a',
'atimu' => 'atimu',
'atimom' => 'atimom',
'atimlyasxe' => 'atimlyasxe',
'atimlyaste' => 'atimlyaste',
'atimlyasmo' => 'atimlyasmo',
'atimlyahu' => 'atimlyahu',
'atimlyah' => 'atimlyah',
'atimivsxi' => 'atimivsxi',
'atimisxe' => 'atimisxe',
'atimiste' => 'atimiste',
'atimismo' => 'atimismo',
'atimima' => 'atimima',
'atimih' => 'atimih',
'atimecyi' => 'atimecyi',
'aticyom' => 'ticyom',
'aticyima' => 'ticyima',
'aticyi' => 'ticyi',
'aticya' => 'ticya',
'aticy' => 'ticy',
'ateu' => 'ateu',
'ateom' => 'ateom',
'ateima' => 'ateima',
'atei' => 'atei',
'atee' => 'atee',
'atecyi' => 'cyi',
'atea' => 'atea',
'atastu' => 'u',
'atastomu' => 'omu',
'atastom' => 'om',
'atastoj' => 'oj',
'atastoga' => 'oga',
'atastog' => 'og',
'atasto' => 'o',
'atastim' => 'im',
'atastih' => 'ih',
'atasti' => 'i',
'atasta' => 'a',
'atast' => '',
'atanye' => 'nye',
'atak' => 'tak',
'asxevima' => 'xevima',
'asxevi' => 'xevi',
'asxeve' => 'xeve',
'asxeva' => 'xeva',
'asxete' => 'sxete',
'asxesx' => 'sxesx',
'asxemo' => 'sxemo',
'asxem' => 'sxem',
'asxecyi' => 'ecyi',
'asxcyasxe' => 'xcyasxe',
'asxcyaste' => 'xcyaste',
'asxcyasmo' => 'xcyasmo',
'asxcyahu' => 'xcyahu',
'asxcyah' => 'xcyah',
'asxasxe' => 'asxe',
'asxaste' => 'aste',
'asxasmo' => 'asmo',
'asxahu' => 'ahu',
'asxah' => 'ah',
'asu' => 'u',
'astavnu' => 'u',
'astavnomu' => 'omu',
'astavnom' => 'om',
'astavnoj' => 'oj',
'astavnoga' => 'oga',
'astavnog' => 'og',
'astavno' => 'o',
'astavnim' => 'im',
'astavnih' => 'ih',
'astavni' => 'i',
'astavne' => 'e',
'astavna' => 'a',
'asom' => 'om',
'ase' => 'e',
'arovima' => 'ovima',
'arovi' => 'ovi',
'arove' => 'ove',
'arova' => 'ova',
'aromu' => 'omu',
'aroj' => 'oj',
'aroga' => 'oga',
'arog' => 'og',
'arivsxi' => 'ivsxi',
'ariti' => 'iti',
'arite' => 'ite',
'arit' => 'it',
'arisxe' => 'isxe',
'arisx' => 'isx',
'ariste' => 'iste',
'arismo' => 'ismo',
'ario' => 'io',
'arimo' => 'imo',
'arilo' => 'ilo',
'arili' => 'ili',
'arile' => 'ile',
'arila' => 'ila',
'aricyu' => 'icyu',
'aricyete' => 'icyete',
'aricyesx' => 'icyesx',
'aricyemo' => 'icyemo',
'aricye' => 'icye',
'arevima' => 'evima',
'arevi' => 'evi',
'areve' => 'eve',
'areva' => 'eva',
'arete' => 'e',
'aresx' => 'aresx',
'areno' => 'eno',
'areni' => 'eni',
'arene' => 'ene',
'arena' => 'ena',
'aren' => 'en',
'aremo' => 'aremo',
'arem' => '',
'aranye' => 'nye',
'arahu' => 'ahu',
'aradu' => 'u',
'aradom' => 'om',
'arado' => 'o',
'aradi' => 'i',
'arade' => 'e',
'aradama' => 'ama',
'arada' => 'ada',
'apu' => 'u',
'apom' => 'om',
'apima' => 'ima',
'api' => 'i',
'ape' => 'e',
'ap' => '',
'aom' => 'om',
'anyte' => 'te',
'anyomu' => 'omu',
'anyoj' => 'oj',
'anyoga' => 'oga',
'anyog' => 'og',
'anymo' => 'mo',
'anyim' => 'im',
'anyih' => 'ih',
'anyenye' => 'yenye',
'anyasxe' => 'sxe',
'anyaste' => 'ste',
'anyasmo' => 'smo',
'anyahu' => 'hu',
'anyah' => 'h',
'anisx' => 'isx',
'animanyu' => 'nyu',
'animanyima' => 'nyima',
'animanyem' => 'nyem',
'animanye' => '',
'animanya' => 'nya',
'anim' => 'im',
'anecyi' => 'anecyi',
'anavsxi' => 'vsxi',
'anati' => 'i',
'anate' => 'e',
'anat' => '',
'anasxima' => 'ima',
'anasxi' => 'i',
'anasxama' => 'anasxama',
'anasxa' => 'asxa',
'anasx' => 'sx',
'anao' => 'o',
'ananye' => 'nye',
'anano' => 'no',
'anani' => 'ni',
'anane' => 'ne',
'anana' => 'na',
'anan' => 'n',
'anamo' => 'mo',
'anam' => 'm',
'analo' => 'lo',
'anali' => 'li',
'anale' => 'le',
'anala' => 'la',
'anaju' => 'ju',
'anajte' => 'jte',
'anajmo' => 'jmo',
'anaj' => 'j',
'anacyu' => 'cyu',
'anacyete' => 'cyete',
'anacyesx' => 'cyesx',
'anacyemo' => 'cyemo',
'anacye' => 'cye',
'amovavsxi' => 'ovavsxi',
'amovati' => 'ovati',
'amovat' => 'ovat',
'amovasxe' => 'ovasxe',
'amovaste' => 'ovaste',
'amovasmo' => 'ovasmo',
'amovao' => 'ovao',
'amovano' => 'ovano',
'amovani' => 'ovani',
'amovane' => 'ovane',
'amovana' => 'ovana',
'amovan' => 'ovan',
'amovalo' => 'ovalo',
'amovali' => 'ovali',
'amovale' => 'ovale',
'amovala' => 'ovala',
'amovahu' => 'ovahu',
'amovah' => 'ovah',
'amovacyu' => 'ovacyu',
'amovacyete' => 'ovacyete',
'amovacyesx' => 'ovacyesx',
'amovacyemo' => 'ovacyemo',
'amovacye' => 'ovacye',
'amova' => 'ova',
'amlyasxe' => 'lyasxe',
'amlyaste' => 'lyaste',
'amlyasmo' => 'lyasmo',
'amlyahu' => 'lyahu',
'amlyah' => 'lyah',
'amcyi' => 'amcyi',
'alyo' => 'o',
'alyima' => 'ima',
'alyeno' => 'yeno',
'alyeni' => 'yeni',
'alyene' => 'yene',
'alyena' => 'yena',
'alyen' => 'yen',
'alyama' => 'ama',
'alte' => 'te',
'alt' => '',
'alou' => 'lou',
'alomu' => 'omu',
'aloj' => 'oj',
'aloima' => 'loima',
'aloi' => 'loi',
'aloga' => 'ga',
'alog' => 'g',
'aloe' => 'loe',
'aloa' => 'loa',
'almo' => 'mo',
'alivsxi' => 'ivsxi',
'aliti' => 'iti',
'alite' => 'ite',
'alit' => 'it',
'alisxe' => 'isxe',
'alisx' => 'isx',
'aliste' => 'e',
'alismo' => 'ismo',
'alio' => 'io',
'alimo' => 'imo',
'alilo' => 'ilo',
'alili' => 'ili',
'alile' => 'ile',
'alila' => 'ila',
'alicyu' => 'icyu',
'alicyete' => 'icyete',
'alicyesx' => 'icyesx',
'alicyemo' => 'icyemo',
'alicye' => 'icye',
'aletu' => 'u',
'aletom' => 'om',
'aleta' => 'a',
'alama' => 'ama',
'aladima' => 'aladima',
'aladi' => 'i',
'alad' => 'alad',
'alacyesx' => 'cyesx',
'alacxu' => 'cxu',
'alacxite' => 'cxite',
'alacximo' => 'cximo',
'alacxi' => 'i',
'alacxete' => 'cxete',
'alacxemo' => 'cxemo',
'alacxem' => 'cxem',
'alacxe' => 'e',
'alaca' => 'laca',
'alac' => 'lac',
'al' => '',
'akovima' => 'kovima',
'akovi' => 'kovi',
'akove' => 'kove',
'akova' => 'kova',
'aknutu' => 'u',
'aknutomu' => 'omu',
'aknutom' => 'om',
'aknutoj' => 'oj',
'aknutoga' => 'oga',
'aknutog' => 'og',
'aknutim' => 'im',
'aknutih' => 'ih',
'akcija' => 'a',
'akate' => 'te',
'akasx' => 'sx',
'akanye' => 'e',
'akamo' => 'mo',
'akam' => 'm',
'akaju' => 'ju',
'akajte' => 'jte',
'akajmo' => 'jmo',
'akaj' => 'j',
'ajnu' => 'u',
'ajnomu' => 'omu',
'ajnom' => 'om',
'ajnoj' => 'oj',
'ajnoga' => 'oga',
'ajnog' => 'og',
'ajno' => 'o',
'ajnim' => 'im',
'ajnih' => 'ih',
'ajni' => 'i',
'ajne' => 'e',
'ajnama' => 'nama',
'ajna' => 'a',
'ajiti' => 'iti',
'ajit' => 'it',
'ajisx' => 'isx',
'ajio' => 'io',
'ajima' => 'ima',
'ajim' => 'im',
'ajilo' => 'ilo',
'ajili' => 'ili',
'ajile' => 'ile',
'ajila' => 'ila',
'ajicyu' => 'icyu',
'ajicyete' => 'icyete',
'ajicyesx' => 'icyesx',
'ajicyemo' => 'icyemo',
'ajicye' => 'icye',
'ajenyu' => 'enyu',
'ajeno' => 'eno',
'ajeni' => 'eni',
'ajene' => 'ene',
'ajena' => 'ena',
'ajen' => 'en',
'ajate' => 'te',
'ajasx' => 'sx',
'ajanyu' => 'u',
'ajanyima' => 'ima',
'ajanyem' => 'em',
'ajanya' => 'a',
'ajamo' => 'mo',
'ajam' => 'm',
'ajaju' => 'ju',
'ajajte' => 'jte',
'ajajmo' => 'jmo',
'ajaj' => 'j',
'aisxucyi' => 'xucyi',
'aisxu' => 'u',
'aisxte' => 'xte',
'aisxmo' => 'xmo',
'aisxete' => 'xete',
'aisxesx' => 'xesx',
'aisxemo' => 'xemo',
'aisxem' => 'xem',
'aisxe' => 'e',
'aisx' => '',
'aima' => 'ima',
'ai' => 'i',
'agu' => 'gu',
'agom' => 'gom',
'age' => 'ge',
'agazxu' => 'zxu',
'agazxite' => 'zxite',
'agazximo' => 'zximo',
'agazxi' => 'zxi',
'agazxete' => 'zxete',
'agazxesx' => 'zxesx',
'agazxemo' => 'zxemo',
'agazxem' => 'zxem',
'agazxe' => 'zxe',
'agate' => 'te',
'agasx' => 'sx',
'aganye' => 'e',
'agamo' => 'mo',
'agam' => 'm',
'agalu' => 'agalu',
'agalom' => 'agalom',
'agalima' => 'agalima',
'agaju' => 'ju',
'agajte' => 'jte',
'agajmo' => 'jmo',
'agaj' => 'j',
'ag' => 'g',
'aeru' => 'eru',
'aerite' => 'erite',
'aerimo' => 'erimo',
'aeri' => 'eri',
'aer' => 'aer',
'aeite' => 'aeite',
'aeimo' => 'aeimo',
'aei' => 'aei',
'ae' => 'e',
'adyeno' => 'yeno',
'adyeni' => 'yeni',
'adyene' => 'yene',
'adyena' => 'yena',
'adyen' => 'yen',
'adute' => 'dute',
'adusx' => '',
'adumo' => 'dumo',
'adom' => 'om',
'ado' => 'o',
'adivsxi' => 'ivsxi',
'aditi' => 'iti',
'adite' => 'ite',
'adit' => 'it',
'adisxe' => 'isxe',
'adisx' => 'isx',
'adiste' => 'iste',
'adismo' => 'ismo',
'adio' => 'io',
'adimo' => 'imo',
'adim' => 'im',
'adilo' => 'ilo',
'adili' => 'ili',
'adile' => 'ile',
'adila' => 'ila',
'adih' => 'ih',
'adicyu' => 'icyu',
'adicyete' => 'icyete',
'adicyesx' => 'icyesx',
'adicyemo' => 'icyemo',
'adicye' => 'icye',
'adem' => 'dem',
'adama' => 'ama',
'acyom' => 'om',
'acyo' => 'o',
'acyiu' => 'u',
'acyiomu' => 'omu',
'acyiom' => 'om',
'acyioj' => 'oj',
'acyim' => 'm',
'acyih' => 'h',
'acyiemu' => 'emu',
'acyiem' => 'em',
'acyiega' => 'ega',
'acyieg' => 'eg',
'acyie' => 'e',
'acyia' => 'a',
'acu' => 'u',
'acom' => 'om',
'ace' => 'e',
'abu' => 'u',
'abom' => 'om',
'abo' => 'o',
'abi' => 'i',
'abe' => 'e',
'abavsxi' => 'vsxi',
'abati' => 'ti',
'abate' => 'te',
'abat' => 't',
'abasxe' => 'sxe',
'abasx' => 'sx',
'abaste' => 'ste',
'abasmo' => 'smo',
'abao' => 'o',
'abanyu' => 'anyu',
'abanyima' => 'anyima',
'abanyem' => 'anyem',
'abanye' => 'nye',
'abanya' => 'anya',
'abano' => 'no',
'abani' => 'ni',
'abane' => 'ne',
'abana' => 'na',
'aban' => 'n',
'abamo' => 'mo',
'abama' => 'ama',
'abam' => 'm',
'abalu' => 'abalu',
'abalom' => 'abalom',
'abalo' => 'lo',
'abalima' => 'abalima',
'abali' => 'li',
'abale' => 'le',
'abala' => 'la',
'abaju' => 'ju',
'abajte' => 'jte',
'abajmo' => 'jmo',
'abaj' => 'j',
'abahu' => 'hu',
'abah' => 'h',
'abacyu' => 'cyu',
'abacyete' => 'cyete',
'abacyesx' => 'cyesx',
'abacyemo' => 'cyemo',
'abacye' => 'cye',
'-biro' => '-biro',
    );

  $MaxSuffixLen = 0;
  foreach my $k (keys %Rules) {
      if (length($k) > $MaxSuffixLen) { $MaxSuffixLen = length($k) }
      $Rules{$k} = length($Rules{$k});
  }
}
